(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 11.2' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    611215,      10894]
NotebookOptionsPosition[    603349,      10797]
NotebookOutlinePosition[    603749,      10814]
CellTagsIndexPosition[    603706,      10811]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["\<\
Determination of the signs and magnitudes of all heteronuclear coupling using \
IPAP-MODO-FESTA data.
Automatically determine optimum ratio when combining IP and AP data, \
adjusting ratio and number of points to shift until rms difference is minimum\
\>", "Subsubsection",
 CellChangeTimes->{{3.835342719267295*^9, 3.8353427673607473`*^9}, {
   3.835342957217922*^9, 3.8353429845994587`*^9}, {3.853579885840021*^9, 
   3.853579910287277*^9}, 
   3.8535799927992496`*^9},ExpressionUUID->"e0dd5b4c-3a91-4051-9a25-\
a39ac98e766a"],

Cell["\<\
Automatically determines the optimum ratio when combining the IP and AP data, \
adjusts the ratio and numbers of points required to shift until the RMS \
difference is at its minimum.
Information required:
shifts={chemical shift in ppm}; (each chemical shift to be separated by a \
comma)
widths={width of multiplet in ppm}; (each width to be separated by a comma)
nreps=1; (number of repetitions of that data - typically 1)
filestart=12; (EXPNO in file)
filenamebase=\[CloseCurlyDoubleQuote]data/folder/nmr/filename/\
\[CloseCurlyDoubleQuote]; (filepath of data)
procnoIP=\[CloseCurlyDoubleQuote]1001\[CloseCurlyDoubleQuote];  (PROCNO of IP \
data)
procnoAP=\[CloseCurlyDoubleQuote]1002\[CloseCurlyDoubleQuote]; (PROCNO of AP \
data - ensure IP and AP are processed with identical parameters)
Sample details:
Fluorohydrin in CDCl3
1H @4.353 ppm; 150Hz
19F @ -189.6861 ppm; 1000Hz
J=48.2 HZ\
\>", "Text",
 CellChangeTimes->{{3.835344344114542*^9, 3.835344495255948*^9}, {
  3.835345752399667*^9, 3.83534578817225*^9}, {3.835416894520056*^9, 
  3.8354170090033817`*^9}, {3.8535743479833965`*^9, 3.8535743941759214`*^9}, {
  3.8535744245888777`*^9, 3.853574427182979*^9}, {3.8535799150722027`*^9, 
  3.8535802318062067`*^9}, {3.853587164123898*^9, 3.853587177771508*^9}, {
  3.85410233599457*^9, 3.8541023835752563`*^9}, {3.873283842082924*^9, 
  3.8732838628798985`*^9}},ExpressionUUID->"c61c22a2-f7f7-4bd3-b074-\
cb3183ff65e0"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{"Evaluate", "[", 
    RowBox[{
     RowBox[{"Context", "[", "]"}], " ", "<>", " ", "\"\<*\>\""}], "]"}], 
   "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"vardiff", "[", 
     RowBox[{"tspip_", ",", "tspap_", ",", 
      RowBox[{"ratio_", "?", "NumericQ"}], ",", 
      RowBox[{"diff_", "?", "NumericQ"}]}], "]"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"zspm", ",", "len"}], "}"}], ",", 
      RowBox[{
       RowBox[{"len", "=", 
        RowBox[{"Length", "[", "tspip", "]"}]}], ";", " ", 
       "\[IndentingNewLine]", 
       RowBox[{"zspm", "=", 
        RowBox[{"Join", "[", 
         RowBox[{
          RowBox[{"Table", "[", 
           RowBox[{"0", ",", 
            RowBox[{"{", 
             RowBox[{"i", ",", "len"}], "}"}]}], "]"}], ",", 
          RowBox[{"Join", "[", 
           RowBox[{
            RowBox[{"tspip", "-", 
             RowBox[{"ratio", " ", "tspap"}]}], ",", 
            RowBox[{"Table", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", 
               RowBox[{"i", ",", "len"}], "}"}]}], "]"}]}], "]"}]}], "]"}]}], 
       ";", "\[IndentingNewLine]", 
       RowBox[{"Total", "[", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"tspip", "+", 
           RowBox[{"ratio", " ", "tspap"}], "-", 
           RowBox[{"Take", "[", 
            RowBox[{
             RowBox[{"RotateRight", "[", 
              RowBox[{"zspm", ",", "diff"}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"len", "+", "1"}], ",", 
               RowBox[{"2", " ", "len"}]}], "}"}]}], "]"}]}], ")"}], "^", 
         "2"}], "]"}]}]}], "\[IndentingNewLine]", "]"}]}], ";"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{
   "Calculate", " ", "variance", " ", "between", " ", "shifted", " ", 
    "spectra", " ", "obtained", " ", "by", " ", "IPAP", " ", "processing"}], 
   " ", "*)"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"getpars", "[", 
    RowBox[{"filenamebase_", ",", "procno_"}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "filename", "}"}], ",", 
     RowBox[{
      RowBox[{"filename", "=", 
       RowBox[{
       "filenamebase", "<>", "\"\</pdata/\>\"", "<>", "procno", "<>", 
        "\"\</procs\>\""}]}], ";", " ", "\[IndentingNewLine]", 
      RowBox[{"stream", "=", 
       RowBox[{"OpenRead", "[", "filename", "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"offset", "=", 
       RowBox[{
        RowBox[{"Read", "[", 
         RowBox[{
          RowBox[{"StringToStream", "[", 
           RowBox[{"Find", "[", 
            RowBox[{"stream", ",", "\"\<OFFSET= \>\""}], "]"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"Word", ",", "Number"}], "}"}]}], "]"}], "[", 
        RowBox[{"[", "2", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"si", "=", 
       RowBox[{
        RowBox[{"Read", "[", 
         RowBox[{
          RowBox[{"StringToStream", "[", 
           RowBox[{"Find", "[", 
            RowBox[{"stream", ",", "\"\<SI= \>\""}], "]"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"Word", ",", "Number"}], "}"}]}], "]"}], "[", 
        RowBox[{"[", "2", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"Close", "[", "stream", "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"filename", "=", 
       RowBox[{"filenamebase", "<>", "\"\</acqus\>\""}]}], ";", " ", 
      "\[IndentingNewLine]", 
      RowBox[{"stream", "=", 
       RowBox[{"OpenRead", "[", "filename", "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"sfo1", "=", 
       RowBox[{
        RowBox[{"Read", "[", 
         RowBox[{
          RowBox[{"StringToStream", "[", 
           RowBox[{"Find", "[", 
            RowBox[{"stream", ",", "\"\<SFO1= \>\""}], "]"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"Word", ",", "Number"}], "}"}]}], "]"}], "[", 
        RowBox[{"[", "2", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"swp", "=", 
       RowBox[{
        RowBox[{"Read", "[", 
         RowBox[{
          RowBox[{"StringToStream", "[", 
           RowBox[{"Find", "[", 
            RowBox[{"stream", ",", "\"\<SW= \>\""}], "]"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"Word", ",", "Number"}], "}"}]}], "]"}], "[", 
        RowBox[{"[", "2", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"Close", "[", "stream", "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"offset", ",", "si", ",", "sfo1", ",", "swp"}], "}"}]}]}], 
    "\[IndentingNewLine]", "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"process", "[", 
     RowBox[{
     "filenamebaseIP_", ",", "filenamebaseAP_", ",", "shift_", ",", "width_", 
      ",", "swp_", ",", "offset_", ",", "si_", ",", "sfo1_"}], "]"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "diff", ",", "dip", ",", "start", ",", "end", ",", "hzpp", ",", 
        "ncproc", ",", "spip", ",", "spap"}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"filename", "=", 
        RowBox[{"filenamebaseIP", "<>", "\"\</procs\>\""}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"stream", "=", 
        RowBox[{"OpenRead", "[", "filename", "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"ncproc", "=", 
        RowBox[{
         RowBox[{"Read", "[", 
          RowBox[{
           RowBox[{"StringToStream", "[", 
            RowBox[{"Find", "[", 
             RowBox[{"stream", ",", "\"\<NC_proc= \>\""}], "]"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"Word", ",", "Number"}], "}"}]}], "]"}], "[", 
         RowBox[{"[", "2", "]"}], "]"}]}], ";", " ", 
       RowBox[{"(*", " ", 
        RowBox[{
        "Need", " ", "to", " ", "correct", " ", "for", " ", "any", " ", 
         "difference", " ", "in", " ", "scaling", " ", "during", " ", "FT", 
         " ", 
         RowBox[{"etc", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
       RowBox[{"Close", "[", "stream", "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{"filename", "=", 
        RowBox[{"filenamebaseIP", "<>", "\"\</1r\>\""}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"spip", "=", 
        RowBox[{
         RowBox[{"2.", "^", "ncproc"}], " ", 
         RowBox[{
          RowBox[{"Import", "[", 
           RowBox[{"filename", ",", "\"\<Integer32\>\""}], "]"}], "/", 
          RowBox[{"10", "^", "6"}]}]}]}], ";", " ", "\[IndentingNewLine]", 
       "\[IndentingNewLine]", 
       RowBox[{"filename", "=", 
        RowBox[{"filenamebaseAP", "<>", "\"\</procs\>\""}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"stream", "=", 
        RowBox[{"OpenRead", "[", "filename", "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"ncproc", "=", 
        RowBox[{
         RowBox[{"Read", "[", 
          RowBox[{
           RowBox[{"StringToStream", "[", 
            RowBox[{"Find", "[", 
             RowBox[{"stream", ",", "\"\<NC_proc= \>\""}], "]"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"Word", ",", "Number"}], "}"}]}], "]"}], "[", 
         RowBox[{"[", "2", "]"}], "]"}]}], ";", " ", 
       RowBox[{"(*", " ", 
        RowBox[{
        "Need", " ", "to", " ", "correct", " ", "for", " ", "any", " ", 
         "difference", " ", "in", " ", "scaling", " ", "during", " ", "FT", 
         " ", 
         RowBox[{"etc", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
       RowBox[{"Close", "[", "stream", "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{"filename", "=", 
        RowBox[{"filenamebaseAP", "<>", "\"\</1r\>\""}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"spap", "=", 
        RowBox[{
         RowBox[{"2.", "^", "ncproc"}], " ", 
         RowBox[{
          RowBox[{"Import", "[", 
           RowBox[{"filename", ",", "\"\<Integer32\>\""}], "]"}], "/", 
          RowBox[{"10", "^", "6"}]}]}]}], ";", " ", "\[IndentingNewLine]", 
       "\[IndentingNewLine]", 
       RowBox[{"hzpp", "=", 
        RowBox[{"swp", " ", 
         RowBox[{"sfo1", "/", 
          RowBox[{"(", 
           RowBox[{"si", "-", "1"}], ")"}]}]}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"start", "=", 
        RowBox[{"Round", "[", 
         RowBox[{"sfo1", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"offset", "-", "shift", "-", 
             RowBox[{"width", "/", "2"}]}], ")"}], "/", "hzpp"}]}], "]"}]}], 
       ";", "\[IndentingNewLine]", 
       RowBox[{"end", "=", 
        RowBox[{"Round", "[", 
         RowBox[{"sfo1", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"offset", "-", "shift", "+", 
             RowBox[{"width", "/", "2"}]}], ")"}], "/", "hzpp"}]}], " ", 
         "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"tspip", "=", 
        RowBox[{"Take", "[", 
         RowBox[{"spip", ",", 
          RowBox[{"{", 
           RowBox[{"start", ",", "end"}], "}"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"len", "=", 
        RowBox[{"Length", "[", "tspip", "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"tspap", "=", 
        RowBox[{"Take", "[", 
         RowBox[{"spap", ",", 
          RowBox[{"{", 
           RowBox[{"start", ",", "end"}], "}"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"Print", "[", 
        RowBox[{
         RowBox[{"Style", "[", 
          RowBox[{"\"\<Chemical shift = \>\"", ",", "\"\<Subsection\>\""}], 
          "]"}], ",", 
         RowBox[{"Style", "[", 
          RowBox[{"shift", ",", "\"\<Subsection\>\""}], "]"}], ",", 
         RowBox[{"Style", "[", 
          RowBox[{"\"\< ppm\>\"", ",", "\"\<Subsection\>\""}], "]"}]}], "]"}],
        ";", "\[IndentingNewLine]", 
       RowBox[{"(*", " ", 
        RowBox[{
         RowBox[{
         "Do", " ", "optimistion", " ", "in", " ", "two", " ", "stages"}], 
         ",", " ", 
         RowBox[{
         "otherwise", " ", "fails", " ", "to", " ", "find", " ", "global", 
          " ", "minimum"}]}], " ", "*)"}], "\[IndentingNewLine]", 
       RowBox[{"res1", "=", 
        RowBox[{"NMinimize", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"vardiff", "[", 
             RowBox[{"tspip", ",", "tspap", ",", "fratio", ",", 
              RowBox[{"5", " ", "fdiff"}]}], "]"}], ",", 
            RowBox[{"fdiff", ">", 
             RowBox[{
              RowBox[{"-", "len"}], "/", "5"}]}], ",", 
            RowBox[{"fdiff", "<", 
             RowBox[{"len", "/", "5"}]}], ",", 
            RowBox[{"fratio", ">", "0.8"}], ",", 
            RowBox[{"fratio", "<", "1.2"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"fdiff", "\[Element]", " ", "Integers"}], ",", "fratio"}],
            "}"}], ",", 
          RowBox[{"MaxIterations", "\[Rule]", "200"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"res2", "=", 
        RowBox[{"NMinimize", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"vardiff", "[", 
             RowBox[{
             "tspip", ",", "tspap", ",", "fratio", ",", " ", "fdiff"}], "]"}],
             ",", 
            RowBox[{"fratio", ">", "0.7"}], ",", 
            RowBox[{"fratio", "<", "1.2"}], ",", 
            RowBox[{"fdiff", ">", 
             RowBox[{
              RowBox[{"Round", "[", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"5", " ", "fdiff"}], "/.", 
                 RowBox[{"res1", "[", 
                  RowBox[{"[", "2", "]"}], "]"}]}], ")"}], "]"}], "-", 
              RowBox[{"len", "/", "10"}]}]}], ",", 
            RowBox[{"fdiff", "<", 
             RowBox[{"Round", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"len", "/", "10"}], "+", 
                RowBox[{"5", " ", "fdiff"}]}], "/.", 
               RowBox[{"res1", "[", 
                RowBox[{"[", "2", "]"}], "]"}]}], "]"}]}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"fdiff", "\[Element]", " ", "Integers"}], ",", "fratio"}],
            "}"}], ",", 
          RowBox[{"MaxIterations", "\[Rule]", "1000"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{
       "Print", "[", "\"\<Variance and optimised shift and ratio:\>\"", "]"}],
        ";", "\[IndentingNewLine]", 
       RowBox[{"Print", "[", "res2", "]"}], ";", " ", "\[IndentingNewLine]", 
       RowBox[{"ratio", "=", 
        RowBox[{"fratio", "/.", 
         RowBox[{"res2", "[", 
          RowBox[{"[", "2", "]"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"spp", "=", 
        RowBox[{"tspip", "+", 
         RowBox[{"ratio", " ", "tspap"}]}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"spm", "=", 
        RowBox[{"tspip", "-", 
         RowBox[{"ratio", " ", "tspap"}]}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"Print", "[", 
        RowBox[{"Style", "[", 
         RowBox[{"\"\<Input data\>\"", ",", "\"\<Subsection\>\""}], "]"}], 
        "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{"Print", "[", 
        RowBox[{"ListPlot", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"spp", ",", "spm"}], "}"}], ",", 
          RowBox[{"Joined", "\[Rule]", "True"}], ",", 
          RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"len", "=", 
        RowBox[{"Length", "[", "spp", "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"zspm", "=", 
        RowBox[{"Join", "[", 
         RowBox[{
          RowBox[{"Table", "[", 
           RowBox[{"0", ",", 
            RowBox[{"{", 
             RowBox[{"i", ",", "len"}], "}"}]}], "]"}], ",", 
          RowBox[{"Join", "[", 
           RowBox[{"spm", ",", 
            RowBox[{"Table", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", 
               RowBox[{"i", ",", "len"}], "}"}]}], "]"}]}], "]"}]}], "]"}]}], 
       ";", "\[IndentingNewLine]", 
       RowBox[{"diff", "=", 
        RowBox[{"Table", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", 
            RowBox[{
             RowBox[{"2", " ", "len"}], "+", "1"}]}], "}"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"For", "[", 
        RowBox[{
         RowBox[{"i", "=", "1"}], ",", 
         RowBox[{"i", "\[LessEqual]", 
          RowBox[{"Length", "[", "diff", "]"}]}], ",", 
         RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{
           RowBox[{"diff", "[", 
            RowBox[{"[", "i", "]"}], "]"}], "=", 
           RowBox[{"Total", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"spp", "-", 
               RowBox[{"Take", "[", 
                RowBox[{
                 RowBox[{"RotateRight", "[", 
                  RowBox[{"zspm", ",", 
                   RowBox[{"len", "-", "i"}]}], "]"}], ",", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"len", "+", "1"}], ",", 
                   RowBox[{"2", " ", "len"}]}], "}"}]}], "]"}]}], ")"}], "^", 
             "2"}], "]"}]}], ";"}]}], "\[IndentingNewLine]", "]"}], ";", "\n", 
       RowBox[{"Print", "[", 
        RowBox[{"Style", "[", 
         RowBox[{
         "\"\<RMS difference vs displacement in data points\>\"", ",", 
          "\"\<Subsection\>\""}], "]"}], "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{"Print", "[", 
        RowBox[{"ListPlot", "[", 
         RowBox[{"diff", ",", 
          RowBox[{"Joined", "\[Rule]", "True"}], ",", 
          RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"min", "=", 
        RowBox[{"Min", "[", "diff", "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"For", "[", 
        RowBox[{
         RowBox[{"i", "=", "1"}], ",", 
         RowBox[{"i", "\[LessEqual]", 
          RowBox[{"Length", "[", "diff", "]"}]}], ",", 
         RowBox[{"i", "++"}], ",", " ", 
         RowBox[{
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"diff", "[", 
              RowBox[{"[", "i", "]"}], "]"}], "\[Equal]", "min"}], ",", 
            RowBox[{"minpoint", "=", "i"}]}], "]"}], ";"}]}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"Print", "[", 
        RowBox[{"Style", "[", 
         RowBox[{
         "\"\<Expansion of RMS difference vs displacement in data points, \
with parabolic fit\>\"", ",", "\"\<Subsection\>\""}], "]"}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"dip", "=", 
        RowBox[{"Take", "[", 
         RowBox[{"diff", ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"minpoint", "-", "10"}], ",", 
            RowBox[{"minpoint", "+", "10"}]}], "}"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"dipfit", "=", 
        RowBox[{"NonlinearModelFit", "[", 
         RowBox[{"dip", ",", 
          RowBox[{"a", "+", 
           RowBox[{"b", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"x", "-", "x0"}], ")"}], "^", "2"}]}]}], ",", 
          RowBox[{"{", 
           RowBox[{"a", ",", "b", ",", "x0"}], "}"}], ",", "x"}], "]"}]}], 
       ";", "\[IndentingNewLine]", 
       RowBox[{"Print", "[", 
        RowBox[{"Show", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Plot", "[", 
            RowBox[{
             RowBox[{"dipfit", "[", "x", "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"x", ",", "1", ",", 
               RowBox[{"Length", "[", "dip", "]"}]}], "}"}], ",", 
             RowBox[{"PlotRange", "\[Rule]", 
              RowBox[{"{", 
               RowBox[{"All", ",", 
                RowBox[{"{", 
                 RowBox[{"0", ",", 
                  RowBox[{"1.1", " ", 
                   RowBox[{"Max", "[", "dip", "]"}]}]}], "}"}]}], "}"}]}]}], 
            "]"}], ",", 
           RowBox[{"ListPlot", "[", 
            RowBox[{"dip", ",", 
             RowBox[{"Joined", "\[Rule]", "False"}], ",", 
             RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]}], "}"}], "]"}],
         "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{"Print", "[", 
        RowBox[{
        "\"\<Interpolated frequency shift with best match is \>\"", ",", 
         RowBox[{
          RowBox[{"-", "hzpp"}], 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"x0", "/.", 
              RowBox[{"dipfit", "[", "\"\<BestFitParameters\>\"", "]"}]}], 
             ")"}], "+", "minpoint", "-", "11", "-", "len"}], ")"}]}], ",", 
         " ", "\"\< Hz\>\""}], "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"-", "hzpp"}], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"x0", "/.", 
            RowBox[{"dipfit", "[", "\"\<BestFitParameters\>\"", "]"}]}], 
           ")"}], "+", "minpoint", "-", "11", "-", "len"}], ")"}]}]}]}], 
     "\[IndentingNewLine]", "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"shifts", "=", 
   RowBox[{"{", 
    RowBox[{
    "4.9395", ",", "4.3501", ",", "3.9844", ",", "3.5537", ",", "2.0811", ",",
      "1.9077", ",", "1.5058"}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"widths", "=", 
   RowBox[{"{", 
    RowBox[{
    "0.04", ",", "0.17", ",", "0.08", ",", "0.07", ",", "0.16", ",", "0.03", 
     ",", "0.1"}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"njs", "=", 
   RowBox[{"Length", "[", "shifts", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nreps", "=", "1"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"filestart", "=", "7"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"js", "=", 
   RowBox[{"Table", "[", 
    RowBox[{"0", ",", "njs", ",", "nreps"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
  "filenamebase", "=", 
   "\"\<V:/dropbox/Coral/_Projects/_Publications/IPAP FESTA/Fluorohydrin \
data/data/GDP_fluoridrinaCDCl3_thais/nmr/\>\""}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"procnoIP", "=", "\"\<1001\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"procnoAP", "=", "\"\<1002\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"getpars", "[", 
   RowBox[{
    RowBox[{"filenamebase", "<>", 
     RowBox[{"ToString", "[", "filestart", "]"}]}], ",", "procnoIP"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"starttime", "=", 
   RowBox[{"AbsoluteTime", "[", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"For", "[", 
   RowBox[{
    RowBox[{"jnumber", "=", "1"}], ",", 
    RowBox[{"jnumber", "\[LessEqual]", 
     RowBox[{"Length", "[", "shifts", "]"}]}], ",", 
    RowBox[{"jnumber", "++"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"For", "[", 
      RowBox[{
       RowBox[{"rep", "=", "1"}], ",", 
       RowBox[{"rep", "\[LessEqual]", "nreps"}], ",", 
       RowBox[{"rep", "++"}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"filename", "=", 
         RowBox[{"filenamebase", "<>", 
          RowBox[{"ToString", "[", 
           RowBox[{"filestart", "+", "rep", "-", "1"}], "]"}], "<>", 
          "\"\</pdata/\>\""}]}], ";", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"js", "[", 
          RowBox[{"[", 
           RowBox[{"jnumber", ",", "rep"}], "]"}], "]"}], "=", 
         RowBox[{"process", "[", 
          RowBox[{
           RowBox[{"filename", "<>", "procnoIP"}], ",", 
           RowBox[{"filename", "<>", "procnoAP"}], ",", 
           RowBox[{"shifts", "[", 
            RowBox[{"[", "jnumber", "]"}], "]"}], ",", 
           RowBox[{"widths", "[", 
            RowBox[{"[", "jnumber", "]"}], "]"}], ",", "swp", ",", "offset", 
           ",", "si", ",", "sfo1"}], "]"}]}], ";"}]}], "\[IndentingNewLine]", 
      "]"}], ";"}]}], "\[IndentingNewLine]", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{"Style", "[", 
    RowBox[{"\"\<Coupling constants\>\"", ",", "\"\<Subsection\>\""}], "]"}], 
   "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"TableForm", "[", "js", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"jslb1", "=", "js"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"timeused", "=", 
   RowBox[{
    RowBox[{"AbsoluteTime", "[", "]"}], "-", "starttime"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{"\"\<Time used = \>\"", ",", "timeused", ",", "\"\<seconds\>\""}], 
   "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"meansdandsdmean", "[", "x_", "]"}], ":=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Mean", "[", "x", "]"}], ",", 
     RowBox[{"Sqrt", "[", 
      RowBox[{
       RowBox[{"Variance", "[", "x", "]"}], "/", 
       RowBox[{"(", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Length", "[", "x", "]"}], "-", "1"}], ")"}], ")"}]}], 
      "]"}], ",", 
     RowBox[{"Sqrt", "[", 
      RowBox[{
       RowBox[{"Variance", "[", "x", "]"}], "/", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Length", "[", "x", "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Length", "[", "x", "]"}], "-", "1"}], ")"}]}], ")"}]}], 
      "]"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{"nreps", ">", "1"}], ",", 
    RowBox[{
     RowBox[{"reslb1", "=", 
      RowBox[{"Table", "[", 
       RowBox[{"0", ",", 
        RowBox[{"Length", "[", "shifts", "]"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"reslb1", "=", 
      RowBox[{"Prepend", "[", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"Flatten", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"shifts", "[", 
              RowBox[{"[", "i", "]"}], "]"}], ",", 
             RowBox[{"meansdandsdmean", "[", 
              RowBox[{"jslb1", "[", 
               RowBox[{"[", "i", "]"}], "]"}], "]"}]}], "}"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", 
            RowBox[{"Length", "[", "shifts", "]"}]}], "}"}]}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{
         "\"\<Shift / ppm\>\"", ",", "\"\<JHF / Hz\>\"", ",", 
          "\"\<std dev / Hz\>\"", ",", "\"\<sd of mean of J / Hz\>\""}], 
         "}"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"Print", "[", 
      RowBox[{"TableForm", "[", "reslb1", "]"}], "]"}], ";"}]}], "]"}], 
  "\[IndentingNewLine]", 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.833448292510956*^9, 3.833448473320225*^9}, {
   3.833448567630739*^9, 3.833448597926832*^9}, {3.833448726706624*^9, 
   3.8334488386106873`*^9}, {3.833448894130322*^9, 3.83344899381962*^9}, {
   3.8334490263559*^9, 3.833449034371501*^9}, {3.833449208176523*^9, 
   3.83344924369489*^9}, {3.8334515420085583`*^9, 3.833451676813837*^9}, {
   3.8335325651614*^9, 3.833532637209276*^9}, {3.833532759034121*^9, 
   3.8335330239765873`*^9}, {3.8335330927635307`*^9, 
   3.8335331455943604`*^9}, {3.833533397697961*^9, 3.8335334255106373`*^9}, {
   3.8335334594455547`*^9, 3.833533507765386*^9}, {3.833533539339788*^9, 
   3.833533659575992*^9}, {3.833533697198904*^9, 3.8335337340891523`*^9}, {
   3.833533780205265*^9, 3.833533893496993*^9}, 3.833533985781467*^9, {
   3.8335340192182083`*^9, 3.833534070521394*^9}, {3.833534125296022*^9, 
   3.833534125914562*^9}, 3.833534226165428*^9, {3.833534380477125*^9, 
   3.833534380818433*^9}, {3.8335344656134453`*^9, 3.833534519575261*^9}, {
   3.8335346317293777`*^9, 3.83353463272573*^9}, 3.8335347268726482`*^9, {
   3.8335347781741343`*^9, 3.83353485994346*^9}, {3.833534904539554*^9, 
   3.83353494839614*^9}, {3.833534999551011*^9, 3.833534999698493*^9}, {
   3.833535037301165*^9, 3.833535103927022*^9}, {3.8335351368517733`*^9, 
   3.833535139414091*^9}, {3.8335352378369083`*^9, 3.833535337311174*^9}, {
   3.833535394550235*^9, 3.833535454170685*^9}, {3.8335361679797087`*^9, 
   3.8335362375090513`*^9}, {3.833536274111115*^9, 3.833536278469448*^9}, 
   3.833536449477241*^9, {3.8335364826240788`*^9, 3.8335365448917313`*^9}, {
   3.833538035225528*^9, 3.833538077529106*^9}, {3.8337034631307096`*^9, 
   3.833703463865309*^9}, {3.833703506926898*^9, 3.833703553753542*^9}, {
   3.833703617125688*^9, 3.833703688345792*^9}, {3.833703718670663*^9, 
   3.8337037764894876`*^9}, {3.8337038223632317`*^9, 
   3.8337039123907833`*^9}, {3.83370394998801*^9, 3.833704007351994*^9}, {
   3.833704056375489*^9, 3.833704136756112*^9}, {3.833704176289364*^9, 
   3.833704289758876*^9}, {3.833704391066206*^9, 3.833704429891245*^9}, {
   3.833704972721045*^9, 3.8337049956209497`*^9}, {3.8337050367076*^9, 
   3.833705038457287*^9}, {3.8337053194184847`*^9, 3.833705411458173*^9}, {
   3.8337070792528667`*^9, 3.833707127605337*^9}, {3.835337695095479*^9, 
   3.835337749538929*^9}, {3.835338577798208*^9, 3.835338620041452*^9}, {
   3.835338653990897*^9, 3.835338823765335*^9}, {3.835338865410541*^9, 
   3.835338962622757*^9}, {3.83533899622244*^9, 3.8353390024553337`*^9}, {
   3.835339165977964*^9, 3.835339170838904*^9}, {3.835339226586821*^9, 
   3.835339252159419*^9}, {3.8353394292671547`*^9, 3.835339457784766*^9}, {
   3.835339500275881*^9, 3.8353395120074873`*^9}, 3.8353400097312202`*^9, {
   3.835340043255178*^9, 3.835340049105363*^9}, {3.835340320155546*^9, 
   3.8353403214856653`*^9}, {3.8353429884303017`*^9, 3.835343088575757*^9}, {
   3.835343169936596*^9, 3.83534322437465*^9}, {3.835343746121127*^9, 
   3.8353437642293177`*^9}, {3.8353445222541227`*^9, 3.835344552148288*^9}, {
   3.835344620203895*^9, 3.835344716850436*^9}, {3.835344824168634*^9, 
   3.835344832897682*^9}, {3.835344894608045*^9, 3.835344999609126*^9}, {
   3.8353450692229977`*^9, 3.835345143285017*^9}, {3.835345243601369*^9, 
   3.835345244855967*^9}, 3.8353452928938713`*^9, {3.835345339394802*^9, 
   3.835345341993548*^9}, {3.835345390387436*^9, 3.835345394595192*^9}, 
   3.835345505879159*^9, {3.835345633336461*^9, 3.835345726337473*^9}, {
   3.8353458377226467`*^9, 3.835345843828887*^9}, {3.835372061030136*^9, 
   3.835372071264954*^9}, {3.835372109388467*^9, 3.83537218434414*^9}, 
   3.835372522290762*^9, {3.8354170700934362`*^9, 3.835417083829755*^9}, {
   3.835417167922065*^9, 3.835417196326001*^9}, {3.835418223179352*^9, 
   3.835418229883106*^9}, {3.835418393819128*^9, 3.835418488516716*^9}, {
   3.835418519132303*^9, 3.835418537842663*^9}, {3.83542543494832*^9, 
   3.835425472964828*^9}, 3.8354255498612223`*^9, {3.835425690259713*^9, 
   3.83542571399114*^9}, {3.835431541550761*^9, 3.835431541640277*^9}, {
   3.852979611453643*^9, 3.852979691319852*^9}, {3.8529797654116774`*^9, 
   3.852979781170024*^9}, {3.852979821986277*^9, 3.8529798368790913`*^9}, 
   3.852982940810091*^9, {3.8535786610591493`*^9, 3.853578743107206*^9}, {
   3.8535791499440546`*^9, 3.853579151302937*^9}, 3.8535799422709336`*^9, {
   3.853584626138847*^9, 3.8535846264724474`*^9}, {3.853588060563446*^9, 
   3.853588147103307*^9}, {3.8541013680700455`*^9, 3.8541014174927487`*^9}, {
   3.8541018854386787`*^9, 3.854101907205002*^9}, {3.8674061893476934`*^9, 
   3.8674062046307745`*^9}, 3.867407387166424*^9, {3.867492104316619*^9, 
   3.8674921100062523`*^9}},
 CellLabel->
  "In[231]:=",ExpressionUUID->"83ce1c8d-1a22-4fa3-84c9-6c6be868c2d5"],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   StyleBox["\<\"Chemical shift = \"\>", "Subsection",
    StripOnInput->False], "\[InvisibleSpace]", 
   StyleBox["4.9395`", "Subsection",
    StripOnInput->False], "\[InvisibleSpace]", 
   StyleBox["\<\" ppm\"\>", "Subsection",
    StripOnInput->False]}],
  SequenceForm[
   Style["Chemical shift = ", "Subsection"], 
   Style[4.9395, "Subsection"], 
   Style[" ppm", "Subsection"]],
  Editable->False]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8538362850216036`*^9, 3.854101458037591*^9, 3.8541019092820697`*^9, 
  3.8674062291319656`*^9, 3.8674077474607763`*^9, 3.867492114777452*^9},
 CellLabel->
  "During evaluation of \
In[231]:=",ExpressionUUID->"e363de3b-18e3-44bd-a478-75ae6971ab3c"],

Cell[BoxData["\<\"Variance and optimised shift and ratio:\"\>"], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8538362850216036`*^9, 3.854101458037591*^9, 3.8541019092820697`*^9, 
  3.8674062291319656`*^9, 3.8674077474607763`*^9, 3.8674921392897387`*^9},
 CellLabel->
  "During evaluation of \
In[231]:=",ExpressionUUID->"df5ff8ba-4fc3-42e3-84ff-6b0383b556ba"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"4.624658338870697`", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"fdiff", "\[Rule]", "153"}], ",", 
     RowBox[{"fratio", "\[Rule]", "1.0988351897223416`"}]}], "}"}]}], 
  "}"}]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8538362850216036`*^9, 3.854101458037591*^9, 3.8541019092820697`*^9, 
  3.8674062291319656`*^9, 3.8674077474607763`*^9, 3.867492139293726*^9},
 CellLabel->
  "During evaluation of \
In[231]:=",ExpressionUUID->"8b3842ff-5e4c-471b-b2e9-e93ca4c25a1a"],

Cell[BoxData[
 StyleBox["\<\"Input data\"\>", "Subsection",
  StripOnInput->False]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8538362850216036`*^9, 3.854101458037591*^9, 3.8541019092820697`*^9, 
  3.8674062291319656`*^9, 3.8674077474607763`*^9, 3.8674921392967176`*^9},
 CellLabel->
  "During evaluation of \
In[231]:=",ExpressionUUID->"8a2c1968-54cb-4f5a-affd-798231646ae0"],

Cell[BoxData[
 GraphicsBox[{{}, {{{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJw1mHlcjOsbxgchHUuUhDAtJyGMlqMsdUkiSqOFSBlF2pumaZmaapCWY6vs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       "]]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJw9mHlcjN37x6eyhCJbQhhlSVlClCU+hGxpotIm0960TjWVappuew9JUREP
JlmSLXposU0kUUiyPZJ5KpUS2VLW3/19dd0/f/B6u87nvu7Puc91nTlntHvw
ai9VHo+nyf71v3+7/rTN9117VGT64c58+g8wpmINa3EpsTqGLdmRerLfXWIt
+MSXWBdlcjwI1RppPZLU7hHrIPro1he/hnCsi0k3zLfqN3Dj+Wi3XK/jvYtj
PSg/ezbOnM3xGJSkpf+7YyDH41B6IM0h14hjA7xfnHJyfwzHhige2/cTmjme
iNlthSciXbj8kxEw+LuKbTHHxtAeFFNtb1BGPBXaRvV7BIc5ngbPQ0YQzS0n
no59rWplVur3iU1gcGTsmdetHM/AqacCu5hbD4hnwmn+gzXjnB8Sm+Lm4kDb
3ukcm8EwY+354Vs4ngWDms+9L1hyPBuli5JX79LneA7qFdgqEnA8F4ajfzkL
3nBsDpOLx844eVUQz0PhfnHZsv84no/HGW61xxY8IgZGRKoU1AYQM4DqyYzG
y25cfAFKW2XD02Zx8QWoN1p7SGcUF18IedTt273ncvGFOJNXbaFxkotbYMPi
TaKejpUUt4BJ5BgN1ymPKb4ID9W+H/7dScwsgsP6wFe6u6sovhja66IyHr8k
Zlgu6xsT0szFl8Bv9Le8kdVcfAn2nVs7yv4FF7fEdqOe2nm8JxS3hPrqx3v7
uhDzlkJ11MPBvZVcfClqPn75fDb8KcWXob1c11xV/RnFl6F05OVftxKJecsR
kPojslPrOcWXo27NSMfyw8S8FdDYMjrt7JIXFF+Bpaq/Kwdo/EvxlZg387xx
Rz0xsxLm765PCLnxkuJWSBTVMvoJ1RS3wsz6Mv8yy1cUXwXfS6LrW38TM6tQ
2Bi3oqWkhuLW6BOrNSo+7zXFrdH6ct+lwUFKigtQyz+S7KLzXxdDANnTmEjN
SmJGAKmvaEhNUm0XKwSQWzx7sGRVHeltoBibPaO9dz3pbVAzYmLljgfEjA0s
4+rWvM98Q3obaJ9eleGd0kD61XDbqjlY5Vgj6VfjhMRuz5BHTaRfjdyrU2VN
2s2kXw2DT6b740NaSL8GV6N1ztco35F+DSZeUMzrLXpP+jUo+Mdi6Aj1NtKv
gVntvjJFKzHPFnMvy+Z5NXwkvS22n/0UduzjJ9LbYukXg6HD+n0hvS2qPPzH
9MJX0tuhtubcy8nx7aS3Q8ouwxyd1m+kt0P+LZ8aU0kn6e0wp2eL/jX+D9Lb
42qE6Gbip5+kt8eNYRqmRo2/SW+Phq0LfoyW8dClt8enkF5hAekqXcxbC78S
Uer+UtUuxlq0e8TJ0b9bFzNrMSAhbbp2dHfSr4X7lO533qj3JL0DzKfbqDQp
1EnvgMTT8bkTj/YmvQNcVs3cIczWIL0Dbsz6s23T076kd0THs48pa/Zokd4R
Ln0qY8Pu9Se9I459XOeyddBA0juivGDxrvSQQaR3Qvxeu3ujaweT3gmKmGWz
oryGkN4J5soruirfdUjvhOaPnWlFh4aR3hnx0Ul+0611Se8M9yffT1/XHEl6
Z+jaFouOvBhFemc0WYxI2f+CT3oX7HAq79NZPpr0LO/T7Pfyth7pXWDoOfDz
jJv6pHfB1WffvlneGEP6dZibaFHWp3As6dfhbYqo/NL5caRfB+kL93k9Do8n
/TqkPf9cvnazAeld4biwMiTcdQLpXZH5QO2G82RD0rti5tF3qzU/EStcscTK
asruLCPSr0f98bIL3W0mkn49XLX5/KfNxMx66F7M23cufBLp16Py7m8Nn4/E
PCEKDV+9L1k3uYv5Qnj20WxfWUgMIdyMB6YM6TGli4VC9DpwqPrHfGJGiJLu
l2oV3sRyIV79vLbbM4pYIcT1wuYsq0hipRD24riB64TEPDes62nbWW9CzHdD
VVKSTvpXLr8bDmd8vPRXJrHQDXoNd68Zgphxw4j8l6/t7pMfuRvGpxXrTLHi
/Lqhes7Yu9VFNB9KNxzr6z9h5CRinjt+Ox7Jr99N88l3R8uKaOvRzTTfcMfN
1//NaZpNLHTHz0V/q79n6Hsx7iiVO56eeYW+p9wdoa8mP7v8lvve7vii27Tx
lCax0h0aQcG1URNoffA8YLLhipc1aP3wPXB4UnlakB2tL3hg7G7p9PP+tP6E
Htg9o4fxzK16lN8DV93OHYnNpPUr90COhXJP4h1a3woPqJe7Lo+tp/Wv9IBw
/4+slKVUHzxPpE+Y8mzLVaofvidmZ/d7dQvDKb8n5jakK95UDaX8nrhcNc38
ZiTVI+OJ9pZK19/jqV7lnvBsFyYX11M9Kzxh90WzavU5qnelJ5amrpg8eBv1
A54XDuzapT0raADl94LJEmFmsy/1D3jBYYzPwH2R1F+EXqjflbdQZ0Y/yu8F
UeqtmSZHNSm/F74aFw6ZYcL1Ky80aN1S0X5L/UzphSdVjXfKbvSi/N7gn3zd
qZNP/Y/vjbqinfzTj6g/whuVnz4cGdiHWOiNHvMWqi9x60H5vWHb0Zz45yH1
V7k37IsiVX6s5vqtN3Seuge6NlI/Vnojok903xMJxDwf6PFbguMXEfN9oNrL
Pe0h17/hA6efHanZ7WqU3wfan68NXfSZmPHBF/4ONevuNF7uA485HQ/uGhAr
fGDw0KXwuCOX3wcDM5Teqalcfl8UVs3Xn/6Ky++Ltp7rPX5Np/eHL/SebDaY
coRY6Its2/oP3/U5/75oPFGY13qbWO6L9ts9143bRvOl8IVfVlnVSQ+aX6Uv
2F9PDkku3PyLMGxcQLU8mL4PXwRJiOkZn0N9KL8I7V55i1Oa6HsKRRgj8uWt
s6P9hxGhUTKyz6ImWg9yEfaqFXh4VNJ6UYjAj92egBJaT0pWvy6iYsdDWm88
P1wOz34paqX1yPfDF+eF8rqR3H7khyq59IaThzbl94NsBkTlhdz+5IeeLZ66
uWOpPuR+KK7YxD94jPYnhR/eb6sZlGpK9aX0w8X4mSuKXo2g/P7ILgp8ppdK
9cn3x/Btcnuvs1S/8EcQhp8/mkr1LfTHv+nqKrs26lF+f4RskNokB1N/kPvD
SD4oeqUr9Q+FPxifgKX+K6m/KP1R4pp/J8KM6z8B6IGcxlN86k/8ACwtqunW
okr9DAHwzP2W/aWaWBiA97a9/DLPcP0vAAW6WfdXiqk/ygNgVDos+dc46qeK
ACQm1WpuqyBWBgBfkq2sA7n+G8j+nvm6Uf03MT8QC9/dqFq2mfo3AtFWeenD
sl/EwkBME9vH5Plz/T8Qoms3XfLuE8sD0ZDlE/VjNLf/BEJuuOl7Lbc/KQNR
Na1y3sED3P4TBJ1MFR+LK9z+E4TQ9A7LYXeI2dlPOljMXLnK7X9B7IwIVnod
5Pa/IGQMG2o53YPb/4IgmL+13WQwlz8Iz97qlFvl0vsp2a854umC1/OJecGI
P3yqcc018scPhvoAVdULkzj/wQj9ecdozR6aH2EwJg6/MuZtC80nE4yXeppm
J2YTy4PxyfdK824Z93shGFME/Hu38uh7KYPh67f81N8N3O8PMfpazX/0Tx9i
LTF+bilyezaeWw9ijO/Q9P0xh9aLsRiurUWM4zLu944Y/+7vEO+zofUmEOO5
jqvuB3tuvxKjufXI9skuel0sFmOh/3nnaE9az4wYpkFmF5+F0npPEsM2emES
BlI9yMVYovdnh6Et1UuOGE/3+4ikWbQ/KcQQC8KMV/aleqsQ47vqodriTbQ/
KcVoHxe/00ON6rVNDPndir2tiVTfvBB0u/r7SPlY2p+0QrD9v+seirvcfsTG
S9pej4il/mEcArt3lrIfC7jfuyGITv7623I69SNBCHhfb2h1qHP9KgT1dY5b
U7pRfxOHQGOC+ZTlY6kfMiHw2zyhmfGj/pkUAt0diX/qH3P9PATVM8+HvhVS
v88JQfzdRskoLVXyHwKHpCjnpzV0PqgIgUnV1V7yPX+6zg/KEFRIwpSq+351
cVsIjBGmOqSYO3+EgudnF9U0+HsXa4Ui6/GYXjt3dnQxPxQJ1aeY32PpPGMc
CsXlD1NmNdD5B6HwLay3NS+j85EgFLb21SMHPfrcxcJQqNs2LRvFnafEoZBk
T7iXos+dr0KRUjisT6wbnb+SQsFPf/nR6QSdz+ShKBW/Ns7970MX54RCqTRV
ObCFzneKULY/1Ggdnd3axRWhSDp/Z/gydToPKtn8GrnCZ+/p/NjGPv/NhL3J
LW/Jfxiamv7kKDrovKkVBr5Q9+u3fsT8MFTUbZl5cCKdT43DIH/n0m+/FZ1f
EYa2n2OfZYXT+VYQBuWb/gO7Z9P5VxgGY9UVv/58oPOyOAxMkblN5HJihn2+
RaC6Vj6dr5PCUHx6a96nacTyMCTNZqQzLtJ5PCcMOgkqmcxEYkUY6mfc9uYd
pPN8RRgM4tOm632j874yDPmjPKaePUr3AW1hECwv/Uvz/+8PJHDIn9H7yle6
b9CSQOvmhVTva3QfwZdAYHp/8cHjdH9hLEHHsdbm1WfpfgMSTGx+cvlmOd2H
CCRISYkKX95J9ydCCcwSTzoVTSAWS8AsHFomcOTuWyRoWt33Yud2uq9JkqA8
r/Tot3y6D5JLUDX5StjINro/ypGAP2nQzowpxAoJ5i5MzJoTSfdNFRKsPKUw
f1VM911KCZQ2pfOXaBO3SZD/9pj5oCfc/Vw48odFvBRupfs7rXA01VX9tXUh
3ffxw9n5+CA1G0D3gcbh2CA65ObVQfeLCIfD5WSLu1/pflQQjudj7vrw1ImF
4ex+sG3EAUO6TxWHQ16ctVjoUEL+w2FwY1jKtITb5D8cZk1brjgVFZP/cKi/
fNJw7vMt8h8OnQm1J96PIlaw7+Mqqo1cdJP8s37qU9p7uBeRf1YfyhxQlyrI
fzgY09EvrYxvkP8IiKMFdg7R18h/BHIWlYUG1V0h/xHgdVTsCY4oJP8RYAQv
6s7PLiD/EUiabGOuOT2f/LPjCyvinV3yyH8EhKdUznU7fZn8s/EH/iFTexEz
7PPE+06eXnuJ/EdAriJNLQj7h/xHgF/5e8i1BbnkPwJK/atrUwsukH/2eVNe
REprzpP/CCiOS1s2jTlD/ll+pbHB/lYW+WfHV+0amzv5BPmPhGLyR7eNx46R
/0jg++7N4wcQ8yPBNKj1U9MhNmbZ8Hd7oRExWM72fKFXnkn+Wd61u9Yq5yj5
Zzl0d69Vr+TkPxK8k45Bt6cfIv8sf583413ifvLP8k3NA9tEKeSfZWO94Dcq
yeSf5ercbtNCE8g/y7NL9FXTtpN/ls8kdF6Yupn8syye6mHtEUf+WY5X4VVO
kpL/DeCZ+fdfXScj/ywv8fyrzngL+Wc5pbH/5jM7yT/LggXjZMP3kH+Wf5pP
MlSmkn+WjaovZLmTHyHLtkuGHkxIJ/8sq1Vv52sdIP8sV+/SV0w4SP5ZnpR8
aePIw+Sf5VlZgy4/yyD/G8BkWqlfVR4n/yzfbYk8n5NN/tnx/R75D06i9aBk
44av7b0aab20sfFfCfMbGFpPvChA3V3HKYnWm1YUFOd6mtiY03rkR4HXmH83
qITYmOUPzSabfGn9IgrMxVtO41fSehew+ql/ftvHUT0I2edXj/sV1kn1Imbj
J1I9FJlUXwwbt8ssGiKk+ktin/cO1gf6UH3KoyD0VOytm0/1m/M/NpZ6lREr
2Pex7j6yfRjVewWrD+K/a5zE1T87PqDl26nBxG1R4DvNiNX/SnpeNHjm1XMv
fiPWioZC4jUufAGN57PxosZJt2uIjaORNGivRlgh9Ruw8cbUh7ly6keCaIAf
bRFvTf1LGA0tf7399ruJxWzcSMJXXU7MREO8oUO6M430SdEQNDbM8sml58uj
IfcbZ1TWRvlzosHsndU2fC+xgo3jXPGsAs4/m0/0pn6kDemVLBcwPX24ftkW
DbPotSEnnhLzYpB/59PiLyb0PloxaPp5+OmD4cR8ll3mtvZPp/HGMZCr3V4+
tYbzHwPBjrETFhgSC9jnPdyVsDOH3kcYA90xYaeWbiMWxyDJPnDUjsPETAyy
8sr9OquIk2IwV8PrR5YK5z8GEw99tzimQZwTgzavpW99Ojj/MUgxz1/1ivs+
FWy8kq91vJb7/jEQa9Y9Kh1O+rYYCAdcPvU1npgnxUS5QW8PDfKnJYXWPec7
ZhHEfCna1fUemezn/Etx2XRMwwdHYkjRcMvaqaCY8y/FkgT9Vifu/YVSuOa1
3XVdyvmXQrai3hXc+mWkUO4NMVghJ06S4h+/3KEVBcRyKZ7fkoftecetfyny
L8U1XFbl/EuRohQn6j6meAWbf8TJ00ZriJVS/GzvdnGZKdVTmxT39rwOmHSN
6o0Xi8N7NrY3H79K/mPRsUm7+NdcYn4s9l9x9Pm8i9g4Fkm1GQ4lXL0ilj2/
r/dyEVwn/+z44x1199uIhez4f984dHwlFsei/mvnGbWVxEws/j5c8Nx2GFf/
seAnJ6q0XqD+II/FuzSXB6HBtP/mxEK9SvVg20HqJ4pYzHtwdJW5PXFFLKau
G2TReyexMhYl/fLmHvtJ3BYLi+7O2cFr6Xk8GW5lLOiYZUWsJUPxhW+OL87T
eL4MI9MWlllupn5mLAPObP2RzKN+Bxm2FPvUn99G/VEggyFj+6wphvqpUIZe
y70c7xoQi2UQLdVt0z9AzMiwSKNPy4x93P4vwxmfCbGFF6m/ymXo1nysoU8Y
5cuRoarzSP6uTcQKGVbK4orNqmh8hQwJ3889/5xNz1PKIHZdEbRNRvnaZPD0
2ZI7tJTr/3HQWL5u2plyYq043OatH63OjefH4WBC7ByvjVz/j4Nz4WJDuSPX
/+Mg/1PyLjGDWBAHqbaqoGw2sTAO/zJlTkOdSC+OQ+mpoemR/pz/OOw52VG0
8yXlT2Lfp6TgUvN/xPI49Ki0KZzqQ+Nz4qB6dbjzt4H0PEUczG0Szm5iiCvY
95VlTzcL4PzHwVHfb1Lia85/HDY7WR7fPI6Yx2CqsL9bxgnKp87ArOV5RwvH
WgweHcyc7cB9Px0GfwmTX6XWc/PDYPg/CYs/SyifAYMQtX2SjwncfDGYd2W9
9n0DYjMG7ekpY+SppAeDh5tO5G1aSbyUwfuJFk/1LxILGBy1jBqsUU16BwYX
O5d8MY3hfl8ykFyfnSLtpPXpy/LwLH3ptYL5/wd12+Xc
       "]]}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, {}, {}, {}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, {}, {}, {}}}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 525.}, {-0.12384496596712236`, 15.977977806363022`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8538362850216036`*^9, 3.854101458037591*^9, 3.8541019092820697`*^9, 
  3.8674062291319656`*^9, 3.8674077474607763`*^9, 3.867492139398446*^9},
 CellLabel->
  "During evaluation of \
In[231]:=",ExpressionUUID->"334b3a6f-4a77-49c1-b8c2-8d4830c15239"],

Cell[BoxData[
 StyleBox["\<\"RMS difference vs displacement in data points\"\>", 
  "Subsection",
  StripOnInput->False]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8538362850216036`*^9, 3.854101458037591*^9, 3.8541019092820697`*^9, 
  3.8674062291319656`*^9, 3.8674077474607763`*^9, 3.867492139636809*^9},
 CellLabel->
  "During evaluation of \
In[231]:=",ExpressionUUID->"7caade18-c9a9-4ac0-9fd1-17e64a817782"],

Cell[BoxData[
 GraphicsBox[{{}, {{{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJxF3HlcTdv7B/AkJFMyRSEJISQkRB+ikqlSZCinQfNwmuc6dep0OtXpmOMa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       "]]}}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6]}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, {}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 1051.}, {0, 36933.39408991154}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8538362850216036`*^9, 3.854101458037591*^9, 3.8541019092820697`*^9, 
  3.8674062291319656`*^9, 3.8674077474607763`*^9, 3.867492139724575*^9},
 CellLabel->
  "During evaluation of \
In[231]:=",ExpressionUUID->"7b4b7c99-a298-4599-a916-0413d600e2cc"],

Cell[BoxData[
 StyleBox["\<\"Expansion of RMS difference vs displacement in data points, \
with parabolic fit\"\>", "Subsection",
  StripOnInput->False]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8538362850216036`*^9, 3.854101458037591*^9, 3.8541019092820697`*^9, 
  3.8674062291319656`*^9, 3.8674077474607763`*^9, 3.867492139730559*^9},
 CellLabel->
  "During evaluation of \
In[231]:=",ExpressionUUID->"812d0df4-dcb8-4fb4-9008-78aae2a795b9"],

Cell[BoxData[
 GraphicsBox[{{{{}, {}, 
     TagBox[
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJwVV3k4lV8XVURJpWhGuPd978U130SmRaa4KWMylKEMZUjdSqWSklKGzLMy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        "]]},
      Annotation[#, "Charting`Private`Tag$4743792#1"]& ]}, {}}, {{}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
      0.012833333333333334`], AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJxTTMoPSmViYGAQBWIQDQEf7JXaZp6ZdXKOA1TAoevNhLa7+dOhfA6H6rJ2
3SkzJkH5Ag55qllKnhN7oHwRB77oPZWvOFqhfAkHoz3nbky1r4XyZRxU7BNj
xHYWQfkKDlsXdTg0CqVC+UoOr1pSPzk8CoLyVRxOLHjPx3zBBMpXc/Cpa8pf
Vi8E5Ws4SD8JL0lns4bytRzenV5R9u9nKJSv47BhkUANZ0I6lK/ncOJBUKS+
XQmUb+DQtk1X96R8PZRv6LDj12TJhSptUL6RQ/rcTw9TrvVC+cYOEzcK+M7y
mwzlmzi8+O2/iN1iBpRv6nDs2+rltYvmOgAAY7VZrw==
       "]]}, {
      {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
       0.012833333333333334`], AbsoluteThickness[1.6]}, {}}, {
      {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
       0.012833333333333334`], AbsoluteThickness[1.6]}, {}}}, {{}, {}}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{Automatic, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{All, {0, 2086.2849809223467`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8538362850216036`*^9, 3.854101458037591*^9, 3.8541019092820697`*^9, 
  3.8674062291319656`*^9, 3.8674077474607763`*^9, 3.867492139852234*^9},
 CellLabel->
  "During evaluation of \
In[231]:=",ExpressionUUID->"5af4b5db-4b8d-4671-b19a-217be50fdb9e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Interpolated frequency shift with best match is \"\>", 
   "\[InvisibleSpace]", "5.839430627131369`", 
   "\[InvisibleSpace]", "\<\" Hz\"\>"}],
  SequenceForm[
  "Interpolated frequency shift with best match is ", 5.839430627131369, 
   " Hz"],
  Editable->False]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8538362850216036`*^9, 3.854101458037591*^9, 3.8541019092820697`*^9, 
  3.8674062291319656`*^9, 3.8674077474607763`*^9, 3.867492139859215*^9},
 CellLabel->
  "During evaluation of \
In[231]:=",ExpressionUUID->"ac66b2d2-cd3e-45a6-affa-1e185a0ca00b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   StyleBox["\<\"Chemical shift = \"\>", "Subsection",
    StripOnInput->False], "\[InvisibleSpace]", 
   StyleBox["4.3501`", "Subsection",
    StripOnInput->False], "\[InvisibleSpace]", 
   StyleBox["\<\" ppm\"\>", "Subsection",
    StripOnInput->False]}],
  SequenceForm[
   Style["Chemical shift = ", "Subsection"], 
   Style[4.3501, "Subsection"], 
   Style[" ppm", "Subsection"]],
  Editable->False]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8538362850216036`*^9, 3.854101458037591*^9, 3.8541019092820697`*^9, 
  3.8674062291319656`*^9, 3.8674077474607763`*^9, 3.8674921404425325`*^9},
 CellLabel->
  "During evaluation of \
In[231]:=",ExpressionUUID->"f9f58659-3cfe-46e2-91b9-9eec7cc3abd8"],

Cell[BoxData["\<\"Variance and optimised shift and ratio:\"\>"], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8538362850216036`*^9, 3.854101458037591*^9, 3.8541019092820697`*^9, 
  3.8674062291319656`*^9, 3.8674077474607763`*^9, 3.8674922249153185`*^9},
 CellLabel->
  "During evaluation of \
In[231]:=",ExpressionUUID->"7d05946c-835c-4bc2-a92e-76fc96795ef6"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"30.594140264056172`", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"fdiff", "\[Rule]", "1263"}], ",", 
     RowBox[{"fratio", "\[Rule]", "1.0602605060020782`"}]}], "}"}]}], 
  "}"}]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8538362850216036`*^9, 3.854101458037591*^9, 3.8541019092820697`*^9, 
  3.8674062291319656`*^9, 3.8674077474607763`*^9, 3.8674922249193077`*^9},
 CellLabel->
  "During evaluation of \
In[231]:=",ExpressionUUID->"c3a71bf5-8eef-43ec-a477-1ac67af80bad"],

Cell[BoxData[
 StyleBox["\<\"Input data\"\>", "Subsection",
  StripOnInput->False]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8538362850216036`*^9, 3.854101458037591*^9, 3.8541019092820697`*^9, 
  3.8674062291319656`*^9, 3.8674077474607763`*^9, 3.8674922249232965`*^9},
 CellLabel->
  "During evaluation of \
In[231]:=",ExpressionUUID->"9b1a05d8-0ad5-4159-b573-7c4802629f30"],

Cell[BoxData[
 GraphicsBox[{{}, {{{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJw8m3lczN37/0dECEWIQtxJCCGE5IUQQpIkSSuVUIRSadr3mmamaVoQQpJk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       "]]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJw8nXtcTN379wchCkkSQnIKISQh+VCIQipJJYMkHacTnU3nc001M6XCRAhR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       "]]}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6]}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6]}, {}, {}, {}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6]}, {}, {}, {}}}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 2229.}, {-0.07030337002459622, 6.441490543012781}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8538362850216036`*^9, 3.854101458037591*^9, 3.8541019092820697`*^9, 
  3.8674062291319656`*^9, 3.8674077474607763`*^9, 3.867492225026022*^9},
 CellLabel->
  "During evaluation of \
In[231]:=",ExpressionUUID->"77d5fc38-d05a-48ca-8f28-51c399f80778"],

Cell[BoxData[
 StyleBox["\<\"RMS difference vs displacement in data points\"\>", 
  "Subsection",
  StripOnInput->False]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8538362850216036`*^9, 3.854101458037591*^9, 3.8541019092820697`*^9, 
  3.8674062291319656`*^9, 3.8674077474607763`*^9, 3.867492229285636*^9},
 CellLabel->
  "During evaluation of \
In[231]:=",ExpressionUUID->"2be16e84-7366-405d-8b22-980f040f7d44"],

Cell[BoxData[
 GraphicsBox[{{}, {{{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJxE23lcTF/4B/DsIQkhJCEkISlC+EgIoUhCJYnSokX7Ou17zUxTzUxFCElI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       "]]}}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.003666666666666667], 
     AbsoluteThickness[1.6]}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6]}, {}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 4459.}, {0, 7919.925889261898}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8538362850216036`*^9, 3.854101458037591*^9, 3.8541019092820697`*^9, 
  3.8674062291319656`*^9, 3.8674077474607763`*^9, 3.867492229397333*^9},
 CellLabel->
  "During evaluation of \
In[231]:=",ExpressionUUID->"84e96fe6-61ec-4b4b-b797-fb3d44f8cfc9"],

Cell[BoxData[
 StyleBox["\<\"Expansion of RMS difference vs displacement in data points, \
with parabolic fit\"\>", "Subsection",
  StripOnInput->False]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8538362850216036`*^9, 3.854101458037591*^9, 3.8541019092820697`*^9, 
  3.8674062291319656`*^9, 3.8674077474607763`*^9, 3.8674922294033184`*^9},
 CellLabel->
  "During evaluation of \
In[231]:=",ExpressionUUID->"5569e310-6704-46f9-b4e3-4ff867a64731"],

Cell[BoxData[
 GraphicsBox[{{{{}, {}, 
     TagBox[
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJwVlXk01O/7xomP0CbRIvvMvGcGhZoUwjXGnkglooUJiSRRpCEtlhZLJWRf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        "]]},
      Annotation[#, "Charting`Private`Tag$4821878#1"]& ]}, {}}, {{}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
      0.012833333333333334`], AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJxTTMoPSmViYGAQBWIQDQEf7P1aq5ivKzY4QAUcsre9ODHnUxWUz+FwwDZ9
koJAGZQv4KCdcibh8JJCKF/EwYN3ytQTBdlQvoTDNK2dZz2XpED5Mg6amzRT
Ah/GQvkKDus2Vm+KPRgC5Ss5xAV/uFbxxRvKV3H42FR1gdnIGcpXc1gV3T1Z
coYdlK/hUMputqHA0wHK13LwMe+arKruBuXrOGjlvNUwywmA8vUc5js5ScxV
joDyDRx4QmpeGYomQvmGDl9/F1j3mKVD+UYOU2TazNyy8qB8Y4d1l9LvdAQW
Q/kmDvuan35lf1kO5Zs6dAh09ld/rnEAABK/VE4=
       "]]}, {
      {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
       0.012833333333333334`], AbsoluteThickness[1.6]}, {}}, {
      {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
       0.012833333333333334`], AbsoluteThickness[1.6]}, {}}}, {{}, {}}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{Automatic, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{All, {0, 567.852985814011}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8538362850216036`*^9, 3.854101458037591*^9, 3.8541019092820697`*^9, 
  3.8674062291319656`*^9, 3.8674077474607763`*^9, 3.8674922294850993`*^9},
 CellLabel->
  "During evaluation of \
In[231]:=",ExpressionUUID->"49f58e22-5b53-4f94-a617-26c6114595e6"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Interpolated frequency shift with best match is \"\>", 
   "\[InvisibleSpace]", "48.16865470595593`", 
   "\[InvisibleSpace]", "\<\" Hz\"\>"}],
  SequenceForm[
  "Interpolated frequency shift with best match is ", 48.16865470595593, 
   " Hz"],
  Editable->False]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8538362850216036`*^9, 3.854101458037591*^9, 3.8541019092820697`*^9, 
  3.8674062291319656`*^9, 3.8674077474607763`*^9, 3.867492229495075*^9},
 CellLabel->
  "During evaluation of \
In[231]:=",ExpressionUUID->"e0884a68-a90e-4aee-a1c8-9bfaa0b43c24"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   StyleBox["\<\"Chemical shift = \"\>", "Subsection",
    StripOnInput->False], "\[InvisibleSpace]", 
   StyleBox["3.9844`", "Subsection",
    StripOnInput->False], "\[InvisibleSpace]", 
   StyleBox["\<\" ppm\"\>", "Subsection",
    StripOnInput->False]}],
  SequenceForm[
   Style["Chemical shift = ", "Subsection"], 
   Style[3.9844, "Subsection"], 
   Style[" ppm", "Subsection"]],
  Editable->False]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8538362850216036`*^9, 3.854101458037591*^9, 3.8541019092820697`*^9, 
  3.8674062291319656`*^9, 3.8674077474607763`*^9, 3.867492230077694*^9},
 CellLabel->
  "During evaluation of \
In[231]:=",ExpressionUUID->"db6a5959-3df9-4a50-93de-1e46b3aefd58"],

Cell[BoxData["\<\"Variance and optimised shift and ratio:\"\>"], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8538362850216036`*^9, 3.854101458037591*^9, 3.8541019092820697`*^9, 
  3.8674062291319656`*^9, 3.8674077474607763`*^9, 3.8674922738217936`*^9},
 CellLabel->
  "During evaluation of \
In[231]:=",ExpressionUUID->"e7f698ed-2b86-4a8d-a24e-5d4cf425bee1"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"8.904130213714677`", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"fdiff", "\[Rule]", "51"}], ",", 
     RowBox[{"fratio", "\[Rule]", "1.1457140491751652`"}]}], "}"}]}], 
  "}"}]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8538362850216036`*^9, 3.854101458037591*^9, 3.8541019092820697`*^9, 
  3.8674062291319656`*^9, 3.8674077474607763`*^9, 3.8674922738247857`*^9},
 CellLabel->
  "During evaluation of \
In[231]:=",ExpressionUUID->"479b9c93-0f14-4dfa-a182-b1d5aaacf1d3"],

Cell[BoxData[
 StyleBox["\<\"Input data\"\>", "Subsection",
  StripOnInput->False]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8538362850216036`*^9, 3.854101458037591*^9, 3.8541019092820697`*^9, 
  3.8674062291319656`*^9, 3.8674077474607763`*^9, 3.867492273827777*^9},
 CellLabel->
  "During evaluation of \
In[231]:=",ExpressionUUID->"37707e4f-2318-4f2d-adf0-a9190e6f9287"],

Cell[BoxData[
 GraphicsBox[{{}, {{{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJw1m3lcjN8XxydLhWQkVMJICCEU2T+UNkshTJumhZKWaZ/2aZ+mmqYUSRhf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       "]]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJw1nHlcjF0bx0e2iAyS0KNBEoWe0JOkfkqEZChUKtOqvWnfa9qnmmpkyz6R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       "]]}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, {}, {}, {}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, {}, {}, {}}}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 1049.}, {-0.01565068704475003, 2.852014756342995}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8538362850216036`*^9, 3.854101458037591*^9, 3.8541019092820697`*^9, 
  3.8674062291319656`*^9, 3.8674077474607763`*^9, 3.867492273907564*^9},
 CellLabel->
  "During evaluation of \
In[231]:=",ExpressionUUID->"5f497058-06b4-47c3-958e-a9d2305e48a5"],

Cell[BoxData[
 StyleBox["\<\"RMS difference vs displacement in data points\"\>", 
  "Subsection",
  StripOnInput->False]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8538362850216036`*^9, 3.854101458037591*^9, 3.8541019092820697`*^9, 
  3.8674062291319656`*^9, 3.8674077474607763`*^9, 3.867492274853036*^9},
 CellLabel->
  "During evaluation of \
In[231]:=",ExpressionUUID->"0d9a2282-343e-4195-8fc7-fec79b24b4c2"],

Cell[BoxData[
 GraphicsBox[{{}, {{{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJxE3HlcTc0fB/AihCSEEJIkhBBC+JAlJO2SJLRJpX1fbvtet9u9t9siIQkh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       "]]}}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6]}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, {}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 2099.}, {0, 1198.2420224583693`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8538362850216036`*^9, 3.854101458037591*^9, 3.8541019092820697`*^9, 
  3.8674062291319656`*^9, 3.8674077474607763`*^9, 3.867492274935816*^9},
 CellLabel->
  "During evaluation of \
In[231]:=",ExpressionUUID->"e4df4a6d-6775-42e2-9361-914fec61b391"],

Cell[BoxData[
 StyleBox["\<\"Expansion of RMS difference vs displacement in data points, \
with parabolic fit\"\>", "Subsection",
  StripOnInput->False]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8538362850216036`*^9, 3.854101458037591*^9, 3.8541019092820697`*^9, 
  3.8674062291319656`*^9, 3.8674077474607763`*^9, 3.867492274942798*^9},
 CellLabel->
  "During evaluation of \
In[231]:=",ExpressionUUID->"8bf7b661-5628-41b4-9c52-d0dff6078d9c"],

Cell[BoxData[
 GraphicsBox[{{{{}, {}, 
     TagBox[
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJwVlnk8VO/7xklRSKKNrGfmnJkxU0mTZMmllJJKDPWVSlOWshYiexIiSyuR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        "]]},
      Annotation[#, "Charting`Private`Tag$4899270#1"]& ]}, {}}, {{}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
      0.012833333333333334`], AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJxTTMoPSmViYGAQBWIQDQEf7DNebb4tcjbMASrgkJuy69NF5WAon8PhW7JU
2ukZ/lC+gMPOGTMEnaZ5QvkiDnM4NDlOu7tA+RIO9len7KvLsIfyZRzyeld9
FzhsDuUrOOy17p9ivdIQyldyWHPK8ASbmxaUr+LAUrE170mOCpSv5nC89Jj6
q3OKUL6Gg+Ep+cNh+UpQvpbDITGthak+alC+jsOb/xpvWON1oXw9h2NN6urZ
Z42hfAOHs3f33LYqt4LyDR0uaInmsgU6QvlGDgkJWZkTFNygfGOHLZkM+8UW
e0P5Jg4cn9Z4pb8IgPJNHf5MX3V5dUCIAwB5C1Rm
       "]]}, {
      {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
       0.012833333333333334`], AbsoluteThickness[1.6]}, {}}, {
      {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
       0.012833333333333334`], AbsoluteThickness[1.6]}, {}}}, {{}, {}}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{Automatic, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{All, {0, 100.32483789278866`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8538362850216036`*^9, 3.854101458037591*^9, 3.8541019092820697`*^9, 
  3.8674062291319656`*^9, 3.8674077474607763`*^9, 3.867492275056492*^9},
 CellLabel->
  "During evaluation of \
In[231]:=",ExpressionUUID->"35f44a8d-9a69-44b3-acd7-374c8eeea51b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Interpolated frequency shift with best match is \"\>", 
   "\[InvisibleSpace]", "1.9333216072060522`", 
   "\[InvisibleSpace]", "\<\" Hz\"\>"}],
  SequenceForm[
  "Interpolated frequency shift with best match is ", 1.9333216072060522`, 
   " Hz"],
  Editable->False]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8538362850216036`*^9, 3.854101458037591*^9, 3.8541019092820697`*^9, 
  3.8674062291319656`*^9, 3.8674077474607763`*^9, 3.867492275062477*^9},
 CellLabel->
  "During evaluation of \
In[231]:=",ExpressionUUID->"2e6bc8bc-886d-40e7-9469-55677a06dacf"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   StyleBox["\<\"Chemical shift = \"\>", "Subsection",
    StripOnInput->False], "\[InvisibleSpace]", 
   StyleBox["3.5537`", "Subsection",
    StripOnInput->False], "\[InvisibleSpace]", 
   StyleBox["\<\" ppm\"\>", "Subsection",
    StripOnInput->False]}],
  SequenceForm[
   Style["Chemical shift = ", "Subsection"], 
   Style[3.5537, "Subsection"], 
   Style[" ppm", "Subsection"]],
  Editable->False]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8538362850216036`*^9, 3.854101458037591*^9, 3.8541019092820697`*^9, 
  3.8674062291319656`*^9, 3.8674077474607763`*^9, 3.8674922755905933`*^9},
 CellLabel->
  "During evaluation of \
In[231]:=",ExpressionUUID->"ca52983f-fb29-44c4-b376-9547ab9b007c"],

Cell[BoxData["\<\"Variance and optimised shift and ratio:\"\>"], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8538362850216036`*^9, 3.854101458037591*^9, 3.8541019092820697`*^9, 
  3.8674062291319656`*^9, 3.8674077474607763`*^9, 3.8674923128935375`*^9},
 CellLabel->
  "During evaluation of \
In[231]:=",ExpressionUUID->"5749ed21-3de3-4031-b5ad-01938ec815e4"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"2.5612010415919193`", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"fdiff", "\[Rule]", 
      RowBox[{"-", "2"}]}], ",", 
     RowBox[{"fratio", "\[Rule]", "0.7`"}]}], "}"}]}], "}"}]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8538362850216036`*^9, 3.854101458037591*^9, 3.8541019092820697`*^9, 
  3.8674062291319656`*^9, 3.8674077474607763`*^9, 3.8674923128975267`*^9},
 CellLabel->
  "During evaluation of \
In[231]:=",ExpressionUUID->"52f2acb9-90e7-4495-b941-80be93598d9b"],

Cell[BoxData[
 StyleBox["\<\"Input data\"\>", "Subsection",
  StripOnInput->False]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8538362850216036`*^9, 3.854101458037591*^9, 3.8541019092820697`*^9, 
  3.8674062291319656`*^9, 3.8674077474607763`*^9, 3.867492312899521*^9},
 CellLabel->
  "During evaluation of \
In[231]:=",ExpressionUUID->"d179a8ed-9173-4cd4-aceb-633a426131a4"],

Cell[BoxData[
 GraphicsBox[{{}, {{{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJw9m3k81N/3x9FGKtqklaRSIe1K5VUiRSXZWkj2rGMf+9sMZsZQSov2iRZJ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       "]]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJw9m3lczc/3xy9Zkih79uwVJS1k7YVSEtoVxW1VWrXe9nu7ddckOyHZki0h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       "]]}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, {}, {}, {}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, {}, {}, {}}}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 919.}, {-0.0007184875, 2.075721725}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8538362850216036`*^9, 3.854101458037591*^9, 3.8541019092820697`*^9, 
  3.8674062291319656`*^9, 3.8674077474607763`*^9, 3.8674923129942675`*^9},
 CellLabel->
  "During evaluation of \
In[231]:=",ExpressionUUID->"b3b45ff3-d768-49f1-b6ea-76cbffb9a58e"],

Cell[BoxData[
 StyleBox["\<\"RMS difference vs displacement in data points\"\>", 
  "Subsection",
  StripOnInput->False]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8538362850216036`*^9, 3.854101458037591*^9, 3.8541019092820697`*^9, 
  3.8674062291319656`*^9, 3.8674077474607763`*^9, 3.867492313942269*^9},
 CellLabel->
  "During evaluation of \
In[231]:=",ExpressionUUID->"e116795c-e506-4c75-a741-6260104ef520"],

Cell[BoxData[
 GraphicsBox[{{}, {{{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJxE3XlcTG/7B/BkC0myRSGEJAlREj5IsiepyFJJu7RvWqZ92qdppmYqiUIS
kpCEkJQ1hCiEEEL29A2/+b26r3mef57X+3s65zrXue/rPuvcxtntMtshKyMj
M72vjMz//3/3/9oXJjg+DTIaGwf2H5AoU77cWGo5GJkt/LRMakUcvD1CfbnU
QzF9j07T/6wM993Ny1ZIrQqdqW13/mc1lMT893Wl1OPxyLm+3xqp1SGvdHrA
Oqknoea4foS51Bo45OJZaSm1JhbzvfU3Sa0FXcNTp6yl1sZKXbHDZql1MPGJ
cfX/PAP+qa0+W6SeiRlTEzu3Sj0L1p+cObZS62KqvMMxe6lnY9LT2PuOUs8B
VpgsdZFaD04D/5a4Sq2PG+pDFrhJPRe/2/rb/M8G2PztxMX/eR6u99so4y61
IezWOUV5SD0fpvcm6vpIvQCT7i70D5B6IdYZyuwOlhrwVlDdG0bmSGwy8UK4
dPkivK2u14iULl+EjX8+uUZJly9GoaWZYox0+WI4f/Jz4UqXL0GFPS8gQbp8
Cd6r7WxMli43wuHsCTJ86XIjbJ7QvksgXb4UaqWag9Oly5dC59Bg7QzpcmN0
1hivFkmXG2NrUWPPTOnyZZgzX3ArW7p8GfqIuc250uUm2BY5asBB6XITvOwa
WX1Eunw59PstCT8hXb4cB1pr209Ll6+Afez5sRXS5Stw0mDQ8kvS5StRcjA9
r1q6fCU0OuoMb0qXr8LQj7Vv70qXr0J2styaR9Llq6Ewa4JWk3T5aswZWpbe
LF2+BpPsFfu/li5fg5TZK2e8ly5fC6tip6R26fK1WFU+cUqHdLkpLDLL3WXU
mGGKl8/7z5Mjc0xR59i1SoFcaYr8o2c+DibLrAP2GW4bIl1/Hd4X36mQmrMO
9ot3+gyVrr8O4x6/Oj9cur4ZRLVVc1Wk65vhGTfs6Djp+maQ0Y/u1JCub4Zs
04fJ06Xrr8dvy6Y5utL11yMh7UTVHOn662Hevm+ovnT99dDQ6xU+V7q+Od7s
9plhKF3fHFFB1hmQrm+OMg8rPWPp+uZ4+eR+/Urp+hvgIhssYypdfwOS91hd
XyddfwP8F7XrSF25AS8KNYasla5vAbusLedWSde3gJnmYGPp9jkWKFuxVkPq
SguEbs0dIP17GUvsHOaptFq6viUm88q2Ss2xRNO0/GTp31dawmDokvYV0vWt
ILK8b7Fcur4Vhj35nGciXd8Kp84pL5Aur7RCG29P7f/W3wgdtzPW/9v/jViA
Yf3+F38jfJrfe/4v/kYY99OT+d/x24TNeY+q/hd/E5YVfPkjNWcTrHqInf63
/ibIZGaUSI+3jDV+Fhr7bZCub43vSg8arKTrWyNORcNho3R9a7gL9x60kK6/
GZZ2Mguk7YPN0DPIOi7Nj7MZmzN4L42k628GZ42O7yLp+ltQqLFJWWpsQcfJ
e+uWSNffgtyJT+v/13+2oMZzl8H/jt9W9A0deOR/x28rulbJaKyRrr8V7V0e
ttL+UrkVB5f0/N/+ymyD17eSjebS9bfh+ufKS//Lfxt2xEzrv1W6/jZUNo3J
2y5d3wafNL/PdSar2WD4oMcd7tLt2WD9Kcc4X7KNDdzmtjwIkW7fBokHFQq4
5Fwb7H+sZZMujWeDjKuP2g+Sm22gellmZLk0vi1OT9M5dkca3xaWFRo33krj
20Ljb9lD2XEU3xYtbzS9x5E5tjhkr+xtRM61Ra7dt3du5EpbNGw6bJFNbraF
Q9ui6/VkGTvUzbjcrDye4tthWEWKrysZdgjtp6h5h2xjB/9vTnLGEyi+HRSM
D+beJefaQWwpvO+tTvHtYLakbrTORIpvh209+jXKT6L42zF7a97zIZMp/na8
zXTvWKdB8bdj1Na3qx5Mofjb8XX8G90jUyn+dng07hM/m0bxt+NEz4a//joU
fzv0eX3iwmZR/O24ELhkmIwexbfHagXj1H7zKL49/DIn1hUvpPj2uGB+V0V+
KcW3R/LWF+unraT49ohONu5UMaP49hg175nBvY0U3x4VoxR/L7Cj+PbIzFu2
aZUrxd+BW39W7nnrQ/F3YKfihAl9wij+Dsxx7v0pP47i70DDwPK0ywKKvwPm
Fc+XW+RS/B2wmvFuiUkRxd8Bl0uDXHeVUXxJPFPOsvQqiu+AnbK/fKPrKL4D
ev+aPXVQE8V3QOnKr2+Gv6X4DhBnG5/hf6H4DrA/4Xk05j+K74CmjQM8/vSK
Z/Ed8FT92uYeCszNDtDy/HpWNJxZxhHp3K03r45hVnNEffXYb3GTmOGIPjnc
+nfTmG0c8dxdmNquy8xxhL324ZvF85hzHbGzcuDuJYspviM+Dh9rdtWE4jvC
Zs281vVrKb4TCgYEOg2woPhOqArdj95bKL4TrqmOOmlpT/GdoFMofDrMjeI7
oUyQf2KtD8V3wtdpa+MHh1B8J+SmWG/bHkPxnaA99kLTMh7Fd0ZR3v3yc5kU
3xna+gOTTh2g+M6IcazvmniC4jtj6pq/Bh0VFN8Zns+v+SvVUnxn3Ow7cJvF
A4rvjGXDtav3vaD4zigR1lTd+UjxXaCQtml9+W+K74IBu56YG/ZOYPFdIOo/
pHaWIrONC9as3vs8chQzxwUFFYalw9WZc10w/9/apGdazJUuMNvV0/uhLnOz
C16/X/axhyGzjCtudmpfcV3MrOYK40MlNyaYUHxXLG/BNMPVFN8VspsFhdXr
KL4r0kdlHb63geK7ImxwoafbRorvCvO41WV7NlN8V3Q07lHZtY3iu2FlQWrt
O1uK74aHvBCusj3Fd8PkOYmH+jpQfDfcn7m69YojxXeDd/LMFitniu+GqX97
5N5xofhu0E49/n6aG8V3w7243k/9dlL8nXBboLStyJ3i74RDZ+S4u7so/k4o
Osyc/96D4u/EZ/nn9f88Kf5OCJZvjVH1pvg7EbhBrXWlD8XfiYI5F4UiX4q/
ExULpvj096f47rity318IIDiu2PY+EJZtyCK747mPXuLNwdTfHfITpk7OyCU
4rvjtJn+30oOxXeHzOBVP+dFUnx3KE9envc5muK7w/6F5a6XXIq/Cws59feV
Eyn+LpQMnKkkSKH4u6B4quL+ujSKvwvvo/XSV2VQ/F24/rM6ODiL4u/C2gkB
Kg17Kf4uiNpSh27Ip/i7sFVd8VBrAcX3gFyfT7bco8yKHtj6WqX31BLaHw9w
O5utak8z63jA3UHx8NZztH8eGF5+r6L1IrOpB66+Twt1rKL99UCMUeaNphpm
Dw/84vVuXHWL9t8DiotPL714l5nngcc7AzXxkPLxgNj1cETzE+ZiD4yq33ip
9Dnl54HAc7Os77Yw13nggkVw2dL3lK8Hnm0fMHZEO3O7B5QLal/M/0n5eyKm
sOTlwS7K3xML/jTUzO2ZyPL3hOwYYf2Lfsw6nkg/48ITKjLDExVqeh0bRzCb
eqJWobBq4RhmG0+0lKZ3WE9k9vBEyf7muAtazBxP3LOWueaiy8zzRGTTgWvm
hsy5nniyc6jdDiPmYk/UT9isErmKudITY0Yf+51lzlzniYF5z2uPbGZu9gT/
3LjgCnvmdsn637dPf+HGLOOFJjWrAm1fZkUv8C/5Z5eGUP5esC3fFRUUQ/l7
4fLhrBZOCuXvBYH3vqqrIsrfC89VVoYu30/5e0FmssZfxSLK3wurBmTJqJ+m
/L0w2mH8o9hKyt8LGqOC7+vfoPy9kHNnSs+JDyl/L1ywT12r+YLy94KqRl6B
chvl74UhJ0PNzvyk/L2w/8yD2BsySSx/Lwx30Lg0pj+zjDe+FvzJj1RiVvSG
4kaNFY9HMqt5o9Hs9j55NWYdbyzw2nxjxERmeKONI6/zT4PZ1BurkvUbb05l
tvHGWV3NHQnTmD28ITo5aftibWaON069bhn/k5bzvJFTF7n0iBZzrjc8CuQ7
3DSZi71RF9Gv02wyc6U39uu4W0ZNYK7zxmWLB790xzI3e8Ot2WVpzijK3xta
wc8W/BhG+fsg/0zqXtvBlL8PXpbavv4tT/n7YNX47xbVcpS/D/qGb/lU24vy
94GIu++EfA/K3wdGBQXV+/5Q+/tgh95orwOd1P4+UHr/Z8qsDmp/H7St79th
Se3F88Gj7a9r+/6g9vfBd+WXl1W+U/v7YLX1jOPW36j9fZB7yOVN8ldqfx8Y
RLQdT/xC7e8Dh/nzxEbt1P994BR1re7cJ+r/vljQmbxc9iP1f19op0R8nPiB
+r8v7JZxlmm+o/7vi9C4o6vl3lL/98XQ366Zp1qo//tCp35lmPZLyt8Xbhuf
TQx5Tvn7YuD15B7lTZS/L66WlO/t/YTy90W5Yo5a2CPK3xcmMz70NnxA+fvi
wtn+a5fep/x90Wf2kflZdyl/X1zq1Sdifh3l7wsXQWbbzDuUv2R7Z/89T7hN
+fthgdWxmC1kRT+0La7OPUNW84N6/fxTYlpfxw+Gey9u/Ejbhx8Od7quj7tH
+fsh4Ojzr4b1lL8fNu1fF/CM9t/DDx78lgMbKD+OH1S2uo7NaaD8/XCkbU3b
pceUvx+uDSuZVUfHp9gPli8a8aCR8veTXH8OnfuIjmedH4a/sPj96Cnl74fv
ywY9evyM8veDxtmixlfUHjL+CO2M+CdL44miP5zdVg8zofZT88eyB7zvV15R
/v448zjle+Rryt8fW/Wr5XnUH0z9cdTD6MJ76i82/rDJn9+bT+OThz9c1s+w
4Xym/P2hsP2qzVHqvzx/aKnPqB9I9ZDrD8UlTz+k/ab8/TFwavLV6VRflf5Y
+mSIYx2Nb3X+iA4J+2RP9dnsD8HzIylP+1L9S5Z//jNQawDVfwCSD4wpWKJA
9R8AlcTxZ5VpPFALwOaRLrtzh1D9B0DmsbHJXRo/EID8sqfb8kZQ/QdgXERU
42AaP20CMLdZNFuFxh+PAGxaWfe7kswJQIuSmNdHhca/AHhuPef0mZbnBsBS
bbNMCLk4AO/M7yYcpe1XBmDa86qfu5Up/wDM9pC1eTGc8g+Ay+xleDSU8g+A
/oYd/6xovJcJxKouCz37QZR/IHJ6bTj3i46PWiAmLTz/ZbB0/AuEvYH/pOM9
Kf9ALHK3jq35S+0fiAhVeXtzai+bQHAO2lxeRuOVRyDqtxwUiKg/cAIxxPNM
1ELqT7xAxFvpifWp/+YGwtyk34EIqqfiQHxytVAYQ+fHykBUTol7POAS9f9A
TCkdcm81nV+bAzHU9Ojft4XU/wNheFBN+DKH+n8QZHUXD1zJp/4fhCdCnuGs
aOr/Qdi138v1mD/1/yD0jpqVccuZ+n8QrIqy32ZbU/5BMPC2G6a+mvIPgn7b
xRbnBZR/EDJXKF0OmE75B+Hvv/IAWzXKPwhVggE1cwdT/kEoz55TP1yW8g+C
2YdNj3p/o+u/IMwwf3Clj/T6Lwg3/n19PeABXf9J4r8f1e/fVbr+C4JNj/og
6fWszG6sEbanbjpE13+70VD11+YwXV+r7cazUCXTE7F0/bsbJadnRLjR/QN2
48GRv8vq6P7IdDciZo04fpvux2x2I/rqILUtRnT9uxsaJ7oqg2fS9e9uCN1H
yUCNrn93I9e234DrA+n6dzda5tn0M/mP3Z8W74acS+zbN610f7sbWrXbRlx/
yFy3G6UKuz37XqX73d1YFHJpQeFJ5vbdaJM93KNiP93/BkN10UvuGj6zYjCe
1B4bEBFB98PB0LefIR/lzawTjK1PnyyL3UH358Ho4rusL7NiNg2G9pZLc3VX
0/16MAqiEo/2XsLsEYxt6XIDNQ3o/j0YL5rOjs6aycwLxnNHi/2WWnQ/H4z/
LE+Ld0ym/IOhUD497+YEyj8YhRER4QnjKP9g5O3bmZGsRvkHo7gz/m8RuT0Y
n7Q27DxGfy8TglU5t2da0vYUQ1BvVa7oM5HyD8FHz8OfnlN8nRAonp7bJ1yT
8g+BTP2sRwvp+YxpCMplDPBnOuUfAm/9cXpJlJ9HCKqmefY6K31+E4IxU7mv
l82h/EOwwOfnyX56lH8IAi2CA57R8uIQvJ18p/PMbMo/BJUnLj0QzqL8Q7Di
bfLUMB3KPwQ8Gf3kEDqe7SFYcnLEyizKRyYUm+ZFqbym46EYCrVMnZ07VSj/
UKR8G9u8ZijlHwrjXTW2RfKUfyi+VLY+PkbPu0xDcTphx4nwLnpeForposmf
1n5n9giFnHnn6CVt9PwsFOP6fpgX1cLMC0X7mZxD85/S87RQmLu/Opr9kLk4
FMUi6+V36XldZSi+v/BKGHCTuU6yfvGoEf419LwvFDEBPx/MrmZuDwWq01dY
X6Xnf2FYfHtLyjuyYhishfob667R88AwzDwyk//xOrNOGMwnvrmjcIeeD4bB
eEae/rf7zKZh0LMInbDmMeUfBqsrQQY3nlH+Yfhqvj5/KOXLCcMFU98zT1op
/zAcrnXhN9LxyQ3DpqPm0a2fKf8wcGf7tryl54+VYbhR+X35/a+Uv2R/Ylxy
TpKbw7Dx+rhb2fT37WEIjPDKL6TtyXDQODHE8R/Fk+NAWdY4/so7Oh4cGGk5
hEx8w6zMwfh9mqlWL+n4cHCkYFM+n/LT4KCmc3Dffo10vDi406PS+OMjZn3J
9vrwQl0e0PHjwLrDPzGPjp8JB1V+CzaX3KPjycF9y4JlBWQrDlbfyFySQn9v
w4H6x32WrrQ9Jw60+lg2zGug481BV/MyxS7anwBJ/I0/FuY10/HnoP+YsUrq
lB+Xg+s6VQ9d6XjwOJg032ag3TdmEQfe1qr3WzupfTiS6yHbsGeyrP8XcDDw
Vr2O2gCqVw4qAmZlJA5hLuMgf422Vh9Vql8OviqcX+2jzlzDwarW/SOuUL3W
SfK7+XLxSxovGjgQbVuYd8WQ6puDiSY2/zYaMbdy0Iz5T0Qrqd45sHuQYepr
xtzBQY/RTdlvabyWCYfp4dsBbVuZ5cIR0btoTzQ971UMxz2PfTJnnZmVw1H8
qP5psjuND+FIbk/tNYjODxrhyPVYOXiBP40X4dhdes5cZTezfjheluvK5obS
+BGOoIVpTRfDmU0kf//m4xDXKBpPJPtz3ySTR8+PrcKRUxY1Ro1L42s4Xl38
qzYgjtkpHLaR9X2Wkj3CoTS6z87L9PcB4Tg8Z/yEgFgaf8PRnlE/fVM0Mzcc
Y83fTLem8x8vHJx1CqvdaH9F4Rj+r7Y1JJDG53AoO4bWcyj/gnA8HDEzx5Ge
jxeHw2qjot5kOp5l4egsSZp5ehO1fzh4xltn9Tel9g+H/7UR9UOoPevCcX2v
0Kycxv+GcBjqKfZ5TON3syS/cLskjKD2D0drZd+NFTQet4djZv7TBSrtrL92
hMOmv/4ifRqfZCLw82hAokwl1X8Evvc+0eaTT/UfgZDEg7cPxlD9R+Djoi/O
JQ5U/xGQ9fYKLjOi+o+A/DP5jsf0/k4nAoJ2eTW9/7jd1o/A7vc3FL/eZ0YE
dj5LGzrrCLNJBEp+jjXTCmc2jUDuB83CURbMVhGI7OtQu1iT2SYCDzSnt73/
E9ttpwjYeOxQXH+X2SMC41RX9DmWzxwQgfOhm0+NDmDmRMC+4ceNkyuZuRHw
3TZ6nt9YZl4E/NR0p+74FtNtUQTy/pW6h11jzo3AflPfuVeymAsisKdX3X5N
D+biCDjz5vocMGIukxyfzTGLhoxkroxATOauGYs+Rne7JgKm5zTrP1Yy10Vg
nc4n2ftpzA0ReFP140/JDubmCKhnaayzn8PcGgGF7F1hDb2Z2yV/n/zuikp9
VLc7ImAWUNZr7T5mmUh0To/ovXcns1wkIm7sCDecy6wYiTGrKmZZ9WJWjoT3
5Sg99TuR3VaLhNbNNc8fi5k1InFp4+jBl+yZdSJh5pzuMluHWT8Sp+9wPA52
RXQbkdg7O2cM/zqziST+4+3quzOZTSPRLDzi9NSN2SoSbQ8OyasvZraJxLap
317ljWJ2isSmtEN3s36Gd9sjEmGDy1/NfcgcEAnFT4Wn951l5kQi75TB+PZc
Zm4kftefvDg3kZkXCX7d/D1Ru5lFkZgZMlKp0p05NxJ+y4sGXtzBXBCJ0Ddb
9urbMBdHonbL54t3tjCXRSJ+WvXtsVuZKyNxPUf7XQ39fU0kHLf+PeZP26uL
hMLuN2feuDI3RGKD89bBjd7MzZH4mGvcNSaEuTUSJ2MNl4fGMrdHIv+Yr201
n7kjEne+/flYm8MsE4X7PT+PdTjCLBcFg7GlT2PKmBWjcHX27QeTq5mVo7DE
ZVZfs3pmtSg0Bp6pHf6KWSMK6Z48w/ivzDpR0BCaT74oy9pHPwqR578XXR3C
jCh4P6mvLZrIbBKFYP3nw6P1mU2joKvjkW63itkqCl7HDJqsbZltouD29IRx
jD+zUxQc7waHtScze0ShKHary55DzAFRSDEtLQu/xMyJwqLiQ/bRTczcKIzh
vj7C7WDmRaG9p0OSyzDWf0VRKDxfN0dhFnNuFGZM3x2xZR1zQRQ2XRuraeLB
XByFc64FxytTmMuiMPaizIGy48yVUWg2Ed8aXcdcEwX5So3PDe3MdVHINmq0
vT2Y1V9DFEp4jXefz2RujkLfARqmn9Yzt0ZBZ/qmh40+zO1RUJ335EyCkOo/
Cj2MZ/97cYrqPxpKb6ZOv/yA6j8avebdU1L4QfUfjYK8HpMPDGHjiXI07EcN
qLOfwawWjRZV1flT1jBrREOkYl9825lZJxrlwwa2zIxi1o/GAZ1Wizl7mBGN
oOJ/28+XMptEY8zeN6NPXGc2lawvV/Hp3zNmq2gYejh+3fOF2SYao74rfYmS
ZeOpUzT+jWp/fXIws0c0csfNGKs9ljkgGke23ZvcqcnMiUbAol+n1WYzc6Px
8cypu0fmM/OiMSlfrH2Qxm9RNHZNFVWPWkHjfzQUVrZvG7qGxv9ofB0+8Um2
KY3/0bj5b6JGxToa/6Nx2jBygj9ZMs6nmL9Ivr2WuSYaaqOVRRdWMddJ8t1X
8GeBCXNDNC6HP69cspi5WXIckjD+ggFzazTcrqhm7JnB3B6Nz79fhdRNYu6I
Bu9qWbzRKGaZGHi9Ozzy7QBmuRjEz2o7dOA/dnwVY3BNtWmf+ztq/xgYuC2P
nPmA2j8Ghj/XqLy+QO0fg+uL40+GHqT2j4FHz98fuxKo/WMgaL27fvsuav8Y
yCmVHTlnSu0fg4rYIxOH61D7x+CT5tslcQOp/WNw8MT5+TPesf5pE4PXvQpS
ta8wO8Vg2dzKY3lZzJLzsFneqgElXswBMajaft7P34SZE4OvB/QPy49m5kr2
p/Xb+WiqP14Mhs9XdP9+meo/Bv1WO313EVD9x6AhclCPv3S+K4hBYh832ypd
qv8YRBRvfHO/J9V/DALivy4zvBfR7UpJPkFbmnrkMtfEgBu7cveoncx1Mbgz
rNdu97nMDTGwOlyJZ72Ym2PwdovqixV3aPyPwWb9m9U5Ihr/Y9C4W3/OfTq/
dMTgb9S+T+2TafyPxcvLKRvlP3G6LReLCQPKYhaeZFaMxfhPSffy/ZmVY9Hz
j9DbfB6zWiwUP1itvtEV1m2NWMzlXH/WEs6sEwtd5bWL9fow68difXtw6LD4
0G4jFhF/Iy80D2Q2icXQS13//U0N6bZpLOR+foq5M5zZKhY6R/3j92cHd9sm
Fn6H7u4+M4HZKRaVljv0lhTt7rZHLFQ2Pi4JmsMsue5Tvl7mn305qNucWAQ5
bJ3/zZSZG4uSkpLZd14EdpsXi9SA2bYBvsyiWGw4uXykmjxzbixWOjeMfnwg
oNsFsdi849qArMXMxbEYbPTqvelL/26XxaLApOByWxRzZSw+BtlN9tdkronF
Cg211CH3/bpdJ7kONZAf3BHK3BCLqBtTlLZoMzfHInjel39uL3y73RqL9iNX
nxqImNtjUf3wp/oVM+aOWOwT/fL/ocgsw8WXJ0ufXLrn0205LtKf2/0cL2JW
5IL3euH0cbbMylz4XJpne3sasxoXYXtnnZv/17vbGlxoGp9WDr7HrMOFUuPR
9oRCZn0u7t42KdgRwwwuCl8fMfpvB7MJFyieu2f+cmZTLipNshaN02G24sLz
8M8P+0Yx23BRlFesWiXH7MTFs7GZcsJOr257cOF9qF13SjtzABd8wbIRme+Y
OVy893zQv+dbZi4XR6bN6xXayszjwmiKPU/tE7OIi8SwnMO/fzHncjFBQa1A
sQ+LX8DF5RGfVXcoMxdzcUY/6McnbeYyLv5ztx6WQ/lVSuJfENVaOTHXcLFY
J0j5dzxzHRcOhnYXl59gbuBCbZbLvF6NzM1cRH7+pn63L2uPVi5kE7Y4rdRj
budizD2LB72dmTu4KD1TlZ6azSwTh98ThzyMvEvtH4cvB64ZB/Zl/UMxDjuP
vd8+YgGzchxGjVuzSN6XWXKfpzn2lrtCEbNGHEy5TSbPXjLrxMFIvlxv+UjW
X/XjcEHYOVp7LTPiUPUrbXZ4FLNJHBJLNySsPstsGgfjYWrLTn5ktorDL60h
S1+NY/ViE4dnMuctR1owO8Xh4L5Fh9LjmT3i4B0wYfWei8wBkv0fNOPIzh/M
nDjcND2hsFSL1Ss3DrDN27bZnpkXh/JPu4Wv9zCLJPE8p/H7PmbOjcNxm+ET
Hw9j40FBHAysR/E3mzMXx6Fii+uHYAFzWRwEY5LkFR4yS+677S98mn5HmY0/
NXHIUboycddm5ro4hH71PsnLZW6Ig8O93zK3W5ib4/A20v5luQYb31rjoGKQ
EfPGlVly35/y79qKp0eZO+JQr+q3euonZpl4dB3xlbHRYuOnXDxU06LdlJyY
FeOhuWyb5etcZuV4/O3c4xn/kFktHrEBRpOr5Nj4rBEPtXlyMxz0mHXisb3B
R3eDHbN+PNr2FB+PjmNGPH7y15l1FjGbxKPxe1b1pZs0/sdj+fXedd9aafyP
x+aG8NKjPdj5wiYe//r/t1BhBLNTPHwH/FWYOYXZIx5KvKG3dPSZA+KRPKLm
iIoRMycem3r5Puxaxfz/z4lUY9Y9MmPmxSP679S9Bzcwi+Kx733x2S3k3HhE
Och5v17HXBCPJHu9J6NWMhfHo3xHOPc2mMviMXNbm8/VmcyV8ehcWbf2nBpz
TTxivBNv7+jPXBePcSW3/vh/Zvk3xCNhsu2F/DvMzfEw7XH9195C5tZ4HNR+
UjiGw9wejzlfOvc9XMvcEY/6e79Ph45klklA70cqdnVN1P4J+PBONT9eTO2f
gK05hcW+a6n9E6BslrnV4S/rP2oJWG2nF4iDzBoJaNL7w/1lzKyTgN0vopcn
N7P+qp8ArQ2OIcO8mZGA8rPjfhf+ZfVgkoCwN0kpgZHMpgkImlCrWt6D2SoB
905W7DgVyOrPJgE1U68rVn+g+k+Ai/fGuo1WVP8JmC83q++Xi2z8CEiAEpSy
VCcwcxKwRiZaNSiCjVfcBHQ8eVV97BkbD3kJsDs2Ut1On1mUgOecsuVzeWz8
zU1AYR/tsPtv2PmgQLI/R/wTawyZixNwduUjrQK+Z7fLErA/QFnwu9Wj25UJ
MA7htcwFc00CbmcrXTwxY1e36xKQ/drsnOObnd1uSMDvsCQltb1u3W5OQLWD
74ypm1273ZqAvUUX3meNdul2ewJcdeaMX/XKqdsdkuP3esyhd0WO3ZZJhHrw
2klyQQ7dlkuE2edDFrNW7Oi2YiJ+Ko2/3qVq323lRIhrp0/s+dWu22qJWDW2
8P23GttuayRC9ktjR8I+m27rJCLnwojjer+2dls/EVEpNo8mHdvcbSTiwhnj
v1OcNnXbJBHJV3+kD59k1W3TRJjMK/nr925Dt60ScaPv2I3i0vXdtklE66e5
TpHx67rtlAjTrLyxe5+u6bZHIvL3WGn/vb6i2wGJ0OEtz8h9bdxtTiI+9XoR
tGzOkm5zE5F995Tt7YSF3eYl4n5Dro/lvLndFiWCd6NC/X3SrG7nJqKz4u/a
Eq1p3S5IxIMBvbrSbql3uzgRnOh3PSMWqHa7LBHjHyntsQpU6nZlIiIGjtP+
r0Wu2zWJSPha2WER0qvbdYmwPXtn+Y4rfbvdkIiT7YMMbq4d3O3mRCg/WOim
7zGq262J6FIvLHuSMqHb7ZLjH7y/fKB4arc7EvGdN45TmT2z25Kbx5XZIW0B
U/S7LZcEwVkr7LFd0G3FJCg07SnQFy/utnISHhq/9B1oxI6fWhLsfc/lzZrM
jq+GZLn8txMP9Nnx10nC0PUDPrXosfbRT0L+lSk2n21Z+yEJjq4dpbIZrH1N
krD83Xy56fWW3TZNgpOjfcLIEax/WCWh2lN2+s8trP/YJCHirZ855xDrX05J
SPUqawwMZP3PIwmaM6Ycks1l/TMgCfOuTR2w85pdtzlJUMm5t67r8/Zuc5Pg
dqfs+MhRrP/zkjBm84vhxsasPkRJkuNXrd/fl9VPbhI2z0xa9+Ygq6+CJOh2
zvu3uMm528VJeCC6HGk/jNVnWRICjn6AnRmr38okVFiUvZuQxuq7JglqOmmG
9o/cu12XBG5Cj1jrQWx8aEiCXlnn5WWlzM1JyBmZN2L8Jja+tEr2f//ZnlwZ
Nv60J2GG7YhsuUPMHUmoXbbg1ITVbPySScYhT5mVK74yyyXDeF1j4AshXf8n
w8ZztqmJHl3/JSNZts7g+QO6/ktG9Z+IjwqebDzVSIaRx5r/Vsmx8VcnGUM/
nrcdncWsn4xsi79bBk9h4zeSEaxac77qBLNJMqwaz4U06tL4n4wLMSX+PUpo
/E/G3v5JZ9s02PnDJhkbdwp32IqZnZLRQ3bkP92edP+XjLsD8+zXOtD9XzIK
09w+FFxm5kjcaGpirMzOb9xk3MxqfTnLkZmXDL2bQ7IjjjOLkjHo4sKQZV+Y
c5OxuGj2rBwtdj4tSMamMweOFtkyF0v2z2FB3QEec1ky9o9Wrq49y1yZjJdp
fznbnzLXSI532onvV/5jrkvGkieexYbD2PVAQzLGWnLaVDSZm5Px4HGVxhED
5tZkxHyYcmj6Mub2ZNRELVT8sJa5IxlnT7ePVqHrF5kUHC5S0OywYJZLQYPv
pdcltFwxBZwdaoWedH2jnIJ6Wbnta1Ywq6XANPajqwVd32ikYKWd4fPEWcw6
KfCyTrT6NIFZPwXD6y7G+gym+/8UqMVp5St30fVfCiqar9ysf0XXfyl4Frrx
Tn4NXf+l4J/b7WcxdL1jI9nfS/Oqgul60ikFltrrHiXtYPaQxNdb7FK7gDkg
Bc35A1+YDGPmpOBn+6ImnXfU/imYJHvK9UQ5tX8K3Hc/F/aOp/ZPQf7drxFe
ltT+KciZE+hmTM8fClKgGNx33KOPrH8Vp0DLYufesDPMZSnQ/F1kn81hrpRs
f+QZccxy5poUhJz61JKsxFwn2Z+brx52NNL1v8SPz9/8dYCu/1OQ+ia1/qgH
c2sK7lRfCtAyZG5PwbIDfYL85Jg7UiDw2q4Z/oDVkwwPDqttrurmMffiIWC8
h46bJ7McD22Tbwz9sZBZnodcz50zUhWYFXkotzvI+93E6ncoD35eMW9eFTIr
83Avh7OtXwCzKg+XfmkPmGbErMZDPiz6qA1iVufhsplF0+UGNl5o8PBxgsmY
3vuYtXj4ohd0vMWRxhce3Gbp1O2cxqzLQ6XKsAUVX+h+k4eKp3/G/yllNuTh
yQyd9x7+dP/JA+f+66Ouc5mNeHC59HjG+v/Y+GbCwzov+8WZ55lX8aC554pJ
OYfZVHJ8tGWDtZYym0v2L3uyuv0AZivJ8Ul1fnv9PhtPN0vWH3xs3sUcZhse
ZN86rBG4MdvzYGO90oc/n9mJhx5burx+DWZ242EU96vlz3dsvPbgwWiOUdPp
q8w+PLTv/E9kfoA5gIdf+Ye5z7jMwZL2Vnq/3tKDmcNDmsGtI6etmaN4eDF4
w/EPK5i5PCz50X9W83zmRB7i418UBOsy83jQKdiOInq+IeBhjaf6URstZhEP
x7RNvgimMWfzsGOc2ZE1M+n6mYcJH/9V7DFgzufBNSGWn2lMz1N42F5gVrjd
grlI0r79+qqouNDzFUn7TQs83xLOXMrD667wza/30PMWHvqU32hYfIG5goeR
q9uOqL+i5y88zFCe/vukPDu+VTwMttrEHTWPuYaHA40TLDjuzDd5OD6pnNf3
EHMdD2ZzfTWutTDX8zDJfM+3qsms/Rt4ULg0ZceXXcxNPMRMezdwMvWnZh62
jtg0avog1v9aJP19uqbm9R3MrTwsPjWyvbySuU1ST8ly3NtjWX9v5yHORn3j
swjm7zy8fDnqcO075g7J3w+7td3ZnNVXFw+nJr/3jLrMLJOKa7PS7G/MovpP
BXd/wPVnh6j+U8Ez+Ge/dQwbP+RT8XLYjGX/pTMrpiLiiemk6MFsvBqaCmWO
iU9bErNyKsyU5m7Qk2fjo2oqZjWqntuZSM8PUqHyX15wtAIbj9Ul67/R+GPB
p+cJqZj7qF01h+7vtVKRfm523945dH5JxZacnmdnTmTPl3VTUXl+18+HRfS8
ORX1VYdfW45iz6sNU7Gr5cmfJVuZkYrM8e/MlPczG6Uiu8/t1orXzCapCJn/
t2D4FPa8fFUqGtb1u9rHjdlUsv8dvWpcjzGbp2JgtrLnhHZmK8nxTCvfIj8j
otubU6F4tvl5H09mG8n+/Vf28PtxZvtU9BlmdLfsI7NTKlr/bOk/W5O9P3BL
xcmQlfUrdjB7pGJxwc47T3KYfVIxe6f45dWHzAGpEG+XS/0kz95vBKeiXGvC
eINF9P4jFTffjNdN9WaOSsUJjYCC53n0PiQVfAXZ6UPvMSemYtheYdPYv8y8
VOSOGD3+52T2fkaQih0nwvSS1jKLUnGpPOjaMx/m7FQU3y4Nbs1gzpW0h/C2
QlEZc34q9KeO5Gk/Yi5IxZebN3/5fWMuSsV473XaiQPp/Zpke173JnlPZC5N
ReHVfuXT5tH7Nkl7vjj9vJzez1Wkoq5gSLiyDb1/S8W89ImRxruYq1LR/6qr
8opgeh+Xip+aAVo6scw3UxEZKvN7II/ez6XCtOWg97905vpUWCnq9VfPpvd1
ku3He13M3MvclIpJcaZfQvfR+zvJ9vesrXhDbkmF8ZPyma9y6X1eKno7Jd8N
z2FuS8XQ2flTb2fS+71U+G/9dP+ekPl7KgoW7pIRp9D7vlQkrw/9PonL3JWK
p1XXboaE0fs/PtSre+Rm+DL34qP29aGnDi70PpCPk7/btz7awizPB76E/FdH
7ysV+QiysvnPAMxD+cgftybjnzazMh95R9sqFVSZVfloCl0k3NaXWY2P/aPy
9drbWfuq81H256ZjVQO9T+RjX63j8Vf0flGLD7tpJzSs8uj9Ih833odFaccw
6/KxYnqQmb8jvW+ULD+34ZfJMmZDPryPerlemkjvH/mYd2jBxz49mY34OFXE
WbTsOevfJnz0X/lf+aly5lV8OO3cXsml9+mmfBh4auT/2sVszkfjxPvmc1cw
W/GhE7itLVKdeTMfPuPCK+T/sfq04WPUHXszuSfM9pL8Vdb0LzzF7MSH3JAV
fSfwqf752Pk1UJi7i+qfj4BXBqNWrKH65+P6uZV3FmhT/UuWi/YfSBvEHMzH
iPrj9eu+RnSbw4fZpplH/B4yR/Exxr3/sB/nmLl8GO6Y9qFsP3MiH/J2vfYe
iWfm8bEkdOPys97MAj6iep45WL+FWcTHhawfaztMmLP52FGWLqM+mzmXD01F
s1UW45nz+YioqpoerchcwEero3Zv8T82nhbxUV5ume72mb6v4ePD/i9X7j1n
LpXsv2rUj7119L0NH/4ndHVLLzFXSPrfyGKu7En6/oaPap+Fr/j5zFV8dD2b
fzkknb7H4UOhdPaeV1zmm3zURF9b2kLfA9XxYbGml1XmLuZ6Ptbkmfqo2tP3
Onw0/zXojNjI3CRpv/WR/T6vpe93JP1j0MulKcuYW/jITPP/sxf0PpcPmd6T
nBzmMbfx0cdZWXaKPr3f5WPo3Fs7NPSYv/Nxq2jUySxa3sFH3c6BRScMmbv4
yF6SvVG4hN7/pmHmIjsn79XMvdKw2Gm2esgm+h4oDfxz35TeujDLp2G69hrt
V6H0fZBkff74IyI6XkPTwBv3XV21hL4XSsPGV9q7Xe4yq6YhZvzwpY7f6fsh
SbySDrtn9P2WehoOri0Vxhoxa6Shj91s9QF0vtRKw5mL1rJ96X25ThouCAaP
H3qXWTcNAyZmed6g9+36abg87c+lWj1mwzRMeu565YQbM9LgIrhcPXU/s1Ea
XnYZfXr1iNkkDWGvbOy5A6n+03AgeuPW2sVU/2n4W/Cjzdqf6l+yv2GKlv8K
qf7TYGg6KTLyKdV/GtyNO4fdVqDvV9JQ+eRYSeMCZvs0aJk71Z7byeyUhvzl
nVWxWcxuabBc9WrYxhpmjzQY6zgfWvyd2ScNJo6L7phKv3dJw7y1J4Upy5mD
0xCi//T9EG/6/kXSfvJJLrJ0vopKg//sIeeSq+h7mDTsuXvy3Zc25kRJvtUC
Deth9H1kGgr7yrx9MZ9ZkIa0VU+Phjkwi9Iw8uXCxiEpzNlp+Fkbvs79DHNu
Gh48ubbF+jlzfhr6Z563PtKHfd9ZkIZBf96tmDWNuSgNK/bMdL1mxlycBrsl
Hrq6/sylaRAovTlhkMlcloY7s+8qpZ1jrkhDZ+Hj0u9PmCvTsPS8lo5aB3NV
Gir2OQx6q8S+X62RtN+pvc3TaL6Vm2lQc85//Rb0vX0avIco/lYwZ65Pw9fj
v/2z7Zkb0pDaT4Uf68XclIbcf97h10Po+/w0hGp+DHOj72tb0jDsyIu8hETm
1jQ09DXQsuUxt6Vh9+G5Twz59D1/GhLuFa0KIH+X9J8zQ8ocU+l7X0n7eAyu
WZPC3JUGleDhj7fQ9mUE0Jni8+80l7mXAIpWqgf8ouh7YAFiY8pPltN8LPIC
ZL9z/pcfRN8HC7A5zi7Hypd5qGR7Tk0x33fR98IC5P5yfJzswqwqwPWPJZi1
g74fFkDjndO+lm3M6gLUOxlH526i74kFuFuXZGi3gVlLgN+GJ4PVTen7YgHc
Ro7zf7GCWVeApJXXDPk0X42+ABXoa69N7WUoQPmprR5FBvT7A0m+VxQey85m
NhJgxAOxzpTp9HsEAYJ7ef2nTPPvrBIgMTto8G2aD8hUgMq8MWeMVZnNBVh5
Reli5DD6vYIA7fZun7gKzJsFsHm3JWtLX/r9ggDCUM0FA2WY7QWIXqiZdoj6
o5MAxjkW/fGF2U2AgLB8fts7Zg8BLhXaTq96yewjwM7+C9qeNjIHCDDu58tE
0wfMwQKEcks+zbzDzBHg1L45tdm1zFEClDgsXX2oipkrgMse1063SuZEAd6f
PDxE7jwzTwDDQYUVKeXMAgGeGOcUDz3LLBJA/33gi5wy5mwBvBJxWYuW50ra
77/UMaW0fr4AV5Ty3kyg7RcI0Ou0+xIHil8kgNzxvrCj/SsWwHPa+l1dNVT/
AvTf1rp7+G2qfwGUvwSvSabvzSsEGFMUdGP+Y6p/AV5elrn73zOqfwFU1UM9
clqYawT4WXn44h863jcl7T8nwvDnJ+Y6AWq0vO87f2OuF2DZncvLFv5ibhDg
QnHPyzadzE0C9Lxa9L68i7lZAM0urfL5f5lbBLD/MGPSc3KrAAd9LRJyyG0C
cNdk34z5w9wuQGDnyA1H6fv67wJUK2mdnPabuUNSD3Kv9kz4ydwlwNOcNzsO
fmWWESJmcsTMGsqnlxCj20ytxe+Z5YRYc6ri6bQ3zPJCcKqX8Pe9YFYUQnfm
CH3lp8xDhfC3jzxV1sCsLESzd3jTgXpmVSGSC77ndtQxqwnBd2y+euEWs7oQ
XZxgnb/XmTWEMElLmVFO7aslRIuK8MPPamYdIfbvXTuz7CqzrhA3ec3Tuqh/
6Avx/abBz1KyoRALEwVbr5IhRMSW/7J70vpGQmjf++K7iGwihGJjznML8ioh
Pu9fdleTbCrEQ+XeQadpe+ZC5N0ZtKkH2UoI58PNCspXmDcLYVS03En2Mv1+
QYie2jn3z1P/thdCfPfOtwUXqf6FuPB6fUEg1YObEJb/told6XzmIYSpm0P7
BKonHyHqU7N/XDlN9S9E3WSTWv9Sqn8hnixLqHEpofoXItbFvvp8MdW/EBXV
D9ZHHaf6F0LQ/7bj9WNU/0L8leszci+ZJ2kf30vzx9DfC4R4pttb3Zu2JxKi
4UuU7j2Kly2UFH/0Ljfav1whLG61L9tO+eQLEcC7NPnKJap/IewGfBkTS+NT
kRDbJjpvybtH9S9E+apHjYrU/0ol/Tdv47b6Vqp/yfGzzNn35wfVvxC8C5YJ
e3vR7+eEODm8+d3VocxVQpxt0/q+k+ZnqxHi297Nr6Lm0vlfiAe8Ltu21XT+
F0JUrHQvfDud/4Xwu3r4uDqdHxuEeIQXnLN0Pm4SQivrUaNGIZ3/hVAdcOyH
9RU6/wvRe3Bav7n0+8dWIdrF77z3/aLzvxCGWaVKXkr0+x5JPd4Sz4mm359+
FyL+0M2bpTTfV4cQgd/3JzVuZ+4Swumfz8F6+j2TTDoSdmzSChIz90qH+ITS
0jz6vbBcOvp8a1aecItZPh2T5t1YUfuafh+WDtmtqer2f5iHpmNV16MhVUPY
75eV0/Fzmmn5RQ1m1XQUGAy9qEfzX6mlo3jE6Gsj1zCrp8Ov4u5Gu63MGunY
YvTq8GiaL0orHfq/dcc50vxMOulYnpO1xDGGWTcdi722+61NZdZPR5nmrSvr
aX4kw3RcSg4qzqP5kJCOE0//DbKn+Y+M0vGmrOjKkVPMJum4dmzowqjzzKvS
oe2xQPkjzW9kmo4VNW7nm28wm6fD6/CX+Vb3mK3Sobfi/LtVDcyb09HrWtSj
M0/p9+HpED7dH8x7yWwvaY/TPs9uvGF2Sseu3O3bttB8Rm7pmH1hrcrcj/R7
csnxio9psvjM7JOOZWFGXqU031FAOiqUbgksvjAHp0Mu01XdhMxJRzbHfISI
/j4qHR6PFS5Jt8eVLN96blkaxUtMh4bLcdlNH+j36ulwudJDtbSVWZCO2zN/
rih4zSxKx+PxKyYaUn7Z6ThmUOvj+4x+354Ox7MBKtY0v1N+OqwGr9X7Qb/f
L5Ds7/LLLqtofqiidGxdIh/pdJPmg0qH4mM/+bXXmEslx8NhXpTsZeaydKR6
KGRFVDBXpMPtDi/2Fv3+vzIdY60Ce7wsZq5Kx4Lx1msuFTLXSOJtt77hQf3l
pqS9z2REde6h+QbSsTc/qcSN5guoT4fdTWfLBh5zQzqCZfYmro1nbkrH+8/f
J7fQ/GDN6YipWK5xKIS5JR3y9Ws7C2h+gVZJe4jGbeyk+c7a0lFU+9D1KM2n
1i45Puu+VDyk+di+p6NndGth0nbmjnRMfn1Nto3me+tKR+aKL4fkt9D8Bxkw
ejQmuJ81c68MGK+43+s3zR8nl4HahPs2bWT5DKwY6fbz4yaaLyED0X77fsnQ
9oZmYJjWs8xxNlT/ku1Xzrm+lOaTU82AlVNK3600X5xaBuqGTzGyoPne1DMw
rjxy13A/qv8MGDrE5kTQ8dHKwOVOxfYgmk9NR7L9itb9jUlU/xmIOr69V2g6
1X8G0r+vuGVA86EZZuCT/VHlTzTfAzJw/UScczC1v1EG9p9K3vyojOpfsn/+
S1RlLlH9Z0D1dL5sn1qq/ww4FazR70H90zwDD+K/dfV/TPWfAYMPo4LnvKD6
z8Dg1V/vJ76j+s/Ab3G708CvVP8Z0CxWunyik+o/A6drap970Xxkbhm4d/7Z
0dXyNJ9GBpydU08ZDWP2ycBo32u2W2n+sYAMCKuTM3MnMwdnwK9kdfGAGTT/
Rgb+Kp5vSDdgjsrAJb27l6bTfGPcDPQ5Pc75PM3nkZiBTQv9NSda0nwdGbCY
fGqeqQ2zQPL3F5Lyp9P8IKIMPDm7cuZ5T+bsDFTt5/ztCKT5PTLAdRogbAln
zs/Ahk7zLyFxzAUZWKDZeKGCx1yUgaT8l1vSMmg+kAzcrMvJ/LaHuTQDdzyL
vR/kMZdloGxMJ+YfZq7IwMTPk7cvOEbzp0j6h8ao/R0lzFUZCLw4yI93hrkm
A+0r799Xr2C+mYERWTPdq2m+sroMmNxYdNP7KnN9BobfPe6scp25IQPaMaPE
+2k+paYMmB8+tPgTzZfUnIHVeR5672l+s5YM5I0cHZxI8x21Zkju5we73qf5
YNoyMHZuUtbFZprPJQPjc89braL5ib5n4OuiT8NcaD6Zjgw0Oxsb/3nD3JWB
oiMXeryk+YpkRLCYUjvsG7mXCDH7+8krkeVESE09u2oabU9ehArO34+LaH4k
RRGgtNbUiuZXGiqCYdkj1RCav0lZBC2Eopzmq1IVwVS2snDILZpfRoQ3s0+e
jaPjpy5C+uN+W9TOM2uIcLnQP/ztSWYtEfQ2xJnJ0Hw2OiIce77uW9ZeZl0R
NDV6WX0TMOuLMFz1UMy8eGZDEcb3XheSFUbz14iwoPPb38k0/52RCD17r1vx
xoXZRASv5uG296l/r5LsH29OzQcLmu9Gkn9B3z46VB/mIiT6a6rlL2G2EuFh
Tb+/K6i+NoswZk7lQTWqPxsRnG7/qBiuwWwv2Z9H1wyHjWV2kuQftmvFP6pv
N8nxSjnTv1xa/yLcyBpfMZPGBx8RbA3W5tn+pvO/CFcOLDxjQufzYBFuW4jf
faL5cjgi/G6embKJzr9RkuMVMOBZ0h06/4vQ+9iXLbF0vZMoguDzBl3js3T+
l6z/fpJtHV0/CUTwC/47XH8/nf9F4JXkZ+2h8ThbBPWpZqFaCXT+lxzfuAef
h9L8mfkiXCqxOBVJ83UWiLBpn0Neliud/0XwDdXJ8rKj878I7pvLlyvR+ahU
hNZkH7/dZnT+lzj01JDClXT+F2HNbe0k0VI6/4vwssAzZhHo/C+CiapV5955
dP6X1EPApFnH9Oj8L8Kcgrfr7Wk+1zoRgh4f1zwzg87/IhQPGH87Yzqd/0Wo
D/818/s0Ov+LUOW+JqmM5odtFoE/oJfy3al0/hfB4LbynankVhE22nhcPKtJ
538RipxnHt1Fbpe0p5PRz6Xk7yL09xhzWY/cIcLZlPPVi8hdIrTUVinakmXE
yE/31uOTe4nRpHBy1l2ynBhyfkduj6T9kRcj7snw7U5kRTG8Pl5MLCcPFWPu
34OOgyg/ZTGej5w6y5GsKsYomeEhl8lqYuh73J8zjo6PuhiJSivGRpA1xLho
EHzxJVlLjI83ev5cqE3nfzEmnc+/l07WFWPlu/nbXpP1xThlXfJLk9rDUIzH
E1N6O5Ehhl/vwsV7yEZimKtceX6dbCLG/vbmL5/Jq8ToeBBg3V+Hzv9iHB/+
Z+IIsrkYKR8uyw8hW4nB3b73bSetv1mM8sjOszfINmKY3txhE0G2l+Q/O2uA
CtlJjEpr8V0e5eMmxmCFjvindDw8xIidcF2mk46njxhDX9jpP6P2CBCjbMZ6
Xji1Z7AY3/Z9CnhC92McMa6X/37wdBLVvxhvi0/ahdJ8xlxJ+4h1M4vGUf2L
Ie/VmGw5hupfjDmLrl1xp/mQBWK0Lt2Q1TKM6l+MoAdTQ4pp/uRsMRw+1pbf
6U/1L0bCS/dco15U/2KoNDZ8GUL3kwVi1O6yf7noB3ORGLPfmnXcaaP5NSTH
d46u7PlXzKVi9Ip4Htz3Cc23IcbMCedunrjDXCHGwfu97lZX0fwbYkw+PP7N
5rPMVWJobHA/JjxK83GIcdrQbFDmPuabEg9Z45wmpPk5xLA84G+XT/ON1Isx
Xi6r4RXNf90gad8ft/jWXsxNYrhXqx3s70jzd0jq5Zuf8ntr5hZJPd5rOvGF
5gNpleTTfGyKijFzmxjppdrn7Wi+73YxFH/4u1+l+Z6+ixEzdqf+Apo/vENS
D5wxv67QfE5dYoxVVDdfPpju/zOxoiGw60Ifuv/PxPKwyCUjaP4muUx0lLjm
L6f5g+QzMTRJFG9O8+UoSnzvfawhza8zNBPFK7qc+tH8TMqZMMyxuHuZ5ltX
zUR+2YNd7mfp+X8mBufNHjb4GD3/z4RqrMixZD89/8+EZtBIB9sMev6fiYKX
zVP06P2FjmT5mTG3N4TT8/9MLGhumvDKj57/Z+L6KKWRPXbS8/9MtASfmnyN
ntcgE22vZYoXWtPz/0x4Pfo20GU9Pf/PhIF28LuFq+j5fyacyi90ldP7BdNM
5Mw8cL6B5ss3z4TCtruCTHq/YJWJx7sG/JadQ8//M1H/eKPB4Jn0/D8Taee/
r7ygTc//MxFbXzKqi943OWViT1mJ3xl6/+CWiT7Lnpk20r8X4JEJUQ6q1tPz
Kp9MvGuq/jaI/r2BgEz8HFSQJkv/HkFwJl5WpIePk/77BZL2uxz+257eZ0Rl
QuBu+Lia/n0EbibKjv2YvJicmIlSA27jPZrfhZeJYwPGnpb++xCCTMiP0Bgl
/fdaRJl4E9N54y39ezPZmbhZVniihJybiUfhPY5I//2gfEn/a1fhS/99pQLJ
+q/lti8iF2XCqOZQgDq5WBJPf8qVfuTSTCTccm5qH8NclgmfX38+PCZXZEI5
6qr9VXJlJhw8PMpOkqsyoTiiavQBck0mgm/3DBSTb0ra//cQBx65LhNrr36x
iiPXZ+LH3FeXI8kNmThZGKcVRm7KxKnIgwt2k5sly2cJz/uTWzLhN+glx4fc
mgnzGnNPT3JbJiIC7/Hdye2ZuNi4Y7Ab+XsmxhjbzXchd0ja/66zuzO5KxP/
+uQ1Sy2TBV6K2gFXcq8s2OmX75duXy4LQ77HpnqR5bPQXhry1Y+smAWniNTx
0nyGZuGWx+H0ULJyFrL7N6uEk1WzwJk/4EMEWS0L9b34MVFk9Sy0Gr0OjSFr
ZMH6h1BPeny1slA9+EN5IlknC5MshxyXtoduFlwiN4QIyPpZ0Fj9X2YG2TAL
p4t8rknbE1moO5U8LotslIXglddGZJNNsjDUn79oD3lVFr7sWj95L9lUsv3g
8r77yeZZWBu98py0/1hlQX9w+o3D5M1ZmHn24dGjZJssvDw68U8x2T4LKUv8
cqT90SkLNzl9ak+R3bIwQdz06QzZIwtnkkpjy8k+kvbp1H50nhyQBcFez7pL
5OAsHCy/Pr6azMmCzVLLrdfJUVl4tv2iym0yNwuhd+eMvktOzILJpZc298k8
yf6pLB/1gCzIwpafMwQPyaIseBXVKTSQs7Mw/k/JMWk95mbh92W1sEZyvqQ/
/RaEPCUXZKHgR7+Dz8lFkv5zaGzXC3JxFrz/lCa0kEslx1dUt+WttP4l8e0K
nN9L6z8LK56Z8j5K61+y/Y2FBdLxoioL2yL3p36T1n8WNvwMNPwprf8srAmz
/L+i7i6k6SgMA7iprSUrZ18uNkqirSUmll8ztB7DPszZB8pSUSYRtaKpxSIJ
KTGDudKWDBr9X/qSPpUsUBiZ22V0URKFmCEUbVA2R4JMGzL637yny9/VOYdz
nvNcvs8XRP4l1E8d/BET+ZdwuuhxZFHkX8LdBtdYXORfgmq0qTOB/6tvErwb
nMpEdlDOg8d9LIn9U0Lv30JHMjssITH+pWkp+4+EqaonpxTsOQndjy45l7EX
JHwvvTmvZC9KmEzb9i5FzP8ibN9bHlWxkwne8UhtKltJaO9zDKexVQRjuta/
mq0m+HL1BWvZawirzs0tX8fWEH6Ff1uFdYTuB+97hDMItvykhHT2ZkKHoWSl
hm0kPHzrm17PziLYU4+7dOwcgjZy5d5Gdh5hxe6x/k1sEwFD+mw9u5gQjjVP
GNggNKtDg1vYZYT9NZ8URvYBQtuzuEXYTDBXdKm3so8QDgX7WjLZ1YSBmTP2
LHYNweO3jWaz6wlLAi/mc9iNhPFedWAH+wRB96ErlMu2yfu3Wlrz2GcJ/lj1
K+EW+byTwxPCDkLKtaPGfHYroeyWfUS4jdBfVXe9QMyDk/dr7rlYyO6U77Ni
oM7EdhJuK6yGIvYNgsljnhV2ExrUrtBOtodQeaFWW8z2Ehrdr6+WiP6X39e+
0ugu0f+E8sBIJUT/y+/jzuXzou+fEmYGZw/vEf0vr9/u+ij8kjDdYYkKDxE+
azKCwj7CyfuZX4Xf/Pc/A91cCA==
       "]]}}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6]}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, {}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 1839.}, {0, 933.7824156783636}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8538362850216036`*^9, 3.854101458037591*^9, 3.8541019092820697`*^9, 
  3.8674062291319656`*^9, 3.8674077474607763`*^9, 3.8674923140320287`*^9},
 CellLabel->
  "During evaluation of \
In[231]:=",ExpressionUUID->"ec822dd1-b16e-41ad-9922-2778de96c332"],

Cell[BoxData[
 StyleBox["\<\"Expansion of RMS difference vs displacement in data points, \
with parabolic fit\"\>", "Subsection",
  StripOnInput->False]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8538362850216036`*^9, 3.854101458037591*^9, 3.8541019092820697`*^9, 
  3.8674062291319656`*^9, 3.8674077474607763`*^9, 3.867492314039011*^9},
 CellLabel->
  "During evaluation of \
In[231]:=",ExpressionUUID->"df1861b4-dd81-4acf-8428-b0c012092866"],

Cell[BoxData[
 GraphicsBox[{{{{}, {}, 
     TagBox[
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJwVl3k81F0bxpUe/WYMZiyVioaZ+c0Yu+aRZLkoo3pU2veUsqRIlkhaJVIi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        "]]},
      Annotation[#, "Charting`Private`Tag$4976591#1"]& ]}, {}}, {{}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
      0.012833333333333334`], AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJxTTMoPSmViYGAQBWIQDQEf7A0meE5f8NTNASrg8I7lYZW7mTOUz+Ew5+LW
xHPd9lC+gMPlGwtKwq0toXwRhwmn96i86jWG8iUcfu35579JRxfKl3G4ys3y
Z/JZFShfwaGh9SVzk50MlK/koHRdaG5EpRCUr+LQxKuo9/sJB5Sv5tD96cCP
sFoWKF/DIXHnec/Uw+xQvpbD5g/8Vmf8BaF8HQeJq/Y5FgVSUL6ewx+VVTtu
9StD+QYO82oW7eKdqQ3lGzp8maDYcGCOEZRv5OA9p/ZNhaYFlG/sMGVnhMPc
RDso38SB787cFRYznaB8U4drbo9KeV3cHADselYH
       "]]}, {
      {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
       0.012833333333333334`], AbsoluteThickness[1.6]}, {}}, {
      {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
       0.012833333333333334`], AbsoluteThickness[1.6]}, {}}}, {{}, {}}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{Automatic, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{All, {0, 50.373359682094105`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8538362850216036`*^9, 3.854101458037591*^9, 3.8541019092820697`*^9, 
  3.8674062291319656`*^9, 3.8674077474607763`*^9, 3.8674923141437306`*^9},
 CellLabel->
  "During evaluation of \
In[231]:=",ExpressionUUID->"28f3166c-595a-4b9f-b598-caf679cfff1c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Interpolated frequency shift with best match is \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"-", "0.07944990842957321`"}], "\[InvisibleSpace]", "\<\" Hz\"\>"}],
  SequenceForm[
  "Interpolated frequency shift with best match is ", -0.07944990842957321, 
   " Hz"],
  Editable->False]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8538362850216036`*^9, 3.854101458037591*^9, 3.8541019092820697`*^9, 
  3.8674062291319656`*^9, 3.8674077474607763`*^9, 3.867492314148717*^9},
 CellLabel->
  "During evaluation of \
In[231]:=",ExpressionUUID->"046d7bc8-7d61-4af9-95b6-be5dad2bec03"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   StyleBox["\<\"Chemical shift = \"\>", "Subsection",
    StripOnInput->False], "\[InvisibleSpace]", 
   StyleBox["2.0811`", "Subsection",
    StripOnInput->False], "\[InvisibleSpace]", 
   StyleBox["\<\" ppm\"\>", "Subsection",
    StripOnInput->False]}],
  SequenceForm[
   Style["Chemical shift = ", "Subsection"], 
   Style[2.0811, "Subsection"], 
   Style[" ppm", "Subsection"]],
  Editable->False]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8538362850216036`*^9, 3.854101458037591*^9, 3.8541019092820697`*^9, 
  3.8674062291319656`*^9, 3.8674077474607763`*^9, 3.8674923148240213`*^9},
 CellLabel->
  "During evaluation of \
In[231]:=",ExpressionUUID->"d41e1c94-1953-42c2-a850-cd56674317d3"],

Cell[BoxData["\<\"Variance and optimised shift and ratio:\"\>"], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8538362850216036`*^9, 3.854101458037591*^9, 3.8541019092820697`*^9, 
  3.8674062291319656`*^9, 3.8674077474607763`*^9, 3.8674923954708076`*^9},
 CellLabel->
  "During evaluation of \
In[231]:=",ExpressionUUID->"3547b980-5279-41f1-a67a-b0e45b925812"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"27.399845371074612`", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"fdiff", "\[Rule]", "789"}], ",", 
     RowBox[{"fratio", "\[Rule]", "1.0258914940665964`"}]}], "}"}]}], 
  "}"}]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8538362850216036`*^9, 3.854101458037591*^9, 3.8541019092820697`*^9, 
  3.8674062291319656`*^9, 3.8674077474607763`*^9, 3.867492395473799*^9},
 CellLabel->
  "During evaluation of \
In[231]:=",ExpressionUUID->"32d75548-2d85-4646-b276-2407f171b3c9"],

Cell[BoxData[
 StyleBox["\<\"Input data\"\>", "Subsection",
  StripOnInput->False]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8538362850216036`*^9, 3.854101458037591*^9, 3.8541019092820697`*^9, 
  3.8674062291319656`*^9, 3.8674077474607763`*^9, 3.867492395475794*^9},
 CellLabel->
  "During evaluation of \
In[231]:=",ExpressionUUID->"e7d6e95a-f6c9-4a6a-881b-47d138b4ca2c"],

Cell[BoxData[
 GraphicsBox[{{}, {{{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJw8mnlczN/XwAchJEkI0SAkYewhOZRKwtBK0UhqpGVaVNIyrdqbvanEoAip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       "]]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJw8nXlcTN//xwdJEqIohBBCSEIILySVJIRo0S4J077XtE/71Ew1LRJCiJIt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       "]]}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6]}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6]}, {}, {}, {}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6]}, {}, {}, {}}}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 2098.}, {-0.005418571104384012, 1.9748002253581005`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8538362850216036`*^9, 3.854101458037591*^9, 3.8541019092820697`*^9, 
  3.8674062291319656`*^9, 3.8674077474607763`*^9, 3.8674923955745296`*^9},
 CellLabel->
  "During evaluation of \
In[231]:=",ExpressionUUID->"d1804f06-ac02-487b-89fb-209be9ea0fde"],

Cell[BoxData[
 StyleBox["\<\"RMS difference vs displacement in data points\"\>", 
  "Subsection",
  StripOnInput->False]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8538362850216036`*^9, 3.854101458037591*^9, 3.8541019092820697`*^9, 
  3.8674062291319656`*^9, 3.8674077474607763`*^9, 3.8674923994181986`*^9},
 CellLabel->
  "During evaluation of \
In[231]:=",ExpressionUUID->"a3947509-1dd5-4f63-b490-bb31d52aded3"],

Cell[BoxData[
 GraphicsBox[{{}, {{{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJxE3HtcTM//B/AQEilEIYQkhJCE8JIkhBCSsKUrSbrf2+7bfdu2bbdCCCGE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       "]]}}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.003666666666666667], 
     AbsoluteThickness[1.6]}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6]}, {}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 4197.}, {0, 1183.0148359001364`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8538362850216036`*^9, 3.854101458037591*^9, 3.8541019092820697`*^9, 
  3.8674062291319656`*^9, 3.8674077474607763`*^9, 3.867492399537793*^9},
 CellLabel->
  "During evaluation of \
In[231]:=",ExpressionUUID->"597227c2-484a-4314-bc41-a860948a9f20"],

Cell[BoxData[
 StyleBox["\<\"Expansion of RMS difference vs displacement in data points, \
with parabolic fit\"\>", "Subsection",
  StripOnInput->False]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8538362850216036`*^9, 3.854101458037591*^9, 3.8541019092820697`*^9, 
  3.8674062291319656`*^9, 3.8674077474607763`*^9, 3.8674923995866623`*^9},
 CellLabel->
  "During evaluation of \
In[231]:=",ExpressionUUID->"d5258ad6-4ed2-48e7-84cd-6f1328d3bec5"],

Cell[BoxData[
 GraphicsBox[{{{{}, {}, 
     TagBox[
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJwV13k8VOsfB3Ditmi5tnSpbDNzZiGkScuZ4ZOiElO5pEhFSbK1ILcohSwt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        "]]},
      Annotation[#, "Charting`Private`Tag$5053852#1"]& ]}, {}}, {{}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
      0.012833333333333334`], AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJxTTMoPSmViYGAQBWIQDQEf7KcLFOj7B/o7QAUcjuQ2OK8R8YHyORymNrs/
vK3qCeULOEy7qjRlYbsblC/ikGkUWNNn4wLlSzgcZjJkeufmBOXLOEw6+rl6
0woHKF/BYffjEqeLx+ygfCWHS8qBzws+2ED5Kg5aMdLvX5y3hvLVHD5ZaLjE
pMH4Gg4qWvxtjVtgfC2HJM3wu5N2wfTrOCj9muQrWwEzX8+hZIHL+celMPsN
HDj+Hf8wlRPmPkOHxxfYtbK/OkP5Rg5CBu8tzM1h/jN2iIhIqak74wHlmzh4
/3/xZsYmbyjf1OF1v8KJo8/8HACwzVUo
       "]]}, {
      {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
       0.012833333333333334`], AbsoluteThickness[1.6]}, {}}, {
      {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
       0.012833333333333334`], AbsoluteThickness[1.6]}, {}}}, {{}, {}}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{Automatic, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{All, {0, 68.898751948062}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8538362850216036`*^9, 3.854101458037591*^9, 3.8541019092820697`*^9, 
  3.8674062291319656`*^9, 3.8674077474607763`*^9, 3.867492399689391*^9},
 CellLabel->
  "During evaluation of \
In[231]:=",ExpressionUUID->"9277bfc0-5f1b-4a36-a30d-348358bb1574"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Interpolated frequency shift with best match is \"\>", 
   "\[InvisibleSpace]", "30.095779589451723`", 
   "\[InvisibleSpace]", "\<\" Hz\"\>"}],
  SequenceForm[
  "Interpolated frequency shift with best match is ", 30.095779589451723`, 
   " Hz"],
  Editable->False]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8538362850216036`*^9, 3.854101458037591*^9, 3.8541019092820697`*^9, 
  3.8674062291319656`*^9, 3.8674077474607763`*^9, 3.867492399694378*^9},
 CellLabel->
  "During evaluation of \
In[231]:=",ExpressionUUID->"eae4638b-467c-4df4-b08d-b6e3ba3c9869"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   StyleBox["\<\"Chemical shift = \"\>", "Subsection",
    StripOnInput->False], "\[InvisibleSpace]", 
   StyleBox["1.9077`", "Subsection",
    StripOnInput->False], "\[InvisibleSpace]", 
   StyleBox["\<\" ppm\"\>", "Subsection",
    StripOnInput->False]}],
  SequenceForm[
   Style["Chemical shift = ", "Subsection"], 
   Style[1.9077, "Subsection"], 
   Style[" ppm", "Subsection"]],
  Editable->False]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8538362850216036`*^9, 3.854101458037591*^9, 3.8541019092820697`*^9, 
  3.8674062291319656`*^9, 3.8674077474607763`*^9, 3.8674924002924623`*^9},
 CellLabel->
  "During evaluation of \
In[231]:=",ExpressionUUID->"142c104f-2c4e-4151-8f34-5e49fec762e3"],

Cell[BoxData["\<\"Variance and optimised shift and ratio:\"\>"], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8538362850216036`*^9, 3.854101458037591*^9, 3.8541019092820697`*^9, 
  3.8674062291319656`*^9, 3.8674077474607763`*^9, 3.8674924201859922`*^9},
 CellLabel->
  "During evaluation of \
In[231]:=",ExpressionUUID->"5571c71f-375f-4b53-9d6c-4822a9bb777f"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.20713274008927884`", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"fdiff", "\[Rule]", "36"}], ",", 
     RowBox[{"fratio", "\[Rule]", "1.0979020423748382`"}]}], "}"}]}], 
  "}"}]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8538362850216036`*^9, 3.854101458037591*^9, 3.8541019092820697`*^9, 
  3.8674062291319656`*^9, 3.8674077474607763`*^9, 3.8674924201899815`*^9},
 CellLabel->
  "During evaluation of \
In[231]:=",ExpressionUUID->"3b6a6d80-fb4d-489b-80d0-1061680305a0"],

Cell[BoxData[
 StyleBox["\<\"Input data\"\>", "Subsection",
  StripOnInput->False]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8538362850216036`*^9, 3.854101458037591*^9, 3.8541019092820697`*^9, 
  3.8674062291319656`*^9, 3.8674077474607763`*^9, 3.8674924201939716`*^9},
 CellLabel->
  "During evaluation of \
In[231]:=",ExpressionUUID->"192e1f10-d95f-4c44-8e49-936a4d20a760"],

Cell[BoxData[
 GraphicsBox[{{}, {{{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
      0.0055000000000000005`], AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJw1mHlczfn3x68WKVGyj2UuNbImS5YRvdCmSdp3ue23/a6VtZuRSZKYxPha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       "]]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[
      0.0055000000000000005`], AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJw9mHs81Pn3x0e6bEWsRIkMlSRF6U71cgmhNe53jfudMWYMaWtot6+0Srq3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       "]]}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
      0.0055000000000000005`], AbsoluteThickness[1.6]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[
      0.0055000000000000005`], AbsoluteThickness[1.6]}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
      0.0055000000000000005`], AbsoluteThickness[1.6]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[
      0.0055000000000000005`], AbsoluteThickness[1.6]}, {}, {}, {}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
      0.0055000000000000005`], AbsoluteThickness[1.6]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[
      0.0055000000000000005`], AbsoluteThickness[
      1.6]}, {}, {}, {}}}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 394.}, {0, 1.2228301782452764`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8538362850216036`*^9, 3.854101458037591*^9, 3.8541019092820697`*^9, 
  3.8674062291319656`*^9, 3.8674077474607763`*^9, 3.867492420277746*^9},
 CellLabel->
  "During evaluation of \
In[231]:=",ExpressionUUID->"4fd521b9-b2eb-4636-b3bf-24ff2f869bd7"],

Cell[BoxData[
 StyleBox["\<\"RMS difference vs displacement in data points\"\>", 
  "Subsection",
  StripOnInput->False]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8538362850216036`*^9, 3.854101458037591*^9, 3.8541019092820697`*^9, 
  3.8674062291319656`*^9, 3.8674077474607763`*^9, 3.8674924204283447`*^9},
 CellLabel->
  "During evaluation of \
In[231]:=",ExpressionUUID->"d727b5da-acf5-4dc1-8a1a-0fe821ab0bf3"],

Cell[BoxData[
 GraphicsBox[{{}, {{{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
      0.0055000000000000005`], AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJxF2nlYzF3YB/CxhWwlqVCSVEoJRQv5UmkjQ0URTdKiRdO+12w1Y4+i7Nmj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       "]]}}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
     0.0055000000000000005`], AbsoluteThickness[1.6]}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
      0.0055000000000000005`], AbsoluteThickness[1.6]}, {}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
      0.0055000000000000005`], AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 789.}, {0, 109.9656648307517}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8538362850216036`*^9, 3.854101458037591*^9, 3.8541019092820697`*^9, 
  3.8674062291319656`*^9, 3.8674077474607763`*^9, 3.8674924205001535`*^9},
 CellLabel->
  "During evaluation of \
In[231]:=",ExpressionUUID->"3631bf7f-0c07-421d-a05a-cde198da5372"],

Cell[BoxData[
 StyleBox["\<\"Expansion of RMS difference vs displacement in data points, \
with parabolic fit\"\>", "Subsection",
  StripOnInput->False]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8538362850216036`*^9, 3.854101458037591*^9, 3.8541019092820697`*^9, 
  3.8674062291319656`*^9, 3.8674077474607763`*^9, 3.8674924205051403`*^9},
 CellLabel->
  "During evaluation of \
In[231]:=",ExpressionUUID->"57f9e702-9745-49a1-ab5a-3cd74ffb55cb"],

Cell[BoxData[
 GraphicsBox[{{{{}, {}, 
     TagBox[
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJwVlnk4Ve33xs0kvEgDTnKcs49jDJ2EyloaVd6kEl9SqGRWUa9CKkPRJClD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        "]]},
      Annotation[#, "Charting`Private`Tag$5131246#1"]& ]}, {}}, {{}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
      0.012833333333333334`], AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJxTTMoPSmViYGAQBWIQDQEf7Kvldyw+bCfpABVw4I5o9zj+XQTK53C4m1j5
upNVEMoXcMgz393w/D4XlC/i0HHGoTOyhgXKl3Bwf6GX/Ov2X3sIX8bhIN+b
qK2tX6B8BQdHSWv5XRqvoHwlB8mS1fz35t+D8lUcbBbdybpYdRHKV3MQWuQX
E9x8CsrXcEhYqbfjvs4lKF/LQU5R4zyn2gMoX8dhke5HBeMTr6F8PYc3wQdv
xn//CuUbODTHa50XUGaAutfQ4dbCmcFbUtmgfCOHRQnGzhoHeaF8Y4fJmv+3
tUkIQ/kmDirq7apN18ShfFOHGXqsJ84JyzoAAO0oVTQ=
       "]]}, {
      {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
       0.012833333333333334`], AbsoluteThickness[1.6]}, {}}, {
      {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
       0.012833333333333334`], AbsoluteThickness[1.6]}, {}}}, {{}, {}}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{Automatic, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{All, {0, 7.99627784523765}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8538362850216036`*^9, 3.854101458037591*^9, 3.8541019092820697`*^9, 
  3.8674062291319656`*^9, 3.8674077474607763`*^9, 3.8674924206048737`*^9},
 CellLabel->
  "During evaluation of \
In[231]:=",ExpressionUUID->"d5d9b8da-1754-44b9-b603-9dcc13cac261"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Interpolated frequency shift with best match is \"\>", 
   "\[InvisibleSpace]", "1.382859369893452`", 
   "\[InvisibleSpace]", "\<\" Hz\"\>"}],
  SequenceForm[
  "Interpolated frequency shift with best match is ", 1.382859369893452, 
   " Hz"],
  Editable->False]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8538362850216036`*^9, 3.854101458037591*^9, 3.8541019092820697`*^9, 
  3.8674062291319656`*^9, 3.8674077474607763`*^9, 3.8674924206148453`*^9},
 CellLabel->
  "During evaluation of \
In[231]:=",ExpressionUUID->"5e4f7522-c0c8-4e86-ac25-f0584f672dcf"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   StyleBox["\<\"Chemical shift = \"\>", "Subsection",
    StripOnInput->False], "\[InvisibleSpace]", 
   StyleBox["1.5058`", "Subsection",
    StripOnInput->False], "\[InvisibleSpace]", 
   StyleBox["\<\" ppm\"\>", "Subsection",
    StripOnInput->False]}],
  SequenceForm[
   Style["Chemical shift = ", "Subsection"], 
   Style[1.5058, "Subsection"], 
   Style[" ppm", "Subsection"]],
  Editable->False]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8538362850216036`*^9, 3.854101458037591*^9, 3.8541019092820697`*^9, 
  3.8674062291319656`*^9, 3.8674077474607763`*^9, 3.8674924211907597`*^9},
 CellLabel->
  "During evaluation of \
In[231]:=",ExpressionUUID->"1602dd76-9ee0-485d-a48a-a21490640d2c"],

Cell[BoxData["\<\"Variance and optimised shift and ratio:\"\>"], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8538362850216036`*^9, 3.854101458037591*^9, 3.8541019092820697`*^9, 
  3.8674062291319656`*^9, 3.8674077474607763`*^9, 3.8674924748061943`*^9},
 CellLabel->
  "During evaluation of \
In[231]:=",ExpressionUUID->"a499f450-df2a-4958-a15b-ac3dec2310a1"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"4.592903363594273`", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"fdiff", "\[Rule]", 
      RowBox[{"-", "14"}]}], ",", 
     RowBox[{"fratio", "\[Rule]", "0.7`"}]}], "}"}]}], "}"}]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8538362850216036`*^9, 3.854101458037591*^9, 3.8541019092820697`*^9, 
  3.8674062291319656`*^9, 3.8674077474607763`*^9, 3.867492474811182*^9},
 CellLabel->
  "During evaluation of \
In[231]:=",ExpressionUUID->"0e22e64b-5bb9-4951-8bc3-0bf822da7414"],

Cell[BoxData[
 StyleBox["\<\"Input data\"\>", "Subsection",
  StripOnInput->False]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8538362850216036`*^9, 3.854101458037591*^9, 3.8541019092820697`*^9, 
  3.8674062291319656`*^9, 3.8674077474607763`*^9, 3.8674924748151712`*^9},
 CellLabel->
  "During evaluation of \
In[231]:=",ExpressionUUID->"e8f018f7-33cd-4b79-bc89-8bc538d27ba4"],

Cell[BoxData[
 GraphicsBox[{{}, {{{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJw9nHlcjU0bx0NItpCEHpIthCJJhR/aENqQRKdV2rR32k/7aTtryPJQCSVL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       "]]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJw9nHlcTd/3/5MpQ2QOUZGUohBC6iUhJNEgSV3NpeE2z3Vv472NdwghJCGE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       "]]}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6]}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6]}, {}, {}, {}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6]}, {}, {}, {}}}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 1311.}, {-0.007114696875, 0.923302403125}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8538362850216036`*^9, 3.854101458037591*^9, 3.8541019092820697`*^9, 
  3.8674062291319656`*^9, 3.8674077474607763`*^9, 3.8674924749178963`*^9},
 CellLabel->
  "During evaluation of \
In[231]:=",ExpressionUUID->"c6044134-fb6c-4228-986c-d7c8ce5b9a2a"],

Cell[BoxData[
 StyleBox["\<\"RMS difference vs displacement in data points\"\>", 
  "Subsection",
  StripOnInput->False]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8538362850216036`*^9, 3.854101458037591*^9, 3.8541019092820697`*^9, 
  3.8674062291319656`*^9, 3.8674077474607763`*^9, 3.8674924764629655`*^9},
 CellLabel->
  "During evaluation of \
In[231]:=",ExpressionUUID->"3e7491c3-b5b5-4eec-a456-bb935cbb1441"],

Cell[BoxData[
 GraphicsBox[{{}, {{{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJxE23lcTG0bB/AQQgghhBBCiCdKwg8hqSRJkhRJKu37Ou3TPlOzNYUQkpDs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       "]]}}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.003666666666666667], 
     AbsoluteThickness[1.6]}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6]}, {}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 2623.}, {0, 377.87450930396324`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8538362850216036`*^9, 3.854101458037591*^9, 3.8541019092820697`*^9, 
  3.8674062291319656`*^9, 3.8674077474607763`*^9, 3.8674924765648623`*^9},
 CellLabel->
  "During evaluation of \
In[231]:=",ExpressionUUID->"b922114f-e345-481b-84df-1e25080f25a3"],

Cell[BoxData[
 StyleBox["\<\"Expansion of RMS difference vs displacement in data points, \
with parabolic fit\"\>", "Subsection",
  StripOnInput->False]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8538362850216036`*^9, 3.854101458037591*^9, 3.8541019092820697`*^9, 
  3.8674062291319656`*^9, 3.8674077474607763`*^9, 3.8674924765706415`*^9},
 CellLabel->
  "During evaluation of \
In[231]:=",ExpressionUUID->"642001ba-db61-4b89-ad91-7f871fa13a7f"],

Cell[BoxData[
 GraphicsBox[{{{{}, {}, 
     TagBox[
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJwV12k8VdsfBnBR6dKgfVAk7HPO3seU0Klo4KHSpEkl0UQiyRTdhCQlopBO
SJn1b+BSbsiUiJChElFJJSUZEipD8l/31f5836y91l5r/37Pom1dzQ+Ii4mJ
cSaIif33VCyLcBYT6zOSEndU+jyBiwZVsx2qCn1G7daiI7xxGmEnJI2h12ek
/iZ2sc1vGhKL/WT97fqMRtYaTG/9SaP7llPBeGWfUfqXgp6WLhoPwk3/Gr/4
3chGo/not0Yatta/U8d4A0YTiw/fdrhN41a/Q8vI6p9GevMmX0/dRqO5qcx5
0awxI0fTVI3URFXcS/hi9nfeBMwLL8h5Oa6C3H6Ru1XTRLwNcZX0rVeGFH1G
8E5/CurNtytNujoXYTLVGkn7pOGt1zGz4awSbN9sK5aomY619v8e3Og0B3m2
JndzOTNRWnTT75udIqz0z6qfT6WQpmGf7eWngGQfp686O2Th9t3gPFc0GwEJ
v7cMdsvBucNl61jFLIi9eI9C71lIEY57RUybBdbT3mubhgLSl7yKSTGXR/uP
aAvpIkXEL/OJTMySw7pPh05Euish7N4KtY+yctjYHqGprKwMsfoojZ5zsvj6
yNa/8h8VSLgUXw+Ul0X0lK6wpExVnBvsCX15k4N+U4+SJ1mq4Eu8CrO+wcHG
wNGBgWxVeMzZdeTDdQ4mi0/daVqoCk1HjTffkjnwHNXidVWqYsrxjgWz4jgw
73XJFbapwv3QxwkRFzmY3tD/rkKWhpiobYaGDweBCSM6vcdpyIr/GRjfzEGh
quxE6xM0ZpmIayVv4mAwaV5ThT+Ncpt8p1UbObBN3XciKYiGGkzFw9dzYHjr
cdW2y+QcHK8J1Tbl4GdWpG3BHRoz3kTKJCzlwP6xhii4g8aJfZIfVgk4iFu9
0uHHVxrTo4Jm/MVy0FC5e4ltL431aQWravkcmFRHvF/6g0a1p1GVJZcD5Wc/
tb6Jc/H+dLaW71wOXr4qLd+uzMXeSOsDgxwOVvdY/eJu5yLbLTzu9gQO4mVP
vzhpycVWF5OuS2Jk/kvTMlusuYi0Zxb7jVNIDBl1iLLlYsDUp2r7GIURwbXm
v9y4MKiwb5YZppBu+zavL4SLt+XLEnL6KMg07/V98JCL4IL2Zw/fU7AfD7Kc
U8bF4mnR7VXvKBSyd4ReFVwE7Tz+80UrBcejYj26dVxIttXKdrVQKKWSdl9/
w0VYVs5S5hUFzw1thud/kvluCdKrek6hudRugpUWD/uD+WVPH1HoM36teGI+
D8mvXSZJEkuWbBIm6vEwrfs7z6iUwqLiJQ6f9XmwM0seuvuQgqhApvbIKh6U
JNLFkosobLpXGBO6h4esNftD03IpPL4uq1MUwYOn0CbULp1CKz9k7ftLPNCH
H3nkplH4kTJuKxHNw4jtHgNpYn7y18tr43jQDjPclX2LQkD8w9HGWzwkvr4h
JnuDgmH04YreUh5urlcuG0mikB1ctkf1Bw+bwmIXusRQuLmuenbQEA+Olp3h
z6IpxE6tr+8Z5aFz/creBcT+Ee9MC8T5UMxUzh27TMEsZkTbQoaP5fYHjsdd
otB2Q2c8VJOP8OglD6eFU2h0XJzXr82H+NB6a/8wCpWahh479fh4c8pxZOAC
hX8y13ewBnwUzaxa2Xqegleu/dMSUz5WcBWlikMoTK+4lvDLhg+ryRN33D1L
YcK5lJ17DvDBjjXpCYkH193mlB/kw3Lufep+IIVXdblBka58dL261lp6hkLq
y3rXeSf4aFwx9L/2AApLPk/B/hg+sl7/HLY8Sc7DpKPv6+r4EMlybk08TkFR
papp9Dkf/K2neBleFOr05z5VayTjH0r0tyRedLi8KOANH+nc722ZxyhMfiF3
ddEXPqQKWlY7/k3hemLO9vgJDGJCWiIne1KwzJfaUD2RgfNWS/0HHhSmNuxZ
OSTJoGPwzMO/iT0lJReYT2dQUdLn9fUIhZUuO2Qmz2Gw/DQV0uJOoX3p0BNn
IYPhVL95Xa4UYrablcYuZiA7JPnnDrGZa2JexRIGL3gmd48R30tec5M2ZoBJ
VcWSxGf+uhLYuIFBzTfVE3ouFPR5Pb7iWxhITdHdP+5MoXuZsef8bQx6hr5r
1hJvc+u0PWfFIMHu7AEnYn6TAZY7MMjdP+yVdZic974Liw8dYjDbOMLzLPF5
qTbtaGcGyr+azK2JB5eHzP3uwUC+53iuJHFZ6uuRVH8G+WJTaCcnsr8PtPuf
n2ZgmMLomRJrNQd0/jnLwF55kOESi6Q1my0vMEiNT8luOURh/xGf7KmxDBoe
mx3dRbxIrzVbPY5Bus7z+UbEUv3IMU1k0Ba1sIxLfMd9cq7//8h4lvHe3Y4U
Tus65sbdYpD9b/K1emKL79W5+ekMbKSDYvKIf7tdvD+YxaA+89vcEOKnOoP3
Z+YwiPrtccODOLnPIk87j8H9Vc1Se4jXuinlHywm66vF3oXESjon8wNLGWyR
XrWZS9z37UN+cjmDzlXqc2SIo1xvFLRUM1hw56Jh70FSX+ZLFQ7XMWh/Jxfd
Srzs2+FC+XoG/dLeVU+JZTKfFi5oZLBH+KCxhPiji17R5mYGajvbCu4R52hf
LnJ+w2Cz92efm8Qhvb+KQlrJ94l+IhdHvDvD6sGND2S/7oadiyTWcSl6UNbO
4FeFXlMwsYS2avGHDgai1zl/ThK/7Ako/vOVQXinopgX8a1/PhXP6WXwZXDP
GzdiX+c1D/W/M4j/HRBxiHjTvLSH2wcZZIkFqRwg5vZMKznyiwFvglPwPuKf
6W4l4SNkPWPa1buIqw6/KEkf++981HfsJL6mtai0SozFzW6L1h3Ebt0xpZ8l
WIS35mdYEK9IHy2VkGTRUPPH8j/LH97zSFWKxbFc7tv/3KlZ8mj5NOJ4dqkl
cWEXr8xKhkXjKSkPK+LwtLNlxzgsImzqzuwmtnXqLBPJk/ctP+JmQ7xQ06z8
rgILFfmfC+2Jp3RllNcpsRj4urPRibjl9szHXSos+IVxG48QZx7yfDyFx+Lf
cyVJx4kDNJoeMyyLhK3ldaeILb4aVJios+hUuNUYQqx++1rFXi0WF1sO54iI
fzuOV/jOZxF1VcY9gfipum3lFT0WwxaiSWnEyZ1llTkLWeRNH/LIJV7rGFLV
t5SFucfe1npiJfWeqmlGLDRV97/+QNz3ZdMTDRMWNlWmd74TRx2Uq7Zbw6JD
JqOTQ86bo5pX9an1LBZl6m5giZd9eV0dv5FF29rLIQbEbQ6JNc3bWGzz/B1p
SzzfQbPOzIbF1bh1rx8QtzqquP5jx0LA01rymvj8YY7M9IMsLqR4xf4k7nQf
3fLUhUW7yHyXHvnfUnyrG7f4sig0kPqUTWx+svjvrJMsZKJWrHlFLBbw7yzO
aRaGPR1pY8S7g67ubDjHgnfe3XMt+d9nRTq9tYhmoXg+WKqH+LFor19uLJl/
sYL7bFI/PKO3qsyOJ+vvkWteSfz82lKbV6nk+xtsupFIHHpD+pN1Fot7ovJ1
dqRejRemde+rZRG6teT6HFL/MooTLpQ8I+MJxTk7iHeVXtLmNrDIn5Hhf4k4
r8LH7eNrFhtyTXfPcKPgUb9+8MAXFvGVPnM4pP52dHSNHpIQoHdgMG0dqddR
X99dq54sgFrAJ5Uo4pU9L5ZrSQmwVNpY1Eac1F9wskdGgJ5pBn5+pP5bj4VK
uCkL4N2otaP0KNl/Skv6qIEAK5x5c71JPzF0du68ukyAdu4Wj6fEGRUZFaVG
ArjvrrnJkH4U5qt7RsZUgK02aXcbiM0+LxpLMxdAN1V66XIfCk/yjL+1OQmw
U367lr4f6W+yp2v/chWgStH62FXi2y5laTpHBGBSM5LGic/xVh/08xIgZZWh
6Anpf2sumH1QCBSg8NF436FTFMr37XixOV4Ay3Tpc42kfwoLYu4eSxIgaryz
0pT011S51+HxqQKUNMl9+a/fnnmyy6z7tgBv5S3KEkg/NhHalgflCjD/mdfg
sWAKDyWdcx88E8B4/uoF5qS/F2QEXNWSUAOVIKmZISL902y7YvRkNcwIFi1Y
TfLElk7BlQlSarDjupp8IO7g1Ua9lFHDbKdpHrNJ/uBcmRXpr6yGZLNelUtX
KDidTg9uMFDDqs3GN/PiKcyxfHnU100NpTu1PKpJ/rH/cXPws4caKp1dVwXe
pnA30sdjyzE1CBaIKYPkpdW1qu6snxp6nku13Sf5ysPE6fCzUDVc21uWnZNJ
oVpLbD//hhrOFVSGfsym4DNBY3PNWzVcPSrfP4Hku88rpZvZD2owkJEOaybe
HNy991S7Glr/PGXvlJH+OSPTdVGXGpY1P9lo+5hCjZIwPHFIDWt8znjVV1FQ
1jes8+SoIzFAckHbM5I3XczN5q5Vh1mU2cpikk+lWrzXuNxTR8zz+iZXkocX
Hbs1LTxXHSX98t+OkLxsQzXXZ+ar41XN+ra/xTm4v2bh7u8PidOCdp2aSPJ7
9jd3z1p1yMutSUycwkFJmN1V78/qCBR12U2ZyYGX8cbes7M1sHB1UZsvyeuf
/keLEnw18NYn9M7wag66z3wYlvDXQCTfatvGteQ+Y5u09+BpDXw0fT6Sso4D
MRVaUzdEA1ZD9zeZb+BAMVq1tDRaA3HTXRQKzDnYHKTS9ylLA95TXLWKdpP7
icNcM61ODQTr1mw+7cmBSE1hYt52TQxYDkTOIvehiFj7ChtVLRTduZ0ZKyUL
K9HuuqkdWnj6Ofv4Ex9ZDK28PpzwYB6kF5vldU+Sw8dPJl6lQdqgipwnal+W
Q/Jy3Tm1NvOx39DwOgt5vCzND/5XXgfaO0riAnvl8ej23eunvHVQW+GgvPrG
LCj2Pmt49FkHdeVLzLknZyNa/eo/tet10T/S06ywQwF+Dy/ErM/TxZ8dEYKB
zYowm7P9+hO+Hpz8h0cNLeYALhXWM8/p4crCWQ1rLJUQr2TLr/mhB4v8Daa3
T84F79GNqI3WC6Cv9MKYSlZG+LxSjfoHxF+31p2oUcGBgYnPqzSEsFy52P1Z
uCps7varngsXwkU0eth4IY1DAVt/r7sohNTM4KEF+jQ8t95rmnpJiGtlHdMF
S2mc/XE0LCKK+Jlqy3RjGukGw6PRcUJwfY8PtZvRGCoZf/m/NCG06XL9NDsa
EfVTL5RVCLElpbwpQUQjNsX54NkqIWL/3C9KiaaR4lm3Yk21EC8jTmrfjKWR
Ix8xUl0nhK7V2TtZiTRarDgHXzQK4eDvvagunYbgo8KKto9CNCiOrVUpp6Fz
z1s59ZMQbp94bzUraSwJfDN8oEOIiR1zR/WraZgJ4u50fiXrCQ9t2vacxhEn
VeXv34WIObKBuvSWhu+yU8NZA0K0DU77nfKeRuC0tgbPH0KoZiS5ZX+kEZOZ
Ejo0JIRvucnIq04ayf4THfJHyPp5m2f0dNNI23LAxPe3EJn3dTLF+mjc4z6e
a/hHiPtn2l/JDtB4MMAOj48LkRvkFK7+k8b/Af2EawM=
        "]]},
      Annotation[#, "Charting`Private`Tag$5208584#1"]& ]}, {}}, {{}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
      0.012833333333333334`], AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJxTTMoPSmViYGAQBWIQDQEf7Hty1/td+KzoABVw+OSrf+Z9qAKUz+Hw7orv
tYt7ZKF8AYclPJ6SkbLSUL6Iwxu2PdV/L0hA+RIOSYz/DnreFoPyZRxa670N
Re1FoXwFB5VyX1fuf8JQvpLDhbUZmoslYHwVh7PiIkwtfUJQvprDXF9DfqV4
GF/D4f+5sMkeXTC+loPAkq38/gIw/ToOj0/fv/boI4yv52DnxBfQog+z38Ch
JpLJ8NcJmPsMHWxucRj82ANzv5HDq49XDIU5Yf4zdrDLXrbz20qY/00chJ4m
KN/1hYWPqYOXpOVpibeKDgBEsk6P
       "]]}, {
      {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
       0.012833333333333334`], AbsoluteThickness[1.6]}, {}}, {
      {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
       0.012833333333333334`], AbsoluteThickness[1.6]}, {}}}, {{}, {}}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{Automatic, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{All, {0, 9.873818497472758}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8538362850216036`*^9, 3.854101458037591*^9, 3.8541019092820697`*^9, 
  3.8674062291319656`*^9, 3.8674077474607763`*^9, 3.867492476688346*^9},
 CellLabel->
  "During evaluation of \
In[231]:=",ExpressionUUID->"11b0a819-bc49-423e-9503-96baf5f1d9de"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Interpolated frequency shift with best match is \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"-", "0.5345596283672306`"}], "\[InvisibleSpace]", "\<\" Hz\"\>"}],
  SequenceForm[
  "Interpolated frequency shift with best match is ", -0.5345596283672306, 
   " Hz"],
  Editable->False]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8538362850216036`*^9, 3.854101458037591*^9, 3.8541019092820697`*^9, 
  3.8674062291319656`*^9, 3.8674077474607763`*^9, 3.86749247669433*^9},
 CellLabel->
  "During evaluation of \
In[231]:=",ExpressionUUID->"83cf060e-6ea7-4539-95c5-5f7989494e59"],

Cell[BoxData[
 StyleBox["\<\"Coupling constants\"\>", "Subsection",
  StripOnInput->False]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8538362850216036`*^9, 3.854101458037591*^9, 3.8541019092820697`*^9, 
  3.8674062291319656`*^9, 3.8674077474607763`*^9, 3.867492476696325*^9},
 CellLabel->
  "During evaluation of \
In[231]:=",ExpressionUUID->"5948af03-b1c5-4991-965c-8794d9e4d3c1"]
}, Open  ]],

Cell[BoxData[
 TagBox[GridBox[{
    {"5.839430627131369`"},
    {"48.16865470595593`"},
    {"1.9333216072060522`"},
    {
     RowBox[{"-", "0.07944990842957321`"}]},
    {"30.095779589451723`"},
    {"1.382859369893452`"},
    {
     RowBox[{"-", "0.5345596283672306`"}]}
   },
   GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[2.0999999999999996`]}, 
       Offset[0.27999999999999997`]}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.8535790442807336`*^9, 3.8535794424007387`*^9, 
  3.853836716314269*^9, 3.8541018267310925`*^9, 3.85410227581022*^9, 
  3.867406627274296*^9, 3.867408136295111*^9, 3.867492476699317*^9},
 CellLabel->
  "Out[248]//TableForm=",ExpressionUUID->"d05a6c51-3ad1-4e1a-b605-\
09d2cc119add"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Time used = \"\>", "\[InvisibleSpace]", 
   "362.3945229`10.01072661878032", "\[InvisibleSpace]", "\<\"seconds\"\>"}],
  SequenceForm["Time used = ", 362.3945229`10.01072661878032, "seconds"],
  Editable->False]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8538362850216036`*^9, 3.854101458037591*^9, 3.8541019092820697`*^9, 
  3.8674062291319656`*^9, 3.8674077474607763`*^9, 3.867492476705301*^9},
 CellLabel->
  "During evaluation of \
In[231]:=",ExpressionUUID->"ffb8c4d6-b573-41d9-a231-20282cf43ef7"]
}, Open  ]],

Cell[BoxData[""], "Input",
 CellChangeTimes->{
  3.867406238240069*^9, {3.867407094850406*^9, 
   3.86740709736171*^9}},ExpressionUUID->"c1cf03e6-ac33-4bf4-b62a-\
071740a4a171"]
}, Open  ]]
},
WindowSize->{1920, 997},
WindowMargins->{{Automatic, -1928}, {Automatic, -8}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
FrontEndVersion->"12.0 for Microsoft Windows (64-bit) (April 8, 2019)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 538, 10, 69, "Subsubsection",ExpressionUUID->"e0dd5b4c-3a91-4051-9a25-a39ac98e766a"],
Cell[1121, 34, 1437, 29, 320, "Text",ExpressionUUID->"c61c22a2-f7f7-4bd3-b074-cb3183ff65e0"],
Cell[CellGroupData[{
Cell[2583, 67, 29567, 705, 1872, "Input",ExpressionUUID->"83ce1c8d-1a22-4fa3-84c9-6c6be868c2d5"],
Cell[CellGroupData[{
Cell[32175, 776, 776, 19, 29, "Print",ExpressionUUID->"e363de3b-18e3-44bd-a478-75ae6971ab3c"],
Cell[32954, 797, 391, 6, 22, "Print",ExpressionUUID->"df5ff8ba-4fc3-42e3-84ff-6b0383b556ba"],
Cell[33348, 805, 550, 13, 22, "Print",ExpressionUUID->"8b3842ff-5e4c-471b-b2e9-e93ca4c25a1a"],
Cell[33901, 820, 411, 8, 33, "Print",ExpressionUUID->"8a2c1968-54cb-4f5a-affd-798231646ae0"],
Cell[34315, 830, 16904, 294, 230, "Print",ExpressionUUID->"334b3a6f-4a77-49c1-b8c2-8d4830c15239"],
Cell[51222, 1126, 447, 9, 33, "Print",ExpressionUUID->"7caade18-c9a9-4ac0-9fd1-17e64a817782"],
Cell[51672, 1137, 15331, 268, 225, "Print",ExpressionUUID->"7b4b7c99-a298-4599-a916-0413d600e2cc"],
Cell[67006, 1407, 479, 9, 33, "Print",ExpressionUUID->"812d0df4-dcb8-4fb4-9008-78aae2a795b9"],
Cell[67488, 1418, 8520, 159, 247, "Print",ExpressionUUID->"5af4b5db-4b8d-4671-b19a-217be50fdb9e"],
Cell[76011, 1579, 639, 14, 22, "Print",ExpressionUUID->"ac66b2d2-cd3e-45a6-affa-1e185a0ca00b"],
Cell[76653, 1595, 778, 19, 29, "Print",ExpressionUUID->"f9f58659-3cfe-46e2-91b9-9eec7cc3abd8"],
Cell[77434, 1616, 391, 6, 22, "Print",ExpressionUUID->"7d05946c-835c-4bc2-a92e-76fc96795ef6"],
Cell[77828, 1624, 554, 13, 22, "Print",ExpressionUUID->"c3a71bf5-8eef-43ec-a477-1ac67af80bad"],
Cell[78385, 1639, 411, 8, 33, "Print",ExpressionUUID->"9b1a05d8-0ad5-4159-b573-7c4802629f30"],
Cell[78799, 1649, 64572, 1076, 233, "Print",ExpressionUUID->"77d5fc38-d05a-48ca-8f28-51c399f80778"],
Cell[143374, 2727, 447, 9, 33, "Print",ExpressionUUID->"2be16e84-7366-405d-8b22-980f040f7d44"],
Cell[143824, 2738, 56888, 949, 230, "Print",ExpressionUUID->"84e96fe6-61ec-4b4b-b797-fb3d44f8cfc9"],
Cell[200715, 3689, 481, 9, 33, "Print",ExpressionUUID->"5569e310-6704-46f9-b4e3-4ff867a64731"],
Cell[201199, 3700, 8169, 153, 247, "Print",ExpressionUUID->"49f58e22-5b53-4f94-a617-26c6114595e6"],
Cell[209371, 3855, 639, 14, 22, "Print",ExpressionUUID->"e0884a68-a90e-4aee-a1c8-9bfaa0b43c24"],
Cell[210013, 3871, 776, 19, 29, "Print",ExpressionUUID->"db6a5959-3df9-4a50-93de-1e46b3aefd58"],
Cell[210792, 3892, 391, 6, 22, "Print",ExpressionUUID->"e7f698ed-2b86-4a8d-a24e-5d4cf425bee1"],
Cell[211186, 3900, 551, 13, 22, "Print",ExpressionUUID->"479b9c93-0f14-4dfa-a182-b1d5aaacf1d3"],
Cell[211740, 3915, 409, 8, 33, "Print",ExpressionUUID->"37707e4f-2318-4f2d-adf0-a9190e6f9287"],
Cell[212152, 3925, 31705, 537, 234, "Print",ExpressionUUID->"5f497058-06b4-47c3-958e-a9d2305e48a5"],
Cell[243860, 4464, 447, 9, 33, "Print",ExpressionUUID->"0d9a2282-343e-4195-8fc7-fec79b24b4c2"],
Cell[244310, 4475, 29387, 498, 230, "Print",ExpressionUUID->"e4df4a6d-6775-42e2-9361-914fec61b391"],
Cell[273700, 4975, 479, 9, 33, "Print",ExpressionUUID->"8bf7b661-5628-41b4-9c52-d0dff6078d9c"],
Cell[274182, 4986, 8378, 157, 252, "Print",ExpressionUUID->"35f44a8d-9a69-44b3-acd7-374c8eeea51b"],
Cell[282563, 5145, 642, 14, 22, "Print",ExpressionUUID->"2e6bc8bc-886d-40e7-9469-55677a06dacf"],
Cell[283208, 5161, 778, 19, 29, "Print",ExpressionUUID->"ca52983f-fb29-44c4-b376-9547ab9b007c"],
Cell[283989, 5182, 391, 6, 22, "Print",ExpressionUUID->"5749ed21-3de3-4031-b5ad-01938ec815e4"],
Cell[284383, 5190, 555, 13, 22, "Print",ExpressionUUID->"52f2acb9-90e7-4495-b941-80be93598d9b"],
Cell[284941, 5205, 409, 8, 33, "Print",ExpressionUUID->"d179a8ed-9173-4cd4-aceb-633a426131a4"],
Cell[285353, 5215, 27720, 472, 229, "Print",ExpressionUUID->"b3b45ff3-d768-49f1-b6ea-76cbffb9a58e"],
Cell[313076, 5689, 447, 9, 33, "Print",ExpressionUUID->"e116795c-e506-4c75-a741-6260104ef520"],
Cell[313526, 5700, 26069, 444, 234, "Print",ExpressionUUID->"ec822dd1-b16e-41ad-9922-2778de96c332"],
Cell[339598, 6146, 479, 9, 33, "Print",ExpressionUUID->"df1861b4-dd81-4acf-8428-b0c012092866"],
Cell[340080, 6157, 8384, 157, 251, "Print",ExpressionUUID->"28f3166c-595a-4b9f-b598-caf679cfff1c"],
Cell[348467, 6316, 659, 14, 22, "Print",ExpressionUUID->"046d7bc8-7d61-4af9-95b6-be5dad2bec03"],
Cell[349129, 6332, 778, 19, 29, "Print",ExpressionUUID->"d41e1c94-1953-42c2-a850-cd56674317d3"],
Cell[349910, 6353, 391, 6, 22, "Print",ExpressionUUID->"3547b980-5279-41f1-a67a-b0e45b925812"],
Cell[350304, 6361, 551, 13, 22, "Print",ExpressionUUID->"32d75548-2d85-4646-b276-2407f171b3c9"],
Cell[350858, 6376, 409, 8, 33, "Print",ExpressionUUID->"e7d6e95a-f6c9-4a6a-881b-47d138b4ca2c"],
Cell[351270, 6386, 60555, 1010, 229, "Print",ExpressionUUID->"d1804f06-ac02-487b-89fb-209be9ea0fde"],
Cell[411828, 7398, 449, 9, 33, "Print",ExpressionUUID->"a3947509-1dd5-4f63-b490-bb31d52aded3"],
Cell[412280, 7409, 55443, 926, 230, "Print",ExpressionUUID->"597227c2-484a-4314-bc41-a860948a9f20"],
Cell[467726, 8337, 481, 9, 33, "Print",ExpressionUUID->"d5258ad6-4ed2-48e7-84cd-6f1328d3bec5"],
Cell[468210, 8348, 8284, 155, 247, "Print",ExpressionUUID->"9277bfc0-5f1b-4a36-a30d-348358bb1574"],
Cell[476497, 8505, 642, 14, 22, "Print",ExpressionUUID->"eae4638b-467c-4df4-b08d-b6e3ba3c9869"],
Cell[477142, 8521, 778, 19, 29, "Print",ExpressionUUID->"142c104f-2c4e-4151-8f34-5e49fec762e3"],
Cell[477923, 8542, 391, 6, 22, "Print",ExpressionUUID->"5571c71f-375f-4b53-9d6c-4822a9bb777f"],
Cell[478317, 8550, 553, 13, 22, "Print",ExpressionUUID->"3b6a6d80-fb4d-489b-80d0-1061680305a0"],
Cell[478873, 8565, 411, 8, 33, "Print",ExpressionUUID->"192e1f10-d95f-4c44-8e49-936a4d20a760"],
Cell[479287, 8575, 13268, 236, 232, "Print",ExpressionUUID->"4fd521b9-b2eb-4636-b3bf-24ff2f869bd7"],
Cell[492558, 8813, 449, 9, 33, "Print",ExpressionUUID->"d727b5da-acf5-4dc1-8a1a-0fe821ab0bf3"],
Cell[493010, 8824, 12489, 221, 230, "Print",ExpressionUUID->"3631bf7f-0c07-421d-a05a-cde198da5372"],
Cell[505502, 9047, 481, 9, 33, "Print",ExpressionUUID->"57f9e702-9745-49a1-ab5a-3cd74ffb55cb"],
Cell[505986, 9058, 8393, 157, 253, "Print",ExpressionUUID->"d5d9b8da-1754-44b9-b603-9dcc13cac261"],
Cell[514382, 9217, 641, 14, 22, "Print",ExpressionUUID->"5e4f7522-c0c8-4e86-ac25-f0584f672dcf"],
Cell[515026, 9233, 778, 19, 29, "Print",ExpressionUUID->"1602dd76-9ee0-485d-a48a-a21490640d2c"],
Cell[515807, 9254, 391, 6, 22, "Print",ExpressionUUID->"a499f450-df2a-4958-a15b-ac3dec2310a1"],
Cell[516201, 9262, 553, 13, 22, "Print",ExpressionUUID->"0e22e64b-5bb9-4951-8bc3-0bf822da7414"],
Cell[516757, 9277, 411, 8, 33, "Print",ExpressionUUID->"e8f018f7-33cd-4b79-bc89-8bc538d27ba4"],
Cell[517171, 9287, 38308, 646, 228, "Print",ExpressionUUID->"c6044134-fb6c-4228-986c-d7c8ce5b9a2a"],
Cell[555482, 9935, 449, 9, 33, "Print",ExpressionUUID->"3e7491c3-b5b5-4eec-a456-bb935cbb1441"],
Cell[555934, 9946, 35807, 604, 234, "Print",ExpressionUUID->"b922114f-e345-481b-84df-1e25080f25a3"],
Cell[591744, 10552, 481, 9, 33, "Print",ExpressionUUID->"642001ba-db61-4b89-ad91-7f871fa13a7f"],
Cell[592228, 10563, 8282, 155, 247, "Print",ExpressionUUID->"11b0a819-bc49-423e-9503-96baf5f1d9de"],
Cell[600513, 10720, 656, 14, 22, "Print",ExpressionUUID->"83cf060e-6ea7-4539-95c5-5f7989494e59"],
Cell[601172, 10736, 417, 8, 33, "Print",ExpressionUUID->"5948af03-b1c5-4991-965c-8794d9e4d3c1"]
}, Open  ]],
Cell[601604, 10747, 947, 27, 147, "Output",ExpressionUUID->"d05a6c51-3ad1-4e1a-b605-09d2cc119add"],
Cell[602554, 10776, 587, 11, 22, "Print",ExpressionUUID->"ffb8c4d6-b573-41d9-a231-20282cf43ef7"]
}, Open  ]],
Cell[603156, 10790, 177, 4, 28, "Input",ExpressionUUID->"c1cf03e6-ac33-4bf4-b62a-071740a4a171"]
}, Open  ]]
}
]
*)

