(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 11.2' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    573116,      10209]
NotebookOptionsPosition[    566312,      10123]
NotebookOutlinePosition[    566709,      10140]
CellTagsIndexPosition[    566666,      10137]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["\<\
Determination of the signs and magnitudes of all heteronuclear coupling using \
IPAP-MODO-FESTA data.
Automatically determine optimum ratio when combining IP and AP data, \
adjusting ratio and number of points to shift until rms difference is minimum\
\>", "Subsubsection",
 CellChangeTimes->{{3.835342719267295*^9, 3.8353427673607473`*^9}, {
   3.835342957217922*^9, 3.8353429845994587`*^9}, {3.853579885840021*^9, 
   3.853579910287277*^9}, 
   3.8535799927992496`*^9},ExpressionUUID->"e0dd5b4c-3a91-4051-9a25-\
a39ac98e766a"],

Cell["\<\
Automatically determines the optimum ratio when combining the IP and AP data, \
adjusts the ratio and numbers of points required to shift until the RMS \
difference is at its minimum.
Information required:
shifts={chemical shift in ppm}; (each chemical shift to be separated by a \
comma)
widths={width of multiplet in ppm}; (each width to be separated by a comma)
nreps=1; (number of repetitions of that data - typically 1)
filestart=12; (EXPNO in file)
filenamebase=\[CloseCurlyDoubleQuote]data/folder/nmr/filename/\
\[CloseCurlyDoubleQuote]; (filepath of data)
procnoIP=\[CloseCurlyDoubleQuote]1001\[CloseCurlyDoubleQuote];  (PROCNO of IP \
data)
procnoAP=\[CloseCurlyDoubleQuote]1002\[CloseCurlyDoubleQuote]; (PROCNO of AP \
data - ensure IP and AP are processed with identical parameters)
Cannot determine peaks at 1.82 ppm due to significant overlap. Calculated \
manually to be +3.4658 Hz and 17.4959 Hz (difficult to determine)
\
\>", "Text",
 CellChangeTimes->{{3.835344344114542*^9, 3.835344495255948*^9}, {
  3.835345752399667*^9, 3.83534578817225*^9}, {3.835416894520056*^9, 
  3.8354170090033817`*^9}, {3.8535743479833965`*^9, 3.8535743941759214`*^9}, {
  3.8535744245888777`*^9, 3.853574427182979*^9}, {3.8535799150722027`*^9, 
  3.8535802318062067`*^9}, {3.854102540353483*^9, 3.8541025792971025`*^9}, {
  3.8541026158732696`*^9, 
  3.8541026268390203`*^9}},ExpressionUUID->"c61c22a2-f7f7-4bd3-b074-\
cb3183ff65e0"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{"Evaluate", "[", 
    RowBox[{
     RowBox[{"Context", "[", "]"}], " ", "<>", " ", "\"\<*\>\""}], "]"}], 
   "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"vardiff", "[", 
     RowBox[{"tspip_", ",", "tspap_", ",", 
      RowBox[{"ratio_", "?", "NumericQ"}], ",", 
      RowBox[{"diff_", "?", "NumericQ"}]}], "]"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"zspm", ",", "len"}], "}"}], ",", 
      RowBox[{
       RowBox[{"len", "=", 
        RowBox[{"Length", "[", "tspip", "]"}]}], ";", " ", 
       "\[IndentingNewLine]", 
       RowBox[{"zspm", "=", 
        RowBox[{"Join", "[", 
         RowBox[{
          RowBox[{"Table", "[", 
           RowBox[{"0", ",", 
            RowBox[{"{", 
             RowBox[{"i", ",", "len"}], "}"}]}], "]"}], ",", 
          RowBox[{"Join", "[", 
           RowBox[{
            RowBox[{"tspip", "-", 
             RowBox[{"ratio", " ", "tspap"}]}], ",", 
            RowBox[{"Table", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", 
               RowBox[{"i", ",", "len"}], "}"}]}], "]"}]}], "]"}]}], "]"}]}], 
       ";", "\[IndentingNewLine]", 
       RowBox[{"Total", "[", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"tspip", "+", 
           RowBox[{"ratio", " ", "tspap"}], "-", 
           RowBox[{"Take", "[", 
            RowBox[{
             RowBox[{"RotateRight", "[", 
              RowBox[{"zspm", ",", "diff"}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"len", "+", "1"}], ",", 
               RowBox[{"2", " ", "len"}]}], "}"}]}], "]"}]}], ")"}], "^", 
         "2"}], "]"}]}]}], "\[IndentingNewLine]", "]"}]}], ";"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{
   "Calculate", " ", "variance", " ", "between", " ", "shifted", " ", 
    "spectra", " ", "obtained", " ", "by", " ", "IPAP", " ", "processing"}], 
   " ", "*)"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"getpars", "[", 
    RowBox[{"filenamebase_", ",", "procno_"}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "filename", "}"}], ",", 
     RowBox[{
      RowBox[{"filename", "=", 
       RowBox[{
       "filenamebase", "<>", "\"\</pdata/\>\"", "<>", "procno", "<>", 
        "\"\</procs\>\""}]}], ";", " ", "\[IndentingNewLine]", 
      RowBox[{"stream", "=", 
       RowBox[{"OpenRead", "[", "filename", "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"offset", "=", 
       RowBox[{
        RowBox[{"Read", "[", 
         RowBox[{
          RowBox[{"StringToStream", "[", 
           RowBox[{"Find", "[", 
            RowBox[{"stream", ",", "\"\<OFFSET= \>\""}], "]"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"Word", ",", "Number"}], "}"}]}], "]"}], "[", 
        RowBox[{"[", "2", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"si", "=", 
       RowBox[{
        RowBox[{"Read", "[", 
         RowBox[{
          RowBox[{"StringToStream", "[", 
           RowBox[{"Find", "[", 
            RowBox[{"stream", ",", "\"\<SI= \>\""}], "]"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"Word", ",", "Number"}], "}"}]}], "]"}], "[", 
        RowBox[{"[", "2", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"Close", "[", "stream", "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"filename", "=", 
       RowBox[{"filenamebase", "<>", "\"\</acqus\>\""}]}], ";", " ", 
      "\[IndentingNewLine]", 
      RowBox[{"stream", "=", 
       RowBox[{"OpenRead", "[", "filename", "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"sfo1", "=", 
       RowBox[{
        RowBox[{"Read", "[", 
         RowBox[{
          RowBox[{"StringToStream", "[", 
           RowBox[{"Find", "[", 
            RowBox[{"stream", ",", "\"\<SFO1= \>\""}], "]"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"Word", ",", "Number"}], "}"}]}], "]"}], "[", 
        RowBox[{"[", "2", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"swp", "=", 
       RowBox[{
        RowBox[{"Read", "[", 
         RowBox[{
          RowBox[{"StringToStream", "[", 
           RowBox[{"Find", "[", 
            RowBox[{"stream", ",", "\"\<SW= \>\""}], "]"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"Word", ",", "Number"}], "}"}]}], "]"}], "[", 
        RowBox[{"[", "2", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"Close", "[", "stream", "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"offset", ",", "si", ",", "sfo1", ",", "swp"}], "}"}]}]}], 
    "\[IndentingNewLine]", "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"process", "[", 
     RowBox[{
     "filenamebaseIP_", ",", "filenamebaseAP_", ",", "shift_", ",", "width_", 
      ",", "swp_", ",", "offset_", ",", "si_", ",", "sfo1_"}], "]"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "diff", ",", "dip", ",", "start", ",", "end", ",", "hzpp", ",", 
        "ncproc", ",", "spip", ",", "spap"}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"filename", "=", 
        RowBox[{"filenamebaseIP", "<>", "\"\</procs\>\""}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"stream", "=", 
        RowBox[{"OpenRead", "[", "filename", "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"ncproc", "=", 
        RowBox[{
         RowBox[{"Read", "[", 
          RowBox[{
           RowBox[{"StringToStream", "[", 
            RowBox[{"Find", "[", 
             RowBox[{"stream", ",", "\"\<NC_proc= \>\""}], "]"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"Word", ",", "Number"}], "}"}]}], "]"}], "[", 
         RowBox[{"[", "2", "]"}], "]"}]}], ";", " ", 
       RowBox[{"(*", " ", 
        RowBox[{
        "Need", " ", "to", " ", "correct", " ", "for", " ", "any", " ", 
         "difference", " ", "in", " ", "scaling", " ", "during", " ", "FT", 
         " ", 
         RowBox[{"etc", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
       RowBox[{"Close", "[", "stream", "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{"filename", "=", 
        RowBox[{"filenamebaseIP", "<>", "\"\</1r\>\""}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"spip", "=", 
        RowBox[{
         RowBox[{"2.", "^", "ncproc"}], " ", 
         RowBox[{
          RowBox[{"Import", "[", 
           RowBox[{"filename", ",", "\"\<Integer32\>\""}], "]"}], "/", 
          RowBox[{"10", "^", "6"}]}]}]}], ";", " ", "\[IndentingNewLine]", 
       "\[IndentingNewLine]", 
       RowBox[{"filename", "=", 
        RowBox[{"filenamebaseAP", "<>", "\"\</procs\>\""}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"stream", "=", 
        RowBox[{"OpenRead", "[", "filename", "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"ncproc", "=", 
        RowBox[{
         RowBox[{"Read", "[", 
          RowBox[{
           RowBox[{"StringToStream", "[", 
            RowBox[{"Find", "[", 
             RowBox[{"stream", ",", "\"\<NC_proc= \>\""}], "]"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"Word", ",", "Number"}], "}"}]}], "]"}], "[", 
         RowBox[{"[", "2", "]"}], "]"}]}], ";", " ", 
       RowBox[{"(*", " ", 
        RowBox[{
        "Need", " ", "to", " ", "correct", " ", "for", " ", "any", " ", 
         "difference", " ", "in", " ", "scaling", " ", "during", " ", "FT", 
         " ", 
         RowBox[{"etc", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
       RowBox[{"Close", "[", "stream", "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{"filename", "=", 
        RowBox[{"filenamebaseAP", "<>", "\"\</1r\>\""}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"spap", "=", 
        RowBox[{
         RowBox[{"2.", "^", "ncproc"}], " ", 
         RowBox[{
          RowBox[{"Import", "[", 
           RowBox[{"filename", ",", "\"\<Integer32\>\""}], "]"}], "/", 
          RowBox[{"10", "^", "6"}]}]}]}], ";", " ", "\[IndentingNewLine]", 
       "\[IndentingNewLine]", 
       RowBox[{"hzpp", "=", 
        RowBox[{"swp", " ", 
         RowBox[{"sfo1", "/", 
          RowBox[{"(", 
           RowBox[{"si", "-", "1"}], ")"}]}]}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"start", "=", 
        RowBox[{"Round", "[", 
         RowBox[{"sfo1", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"offset", "-", "shift", "-", 
             RowBox[{"width", "/", "2"}]}], ")"}], "/", "hzpp"}]}], "]"}]}], 
       ";", "\[IndentingNewLine]", 
       RowBox[{"end", "=", 
        RowBox[{"Round", "[", 
         RowBox[{"sfo1", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"offset", "-", "shift", "+", 
             RowBox[{"width", "/", "2"}]}], ")"}], "/", "hzpp"}]}], " ", 
         "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"tspip", "=", 
        RowBox[{"Take", "[", 
         RowBox[{"spip", ",", 
          RowBox[{"{", 
           RowBox[{"start", ",", "end"}], "}"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"len", "=", 
        RowBox[{"Length", "[", "tspip", "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"tspap", "=", 
        RowBox[{"Take", "[", 
         RowBox[{"spap", ",", 
          RowBox[{"{", 
           RowBox[{"start", ",", "end"}], "}"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"Print", "[", 
        RowBox[{
         RowBox[{"Style", "[", 
          RowBox[{"\"\<Chemical shift = \>\"", ",", "\"\<Subsection\>\""}], 
          "]"}], ",", 
         RowBox[{"Style", "[", 
          RowBox[{"shift", ",", "\"\<Subsection\>\""}], "]"}], ",", 
         RowBox[{"Style", "[", 
          RowBox[{"\"\< ppm\>\"", ",", "\"\<Subsection\>\""}], "]"}]}], "]"}],
        ";", "\[IndentingNewLine]", 
       RowBox[{"(*", " ", 
        RowBox[{
         RowBox[{
         "Do", " ", "optimistion", " ", "in", " ", "two", " ", "stages"}], 
         ",", " ", 
         RowBox[{
         "otherwise", " ", "fails", " ", "to", " ", "find", " ", "global", 
          " ", "minimum"}]}], " ", "*)"}], "\[IndentingNewLine]", 
       RowBox[{"res1", "=", 
        RowBox[{"NMinimize", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"vardiff", "[", 
             RowBox[{"tspip", ",", "tspap", ",", "fratio", ",", 
              RowBox[{"5", " ", "fdiff"}]}], "]"}], ",", 
            RowBox[{"fdiff", ">", 
             RowBox[{
              RowBox[{"-", "len"}], "/", "5"}]}], ",", 
            RowBox[{"fdiff", "<", 
             RowBox[{"len", "/", "5"}]}], ",", 
            RowBox[{"fratio", ">", "0.8"}], ",", 
            RowBox[{"fratio", "<", "1.2"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"fdiff", "\[Element]", " ", "Integers"}], ",", "fratio"}],
            "}"}], ",", 
          RowBox[{"MaxIterations", "\[Rule]", "200"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"res2", "=", 
        RowBox[{"NMinimize", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"vardiff", "[", 
             RowBox[{
             "tspip", ",", "tspap", ",", "fratio", ",", " ", "fdiff"}], "]"}],
             ",", 
            RowBox[{"fratio", ">", "0.7"}], ",", 
            RowBox[{"fratio", "<", "1.2"}], ",", 
            RowBox[{"fdiff", ">", 
             RowBox[{
              RowBox[{"Round", "[", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"5", " ", "fdiff"}], "/.", 
                 RowBox[{"res1", "[", 
                  RowBox[{"[", "2", "]"}], "]"}]}], ")"}], "]"}], "-", 
              RowBox[{"len", "/", "10"}]}]}], ",", 
            RowBox[{"fdiff", "<", 
             RowBox[{"Round", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"len", "/", "10"}], "+", 
                RowBox[{"5", " ", "fdiff"}]}], "/.", 
               RowBox[{"res1", "[", 
                RowBox[{"[", "2", "]"}], "]"}]}], "]"}]}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"fdiff", "\[Element]", " ", "Integers"}], ",", "fratio"}],
            "}"}], ",", 
          RowBox[{"MaxIterations", "\[Rule]", "1000"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{
       "Print", "[", "\"\<Variance and optimised shift and ratio:\>\"", "]"}],
        ";", "\[IndentingNewLine]", 
       RowBox[{"Print", "[", "res2", "]"}], ";", " ", "\[IndentingNewLine]", 
       RowBox[{"ratio", "=", 
        RowBox[{"fratio", "/.", 
         RowBox[{"res2", "[", 
          RowBox[{"[", "2", "]"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"spp", "=", 
        RowBox[{"tspip", "+", 
         RowBox[{"ratio", " ", "tspap"}]}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"spm", "=", 
        RowBox[{"tspip", "-", 
         RowBox[{"ratio", " ", "tspap"}]}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"Print", "[", 
        RowBox[{"Style", "[", 
         RowBox[{"\"\<Input data\>\"", ",", "\"\<Subsection\>\""}], "]"}], 
        "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{"Print", "[", 
        RowBox[{"ListPlot", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"spp", ",", "spm"}], "}"}], ",", 
          RowBox[{"Joined", "\[Rule]", "True"}], ",", 
          RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"len", "=", 
        RowBox[{"Length", "[", "spp", "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"zspm", "=", 
        RowBox[{"Join", "[", 
         RowBox[{
          RowBox[{"Table", "[", 
           RowBox[{"0", ",", 
            RowBox[{"{", 
             RowBox[{"i", ",", "len"}], "}"}]}], "]"}], ",", 
          RowBox[{"Join", "[", 
           RowBox[{"spm", ",", 
            RowBox[{"Table", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", 
               RowBox[{"i", ",", "len"}], "}"}]}], "]"}]}], "]"}]}], "]"}]}], 
       ";", "\[IndentingNewLine]", 
       RowBox[{"diff", "=", 
        RowBox[{"Table", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", 
            RowBox[{
             RowBox[{"2", " ", "len"}], "+", "1"}]}], "}"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"For", "[", 
        RowBox[{
         RowBox[{"i", "=", "1"}], ",", 
         RowBox[{"i", "\[LessEqual]", 
          RowBox[{"Length", "[", "diff", "]"}]}], ",", 
         RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{
           RowBox[{"diff", "[", 
            RowBox[{"[", "i", "]"}], "]"}], "=", 
           RowBox[{"Total", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"spp", "-", 
               RowBox[{"Take", "[", 
                RowBox[{
                 RowBox[{"RotateRight", "[", 
                  RowBox[{"zspm", ",", 
                   RowBox[{"len", "-", "i"}]}], "]"}], ",", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"len", "+", "1"}], ",", 
                   RowBox[{"2", " ", "len"}]}], "}"}]}], "]"}]}], ")"}], "^", 
             "2"}], "]"}]}], ";"}]}], "\[IndentingNewLine]", "]"}], ";", "\n", 
       RowBox[{"Print", "[", 
        RowBox[{"Style", "[", 
         RowBox[{
         "\"\<RMS difference vs displacement in data points\>\"", ",", 
          "\"\<Subsection\>\""}], "]"}], "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{"Print", "[", 
        RowBox[{"ListPlot", "[", 
         RowBox[{"diff", ",", 
          RowBox[{"Joined", "\[Rule]", "True"}], ",", 
          RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"min", "=", 
        RowBox[{"Min", "[", "diff", "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"For", "[", 
        RowBox[{
         RowBox[{"i", "=", "1"}], ",", 
         RowBox[{"i", "\[LessEqual]", 
          RowBox[{"Length", "[", "diff", "]"}]}], ",", 
         RowBox[{"i", "++"}], ",", " ", 
         RowBox[{
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"diff", "[", 
              RowBox[{"[", "i", "]"}], "]"}], "\[Equal]", "min"}], ",", 
            RowBox[{"minpoint", "=", "i"}]}], "]"}], ";"}]}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"Print", "[", 
        RowBox[{"Style", "[", 
         RowBox[{
         "\"\<Expansion of RMS difference vs displacement in data points, \
with parabolic fit\>\"", ",", "\"\<Subsection\>\""}], "]"}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"dip", "=", 
        RowBox[{"Take", "[", 
         RowBox[{"diff", ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"minpoint", "-", "10"}], ",", 
            RowBox[{"minpoint", "+", "10"}]}], "}"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"dipfit", "=", 
        RowBox[{"NonlinearModelFit", "[", 
         RowBox[{"dip", ",", 
          RowBox[{"a", "+", 
           RowBox[{"b", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"x", "-", "x0"}], ")"}], "^", "2"}]}]}], ",", 
          RowBox[{"{", 
           RowBox[{"a", ",", "b", ",", "x0"}], "}"}], ",", "x"}], "]"}]}], 
       ";", "\[IndentingNewLine]", 
       RowBox[{"Print", "[", 
        RowBox[{"Show", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Plot", "[", 
            RowBox[{
             RowBox[{"dipfit", "[", "x", "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"x", ",", "1", ",", 
               RowBox[{"Length", "[", "dip", "]"}]}], "}"}], ",", 
             RowBox[{"PlotRange", "\[Rule]", 
              RowBox[{"{", 
               RowBox[{"All", ",", 
                RowBox[{"{", 
                 RowBox[{"0", ",", 
                  RowBox[{"1.1", " ", 
                   RowBox[{"Max", "[", "dip", "]"}]}]}], "}"}]}], "}"}]}]}], 
            "]"}], ",", 
           RowBox[{"ListPlot", "[", 
            RowBox[{"dip", ",", 
             RowBox[{"Joined", "\[Rule]", "False"}], ",", 
             RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]}], "}"}], "]"}],
         "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{"Print", "[", 
        RowBox[{
        "\"\<Interpolated frequency shift with best match is \>\"", ",", 
         RowBox[{
          RowBox[{"-", "hzpp"}], 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"x0", "/.", 
              RowBox[{"dipfit", "[", "\"\<BestFitParameters\>\"", "]"}]}], 
             ")"}], "+", "minpoint", "-", "11", "-", "len"}], ")"}]}], ",", 
         " ", "\"\< Hz\>\""}], "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"-", "hzpp"}], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"x0", "/.", 
            RowBox[{"dipfit", "[", "\"\<BestFitParameters\>\"", "]"}]}], 
           ")"}], "+", "minpoint", "-", "11", "-", "len"}], ")"}]}]}]}], 
     "\[IndentingNewLine]", "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"shifts", "=", 
   RowBox[{"{", 
    RowBox[{
    "4.944", ",", "4.54", ",", "3.965", ",", "3.53", ",", "2.1237", ",", 
     "1.5401"}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"widths", "=", 
   RowBox[{"{", 
    RowBox[{
    "0.05", ",", "0.15", ",", "0.08", ",", "0.07", ",", "0.12", ",", "0.14"}],
     "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"njs", "=", 
   RowBox[{"Length", "[", "shifts", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nreps", "=", "1"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"filestart", "=", "9"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"js", "=", 
   RowBox[{"Table", "[", 
    RowBox[{"0", ",", "njs", ",", "nreps"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
  "filenamebase", "=", 
   "\"\<V:/dropbox/Coral/_Projects/_Publications/IPAP FESTA/Fluorohydrin \
data/data/GDP_fluoridrinaCDCl3_thais/nmr/\>\""}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"procnoIP", "=", "\"\<1001\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"procnoAP", "=", "\"\<1002\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"getpars", "[", 
   RowBox[{
    RowBox[{"filenamebase", "<>", 
     RowBox[{"ToString", "[", "filestart", "]"}]}], ",", "procnoIP"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"starttime", "=", 
   RowBox[{"AbsoluteTime", "[", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"For", "[", 
   RowBox[{
    RowBox[{"jnumber", "=", "1"}], ",", 
    RowBox[{"jnumber", "\[LessEqual]", 
     RowBox[{"Length", "[", "shifts", "]"}]}], ",", 
    RowBox[{"jnumber", "++"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"For", "[", 
      RowBox[{
       RowBox[{"rep", "=", "1"}], ",", 
       RowBox[{"rep", "\[LessEqual]", "nreps"}], ",", 
       RowBox[{"rep", "++"}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"filename", "=", 
         RowBox[{"filenamebase", "<>", 
          RowBox[{"ToString", "[", 
           RowBox[{"filestart", "+", "rep", "-", "1"}], "]"}], "<>", 
          "\"\</pdata/\>\""}]}], ";", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"js", "[", 
          RowBox[{"[", 
           RowBox[{"jnumber", ",", "rep"}], "]"}], "]"}], "=", 
         RowBox[{"process", "[", 
          RowBox[{
           RowBox[{"filename", "<>", "procnoIP"}], ",", 
           RowBox[{"filename", "<>", "procnoAP"}], ",", 
           RowBox[{"shifts", "[", 
            RowBox[{"[", "jnumber", "]"}], "]"}], ",", 
           RowBox[{"widths", "[", 
            RowBox[{"[", "jnumber", "]"}], "]"}], ",", "swp", ",", "offset", 
           ",", "si", ",", "sfo1"}], "]"}]}], ";"}]}], "\[IndentingNewLine]", 
      "]"}], ";"}]}], "\[IndentingNewLine]", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{"Style", "[", 
    RowBox[{"\"\<Coupling constants\>\"", ",", "\"\<Subsection\>\""}], "]"}], 
   "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"TableForm", "[", "js", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"jslb1", "=", "js"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"timeused", "=", 
   RowBox[{
    RowBox[{"AbsoluteTime", "[", "]"}], "-", "starttime"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{"\"\<Time used = \>\"", ",", "timeused", ",", "\"\<seconds\>\""}], 
   "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"meansdandsdmean", "[", "x_", "]"}], ":=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Mean", "[", "x", "]"}], ",", 
     RowBox[{"Sqrt", "[", 
      RowBox[{
       RowBox[{"Variance", "[", "x", "]"}], "/", 
       RowBox[{"(", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Length", "[", "x", "]"}], "-", "1"}], ")"}], ")"}]}], 
      "]"}], ",", 
     RowBox[{"Sqrt", "[", 
      RowBox[{
       RowBox[{"Variance", "[", "x", "]"}], "/", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Length", "[", "x", "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Length", "[", "x", "]"}], "-", "1"}], ")"}]}], ")"}]}], 
      "]"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{"nreps", ">", "1"}], ",", 
    RowBox[{
     RowBox[{"reslb1", "=", 
      RowBox[{"Table", "[", 
       RowBox[{"0", ",", 
        RowBox[{"Length", "[", "shifts", "]"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"reslb1", "=", 
      RowBox[{"Prepend", "[", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"Flatten", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"shifts", "[", 
              RowBox[{"[", "i", "]"}], "]"}], ",", 
             RowBox[{"meansdandsdmean", "[", 
              RowBox[{"jslb1", "[", 
               RowBox[{"[", "i", "]"}], "]"}], "]"}]}], "}"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", 
            RowBox[{"Length", "[", "shifts", "]"}]}], "}"}]}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{
         "\"\<Shift / ppm\>\"", ",", "\"\<JHF / Hz\>\"", ",", 
          "\"\<std dev / Hz\>\"", ",", "\"\<sd of mean of J / Hz\>\""}], 
         "}"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"Print", "[", 
      RowBox[{"TableForm", "[", "reslb1", "]"}], "]"}], ";"}]}], "]"}], 
  "\[IndentingNewLine]", 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.833448292510956*^9, 3.833448473320225*^9}, {
   3.833448567630739*^9, 3.833448597926832*^9}, {3.833448726706624*^9, 
   3.8334488386106873`*^9}, {3.833448894130322*^9, 3.83344899381962*^9}, {
   3.8334490263559*^9, 3.833449034371501*^9}, {3.833449208176523*^9, 
   3.83344924369489*^9}, {3.8334515420085583`*^9, 3.833451676813837*^9}, {
   3.8335325651614*^9, 3.833532637209276*^9}, {3.833532759034121*^9, 
   3.8335330239765873`*^9}, {3.8335330927635307`*^9, 
   3.8335331455943604`*^9}, {3.833533397697961*^9, 3.8335334255106373`*^9}, {
   3.8335334594455547`*^9, 3.833533507765386*^9}, {3.833533539339788*^9, 
   3.833533659575992*^9}, {3.833533697198904*^9, 3.8335337340891523`*^9}, {
   3.833533780205265*^9, 3.833533893496993*^9}, 3.833533985781467*^9, {
   3.8335340192182083`*^9, 3.833534070521394*^9}, {3.833534125296022*^9, 
   3.833534125914562*^9}, 3.833534226165428*^9, {3.833534380477125*^9, 
   3.833534380818433*^9}, {3.8335344656134453`*^9, 3.833534519575261*^9}, {
   3.8335346317293777`*^9, 3.83353463272573*^9}, 3.8335347268726482`*^9, {
   3.8335347781741343`*^9, 3.83353485994346*^9}, {3.833534904539554*^9, 
   3.83353494839614*^9}, {3.833534999551011*^9, 3.833534999698493*^9}, {
   3.833535037301165*^9, 3.833535103927022*^9}, {3.8335351368517733`*^9, 
   3.833535139414091*^9}, {3.8335352378369083`*^9, 3.833535337311174*^9}, {
   3.833535394550235*^9, 3.833535454170685*^9}, {3.8335361679797087`*^9, 
   3.8335362375090513`*^9}, {3.833536274111115*^9, 3.833536278469448*^9}, 
   3.833536449477241*^9, {3.8335364826240788`*^9, 3.8335365448917313`*^9}, {
   3.833538035225528*^9, 3.833538077529106*^9}, {3.8337034631307096`*^9, 
   3.833703463865309*^9}, {3.833703506926898*^9, 3.833703553753542*^9}, {
   3.833703617125688*^9, 3.833703688345792*^9}, {3.833703718670663*^9, 
   3.8337037764894876`*^9}, {3.8337038223632317`*^9, 
   3.8337039123907833`*^9}, {3.83370394998801*^9, 3.833704007351994*^9}, {
   3.833704056375489*^9, 3.833704136756112*^9}, {3.833704176289364*^9, 
   3.833704289758876*^9}, {3.833704391066206*^9, 3.833704429891245*^9}, {
   3.833704972721045*^9, 3.8337049956209497`*^9}, {3.8337050367076*^9, 
   3.833705038457287*^9}, {3.8337053194184847`*^9, 3.833705411458173*^9}, {
   3.8337070792528667`*^9, 3.833707127605337*^9}, {3.835337695095479*^9, 
   3.835337749538929*^9}, {3.835338577798208*^9, 3.835338620041452*^9}, {
   3.835338653990897*^9, 3.835338823765335*^9}, {3.835338865410541*^9, 
   3.835338962622757*^9}, {3.83533899622244*^9, 3.8353390024553337`*^9}, {
   3.835339165977964*^9, 3.835339170838904*^9}, {3.835339226586821*^9, 
   3.835339252159419*^9}, {3.8353394292671547`*^9, 3.835339457784766*^9}, {
   3.835339500275881*^9, 3.8353395120074873`*^9}, 3.8353400097312202`*^9, {
   3.835340043255178*^9, 3.835340049105363*^9}, {3.835340320155546*^9, 
   3.8353403214856653`*^9}, {3.8353429884303017`*^9, 3.835343088575757*^9}, {
   3.835343169936596*^9, 3.83534322437465*^9}, {3.835343746121127*^9, 
   3.8353437642293177`*^9}, {3.8353445222541227`*^9, 3.835344552148288*^9}, {
   3.835344620203895*^9, 3.835344716850436*^9}, {3.835344824168634*^9, 
   3.835344832897682*^9}, {3.835344894608045*^9, 3.835344999609126*^9}, {
   3.8353450692229977`*^9, 3.835345143285017*^9}, {3.835345243601369*^9, 
   3.835345244855967*^9}, 3.8353452928938713`*^9, {3.835345339394802*^9, 
   3.835345341993548*^9}, {3.835345390387436*^9, 3.835345394595192*^9}, 
   3.835345505879159*^9, {3.835345633336461*^9, 3.835345726337473*^9}, {
   3.8353458377226467`*^9, 3.835345843828887*^9}, {3.835372061030136*^9, 
   3.835372071264954*^9}, {3.835372109388467*^9, 3.83537218434414*^9}, 
   3.835372522290762*^9, {3.8354170700934362`*^9, 3.835417083829755*^9}, {
   3.835417167922065*^9, 3.835417196326001*^9}, {3.835418223179352*^9, 
   3.835418229883106*^9}, {3.835418393819128*^9, 3.835418488516716*^9}, {
   3.835418519132303*^9, 3.835418537842663*^9}, {3.83542543494832*^9, 
   3.835425472964828*^9}, 3.8354255498612223`*^9, {3.835425690259713*^9, 
   3.83542571399114*^9}, {3.835431541550761*^9, 3.835431541640277*^9}, {
   3.852979611453643*^9, 3.852979691319852*^9}, {3.8529797654116774`*^9, 
   3.852979781170024*^9}, {3.852979821986277*^9, 3.8529798368790913`*^9}, 
   3.852982940810091*^9, {3.8535786610591493`*^9, 3.853578743107206*^9}, {
   3.8535791499440546`*^9, 3.853579151302937*^9}, 3.8535799422709336`*^9, {
   3.853584626138847*^9, 3.8535846264724474`*^9}, {3.85358817062313*^9, 
   3.853588175851653*^9}, {3.8535882669992933`*^9, 3.853588291933257*^9}, {
   3.854102424210286*^9, 3.8541024472135954`*^9}, {3.854102490089899*^9, 
   3.8541024944999967`*^9}, {3.8541026579256215`*^9, 3.854102659298328*^9}, 
   3.854102787712702*^9, {3.854103116184321*^9, 3.854103144162113*^9}, 
   3.8541031995511036`*^9, {3.8541034917968407`*^9, 3.8541034919695945`*^9}, {
   3.85410369202219*^9, 3.8541036921439033`*^9}, 3.8541039502998095`*^9, 
   3.8674088386112814`*^9},
 CellLabel->"In[1]:=",ExpressionUUID->"83ce1c8d-1a22-4fa3-84c9-6c6be868c2d5"],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   StyleBox["\<\"Chemical shift = \"\>", "Subsection",
    StripOnInput->False], "\[InvisibleSpace]", 
   StyleBox["4.944`", "Subsection",
    StripOnInput->False], "\[InvisibleSpace]", 
   StyleBox["\<\" ppm\"\>", "Subsection",
    StripOnInput->False]}],
  SequenceForm[
   Style["Chemical shift = ", "Subsection"], 
   Style[4.944, "Subsection"], 
   Style[" ppm", "Subsection"]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.853578749640018*^9, 3.853579153998145*^9, 3.8538368371015477`*^9, 
   3.854102663741539*^9, 3.854102950555961*^9, 3.8541031567901087`*^9, 
   3.854103209573694*^9, 3.85410350499084*^9, 3.8541037980454483`*^9, 
   3.8541041079865036`*^9, {3.8674088225931683`*^9, 3.867408847936223*^9}},
 CellLabel->
  "During evaluation of \
In[1]:=",ExpressionUUID->"27377ee3-f6d1-40f9-b42b-29cae9f4ba17"],

Cell[BoxData["\<\"Variance and optimised shift and ratio:\"\>"], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8538368371015477`*^9, 3.854102663741539*^9, 3.854102950555961*^9, 
  3.8541031567901087`*^9, 3.854103209573694*^9, 3.85410350499084*^9, 
  3.8541037980454483`*^9, 3.8541041079865036`*^9, 3.8674088225931683`*^9, 
  3.8674088943693275`*^9},
 CellLabel->
  "During evaluation of \
In[1]:=",ExpressionUUID->"a028f508-8b12-4844-bed4-369db7c036e4"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"4.189082979885666`", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"fdiff", "\[Rule]", "277"}], ",", 
     RowBox[{"fratio", "\[Rule]", "0.9692153106687474`"}]}], "}"}]}], 
  "}"}]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8538368371015477`*^9, 3.854102663741539*^9, 3.854102950555961*^9, 
  3.8541031567901087`*^9, 3.854103209573694*^9, 3.85410350499084*^9, 
  3.8541037980454483`*^9, 3.8541041079865036`*^9, 3.8674088225931683`*^9, 
  3.867408894377306*^9},
 CellLabel->
  "During evaluation of \
In[1]:=",ExpressionUUID->"f58f6fc5-9b21-44ad-a0ed-e76ee709629d"],

Cell[BoxData[
 StyleBox["\<\"Input data\"\>", "Subsection",
  StripOnInput->False]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8538368371015477`*^9, 3.854102663741539*^9, 3.854102950555961*^9, 
  3.8541031567901087`*^9, 3.854103209573694*^9, 3.85410350499084*^9, 
  3.8541037980454483`*^9, 3.8541041079865036`*^9, 3.8674088225931683`*^9, 
  3.867408894381296*^9},
 CellLabel->
  "During evaluation of \
In[1]:=",ExpressionUUID->"278f7ce1-460c-4464-bb12-ce13959070d8"],

Cell[BoxData[
 GraphicsBox[{{}, {{{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJw9mXlczPv3x0ekKGQpZWssbSJdN8l2vVDWpNJNe1PaUJr2af/MTMg+lhJp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       "]]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJw9mHlcjN37x0ePJUvJllQysmUf+1p9bCmUkXYto31T0zbau2uSKEREKUb2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       "]]}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, {}, {}, {}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, {}, {}, {}}}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 656.}, {-0.1444343581232208, 6.712273204566078}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8538368371015477`*^9, 3.854102663741539*^9, 3.854102950555961*^9, 
  3.8541031567901087`*^9, 3.854103209573694*^9, 3.85410350499084*^9, 
  3.8541037980454483`*^9, 3.8541041079865036`*^9, 3.8674088225931683`*^9, 
  3.8674088945807624`*^9},
 CellLabel->
  "During evaluation of \
In[1]:=",ExpressionUUID->"2f4e6978-5a14-406e-9a1a-77b790a57e42"],

Cell[BoxData[
 StyleBox["\<\"RMS difference vs displacement in data points\"\>", 
  "Subsection",
  StripOnInput->False]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8538368371015477`*^9, 3.854102663741539*^9, 3.854102950555961*^9, 
  3.8541031567901087`*^9, 3.854103209573694*^9, 3.85410350499084*^9, 
  3.8541037980454483`*^9, 3.8541041079865036`*^9, 3.8674088225931683`*^9, 
  3.8674088949278345`*^9},
 CellLabel->
  "During evaluation of \
In[1]:=",ExpressionUUID->"6e7ca987-caa4-418c-8ff6-e06af95b8c38"],

Cell[BoxData[
 GraphicsBox[{{}, {{{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJxF3HlYTV//N/CUoa8xikIIIXMyJeEtSZRKkpBKkyR1SvN4qlOd5jMhhFDK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       "]]}}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6]}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, {}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 1313.}, {0, 7013.124513122586}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8538368371015477`*^9, 3.854102663741539*^9, 3.854102950555961*^9, 
  3.8541031567901087`*^9, 3.854103209573694*^9, 3.85410350499084*^9, 
  3.8541037980454483`*^9, 3.8541041079865036`*^9, 3.8674088225931683`*^9, 
  3.8674088950106153`*^9},
 CellLabel->
  "During evaluation of \
In[1]:=",ExpressionUUID->"633330e8-e636-49e5-8550-4f738d11e5d3"],

Cell[BoxData[
 StyleBox["\<\"Expansion of RMS difference vs displacement in data points, \
with parabolic fit\"\>", "Subsection",
  StripOnInput->False]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8538368371015477`*^9, 3.854102663741539*^9, 3.854102950555961*^9, 
  3.8541031567901087`*^9, 3.854103209573694*^9, 3.85410350499084*^9, 
  3.8541037980454483`*^9, 3.8541041079865036`*^9, 3.8674088225931683`*^9, 
  3.867408895020587*^9},
 CellLabel->
  "During evaluation of \
In[1]:=",ExpressionUUID->"8793543d-a0be-429c-bbf3-86753785986f"],

Cell[BoxData[
 GraphicsBox[{{{{}, {}, 
     TagBox[
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJwVlnk41N3/xi1FIukz1sYyy2dmGEto6pGecpO0SSVUlJBt7BU9vqGULYVk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        "]]},
      Annotation[#, "Charting`Private`Tag$79357#1"]& ]}, {}}, {{}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
      0.012833333333333334`], AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJxTTMoPSmViYGAQBWIQDQEf7P9x9/3g8E51gAo4GB7cPOWmWyKUz+Hg96X8
aLJfNJQv4PBAwu+r38MQKF/E4cGuJVv95/pB+RIOXr6Tr6lYu0L5Mg7TEkNL
kwKsoXwFB5f3B6/a7tSH8pUcGOR+XmoLUYDyVRyOf89PrBIQhPLVHHyjf3+f
d1AAytdwcPpjtfrGQXkoX8thQUN3zCUGmHk6DiyqstKfr1lB+XoO51JXVG//
5ALlGzistXYpU/CBudfQYf3T6WE3tsL8Y+Rw/cIVi12KMP8aO7jP3nHtnQEs
PEwcRO6rfj5lBgsvU4e6Z9vnr5ub6QAAY3hZwQ==
       "]]}, {
      {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
       0.012833333333333334`], AbsoluteThickness[1.6]}, {}}, {
      {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
       0.012833333333333334`], AbsoluteThickness[1.6]}, {}}}, {{}, {}}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{Automatic, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{All, {0, 225.4203230334267}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8538368371015477`*^9, 3.854102663741539*^9, 3.854102950555961*^9, 
  3.8541031567901087`*^9, 3.854103209573694*^9, 3.85410350499084*^9, 
  3.8541037980454483`*^9, 3.8541041079865036`*^9, 3.8674088225931683`*^9, 
  3.867408895164202*^9},
 CellLabel->
  "During evaluation of \
In[1]:=",ExpressionUUID->"180f3cf5-c3ad-4836-b27b-ddeb7947d6f8"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Interpolated frequency shift with best match is \"\>", 
   "\[InvisibleSpace]", "10.585118228885493`", 
   "\[InvisibleSpace]", "\<\" Hz\"\>"}],
  SequenceForm[
  "Interpolated frequency shift with best match is ", 10.585118228885493`, 
   " Hz"],
  Editable->False]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8538368371015477`*^9, 3.854102663741539*^9, 3.854102950555961*^9, 
  3.8541031567901087`*^9, 3.854103209573694*^9, 3.85410350499084*^9, 
  3.8541037980454483`*^9, 3.8541041079865036`*^9, 3.8674088225931683`*^9, 
  3.8674088951741743`*^9},
 CellLabel->
  "During evaluation of \
In[1]:=",ExpressionUUID->"e2b44823-310f-413b-b02f-18e27d6bc0e3"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   StyleBox["\<\"Chemical shift = \"\>", "Subsection",
    StripOnInput->False], "\[InvisibleSpace]", 
   StyleBox["4.54`", "Subsection",
    StripOnInput->False], "\[InvisibleSpace]", 
   StyleBox["\<\" ppm\"\>", "Subsection",
    StripOnInput->False]}],
  SequenceForm[
   Style["Chemical shift = ", "Subsection"], 
   Style[4.54, "Subsection"], 
   Style[" ppm", "Subsection"]],
  Editable->False]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8538368371015477`*^9, 3.854102663741539*^9, 3.854102950555961*^9, 
  3.8541031567901087`*^9, 3.854103209573694*^9, 3.85410350499084*^9, 
  3.8541037980454483`*^9, 3.8541041079865036`*^9, 3.8674088225931683`*^9, 
  3.8674088957916985`*^9},
 CellLabel->
  "During evaluation of \
In[1]:=",ExpressionUUID->"3933e3ae-3138-4858-bef2-b999d389b94a"],

Cell[BoxData["\<\"Variance and optimised shift and ratio:\"\>"], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8538368371015477`*^9, 3.854102663741539*^9, 3.854102950555961*^9, 
  3.8541031567901087`*^9, 3.854103209573694*^9, 3.85410350499084*^9, 
  3.8541037980454483`*^9, 3.8541041079865036`*^9, 3.8674088225931683`*^9, 
  3.8674089684653845`*^9},
 CellLabel->
  "During evaluation of \
In[1]:=",ExpressionUUID->"35e76e83-93a8-42a6-bb94-f189986a9cdd"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"107.78561380164211`", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"fdiff", "\[Rule]", "1269"}], ",", 
     RowBox[{"fratio", "\[Rule]", "0.8722159808636033`"}]}], "}"}]}], 
  "}"}]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8538368371015477`*^9, 3.854102663741539*^9, 3.854102950555961*^9, 
  3.8541031567901087`*^9, 3.854103209573694*^9, 3.85410350499084*^9, 
  3.8541037980454483`*^9, 3.8541041079865036`*^9, 3.8674088225931683`*^9, 
  3.867408968484334*^9},
 CellLabel->
  "During evaluation of \
In[1]:=",ExpressionUUID->"981027e1-f65b-4c65-9a79-0c005e1661a6"],

Cell[BoxData[
 StyleBox["\<\"Input data\"\>", "Subsection",
  StripOnInput->False]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8538368371015477`*^9, 3.854102663741539*^9, 3.854102950555961*^9, 
  3.8541031567901087`*^9, 3.854103209573694*^9, 3.85410350499084*^9, 
  3.8541037980454483`*^9, 3.8541041079865036`*^9, 3.8674088225931683`*^9, 
  3.8674089685012875`*^9},
 CellLabel->
  "During evaluation of \
In[1]:=",ExpressionUUID->"be0adde6-cb88-42ec-96e0-f925f9cf07b1"],

Cell[BoxData[
 GraphicsBox[{{}, {{{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJw8XHlcjF3YHuklCYMQQlSEMBKyXwhFGBSVMKgUybRq1bRP+0zNTDMJY0tI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       "]]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJw8XXlcTN/7HwkhCSGEkIQQQhK9kVRCUknCqCit077XtE/7NE01pRh79iRE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       "]]}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6]}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6]}, {}, {}, {}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6]}, {}, {}, {}}}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 1967.}, {-0.0416717958905141, 4.619107022697271}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8538368371015477`*^9, 3.854102663741539*^9, 3.854102950555961*^9, 
  3.8541031567901087`*^9, 3.854103209573694*^9, 3.85410350499084*^9, 
  3.8541037980454483`*^9, 3.8541041079865036`*^9, 3.8674088225931683`*^9, 
  3.8674089686688404`*^9},
 CellLabel->
  "During evaluation of \
In[1]:=",ExpressionUUID->"d2a916bb-9026-418d-9fd5-4506a1536225"],

Cell[BoxData[
 StyleBox["\<\"RMS difference vs displacement in data points\"\>", 
  "Subsection",
  StripOnInput->False]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8538368371015477`*^9, 3.854102663741539*^9, 3.854102950555961*^9, 
  3.8541031567901087`*^9, 3.854103209573694*^9, 3.85410350499084*^9, 
  3.8541037980454483`*^9, 3.8541041079865036`*^9, 3.8674088225931683`*^9, 
  3.867408971792489*^9},
 CellLabel->
  "During evaluation of \
In[1]:=",ExpressionUUID->"7788811a-04e7-4d94-be86-98578b73a3e0"],

Cell[BoxData[
 GraphicsBox[{{}, {{{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJxE23lcTN//B/AQQghJiLJECCHJlleEEEKSFtrQJmkvLdM+7dPMNDPNRCFk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       "]]}}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.003666666666666667], 
     AbsoluteThickness[1.6]}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6]}, {}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 3935.}, {0, 5449.709872195521}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8538368371015477`*^9, 3.854102663741539*^9, 3.854102950555961*^9, 
  3.8541031567901087`*^9, 3.854103209573694*^9, 3.85410350499084*^9, 
  3.8541037980454483`*^9, 3.8541041079865036`*^9, 3.8674088225931683`*^9, 
  3.8674089718652935`*^9},
 CellLabel->
  "During evaluation of \
In[1]:=",ExpressionUUID->"9117e7b6-1861-49f0-ad01-4a8033349ec6"],

Cell[BoxData[
 StyleBox["\<\"Expansion of RMS difference vs displacement in data points, \
with parabolic fit\"\>", "Subsection",
  StripOnInput->False]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8538368371015477`*^9, 3.854102663741539*^9, 3.854102950555961*^9, 
  3.8541031567901087`*^9, 3.854103209573694*^9, 3.85410350499084*^9, 
  3.8541037980454483`*^9, 3.8541041079865036`*^9, 3.8674088225931683`*^9, 
  3.8674089718722744`*^9},
 CellLabel->
  "During evaluation of \
In[1]:=",ExpressionUUID->"6fed2971-c130-4c42-806b-4e18356b9eee"],

Cell[BoxData[
 GraphicsBox[{{{{}, {}, 
     TagBox[
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJwV1nlYDW8bB/CEQiGktMjZ5pzTIi1HylJf/UKRKEo051RHi1ZpoZWQEBJS
hBYVRUQiLbRIq5J2ZKlUSiUtpNA7719zfa6ZuWau53nu+3vThfstHEVFREQk
pomI/P8qXxrlISIyZNAU31XoIxuARprpLprckIFw7w/3qwsCEBkivh5aQwYz
DjtJFkkEYPqqw9KhDkMGxx+fZUiJBKA/3S1/qmLIwH155d38r/54fn7j7KkL
Pwz6IaqFPH8Ibf6k/GWOGGT99J07xfdH+rBz28SmnwbGN0iRnWmH0NpS6qEj
+9fA1iLohJfqQWQnfDU9mDsNt65sX/KxxRc5w9EH9rTMAE1tuox4nA/m0MM4
n3RnQbTW9ZeShTcipapVkuwkQM5Mbf++4gCE73cWTn81D20qlwpyxbyQKzR8
mLNoAea1BzrWffXAHt1w5bMpC6G2beGk4Sx33Axy69PYJY2jK8PXrKK74ljC
H/PR/sVg7X9UEhq4DyINn1EQKAvtqg35CyecwPZ18t+pIgdOj4VxeKAjvozF
Wkk8k0fGv1PrWTwHbO5yDbl4QBH309SiH40KYfYlSlVJSQkmBpYL2j7Yo++F
MLTi3jL8YQcXt4zbIXbWt8ikTBr+a5mFbQw7DG/0Ka7KoqGfe27mgWV2MDsx
OTLymIYwR80n0Yp2EBOV3L2xgEb959vWdhk7+E6qMb9V0PBYJp15ScIOFoOe
ObwOGnqYp+KT+2wxr3H4U7k0HdmHGv8cjrbFiYQJjcEAOqLzBv2fjghQQJOe
YRNCR35h59kzgwKMJi1vKQ+lo7CRwdjbK4AwxS4k6SQd+9SP1C37JIB+elnl
zst0qCQ+WPu6SoCfWReF+Q/o8Av5aSGWLIBTmUr0qR46lJfNO9RkJcCNTUbO
Y33U87QN2boWAjRW8FcLB+mYo1nmnbhVAMPqqM9rxuhwPnbLJ8RIAKW6n2rf
RRm40PkpzENLgOa3JS8tlRi4n7Cyi5gvwKaBPb8YlgyITrnf+FXNR7z08YYj
1gxYp61/+7ecj9E1dzPbbBiwpL1wn1XKR2LEpHOMkIH1wa/iVAr4mOBcb53t
xcCnzvGFyRl8ZAg/5A5FMLDW+6mPQyQfUq22wc+LGPA5U/+Ta8mH09RJa4VS
Bk7PXs/NM+ejgP2A51/OwEYr8uE2Mz5c/EQGNGsZyLS5WnVyEx8lC5P4qe8Z
MJVZLqe2mg/frR36Z38ykLw5n72BxkdricO0PWpM1GR6T8/9TmJo/Tv5kBVM
iHZU3xUbICFevI2XqMWEvU2qgnUfCZ3C1c7dukzEMN+ai3WRiM6XqvHewET3
bKMlUe9IbMsuuHJGwISiOmfu7jISZanSGs+imOhsZMQWJZL4yIow+XyJCU5/
2IqT8STGkqeE02OZiN7sfN78OgnWzb7LJjeY6GnLSP0RS+JYfNFkUzoT3rvW
qNmeJ6Ef614+WMIELcUx6fthEo9PlQpoY0w0Xfuu2m1HIm1z9ZKT40w8XN6o
KGJLIk6yvn5gkglGuNgRJT6J0KhPG/NFWSiK2Bm7bzcJ0ysT6lZSLIx2XJbV
siDRcVtj6owqC3qv71nFGZFoclmVO6zOgqDKk5w0JFGhqu+zW4uFJWdDGuzW
k7iXuaWHrceCyd6wxXr6JPxznF4Xb2Thpt2qXiVdEvPKryf8smdBI1brdaEa
iWmnk3cLHFmIn3zd66xKYnTznUUv97GQxM73k1Yh8bY25+TF/Sw41gW2B3JI
pDTX718ewkKnd8KsEAaJ2CtvlaNDWfgpcfeeMZ1ExJ7PnRPHWbjhNqN0CY3E
/o8DuyoiWLhzONGobCmJ1d2zsPcKC3kjIZet5EgsT5s/UXmNBe/iX6UblpCg
ucpkaySw8Nyy0FFPlsTMQSb3XyoL0vWrJpcvJlE3pi919RELT+Rq/UwXkHCa
6fe5tpaFli/n0wVzSMgvq2yZfMMCefm42s3ZJGp1l77mNrEQ97ojsncWdV7c
Xz479p4FtHf+OC5OQqxh8TWdryxoBwxp9MwgkdfvcnHvNxYOH0KmCWVPseen
owZZODo1KflgOolmPSf/vlEWsjIeO50SJZGa+MQyfhqBgiDtS84iJKzz5myt
nkGgpvyTZO+UDSQbBUbj4gRibvxy9KTsKy6ubTGPgEW3y5Owfzbg0m1Ujiwg
sGF36b3FlNtWZ9IzpAn8sIwIu/PXBkaeu6TEFAh491vXffpjg/GTd8W1lQgY
h9tvCKWckTT1z5ZOoDm96SqLsnTT7YFcDgGlSJF2/0kbVAxOfulWoe6b5TRw
KQfP2t62SJ16/+rb1LYJG3xZM17lwSOws9ru6zbKVyxNS+JWERjKemk9n7Lp
/sTc8tUEjFgxafW/bSByevTB6DoC5svqW65Szr5pnEZfT0AmJaDbgfK+gusJ
ZkYEorPONmpTVmweignaRKB6s8RNMcp1340i0zYTyHcfM/swboOw2VdPNG0l
sHfJlvc5lHWZA8Gi5gRKt0puiqHcv3a974qdBD5K6l30p5xoddmN3EXggeWb
AgHlnV69wtN7CKzhNpUZU54VsW7PEz6BI2FGD3QoFyRfMO+0IxDsuiyAS9nr
WZexlAMBzXeOdCXKrBY9rHMmkNAgmy5LuXXo3CpXVwIvrVZKLaZ8dk6HeqwH
gZS9z61kKIOlwy71IrB2IitYgfLouoilP3wInJNfdIxFOW3XR2mlQ9R+l350
0qRMHtCS3BJIwHp8saohZakz4dP9Qwg0PH5aa0W5NOXdREooAfG/Zeb7Kfs/
Vx9+c5zASA2yz1BWaz3W+y+cwBUu++ddyp9/NH9WjSAwJnlIto5ytIRqq/U5
ApJB2kvGKRsTR16fiCLwzttmnEmt9x/9hrKsSwSEo4M5Oyjv9Q56LBlH4Fq0
ddNzyjpaHx8r3yDAmas5NU55zjCebEwkYFPT3a5D7f+DA2I5obcIPGP1vXlG
+bimS86NdALf8ld9EqPOk9WP6py8DALFccLUHZT/eF14OppFwGXFdnKc8muN
0acLnhDQ61q4dTt1Pm8OWeWq5xJ41JH18y5lEy/FvH2F1PpnR/h6Uuc9Zv/t
/LZqAvbZV+VpVL24rJhT8LuWgP/tjfWXKa/97l4gU09Ap6POcD5Vb52eWs+2
txK4rx5iNncaCQ3PZ89LvxAIZ66U0qHqdbo6rbC9h0DHjleRlf+v34Fjhf/6
CHRXo8yOqu9gD+Mi3R8Evl4sto2bSaLSvaE44y9VL8GMdaupfnFdTaekUoSN
Q33Jx75R9uq/UtI9nY3iBNGjiVR/kXEXvKDNYWNb+660xRIkhG69pdEybFgU
2SepzSOxUtX05UM5NnTdau5NUp717f7LWkU2KvgyPrXzSWS6+pbNYrLxWQ7c
I1Q/++MyVR68go2JgeG1c6l+91pZWHFViw12s7HUBOWbvaUVT1ZS92cGX++T
IWHiElE5tIaN+LWBn5qp/hmzb3G1gzEbNTOb57cpkljhrFpras/GK3EJ+asE
lXcuy/bfc2Bjner8mndsEmfdF0nN28fGCpuj7TQuid4Dk+avPdmI/pypnkf1
/+Tg6ibzYDYcjq7cQ9cgIXvR7YNVLBuKCp1jxWuoPI22PZwTx0aMWEWhyToS
vrE7li2JZyPqn/y3Jip/3lxfY/82hY2Z0hJOk1Q+nbkt0WWTxcZY46KBQGMS
UwV3++1q2Bi8X25gakXifmHCueI6NryE52jy1iTIkkvqjEY2DjCKhf1UPuaW
B3l1vmPjZ7m3RDyVnz71W0Ydv7Ihnv5vYKUjiZ6eb5Ou0znAi6e/VvlR67dQ
TcJPjwNp6ydLT1yh8trDo/faWg5Ek2a/eRJHfa/8fnmJAQf2+r929lN5Hxms
GSa1kQO3g0m1wiQqj7t1/t614ODBe83TIXdIVOWu/97hxoFEkKGC6zMSL+12
NWyP52BckvloWTcJXv6Vh4eSOCjrLAqo/krl5eJ35+NTOJg+/7dU0DcSYVWk
af8dDqqEug+7hkgY8oQvT+ZwcGZq+OnXSRJF4h45z+s4eD/Xuit1IR/5949d
U5vORXZI+8M/hnyImVrKx4pxMU/4xdBpIx/mvZyr0+ZQfrdwW6MJn5pra2Ka
pbj4Fzbc+mw7H4uuyl4MVeLiellBVpmAD7fjGaca9bhoGg8+nBnEh4J1s1+w
Fxdr5DIOfnhKzXNjaaPdPlwYeNM9mql58OHFIB/zQ1z0CEo+NhTxsamGdoB9
mAvuSLh2WwUfPoZu7nVnuHARV0hmvOWjWk1kL+s2F18/esaFT/ARNE1l+6sP
XLwzedl7BwJ0G0m0stu5yOcFSCptEGD7qX7bo1+40J/WGnrZRADW/Mz9Ot+4
UDOIEVyg5uFXirzzieNc3DJbPFjgQM2/uvq1vouUIV+wlN95WoASTwvTpSbK
+FW3K8ijRYA5bYHGntnKONbh9fTgEVvoHEqfez5HGZqcwu74MFvYL2ytz8xT
hp78SHPVaVs8NV7J/1GkDIGE5N/l1Pzv9Pj7Ad8aZXyXE7Wjp9uiONLhWmC3
MrS//gstaLCF/3qzwfAlKkhNuSHbsdgOXbfo0QnBKngTaRt/1scO0Vy5GbmW
qpDPuD0cbm2PqDincnuaGo6Xim1YbibEnmh+rWSPGsZkLNM7yb0YN0r9nfB8
OaxfaInQUxzQ2WXoX3JSHa1FEX7to464uU5TocZ+BRTnlU/ohDmjuSTv1CMZ
Dfg7P+3fIueCF3ceph4N1MBoc7dIQqkr5AfrGl90ayDxlUbqwGN3xCpfu1ez
RRP5l2V9qlI9cbjo3JUtuZoY8vQZf+/lBVMFy9QqlhZEn7WqKFw7AHiW2yw4
rQVZDe2k4SJvxCsKWa/GtKDou3ksTsoXzBe3Y8xstPGkVEVicrcfzi8vUal/
rg2vSI2ojrsH4Tgy402lCg9OF+pObVH1h/3DYdrp8zwM7TDRa04MgOuxHX82
X+BhiXtyYfDtAPjuyG6RvMRD2dB5P9b9AISP+UVGxfCQYEDzOpQfgAy935Ox
N3jwGFmaqNocgPHiqeZbd3mwfnTu2yuJQETVS54rLedhf7S+xsihQMQle+wL
r+Shbm13WuHhQCT71v5nXM3DA3Oa+bkTgXgiEzVRXcvDr6ItGmqXAtG2Z9G+
hiYe4h4fUfa/HwhOp9x/HZ08qP2yETfpCoRGdqBSShcPqc4qAdz+QKw+8f63
Yw8PN43OyM8eCYQp58aD3j4eFIxm9NeIBMHbjab04wcPyrsbKh0VgxC89ujv
rBEeHi1f+dSMGYQTczsafcd4yPNUbtZVCcKVzOQz4+M8WOhUJkrpBuFm6Azn
vAke2gt8t/7TD8Jdc0fD4D/U+mVmKQ9sCEI2o2yp/j8ejsw/vvKDaRCej7B/
T03xcPl9l1ftjiD8D4G4jfA=
        "]]},
      Annotation[#, "Charting`Private`Tag$156559#1"]& ]}, {}}, {{}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
      0.012833333333333334`], AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJxTTMoPSmViYGAQBWIQDQEf7F/tXl968XCFA1TAIcxM5JXA1FIon8NhzvrI
rQVzi6B8AYc9W3/ULD6bD+WLODzgNuKv+5oF5Us4pPLl34w9kgblyzhMipn3
rd4rGcpXcNiVU77x1dQEKF/Joe3Rg8D7ybFQvorDSzPrA02+0VC+msOWUJl6
909RUL6GQ7nO3kllITFQvpaDkfH09m958VC+jsOqrWXXN0glQfl6DjsUcz01
vFKhfAOHusjFr15aZEL5hg560m9yeK/nQvlGDifnTwkT7CyE8o0dbn5n2H8t
qwTKN3FQ8LVadb21HMo3ddic5aE+51yVAwAw8FqX
       "]]}, {
      {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
       0.012833333333333334`], AbsoluteThickness[1.6]}, {}}, {
      {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
       0.012833333333333334`], AbsoluteThickness[1.6]}, {}}}, {{}, {}}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{Automatic, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{All, {0, 471.8044357406292}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8538368371015477`*^9, 3.854102663741539*^9, 3.854102950555961*^9, 
  3.8541031567901087`*^9, 3.854103209573694*^9, 3.85410350499084*^9, 
  3.8541037980454483`*^9, 3.8541041079865036`*^9, 3.8674088225931683`*^9, 
  3.86740897194508*^9},
 CellLabel->
  "During evaluation of \
In[1]:=",ExpressionUUID->"5550ae59-8471-4ba2-ac36-008c3366e0c9"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Interpolated frequency shift with best match is \"\>", 
   "\[InvisibleSpace]", "48.41998229974684`", 
   "\[InvisibleSpace]", "\<\" Hz\"\>"}],
  SequenceForm[
  "Interpolated frequency shift with best match is ", 48.41998229974684, 
   " Hz"],
  Editable->False]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8538368371015477`*^9, 3.854102663741539*^9, 3.854102950555961*^9, 
  3.8541031567901087`*^9, 3.854103209573694*^9, 3.85410350499084*^9, 
  3.8541037980454483`*^9, 3.8541041079865036`*^9, 3.8674088225931683`*^9, 
  3.867408971951064*^9},
 CellLabel->
  "During evaluation of \
In[1]:=",ExpressionUUID->"415234f5-f322-4d6e-99fd-5d4df49e1ced"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   StyleBox["\<\"Chemical shift = \"\>", "Subsection",
    StripOnInput->False], "\[InvisibleSpace]", 
   StyleBox["3.965`", "Subsection",
    StripOnInput->False], "\[InvisibleSpace]", 
   StyleBox["\<\" ppm\"\>", "Subsection",
    StripOnInput->False]}],
  SequenceForm[
   Style["Chemical shift = ", "Subsection"], 
   Style[3.965, "Subsection"], 
   Style[" ppm", "Subsection"]],
  Editable->False]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8538368371015477`*^9, 3.854102663741539*^9, 3.854102950555961*^9, 
  3.8541031567901087`*^9, 3.854103209573694*^9, 3.85410350499084*^9, 
  3.8541037980454483`*^9, 3.8541041079865036`*^9, 3.8674088225931683`*^9, 
  3.8674089725058055`*^9},
 CellLabel->
  "During evaluation of \
In[1]:=",ExpressionUUID->"562da4fe-aaf5-4df8-ba4d-0887a5d170a4"],

Cell[BoxData["\<\"Variance and optimised shift and ratio:\"\>"], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8538368371015477`*^9, 3.854102663741539*^9, 3.854102950555961*^9, 
  3.8541031567901087`*^9, 3.854103209573694*^9, 3.85410350499084*^9, 
  3.8541037980454483`*^9, 3.8541041079865036`*^9, 3.8674088225931683`*^9, 
  3.8674090163436394`*^9},
 CellLabel->
  "During evaluation of \
In[1]:=",ExpressionUUID->"139aaa46-2d8e-4d81-9c9f-2a545a89d7d7"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"30.962137079632704`", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"fdiff", "\[Rule]", 
      RowBox[{"-", "3"}]}], ",", 
     RowBox[{"fratio", "\[Rule]", "0.7`"}]}], "}"}]}], "}"}]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8538368371015477`*^9, 3.854102663741539*^9, 3.854102950555961*^9, 
  3.8541031567901087`*^9, 3.854103209573694*^9, 3.85410350499084*^9, 
  3.8541037980454483`*^9, 3.8541041079865036`*^9, 3.8674088225931683`*^9, 
  3.86740901635461*^9},
 CellLabel->
  "During evaluation of \
In[1]:=",ExpressionUUID->"9664e52b-3f40-4598-bfb6-5d694cf3ad86"],

Cell[BoxData[
 StyleBox["\<\"Input data\"\>", "Subsection",
  StripOnInput->False]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8538368371015477`*^9, 3.854102663741539*^9, 3.854102950555961*^9, 
  3.8541031567901087`*^9, 3.854103209573694*^9, 3.85410350499084*^9, 
  3.8541037980454483`*^9, 3.8541041079865036`*^9, 3.8674088225931683`*^9, 
  3.8674090163615923`*^9},
 CellLabel->
  "During evaluation of \
In[1]:=",ExpressionUUID->"a18aae7d-dd36-4a91-8dc6-656499298ec3"],

Cell[BoxData[
 GraphicsBox[{{}, {{{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJw9nHlczN/3x4siIlmiROIjQipJSpaXpQUhRIkybVq0TPu0TzMtM01Tg0qW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       "]]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJw1m3lczN/3x8datmSPFpEl+yAUyStLhVIpSuto3037tM+0Tk1NI0UiEip7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       "]]}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, {}, {}, {}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, {}, {}, {}}}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 1050.}, {-0.02013173125, 2.1716311203125}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8538368371015477`*^9, 3.854102663741539*^9, 3.854102950555961*^9, 
  3.8541031567901087`*^9, 3.854103209573694*^9, 3.85410350499084*^9, 
  3.8541037980454483`*^9, 3.8541041079865036`*^9, 3.8674088225931683`*^9, 
  3.8674090164353957`*^9},
 CellLabel->
  "During evaluation of \
In[1]:=",ExpressionUUID->"fc88b7eb-47e7-4a72-a2cc-a213625e02a1"],

Cell[BoxData[
 StyleBox["\<\"RMS difference vs displacement in data points\"\>", 
  "Subsection",
  StripOnInput->False]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8538368371015477`*^9, 3.854102663741539*^9, 3.854102950555961*^9, 
  3.8541031567901087`*^9, 3.854103209573694*^9, 3.85410350499084*^9, 
  3.8541037980454483`*^9, 3.8541041079865036`*^9, 3.8674088225931683`*^9, 
  3.867409017478605*^9},
 CellLabel->
  "During evaluation of \
In[1]:=",ExpressionUUID->"97a28fe4-97da-496e-bd02-cfeecbab7eef"],

Cell[BoxData[
 GraphicsBox[{{}, {{{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJxMnHtcTF3Ux3sIIYQQQgghCUnuPwlJCEkSRkKl0v1+me73mplmpmkKuSch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       "]]}}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6]}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, {}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 2101.}, {0, 856.5921554601423}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8538368371015477`*^9, 3.854102663741539*^9, 3.854102950555961*^9, 
  3.8541031567901087`*^9, 3.854103209573694*^9, 3.85410350499084*^9, 
  3.8541037980454483`*^9, 3.8541041079865036`*^9, 3.8674088225931683`*^9, 
  3.867409017552987*^9},
 CellLabel->
  "During evaluation of \
In[1]:=",ExpressionUUID->"b0b0713b-8b1c-4b38-a257-c335e6c6429d"],

Cell[BoxData[
 StyleBox["\<\"Expansion of RMS difference vs displacement in data points, \
with parabolic fit\"\>", "Subsection",
  StripOnInput->False]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8538368371015477`*^9, 3.854102663741539*^9, 3.854102950555961*^9, 
  3.8541031567901087`*^9, 3.854103209573694*^9, 3.85410350499084*^9, 
  3.8541037980454483`*^9, 3.8541041079865036`*^9, 3.8674088225931683`*^9, 
  3.8674090175589705`*^9},
 CellLabel->
  "During evaluation of \
In[1]:=",ExpressionUUID->"4ee4f7e2-8a1c-40ce-9642-f4534d8439c5"],

Cell[BoxData[
 GraphicsBox[{{{{}, {}, 
     TagBox[
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJwV13c8Vu0fB3CjByER2mTc576tJN1Jy/kY2bOkQkJWdlFklCSzIZE0bFGU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        "]]},
      Annotation[#, "Charting`Private`Tag$234141#1"]& ]}, {}}, {{}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
      0.012833333333333334`], AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJxTTMoPSmViYGAQBWIQDQEf7P9XmmvOO+zrABVwcFvg+G2BuDeUz+Hw30KY
c8kyDyhfwOHfRHsTg1I3KF/EgSVb2J2/wwXKl3BoYuj7q/PECcqXcYhicJQ3
6XOE8hUcauaL7+focoDylRyOcdsdyNtiD+WrOMy61GfAyQDjqznM8po91++b
HZSv4XDl12qpoCkweS2Hr9lnow9mwczTcTinWaEkGwWzT89Becfydb+nwNxj
4DD1R77mMnGYew0djm0tvHfrriuUb+QgICYhePKRO5Rv7LDE/ZCIrqIXlG/i
MHHLtiMdk32gfFOHjgCBFykm/g4ALANQiw==
       "]]}, {
      {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
       0.012833333333333334`], AbsoluteThickness[1.6]}, {}}, {
      {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
       0.012833333333333334`], AbsoluteThickness[1.6]}, {}}}, {{}, {}}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{Automatic, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{All, {0, 68.65026236416122}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8538368371015477`*^9, 3.854102663741539*^9, 3.854102950555961*^9, 
  3.8541031567901087`*^9, 3.854103209573694*^9, 3.85410350499084*^9, 
  3.8541037980454483`*^9, 3.8541041079865036`*^9, 3.8674088225931683`*^9, 
  3.8674090176301613`*^9},
 CellLabel->
  "During evaluation of \
In[1]:=",ExpressionUUID->"71a3e45e-56f6-422f-84c0-6b9c71946871"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Interpolated frequency shift with best match is \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"-", "0.10268844908610864`"}], "\[InvisibleSpace]", "\<\" Hz\"\>"}],
  SequenceForm[
  "Interpolated frequency shift with best match is ", -0.10268844908610864`, 
   " Hz"],
  Editable->False]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8538368371015477`*^9, 3.854102663741539*^9, 3.854102950555961*^9, 
  3.8541031567901087`*^9, 3.854103209573694*^9, 3.85410350499084*^9, 
  3.8541037980454483`*^9, 3.8541041079865036`*^9, 3.8674088225931683`*^9, 
  3.8674090176361465`*^9},
 CellLabel->
  "During evaluation of \
In[1]:=",ExpressionUUID->"7d303660-e8e7-42f2-ae33-61b5c412fcf4"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   StyleBox["\<\"Chemical shift = \"\>", "Subsection",
    StripOnInput->False], "\[InvisibleSpace]", 
   StyleBox["3.53`", "Subsection",
    StripOnInput->False], "\[InvisibleSpace]", 
   StyleBox["\<\" ppm\"\>", "Subsection",
    StripOnInput->False]}],
  SequenceForm[
   Style["Chemical shift = ", "Subsection"], 
   Style[3.53, "Subsection"], 
   Style[" ppm", "Subsection"]],
  Editable->False]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8538368371015477`*^9, 3.854102663741539*^9, 3.854102950555961*^9, 
  3.8541031567901087`*^9, 3.854103209573694*^9, 3.85410350499084*^9, 
  3.8541037980454483`*^9, 3.8541041079865036`*^9, 3.8674088225931683`*^9, 
  3.8674090182367973`*^9},
 CellLabel->
  "During evaluation of \
In[1]:=",ExpressionUUID->"b9dab452-2177-483a-915d-2e198e094baf"],

Cell[BoxData["\<\"Variance and optimised shift and ratio:\"\>"], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8538368371015477`*^9, 3.854102663741539*^9, 3.854102950555961*^9, 
  3.8541031567901087`*^9, 3.854103209573694*^9, 3.85410350499084*^9, 
  3.8541037980454483`*^9, 3.8541041079865036`*^9, 3.8674088225931683`*^9, 
  3.8674090568954763`*^9},
 CellLabel->
  "During evaluation of \
In[1]:=",ExpressionUUID->"808bf9ab-9d95-444b-9038-49bc06abbfa1"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"69.94921547398083`", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"fdiff", "\[Rule]", "62"}], ",", 
     RowBox[{"fratio", "\[Rule]", "0.7127826782325478`"}]}], "}"}]}], 
  "}"}]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8538368371015477`*^9, 3.854102663741539*^9, 3.854102950555961*^9, 
  3.8541031567901087`*^9, 3.854103209573694*^9, 3.85410350499084*^9, 
  3.8541037980454483`*^9, 3.8541041079865036`*^9, 3.8674088225931683`*^9, 
  3.867409056901459*^9},
 CellLabel->
  "During evaluation of \
In[1]:=",ExpressionUUID->"7e804301-2cde-4a69-b8d9-db376ea607e2"],

Cell[BoxData[
 StyleBox["\<\"Input data\"\>", "Subsection",
  StripOnInput->False]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8538368371015477`*^9, 3.854102663741539*^9, 3.854102950555961*^9, 
  3.8541031567901087`*^9, 3.854103209573694*^9, 3.85410350499084*^9, 
  3.8541037980454483`*^9, 3.8541041079865036`*^9, 3.8674088225931683`*^9, 
  3.8674090569044514`*^9},
 CellLabel->
  "During evaluation of \
In[1]:=",ExpressionUUID->"99ad1020-b1ca-40a8-8861-39c0a30242c1"],

Cell[BoxData[
 GraphicsBox[{{}, {{{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJw9m3dcze/7x4+sUIT4ZHzI6pOsQ6GsXoiKcEQayKm0NJz2rrNHJ8pKsrKT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       "]]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJw9mnlczN37/4dCZImK7GOJhISkpHrZKkKLSopMe2kx7XvN1FRTE0aKJBkR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       "]]}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, {}, {}, {}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, {}, {}, {}}}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 918.}, {-0.0044121358913702885`, 2.0757390129195112`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8538368371015477`*^9, 3.854102663741539*^9, 3.854102950555961*^9, 
  3.8541031567901087`*^9, 3.854103209573694*^9, 3.85410350499084*^9, 
  3.8541037980454483`*^9, 3.8541041079865036`*^9, 3.8674088225931683`*^9, 
  3.8674090569603033`*^9},
 CellLabel->
  "During evaluation of \
In[1]:=",ExpressionUUID->"82cac23e-f621-43b8-8918-87e8676e15aa"],

Cell[BoxData[
 StyleBox["\<\"RMS difference vs displacement in data points\"\>", 
  "Subsection",
  StripOnInput->False]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8538368371015477`*^9, 3.854102663741539*^9, 3.854102950555961*^9, 
  3.8541031567901087`*^9, 3.854103209573694*^9, 3.85410350499084*^9, 
  3.8541037980454483`*^9, 3.8541041079865036`*^9, 3.8674088225931683`*^9, 
  3.867409057725257*^9},
 CellLabel->
  "During evaluation of \
In[1]:=",ExpressionUUID->"0819e41b-8568-401d-aca0-c1b9536811f0"],

Cell[BoxData[
 GraphicsBox[{{}, {{{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJw83HlcjN8XB/AkhJC9b5KQZEv2ED72EEISQloohbTvTfu0T9M0My0IIXsI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       "]]}}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6]}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, {}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 1837.}, {0, 710.2034807755247}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8538368371015477`*^9, 3.854102663741539*^9, 3.854102950555961*^9, 
  3.8541031567901087`*^9, 3.854103209573694*^9, 3.85410350499084*^9, 
  3.8541037980454483`*^9, 3.8541041079865036`*^9, 3.8674088225931683`*^9, 
  3.8674090577752852`*^9},
 CellLabel->
  "During evaluation of \
In[1]:=",ExpressionUUID->"a37d69fb-4369-4d88-887a-f18f4c393079"],

Cell[BoxData[
 StyleBox["\<\"Expansion of RMS difference vs displacement in data points, \
with parabolic fit\"\>", "Subsection",
  StripOnInput->False]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8538368371015477`*^9, 3.854102663741539*^9, 3.854102950555961*^9, 
  3.8541031567901087`*^9, 3.854103209573694*^9, 3.85410350499084*^9, 
  3.8541037980454483`*^9, 3.8541041079865036`*^9, 3.8674088225931683`*^9, 
  3.867409057782278*^9},
 CellLabel->
  "During evaluation of \
In[1]:=",ExpressionUUID->"5482740b-6f30-4ab3-a3de-7a5857ff4ef3"],

Cell[BoxData[
 GraphicsBox[{{{{}, {}, 
     TagBox[
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJwV13dcTf8fB/CSX0hIkdm649xbiuQKiV6ShIzTuldJJKRURr5CkYxKU9Kk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        "]]},
      Annotation[#, "Charting`Private`Tag$311596#1"]& ]}, {}}, {{}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
      0.012833333333333334`], AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJxTTMoPSmViYGAQBWIQDQEf7PtMX59Y1RfhABVwqPI8ZBYRHw7lczh8KVkT
quAcBuULOCwumHc7zzYUyhdx+H3oa/iCwBAoX8JByDn19pWmYChfxiHirQbb
6ctBUL6Cg7LrfrXzbjC+ksM676pne+4GQvkqDiI2u96xz4Lx1Ry2pTl92l8D
42s4CG9g+d7VBuNrOUgF+vFM3w7j6ziEuDczdvLDzNdz6DL99b2gF8Y3cFCz
lPt2Vh/mPkOH2eeL/JZ8gfGNHE6tj56/8CbMP8YOTn1OTk53YP41cWh9+yb2
9U9YeJg68Kn8zPikH+EAAJQ5V40=
       "]]}, {
      {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
       0.012833333333333334`], AbsoluteThickness[1.6]}, {}}, {
      {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
       0.012833333333333334`], AbsoluteThickness[1.6]}, {}}}, {{}, {}}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{Automatic, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{All, {0, 108.05209126726736`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8538368371015477`*^9, 3.854102663741539*^9, 3.854102950555961*^9, 
  3.8541031567901087`*^9, 3.854103209573694*^9, 3.85410350499084*^9, 
  3.8541037980454483`*^9, 3.8541041079865036`*^9, 3.8674088225931683`*^9, 
  3.86740905784319*^9},
 CellLabel->
  "During evaluation of \
In[1]:=",ExpressionUUID->"b4169ecc-5550-46a5-b43a-8b097ea766dc"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Interpolated frequency shift with best match is \"\>", 
   "\[InvisibleSpace]", "2.3582913165783017`", 
   "\[InvisibleSpace]", "\<\" Hz\"\>"}],
  SequenceForm[
  "Interpolated frequency shift with best match is ", 2.3582913165783017`, 
   " Hz"],
  Editable->False]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8538368371015477`*^9, 3.854102663741539*^9, 3.854102950555961*^9, 
  3.8541031567901087`*^9, 3.854103209573694*^9, 3.85410350499084*^9, 
  3.8541037980454483`*^9, 3.8541041079865036`*^9, 3.8674088225931683`*^9, 
  3.8674090578491735`*^9},
 CellLabel->
  "During evaluation of \
In[1]:=",ExpressionUUID->"cb8229e5-cf8d-4665-b6d2-c9c542ef8a80"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   StyleBox["\<\"Chemical shift = \"\>", "Subsection",
    StripOnInput->False], "\[InvisibleSpace]", 
   StyleBox["2.1237`", "Subsection",
    StripOnInput->False], "\[InvisibleSpace]", 
   StyleBox["\<\" ppm\"\>", "Subsection",
    StripOnInput->False]}],
  SequenceForm[
   Style["Chemical shift = ", "Subsection"], 
   Style[2.1237, "Subsection"], 
   Style[" ppm", "Subsection"]],
  Editable->False]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8538368371015477`*^9, 3.854102663741539*^9, 3.854102950555961*^9, 
  3.8541031567901087`*^9, 3.854103209573694*^9, 3.85410350499084*^9, 
  3.8541037980454483`*^9, 3.8541041079865036`*^9, 3.8674088225931683`*^9, 
  3.8674090584001136`*^9},
 CellLabel->
  "During evaluation of \
In[1]:=",ExpressionUUID->"9c2047e5-51c6-46e5-b672-3fd46806b600"],

Cell[BoxData["\<\"Variance and optimised shift and ratio:\"\>"], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8538368371015477`*^9, 3.854102663741539*^9, 3.854102950555961*^9, 
  3.8541031567901087`*^9, 3.854103209573694*^9, 3.85410350499084*^9, 
  3.8541037980454483`*^9, 3.8541041079865036`*^9, 3.8674088225931683`*^9, 
  3.867409120660692*^9},
 CellLabel->
  "During evaluation of \
In[1]:=",ExpressionUUID->"df5cb873-4cb5-4c53-b5cc-b5bf44218d98"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"40.47163376628333`", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"fdiff", "\[Rule]", "257"}], ",", 
     RowBox[{"fratio", "\[Rule]", "0.7088454364921737`"}]}], "}"}]}], 
  "}"}]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8538368371015477`*^9, 3.854102663741539*^9, 3.854102950555961*^9, 
  3.8541031567901087`*^9, 3.854103209573694*^9, 3.85410350499084*^9, 
  3.8541037980454483`*^9, 3.8541041079865036`*^9, 3.8674088225931683`*^9, 
  3.8674091206646814`*^9},
 CellLabel->
  "During evaluation of \
In[1]:=",ExpressionUUID->"60b06b14-548c-47d8-aa70-9c75783e37d9"],

Cell[BoxData[
 StyleBox["\<\"Input data\"\>", "Subsection",
  StripOnInput->False]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8538368371015477`*^9, 3.854102663741539*^9, 3.854102950555961*^9, 
  3.8541031567901087`*^9, 3.854103209573694*^9, 3.85410350499084*^9, 
  3.8541037980454483`*^9, 3.8541041079865036`*^9, 3.8674088225931683`*^9, 
  3.867409120667674*^9},
 CellLabel->
  "During evaluation of \
In[1]:=",ExpressionUUID->"ca183772-6417-4c9d-ad55-c4d08899128b"],

Cell[BoxData[
 GraphicsBox[{{}, {{{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJw9nHlczN/3x0PInoQQRrZUCEUoXtYWW0iSyrQvktI27dM+7bPP2BJC6EMI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       "]]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJw9nHlczU/Ux7NHIYQQQhJCSCXJpyShKCpJ6rYX0b5vt/22363blSSEJCRK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       "]]}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6]}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6]}, {}, {}, {}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6]}, {}, {}, {}}}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 1574.}, {-0.027886805906784655`, 1.3838323819493794`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8538368371015477`*^9, 3.854102663741539*^9, 3.854102950555961*^9, 
  3.8541031567901087`*^9, 3.854103209573694*^9, 3.85410350499084*^9, 
  3.8541037980454483`*^9, 3.8541041079865036`*^9, 3.8674088225931683`*^9, 
  3.867409120746462*^9},
 CellLabel->
  "During evaluation of \
In[1]:=",ExpressionUUID->"b4bd76db-493f-41d8-bcee-75ec2c3540b6"],

Cell[BoxData[
 StyleBox["\<\"RMS difference vs displacement in data points\"\>", 
  "Subsection",
  StripOnInput->False]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8538368371015477`*^9, 3.854102663741539*^9, 3.854102950555961*^9, 
  3.8541031567901087`*^9, 3.854103209573694*^9, 3.85410350499084*^9, 
  3.8541037980454483`*^9, 3.8541041079865036`*^9, 3.8674088225931683`*^9, 
  3.867409122834879*^9},
 CellLabel->
  "During evaluation of \
In[1]:=",ExpressionUUID->"875542db-1084-44bd-9336-c009a7bf7198"],

Cell[BoxData[
 GraphicsBox[{{}, {{{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJxE3HtcTF/3B/CQhJAKIYT4hlCE3D8ISUiSJHQvSqX7lel+m2pmmmqaCSGE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       "]]}}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.003666666666666667], 
     AbsoluteThickness[1.6]}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6]}, {}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 3149.}, {0, 519.6859865167113}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8538368371015477`*^9, 3.854102663741539*^9, 3.854102950555961*^9, 
  3.8541031567901087`*^9, 3.854103209573694*^9, 3.85410350499084*^9, 
  3.8541037980454483`*^9, 3.8541041079865036`*^9, 3.8674088225931683`*^9, 
  3.8674091229181433`*^9},
 CellLabel->
  "During evaluation of \
In[1]:=",ExpressionUUID->"8d4221a5-d6a9-44d5-a349-af22759adf98"],

Cell[BoxData[
 StyleBox["\<\"Expansion of RMS difference vs displacement in data points, \
with parabolic fit\"\>", "Subsection",
  StripOnInput->False]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8538368371015477`*^9, 3.854102663741539*^9, 3.854102950555961*^9, 
  3.8541031567901087`*^9, 3.854103209573694*^9, 3.85410350499084*^9, 
  3.8541037980454483`*^9, 3.8541041079865036`*^9, 3.8674088225931683`*^9, 
  3.867409122927126*^9},
 CellLabel->
  "During evaluation of \
In[1]:=",ExpressionUUID->"6daabdf3-fd87-423c-b46b-ae5a1aee865b"],

Cell[BoxData[
 GraphicsBox[{{{{}, {}, 
     TagBox[
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJwV12k8lG8XB3CyRSqFshtm7nvGUpYmUeKo28yQlEqFVKZky04kIvtOJYRI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        "]]},
      Annotation[#, "Charting`Private`Tag$389140#1"]& ]}, {}}, {{}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
      0.012833333333333334`], AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJxTTMoPSmViYGAQBWIQDQEf7P8tz3i6UcvDASrg0JQYI3ms0h3K53D4tud4
7MurblC+gMOMC91/vznA+CIOAj9DXBbvcYXyJRye/g1eF+YF48s4bDwl+1Pt
tQuUr+CQny6w7uV8GF/J4aWu2k7/TBhfxeFT3zedb+4wvpqDxocTdXE2ML6G
w8oVn6efd4PxtRyKHu/LMEyH8XUcsh4xzf81B8bXc9Dew3XF7jmMb+Dg3v5L
8aYLzH2GDm8Mnn+ZtwXGN3KQfPjoSaMpzH/GDsoPb4lPOAbjmzhoTjA5cSUN
Fj6mDjzfa0p0RD0cAGwgXC0=
       "]]}, {
      {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
       0.012833333333333334`], AbsoluteThickness[1.6]}, {}}, {
      {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
       0.012833333333333334`], AbsoluteThickness[1.6]}, {}}}, {{}, {}}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{Automatic, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{All, {0, 53.166909354888766`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8538368371015477`*^9, 3.854102663741539*^9, 3.854102950555961*^9, 
  3.8541031567901087`*^9, 3.854103209573694*^9, 3.85410350499084*^9, 
  3.8541037980454483`*^9, 3.8541041079865036`*^9, 3.8674088225931683`*^9, 
  3.867409123014413*^9},
 CellLabel->
  "During evaluation of \
In[1]:=",ExpressionUUID->"8935a7cf-f9ea-48b9-8156-4c37f3fec82c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Interpolated frequency shift with best match is \"\>", 
   "\[InvisibleSpace]", "9.80212812265796`", 
   "\[InvisibleSpace]", "\<\" Hz\"\>"}],
  SequenceForm[
  "Interpolated frequency shift with best match is ", 9.80212812265796, " Hz"],
  Editable->False]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8538368371015477`*^9, 3.854102663741539*^9, 3.854102950555961*^9, 
  3.8541031567901087`*^9, 3.854103209573694*^9, 3.85410350499084*^9, 
  3.8541037980454483`*^9, 3.8541041079865036`*^9, 3.8674088225931683`*^9, 
  3.8674091230243855`*^9},
 CellLabel->
  "During evaluation of \
In[1]:=",ExpressionUUID->"809cae20-af6c-4141-b8f9-0748a0ca1efd"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   StyleBox["\<\"Chemical shift = \"\>", "Subsection",
    StripOnInput->False], "\[InvisibleSpace]", 
   StyleBox["1.5401`", "Subsection",
    StripOnInput->False], "\[InvisibleSpace]", 
   StyleBox["\<\" ppm\"\>", "Subsection",
    StripOnInput->False]}],
  SequenceForm[
   Style["Chemical shift = ", "Subsection"], 
   Style[1.5401, "Subsection"], 
   Style[" ppm", "Subsection"]],
  Editable->False]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8538368371015477`*^9, 3.854102663741539*^9, 3.854102950555961*^9, 
  3.8541031567901087`*^9, 3.854103209573694*^9, 3.85410350499084*^9, 
  3.8541037980454483`*^9, 3.8541041079865036`*^9, 3.8674088225931683`*^9, 
  3.86740912368157*^9},
 CellLabel->
  "During evaluation of \
In[1]:=",ExpressionUUID->"d057344c-ca04-4528-a636-ce4367064c7e"],

Cell[BoxData["\<\"Variance and optimised shift and ratio:\"\>"], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8538368371015477`*^9, 3.854102663741539*^9, 3.854102950555961*^9, 
  3.8541031567901087`*^9, 3.854103209573694*^9, 3.85410350499084*^9, 
  3.8541037980454483`*^9, 3.8541041079865036`*^9, 3.8674088225931683`*^9, 
  3.8674091937133183`*^9},
 CellLabel->
  "During evaluation of \
In[1]:=",ExpressionUUID->"c35f2da7-d38c-43ee-a516-8bee5f7cffa6"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"15.831943008688356`", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"fdiff", "\[Rule]", 
      RowBox[{"-", "17"}]}], ",", 
     RowBox[{"fratio", "\[Rule]", "0.7`"}]}], "}"}]}], "}"}]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8538368371015477`*^9, 3.854102663741539*^9, 3.854102950555961*^9, 
  3.8541031567901087`*^9, 3.854103209573694*^9, 3.85410350499084*^9, 
  3.8541037980454483`*^9, 3.8541041079865036`*^9, 3.8674088225931683`*^9, 
  3.8674091937183065`*^9},
 CellLabel->
  "During evaluation of \
In[1]:=",ExpressionUUID->"49ec4b67-b44b-4675-a8b6-121615d678bd"],

Cell[BoxData[
 StyleBox["\<\"Input data\"\>", "Subsection",
  StripOnInput->False]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8538368371015477`*^9, 3.854102663741539*^9, 3.854102950555961*^9, 
  3.8541031567901087`*^9, 3.854103209573694*^9, 3.85410350499084*^9, 
  3.8541037980454483`*^9, 3.8541041079865036`*^9, 3.8674088225931683`*^9, 
  3.8674091937203016`*^9},
 CellLabel->
  "During evaluation of \
In[1]:=",ExpressionUUID->"bea3c5be-584a-4305-b1f0-4ea117872139"],

Cell[BoxData[
 GraphicsBox[{{}, {{{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJw8nXlcTO37x0MISQghhCQVhVCEj6RCKokWS1OSNtpr2qd92qfZJyFRIpI9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       "]]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJw8nXlcTN//x8snhJA9JCGJQiUk4UWLIiRJUkmLQvu+N+3TPvtMCSGEEIoQ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       "]]}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6]}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6]}, {}, {}, {}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6]}, {}, {}, {}}}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 1836.}, {-0.041347990625, 1.16820768828125}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8538368371015477`*^9, 3.854102663741539*^9, 3.854102950555961*^9, 
  3.8541031567901087`*^9, 3.854103209573694*^9, 3.85410350499084*^9, 
  3.8541037980454483`*^9, 3.8541041079865036`*^9, 3.8674088225931683`*^9, 
  3.86740919378918*^9},
 CellLabel->
  "During evaluation of \
In[1]:=",ExpressionUUID->"e1f6cd11-349b-4bf6-9b6d-31e86588aae4"],

Cell[BoxData[
 StyleBox["\<\"RMS difference vs displacement in data points\"\>", 
  "Subsection",
  StripOnInput->False]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8538368371015477`*^9, 3.854102663741539*^9, 3.854102950555961*^9, 
  3.8541031567901087`*^9, 3.854103209573694*^9, 3.85410350499084*^9, 
  3.8541037980454483`*^9, 3.8541041079865036`*^9, 3.8674088225931683`*^9, 
  3.867409196715296*^9},
 CellLabel->
  "During evaluation of \
In[1]:=",ExpressionUUID->"fe57ff49-1015-4dc7-8d85-6d1e265923df"],

Cell[BoxData[
 GraphicsBox[{{}, {{{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJxE3HtcTFsfBvDcEkKUJCGEEJIQwtNFiiJJoqQbkkr30nW632uamWamKQkh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       "]]}}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.003666666666666667], 
     AbsoluteThickness[1.6]}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6]}, {}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 3673.}, {0, 293.7654642484065}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8538368371015477`*^9, 3.854102663741539*^9, 3.854102950555961*^9, 
  3.8541031567901087`*^9, 3.854103209573694*^9, 3.85410350499084*^9, 
  3.8541037980454483`*^9, 3.8541041079865036`*^9, 3.8674088225931683`*^9, 
  3.8674091967960763`*^9},
 CellLabel->
  "During evaluation of \
In[1]:=",ExpressionUUID->"4ce8e83f-3715-4096-95bb-69d4400fb4a1"],

Cell[BoxData[
 StyleBox["\<\"Expansion of RMS difference vs displacement in data points, \
with parabolic fit\"\>", "Subsection",
  StripOnInput->False]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8538368371015477`*^9, 3.854102663741539*^9, 3.854102950555961*^9, 
  3.8541031567901087`*^9, 3.854103209573694*^9, 3.85410350499084*^9, 
  3.8541037980454483`*^9, 3.8541041079865036`*^9, 3.8674088225931683`*^9, 
  3.8674091968020625`*^9},
 CellLabel->
  "During evaluation of \
In[1]:=",ExpressionUUID->"860f7019-dea6-42ff-aa0a-435267cf9baa"],

Cell[BoxData[
 GraphicsBox[{{{{}, {}, 
     TagBox[
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJwV13c8le8bB3CiNCQiktEZzxmE8zgOovBBUxpWQyVUqIyG+lYoSRGFSpGM
lGgo0vAjKZsUZZeWERkNq0Txu/vrvN6v13Pu537OdT/X9TlMVx/b7RPExMQm
i4uJ/fucUxzlJSb2w0zWZBmj4rE+6hjW6xjKP8yM34ders/RR0SAlDmEP8xq
7FR3tmbrQ8LwiELgth9mS4oXiP+9r4/em7sej5eT67M2KRmk6yM/csmU8bN9
Zk6F3LbseH24bvyT8pc9YBZ9v3n4d4A+bva7vxtZ+tMs80256kFzfTQ1FnsZ
KP01KyyVs31aKMKDpC/WB3LEIXw70NFvI0J2f/Qex0ZJpJbbKYV/0cNUZjDv
4/zJ+GX9skXMXw8RspWayc7T4OrsVs1V1YNrs/1TiRcySAjVKNPPFSLH1eJe
trwc+Embjs1wFsJx/kmN0ykz8c1KPshBToirfru66XUKyBtUNn1doIugpD82
g72zkCTwFCoE6EKs9hPyDivh+Jr8F42muuD6uh2011RGpoC+NEtcF+1DMWun
PZmD+IYziz++oGH1eWfAuT2qmPA3sF47jsaq9qh56urq6NOO7XL1ptFd5BpY
fmcuHozM/vzJisbcs007Ix7MRVJAoZ4tsb3TKgf7x3Nx/deqtqLlNPKHjTQ/
lc+F+GvZ7TeW0TivLVf3q20uxJTnD+xfQiOx8uN5+ekMyI8pGLMtaCzRj+i0
sGQgWnXy3lIjGjGTeyKSMxgYvVUbJtCk0b9kX8HzLAb6TzYOPNMg+zsxOjDw
kIFIP8t7tsSTJkhvWJLHQM5dO43/+DR8R7XYPeUM1C50kCnm0rD95p0tamVA
ZfjdbS82DZm6/o9lCkwMd4+JxNRo7JzpN7NPiYm05onz4lVplK6RWDxHhYnR
dt/984kDXsrf8mQyccE8XGqvCo3eUpGvnA4TEaxLjC5lGs9zDkzeuJSJ88eN
uJ2KNE4kjdDfDjHRW3D6KEuORh5DQXJjABMt3fXhBbI0BpO1G8sCmQipNhp1
JnZNcQ5IDmGitdJGInkGDdObpRX2F5hojir8H0eGxs+sc66PM5moWZH2P/Np
NNxKNaNDO5l4eyJAungijYSli9yHupmoo9T9fYjryjcbu35j4sjRN6tUiC0q
oz4tGCLru19R85Wkof7qp9b3CSz0SPo4a0rQaHhTWOKgzsLE3TP8borRWPrV
8RfLgYVkhdzJ7b8ESFQ4Xnt0PQvBi3NXriUeXHA7491GFh5JVthU/BTgStio
+0VXFibpzIy5NyTACC++acpuFtZr2SmGDwiQ7vo+50cYC6WNkZ0u3wWQbdri
n/+MhcqugbrETgHcxkPWqxSzcKq9ZJRPnMfNFB0sYyHGK7XlfocAO/aLfdWt
YiFJ83x35WcBCmcmb77ezILLGpU+yXYBfFe2mp7+ycJdq45XcZ8EaCrcJu6o
xcaeEbdmh7cC/DB/OydAwEZ/hqLW2BsBpApWi64I2fj8YDo7jdjgqbF7x3w2
OHdeS4w2CRD9WPbl3sVsTF53L+pWowCrH+TFhjux4RhV3civJ/vVE2bddWFj
qsng6eY6AY5kpVW+3saGlpHzlwji9MxzY0q72KiYK3PuV60AU+94bEv5jw33
1ILMVzUClF5XoJ9EsSG4FKJy9ZUAH6iw5Z/OsyFjwtTfQjx0bdxVIoaNLfSE
IVVi6mr3heUJ5P4T49zjqgUISnw2Wn+TjfsezNkJVQKYxniWfStko08hMrXg
hQBrFVs/yZWyMZaRQJ0i9rqwbkRUwcaRuIFlNsTx5y20/arZaNy8P7itktQr
cvZ5qXds9CS8Kp1B/DC02IkxxEaSRMfBkAoBblhVzg4ZJvtJbQt0II6Trqn5
OsqGn886a4o4MOrjkscTKJT4JmsXlwtgHTuis1aWQsqKp8rTic0cxbvy5CmY
M71NWsoEEKpOvsZWomCsdp56RKx0ZZZSnxoF01AzE1fi1jR6PHwehbOarNii
UgHqdxjm9OtQmKYX1JhAXD7PdN8GIYUWl/VvDxLfyVjRyTWikCR019QlPpjt
Vl2whIL7FZnBWyUC7DrkdYpvRSG/ee7qcGKnBb6WkSsp7DFJ8/Iktnx6LHuT
PYWufbOHaGKZsvikXy4UOQ/B2kXFAoifurbBaTsFR5WlKTeJB61uyZd4kOsz
jn6IIn5TlR1yzoeCqrVdggvxi6h88997yf3svjFXEOfbloxuOUDhybHxHfrE
KQ01PtoBFF6sCV4kTRwT+0YjOpDCh75fDcNFAoQ5fmobOU7BKqdFq4PY58PX
deVhFAwfK7GLiF2vDMoJIihkD20tyiK2dx2tvHCWwrm1XN41YuOOydgaS2FT
+HSjk8TaN2aMVFwm620Rdh4kZuxUfEAnUYje8HK9J/FMLTXvmKukHoc/nHEm
nviNzR+7TmFBwfaTDsTDGZqt225SiNXZarGCuHuPbnxlOoU1hQ0F5sTv9eav
FWZS2Ob/TNKI+NWQqeyl+xTqNjGm6RIXZS9+Pv6I1GfrzzoN4keHrIPdcimU
Rlm4solvLLAzffmEwvJ2yftqxJf/bhjWK6DAczIpm00c8dQ5K66YgstYT6IC
ceAxd0/xcgo/i2WN5Yj3WXpzPSopfLl3O1aG2G3i/k9VVRREJXm50sRz5lY0
jr4m9do8kD6NuGq+WjW/noJOypnl/xxku6fUoYmCRGx41D8beJY8CWqmsMPo
67F/3+8+ofww4wMF59AstX/rJyZ5pb9rodAZ3LxVltg2p+DalM8UxnQ87OWJ
J9XOumzwhULqyfXfFYlze3ec29pD4WN4ukiF2HtS/qmobxRumG6jGMQsxsxj
T/ooiCcdzecQNxi5HewepNCTPjZB6995sMv1URqm4ObR0ickNvWScV80Ss7v
a164MfH1K48cEsU5MEr/mPevPutzp66slORgSM3G4V/9pOucFg1LcWBhwo3d
QuwrJaVnK8NBRPCo6gFiPnOj5lE5Ds6kjzoFEb8zzmCmK3CgGrRlRSTxIu91
spNUOOjVt2Xf/nceQm5L6alzoKXQIpNLnJ48PraFycHfpNqUCmKF+rSvOTwO
bJ61VXcTty8Yfu4l4uApO5P17/zHOlgXxhlyEOy9yWU5sbXPlZwyYw7euHla
ORE/uLrsBtOcA33nbJUw4uApl07Ur+Tg/v7fuV3E89lf/SfYcPBHq8hagryv
vQvNfQX2HNSf/RGqRmy/u8v1lCP5PbYdELMnphqNYOLOQdk8nd5y4qYfZwx3
7uQgevWs153Ep6e26sR4cdDHcHaWIv1j0CRMrW8fB5tfMI4sIy5OeTuSEkju
t3jVoxrirXv9HkrHkecr3qAsRfqbgfDDQ40EDjh9Y68FxFP78WjJFQ5UfN11
NhBn7pmUHZjKwV7/oJo7xH92n/3fYBYHhRc/lTmR/nnRJ+3xu0oOBvoWun98
TuadYGre7yoOfgYqbZpJ+vHC7555ijUcqLk9HFxM3OYtfLKmiYNa4QK5DGLa
+0l+cTsHrfXev0JJf6/wrC1I/8vBOYsDBzeS+RCvZVBYIcZFid7Jm7HEu3tj
CzskuFDx23CkgVjR06mIMZULXWkreXsyX1x3dRVHK3IhNt+uey2ZP392jJf5
C7jQeTRxpR+ZXwL3eVXWLlyUW/e0m5L5+GHHXJ8727homFx9PIb4tKe8rIwH
F0VB3m0/iLv2jNpUe3OxIPNT+3UyX6/5V9bb+HNxs+/sj9lkPiud2/V+bQwX
e2X489jvBRjPu93r/JKLvAyWdnmbAHefJp0peMXFE96Rtvlk3m8qPK/DquMi
cfMFx1vEOWV+u9vecjE+4VdYJMkH+2pWDG7/woWJKGTQleSJzs6e0Z0SPKTS
zd3aPQJUz9Satt+IB92zNtvsB/69T15dlxfyYPIrbHId8d2yu2WFZjzsYsTb
2w+S/uOvGyy7hAe9vMXta0m+se4w+Hvblocdyo9atpI89DzH/HvrLh4O7Jzm
kDAqQInzuto1iTyE6hXLLJ1AQ/Q49t5/yTwUzd7sdJY4ZdbbyMQUHiI/toi/
Iw5+vsm69xYPH+QyFu0lecxC5FoSks3Dqinrc66SvPZMyis7/xUPgZbtTvJS
NB7fDbqsJcEH6/PnOD1pkn+tHebETOIj7qFdSCSxTRfvkvhUPqyvOzT0EHey
X15skOXDuXVW/PXpNOQvKZ0LVOdjaW1IqRrJm7uOp4fWGfEhHaUbw5hJQ2V9
w37/3Xz8tz+et3s2DT9xzTUv3vNR+71a0pDk6Y5F05q4LXw0P7nse5N4TWjv
lmPtfDTd2mmpyqNBzcjwMejh41GL3NgEksdfqIoirwzzMVp4orOO5HX1+aZV
vvIaSLeTCA/TplHobWuttlwDKXccFEz0aUx9d3iZ9wMNDFiuo58upvE5lRmd
5K8Jp2leR4M8aETzlSVzHObheIcFTzqaRlScW5kLQwtSct5yWoU0HKM3V0l3
akHdpHjk5CCN4UXXfyflayPkkJJjL62Lts8WBwtDdPD6buBIurcurproqrx0
IXO8NOJQULYuGgpzQ++THD/z54dL08WFKLp17/qxw+R/yV5h6rpVQsz59qqu
qIMGb1aTxp80IWI0Lt95uUIXTqu93imL6+HIszOxK3J0USmz7VqCux6sVRyu
P6eEOCoWGLGkRg/wLtsod0qIh2mKF6kFIiSqulIvhoQwfhwV9zBLBHZR2sVV
G/UQuefI2QaePiK1CzVr8vVQLjq+viZJH9sHJF9XaIqwmxXzvIRnAJd7/YxT
kSKsEu+4Mj3dADuD7P5YnRVB5KGk7XHXAL52Dxqlz4uQ4pnMLMo0wMmh/RFR
F0WYs+qp5eGHBkg3+j0akyCC5z6W59d8AwwXjDek3hYhZunJlZ2vDRBVI32m
uEwEecViW41hA8Rd8/I4WSGCuM6U7qgRA1zzrbJcVinCgbbUruE/BnikGDVS
WSXCb24v87m4Id45ynvU1ouwVTbxwJ5phuC1KVu2tomQ75mUWatuCPrBYfWU
zyLobPZ+ac40hPGJ5t/bO0Xg9VywzWQbwpqXkNnVLULmx28XIviG2LuLod7X
JwJnXrnYGqEh/Bce+501IEKT1CbnApEhTkxvrfMdEkEuaBlfz9AQsRnXwoeH
RVBfPa9PaaEhrgZKuueOiNCfzOwPMzXEbZvtFv5/RLA+t3vjGAzxgFWqZjpG
9sOYrb3X0hD5A9zf4+MixK2Y7d6x2BD/B+r2Ohc=
        "]]},
      Annotation[#, "Charting`Private`Tag$466599#1"]& ]}, {}}, {{}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
      0.012833333333333334`], AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJxTTMoPSmViYGAQBWIQDQEf7Ney//S1czF1gAo4bLj3Y9b5ZBMon8Oh5Oaq
pKn9xlC+gMMPhugdBqeMoHwRh8fJGz5tEYXxJRz4bkzdY1RiCOXLOGwQ1/hh
9cIAyldwmNBxk4e/FMZXcti/SW1ZlhyMr+JwI/nuAdYL+lC+msPM5zL5X1bC
+BoO9yYcey1/HsbXcrDyORWpqwjTr+PAwpjhtbUJxtdzMBM0Lr7MA3OPgYPt
D44/vAdgfEMHDpGM7pY5MPcbOSR1ZyeVL4T519hh2XOHy9fOwMLDxKGk4YaT
grQZlG/qMC1o/+6l7eYOAH0nU28=
       "]]}, {
      {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
       0.012833333333333334`], AbsoluteThickness[1.6]}, {}}, {
      {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
       0.012833333333333334`], AbsoluteThickness[1.6]}, {}}}, {{}, {}}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{Automatic, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{All, {0, 25.882859904890616`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8538368371015477`*^9, 3.854102663741539*^9, 3.854102950555961*^9, 
  3.8541031567901087`*^9, 3.854103209573694*^9, 3.85410350499084*^9, 
  3.8541037980454483`*^9, 3.8541041079865036`*^9, 3.8674088225931683`*^9, 
  3.8674091968688807`*^9},
 CellLabel->
  "During evaluation of \
In[1]:=",ExpressionUUID->"e7b472c4-8953-4fdd-b0fb-7c86f529c839"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Interpolated frequency shift with best match is \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"-", "0.6262576761098987`"}], "\[InvisibleSpace]", "\<\" Hz\"\>"}],
  SequenceForm[
  "Interpolated frequency shift with best match is ", -0.6262576761098987, 
   " Hz"],
  Editable->False]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8538368371015477`*^9, 3.854102663741539*^9, 3.854102950555961*^9, 
  3.8541031567901087`*^9, 3.854103209573694*^9, 3.85410350499084*^9, 
  3.8541037980454483`*^9, 3.8541041079865036`*^9, 3.8674088225931683`*^9, 
  3.867409196904786*^9},
 CellLabel->
  "During evaluation of \
In[1]:=",ExpressionUUID->"94b9dc08-fee9-45eb-8049-c11a8c0a3725"],

Cell[BoxData[
 StyleBox["\<\"Coupling constants\"\>", "Subsection",
  StripOnInput->False]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8538368371015477`*^9, 3.854102663741539*^9, 3.854102950555961*^9, 
  3.8541031567901087`*^9, 3.854103209573694*^9, 3.85410350499084*^9, 
  3.8541037980454483`*^9, 3.8541041079865036`*^9, 3.8674088225931683`*^9, 
  3.8674091969217405`*^9},
 CellLabel->
  "During evaluation of \
In[1]:=",ExpressionUUID->"e3e62d9e-d54f-4b11-bdf4-09aeb0be9eab"]
}, Open  ]],

Cell[BoxData[
 TagBox[GridBox[{
    {"10.585118228885493`"},
    {"48.41998229974684`"},
    {
     RowBox[{"-", "0.10268844908610864`"}]},
    {"2.3582913165783017`"},
    {"9.80212812265796`"},
    {
     RowBox[{"-", "0.6262576761098987`"}]}
   },
   GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[2.0999999999999996`]}, 
       Offset[0.27999999999999997`]}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.8541035040725584`*^9, 3.854103797322248*^9, 
  3.8541041072608004`*^9, 3.8541044230380955`*^9, 3.8674088318141108`*^9, 
  3.8674091969466734`*^9},
 CellLabel->
  "Out[18]//TableForm=",ExpressionUUID->"bd08b539-47f4-43f8-966d-\
56d369da998e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Time used = \"\>", "\[InvisibleSpace]", 
   "350.1462265`9.995794443845675", "\[InvisibleSpace]", "\<\"seconds\"\>"}],
  SequenceForm["Time used = ", 350.1462265`9.995794443845675, "seconds"],
  Editable->False]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8538368371015477`*^9, 3.854102663741539*^9, 3.854102950555961*^9, 
  3.8541031567901087`*^9, 3.854103209573694*^9, 3.85410350499084*^9, 
  3.8541037980454483`*^9, 3.8541041079865036`*^9, 3.8674088225931683`*^9, 
  3.8674091969686155`*^9},
 CellLabel->
  "During evaluation of \
In[1]:=",ExpressionUUID->"8513b631-82c5-4352-af0e-4a9347467f41"]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1922, 611},
WindowMargins->{{Automatic, 234}, {Automatic, 0}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
FrontEndVersion->"12.0 for Microsoft Windows (64-bit) (April 8, 2019)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 538, 10, 69, "Subsubsection",ExpressionUUID->"e0dd5b4c-3a91-4051-9a25-a39ac98e766a"],
Cell[1121, 34, 1440, 27, 254, "Text",ExpressionUUID->"c61c22a2-f7f7-4bd3-b074-cb3183ff65e0"],
Cell[CellGroupData[{
Cell[2586, 65, 29750, 707, 1872, "Input",ExpressionUUID->"83ce1c8d-1a22-4fa3-84c9-6c6be868c2d5"],
Cell[CellGroupData[{
Cell[32361, 776, 872, 21, 29, "Print",ExpressionUUID->"27377ee3-f6d1-40f9-b42b-29cae9f4ba17"],
Cell[33236, 799, 484, 8, 22, "Print",ExpressionUUID->"a028f508-8b12-4844-bed4-369db7c036e4"],
Cell[33723, 809, 643, 15, 22, "Print",ExpressionUUID->"f58f6fc5-9b21-44ad-a0ed-e76ee709629d"],
Cell[34369, 826, 502, 10, 33, "Print",ExpressionUUID->"278f7ce1-460c-4464-bb12-ce13959070d8"],
Cell[34874, 838, 20554, 355, 234, "Print",ExpressionUUID->"2f4e6978-5a14-406e-9a1a-77b790a57e42"],
Cell[55431, 1195, 542, 11, 33, "Print",ExpressionUUID->"6e7ca987-caa4-418c-8ff6-e06af95b8c38"],
Cell[55976, 1208, 18716, 324, 231, "Print",ExpressionUUID->"633330e8-e636-49e5-8550-4f738d11e5d3"],
Cell[74695, 1534, 572, 11, 33, "Print",ExpressionUUID->"8793543d-a0be-429c-bbf3-86753785986f"],
Cell[75270, 1547, 8381, 157, 247, "Print",ExpressionUUID->"180f3cf5-c3ad-4836-b27b-ddeb7947d6f8"],
Cell[83654, 1706, 737, 16, 22, "Print",ExpressionUUID->"e2b44823-310f-413b-b02f-18e27d6bc0e3"],
Cell[84394, 1724, 867, 21, 29, "Print",ExpressionUUID->"3933e3ae-3138-4858-bef2-b999d389b94a"],
Cell[85264, 1747, 484, 8, 22, "Print",ExpressionUUID->"35e76e83-93a8-42a6-bb94-f189986a9cdd"],
Cell[85751, 1757, 645, 15, 22, "Print",ExpressionUUID->"981027e1-f65b-4c65-9a79-0c005e1661a6"],
Cell[86399, 1774, 504, 10, 33, "Print",ExpressionUUID->"be0adde6-cb88-42ec-96e0-f925f9cf07b1"],
Cell[86906, 1786, 58424, 976, 227, "Print",ExpressionUUID->"d2a916bb-9026-418d-9fd5-4506a1536225"],
Cell[145333, 2764, 540, 11, 33, "Print",ExpressionUUID->"7788811a-04e7-4d94-be86-98578b73a3e0"],
Cell[145876, 2777, 50908, 852, 224, "Print",ExpressionUUID->"9117e7b6-1861-49f0-ad01-4a8033349ec6"],
Cell[196787, 3631, 574, 11, 33, "Print",ExpressionUUID->"6fed2971-c130-4c42-806b-4e18356b9eee"],
Cell[197364, 3644, 8304, 156, 247, "Print",ExpressionUUID->"5550ae59-8471-4ba2-ac36-008c3366e0c9"],
Cell[205671, 3802, 732, 16, 22, "Print",ExpressionUUID->"415234f5-f322-4d6e-99fd-5d4df49e1ced"],
Cell[206406, 3820, 869, 21, 29, "Print",ExpressionUUID->"562da4fe-aaf5-4df8-ba4d-0887a5d170a4"],
Cell[207278, 3843, 484, 8, 22, "Print",ExpressionUUID->"139aaa46-2d8e-4d81-9c9f-2a545a89d7d7"],
Cell[207765, 3853, 645, 15, 22, "Print",ExpressionUUID->"9664e52b-3f40-4598-bfb6-5d694cf3ad86"],
Cell[208413, 3870, 504, 10, 33, "Print",ExpressionUUID->"a18aae7d-dd36-4a91-8dc6-656499298ec3"],
Cell[208920, 3882, 31727, 538, 228, "Print",ExpressionUUID->"fc88b7eb-47e7-4a72-a2cc-a213625e02a1"],
Cell[240650, 4422, 540, 11, 33, "Print",ExpressionUUID->"97a28fe4-97da-496e-bd02-cfeecbab7eef"],
Cell[241193, 4435, 29409, 499, 234, "Print",ExpressionUUID->"b0b0713b-8b1c-4b38-a257-c335e6c6429d"],
Cell[270605, 4936, 574, 11, 33, "Print",ExpressionUUID->"4ee4f7e2-8a1c-40ce-9642-f4534d8439c5"],
Cell[271182, 4949, 8295, 156, 247, "Print",ExpressionUUID->"71a3e45e-56f6-422f-84c0-6b9c71946871"],
Cell[279480, 5107, 755, 16, 22, "Print",ExpressionUUID->"7d303660-e8e7-42f2-ae33-61b5c412fcf4"],
Cell[280238, 5125, 867, 21, 29, "Print",ExpressionUUID->"b9dab452-2177-483a-915d-2e198e094baf"],
Cell[281108, 5148, 484, 8, 22, "Print",ExpressionUUID->"808bf9ab-9d95-444b-9038-49bc06abbfa1"],
Cell[281595, 5158, 642, 15, 22, "Print",ExpressionUUID->"7e804301-2cde-4a69-b8d9-db376ea607e2"],
Cell[282240, 5175, 504, 10, 33, "Print",ExpressionUUID->"99ad1020-b1ca-40a8-8861-39c0a30242c1"],
Cell[282747, 5187, 27884, 475, 229, "Print",ExpressionUUID->"82cac23e-f621-43b8-8918-87e8676e15aa"],
Cell[310634, 5664, 540, 11, 33, "Print",ExpressionUUID->"0819e41b-8568-401d-aca0-c1b9536811f0"],
Cell[311177, 5677, 26036, 444, 234, "Print",ExpressionUUID->"a37d69fb-4369-4d88-887a-f18f4c393079"],
Cell[337216, 6123, 572, 11, 33, "Print",ExpressionUUID->"5482740b-6f30-4ab3-a3de-7a5857ff4ef3"],
Cell[337791, 6136, 8005, 151, 247, "Print",ExpressionUUID->"b4169ecc-5550-46a5-b43a-8b097ea766dc"],
Cell[345799, 6289, 737, 16, 22, "Print",ExpressionUUID->"cb8229e5-cf8d-4665-b6d2-c9c542ef8a80"],
Cell[346539, 6307, 871, 21, 29, "Print",ExpressionUUID->"9c2047e5-51c6-46e5-b672-3fd46806b600"],
Cell[347413, 6330, 482, 8, 22, "Print",ExpressionUUID->"df5cb873-4cb5-4c53-b5cc-b5bf44218d98"],
Cell[347898, 6340, 645, 15, 22, "Print",ExpressionUUID->"60b06b14-548c-47d8-aa70-9c75783e37d9"],
Cell[348546, 6357, 502, 10, 33, "Print",ExpressionUUID->"ca183772-6417-4c9d-ad55-c4d08899128b"],
Cell[349051, 6369, 46377, 778, 226, "Print",ExpressionUUID->"b4bd76db-493f-41d8-bcee-75ec2c3540b6"],
Cell[395431, 7149, 540, 11, 33, "Print",ExpressionUUID->"875542db-1084-44bd-9336-c009a7bf7198"],
Cell[395974, 7162, 42551, 715, 234, "Print",ExpressionUUID->"8d4221a5-d6a9-44d5-a349-af22759adf98"],
Cell[438528, 7879, 572, 11, 33, "Print",ExpressionUUID->"6daabdf3-fd87-423c-b46b-ae5a1aee865b"],
Cell[439103, 7892, 8193, 154, 247, "Print",ExpressionUUID->"8935a7cf-f9ea-48b9-8156-4c37f3fec82c"],
Cell[447299, 8048, 728, 15, 22, "Print",ExpressionUUID->"809cae20-af6c-4141-b8f9-0748a0ca1efd"],
Cell[448030, 8065, 868, 21, 29, "Print",ExpressionUUID->"d057344c-ca04-4528-a636-ce4367064c7e"],
Cell[448901, 8088, 484, 8, 22, "Print",ExpressionUUID->"c35f2da7-d38c-43ee-a516-8bee5f7cffa6"],
Cell[449388, 8098, 649, 15, 22, "Print",ExpressionUUID->"49ec4b67-b44b-4675-a8b6-121615d678bd"],
Cell[450040, 8115, 504, 10, 33, "Print",ExpressionUUID->"bea3c5be-584a-4305-b1f0-4ea117872139"],
Cell[450547, 8127, 54191, 907, 225, "Print",ExpressionUUID->"e1f6cd11-349b-4bf6-9b6d-31e86588aae4"],
Cell[504741, 9036, 540, 11, 33, "Print",ExpressionUUID->"fe57ff49-1015-4dc7-8d85-6d1e265923df"],
Cell[505284, 9049, 49444, 828, 234, "Print",ExpressionUUID->"4ce8e83f-3715-4096-95bb-69d4400fb4a1"],
Cell[554731, 9879, 574, 11, 33, "Print",ExpressionUUID->"860f7019-dea6-42ff-aa0a-435267cf9baa"],
Cell[555308, 9892, 8130, 153, 247, "Print",ExpressionUUID->"e7b472c4-8953-4fdd-b0fb-7c86f529c839"],
Cell[563441, 10047, 750, 16, 22, "Print",ExpressionUUID->"94b9dc08-fee9-45eb-8049-c11a8c0a3725"],
Cell[564194, 10065, 512, 10, 33, "Print",ExpressionUUID->"e3e62d9e-d54f-4b11-bdf4-09aeb0be9eab"]
}, Open  ]],
Cell[564721, 10078, 878, 26, 130, "Output",ExpressionUUID->"bd08b539-47f4-43f8-966d-56d369da998e"],
Cell[565602, 10106, 682, 13, 22, "Print",ExpressionUUID->"8513b631-82c5-4352-af0e-4a9347467f41"]
}, Open  ]]
}, Open  ]]
}
]
*)

