(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 11.2' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    487238,       8792]
NotebookOptionsPosition[    480457,       8706]
NotebookOutlinePosition[    480854,       8723]
CellTagsIndexPosition[    480811,       8720]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["\<\
Determination of the signs and magnitudes of all heteronuclear coupling using \
IPAP-MODO-FESTA data.
Automatically determine optimum ratio when combining IP and AP data, \
adjusting ratio and number of points to shift until rms difference is minimum\
\>", "Subsubsection",
 CellChangeTimes->{{3.835342719267295*^9, 3.8353427673607473`*^9}, {
   3.835342957217922*^9, 3.8353429845994587`*^9}, {3.853579885840021*^9, 
   3.853579910287277*^9}, 
   3.8535799927992496`*^9},ExpressionUUID->"e0dd5b4c-3a91-4051-9a25-\
a39ac98e766a"],

Cell["\<\
Automatically determines the optimum ratio when combining the IP and AP data, \
adjusts the ratio and numbers of points required to shift until the RMS \
difference is at its minimum.
Information required:
shifts={chemical shift in ppm}; (each chemical shift to be separated by a \
comma)
widths={width of multiplet in ppm}; (each width to be separated by a comma)
nreps=1; (number of repetitions of that data - typically 1)
filestart=12; (EXPNO in file)
filenamebase=\[CloseCurlyDoubleQuote]data/folder/nmr/filename/\
\[CloseCurlyDoubleQuote]; (filepath of data)
procnoIP=\[CloseCurlyDoubleQuote]1001\[CloseCurlyDoubleQuote];  (PROCNO of IP \
data)
procnoAP=\[CloseCurlyDoubleQuote]1002\[CloseCurlyDoubleQuote]; (PROCNO of AP \
data - ensure IP and AP are processed with identical parameters)
Sample details:
Fluorohydrin in D2O
1H @ 4.3038 ppm; 150Hz
19F @ -187.6826 ppm; 1000Hz
J=48.4 HZ
Removed 1.74 ppm due to overlap\
\>", "Text",
 CellChangeTimes->{{3.835344344114542*^9, 3.835344495255948*^9}, {
  3.835345752399667*^9, 3.83534578817225*^9}, {3.835416894520056*^9, 
  3.8354170090033817`*^9}, {3.8535743479833965`*^9, 3.8535743941759214`*^9}, {
  3.8535744245888777`*^9, 3.853574427182979*^9}, {3.8535799150722027`*^9, 
  3.8535802318062067`*^9}, {3.853587164123898*^9, 3.853587177771508*^9}, {
  3.8535875400501995`*^9, 3.8535875426377263`*^9}, {3.8541046599278955`*^9, 
  3.8541046662468185`*^9}},ExpressionUUID->"c61c22a2-f7f7-4bd3-b074-\
cb3183ff65e0"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{"Evaluate", "[", 
    RowBox[{
     RowBox[{"Context", "[", "]"}], " ", "<>", " ", "\"\<*\>\""}], "]"}], 
   "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"vardiff", "[", 
     RowBox[{"tspip_", ",", "tspap_", ",", 
      RowBox[{"ratio_", "?", "NumericQ"}], ",", 
      RowBox[{"diff_", "?", "NumericQ"}]}], "]"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"zspm", ",", "len"}], "}"}], ",", 
      RowBox[{
       RowBox[{"len", "=", 
        RowBox[{"Length", "[", "tspip", "]"}]}], ";", " ", 
       "\[IndentingNewLine]", 
       RowBox[{"zspm", "=", 
        RowBox[{"Join", "[", 
         RowBox[{
          RowBox[{"Table", "[", 
           RowBox[{"0", ",", 
            RowBox[{"{", 
             RowBox[{"i", ",", "len"}], "}"}]}], "]"}], ",", 
          RowBox[{"Join", "[", 
           RowBox[{
            RowBox[{"tspip", "-", 
             RowBox[{"ratio", " ", "tspap"}]}], ",", 
            RowBox[{"Table", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", 
               RowBox[{"i", ",", "len"}], "}"}]}], "]"}]}], "]"}]}], "]"}]}], 
       ";", "\[IndentingNewLine]", 
       RowBox[{"Total", "[", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"tspip", "+", 
           RowBox[{"ratio", " ", "tspap"}], "-", 
           RowBox[{"Take", "[", 
            RowBox[{
             RowBox[{"RotateRight", "[", 
              RowBox[{"zspm", ",", "diff"}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"len", "+", "1"}], ",", 
               RowBox[{"2", " ", "len"}]}], "}"}]}], "]"}]}], ")"}], "^", 
         "2"}], "]"}]}]}], "\[IndentingNewLine]", "]"}]}], ";"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{
   "Calculate", " ", "variance", " ", "between", " ", "shifted", " ", 
    "spectra", " ", "obtained", " ", "by", " ", "IPAP", " ", "processing"}], 
   " ", "*)"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"getpars", "[", 
    RowBox[{"filenamebase_", ",", "procno_"}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "filename", "}"}], ",", 
     RowBox[{
      RowBox[{"filename", "=", 
       RowBox[{
       "filenamebase", "<>", "\"\</pdata/\>\"", "<>", "procno", "<>", 
        "\"\</procs\>\""}]}], ";", " ", "\[IndentingNewLine]", 
      RowBox[{"stream", "=", 
       RowBox[{"OpenRead", "[", "filename", "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"offset", "=", 
       RowBox[{
        RowBox[{"Read", "[", 
         RowBox[{
          RowBox[{"StringToStream", "[", 
           RowBox[{"Find", "[", 
            RowBox[{"stream", ",", "\"\<OFFSET= \>\""}], "]"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"Word", ",", "Number"}], "}"}]}], "]"}], "[", 
        RowBox[{"[", "2", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"si", "=", 
       RowBox[{
        RowBox[{"Read", "[", 
         RowBox[{
          RowBox[{"StringToStream", "[", 
           RowBox[{"Find", "[", 
            RowBox[{"stream", ",", "\"\<SI= \>\""}], "]"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"Word", ",", "Number"}], "}"}]}], "]"}], "[", 
        RowBox[{"[", "2", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"Close", "[", "stream", "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"filename", "=", 
       RowBox[{"filenamebase", "<>", "\"\</acqus\>\""}]}], ";", " ", 
      "\[IndentingNewLine]", 
      RowBox[{"stream", "=", 
       RowBox[{"OpenRead", "[", "filename", "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"sfo1", "=", 
       RowBox[{
        RowBox[{"Read", "[", 
         RowBox[{
          RowBox[{"StringToStream", "[", 
           RowBox[{"Find", "[", 
            RowBox[{"stream", ",", "\"\<SFO1= \>\""}], "]"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"Word", ",", "Number"}], "}"}]}], "]"}], "[", 
        RowBox[{"[", "2", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"swp", "=", 
       RowBox[{
        RowBox[{"Read", "[", 
         RowBox[{
          RowBox[{"StringToStream", "[", 
           RowBox[{"Find", "[", 
            RowBox[{"stream", ",", "\"\<SW= \>\""}], "]"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"Word", ",", "Number"}], "}"}]}], "]"}], "[", 
        RowBox[{"[", "2", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"Close", "[", "stream", "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"offset", ",", "si", ",", "sfo1", ",", "swp"}], "}"}]}]}], 
    "\[IndentingNewLine]", "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"process", "[", 
     RowBox[{
     "filenamebaseIP_", ",", "filenamebaseAP_", ",", "shift_", ",", "width_", 
      ",", "swp_", ",", "offset_", ",", "si_", ",", "sfo1_"}], "]"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "diff", ",", "dip", ",", "start", ",", "end", ",", "hzpp", ",", 
        "ncproc", ",", "spip", ",", "spap"}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"filename", "=", 
        RowBox[{"filenamebaseIP", "<>", "\"\</procs\>\""}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"stream", "=", 
        RowBox[{"OpenRead", "[", "filename", "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"ncproc", "=", 
        RowBox[{
         RowBox[{"Read", "[", 
          RowBox[{
           RowBox[{"StringToStream", "[", 
            RowBox[{"Find", "[", 
             RowBox[{"stream", ",", "\"\<NC_proc= \>\""}], "]"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"Word", ",", "Number"}], "}"}]}], "]"}], "[", 
         RowBox[{"[", "2", "]"}], "]"}]}], ";", " ", 
       RowBox[{"(*", " ", 
        RowBox[{
        "Need", " ", "to", " ", "correct", " ", "for", " ", "any", " ", 
         "difference", " ", "in", " ", "scaling", " ", "during", " ", "FT", 
         " ", 
         RowBox[{"etc", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
       RowBox[{"Close", "[", "stream", "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{"filename", "=", 
        RowBox[{"filenamebaseIP", "<>", "\"\</1r\>\""}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"spip", "=", 
        RowBox[{
         RowBox[{"2.", "^", "ncproc"}], " ", 
         RowBox[{
          RowBox[{"Import", "[", 
           RowBox[{"filename", ",", "\"\<Integer32\>\""}], "]"}], "/", 
          RowBox[{"10", "^", "6"}]}]}]}], ";", " ", "\[IndentingNewLine]", 
       "\[IndentingNewLine]", 
       RowBox[{"filename", "=", 
        RowBox[{"filenamebaseAP", "<>", "\"\</procs\>\""}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"stream", "=", 
        RowBox[{"OpenRead", "[", "filename", "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"ncproc", "=", 
        RowBox[{
         RowBox[{"Read", "[", 
          RowBox[{
           RowBox[{"StringToStream", "[", 
            RowBox[{"Find", "[", 
             RowBox[{"stream", ",", "\"\<NC_proc= \>\""}], "]"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"Word", ",", "Number"}], "}"}]}], "]"}], "[", 
         RowBox[{"[", "2", "]"}], "]"}]}], ";", " ", 
       RowBox[{"(*", " ", 
        RowBox[{
        "Need", " ", "to", " ", "correct", " ", "for", " ", "any", " ", 
         "difference", " ", "in", " ", "scaling", " ", "during", " ", "FT", 
         " ", 
         RowBox[{"etc", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
       RowBox[{"Close", "[", "stream", "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{"filename", "=", 
        RowBox[{"filenamebaseAP", "<>", "\"\</1r\>\""}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"spap", "=", 
        RowBox[{
         RowBox[{"2.", "^", "ncproc"}], " ", 
         RowBox[{
          RowBox[{"Import", "[", 
           RowBox[{"filename", ",", "\"\<Integer32\>\""}], "]"}], "/", 
          RowBox[{"10", "^", "6"}]}]}]}], ";", " ", "\[IndentingNewLine]", 
       "\[IndentingNewLine]", 
       RowBox[{"hzpp", "=", 
        RowBox[{"swp", " ", 
         RowBox[{"sfo1", "/", 
          RowBox[{"(", 
           RowBox[{"si", "-", "1"}], ")"}]}]}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"start", "=", 
        RowBox[{"Round", "[", 
         RowBox[{"sfo1", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"offset", "-", "shift", "-", 
             RowBox[{"width", "/", "2"}]}], ")"}], "/", "hzpp"}]}], "]"}]}], 
       ";", "\[IndentingNewLine]", 
       RowBox[{"end", "=", 
        RowBox[{"Round", "[", 
         RowBox[{"sfo1", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"offset", "-", "shift", "+", 
             RowBox[{"width", "/", "2"}]}], ")"}], "/", "hzpp"}]}], " ", 
         "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"tspip", "=", 
        RowBox[{"Take", "[", 
         RowBox[{"spip", ",", 
          RowBox[{"{", 
           RowBox[{"start", ",", "end"}], "}"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"len", "=", 
        RowBox[{"Length", "[", "tspip", "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"tspap", "=", 
        RowBox[{"Take", "[", 
         RowBox[{"spap", ",", 
          RowBox[{"{", 
           RowBox[{"start", ",", "end"}], "}"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"Print", "[", 
        RowBox[{
         RowBox[{"Style", "[", 
          RowBox[{"\"\<Chemical shift = \>\"", ",", "\"\<Subsection\>\""}], 
          "]"}], ",", 
         RowBox[{"Style", "[", 
          RowBox[{"shift", ",", "\"\<Subsection\>\""}], "]"}], ",", 
         RowBox[{"Style", "[", 
          RowBox[{"\"\< ppm\>\"", ",", "\"\<Subsection\>\""}], "]"}]}], "]"}],
        ";", "\[IndentingNewLine]", 
       RowBox[{"(*", " ", 
        RowBox[{
         RowBox[{
         "Do", " ", "optimistion", " ", "in", " ", "two", " ", "stages"}], 
         ",", " ", 
         RowBox[{
         "otherwise", " ", "fails", " ", "to", " ", "find", " ", "global", 
          " ", "minimum"}]}], " ", "*)"}], "\[IndentingNewLine]", 
       RowBox[{"res1", "=", 
        RowBox[{"NMinimize", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"vardiff", "[", 
             RowBox[{"tspip", ",", "tspap", ",", "fratio", ",", 
              RowBox[{"5", " ", "fdiff"}]}], "]"}], ",", 
            RowBox[{"fdiff", ">", 
             RowBox[{
              RowBox[{"-", "len"}], "/", "5"}]}], ",", 
            RowBox[{"fdiff", "<", 
             RowBox[{"len", "/", "5"}]}], ",", 
            RowBox[{"fratio", ">", "0.8"}], ",", 
            RowBox[{"fratio", "<", "1.2"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"fdiff", "\[Element]", " ", "Integers"}], ",", "fratio"}],
            "}"}], ",", 
          RowBox[{"MaxIterations", "\[Rule]", "100"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"res2", "=", 
        RowBox[{"NMinimize", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"vardiff", "[", 
             RowBox[{
             "tspip", ",", "tspap", ",", "fratio", ",", " ", "fdiff"}], "]"}],
             ",", 
            RowBox[{"fratio", ">", "0.8"}], ",", 
            RowBox[{"fratio", "<", "1.2"}], ",", 
            RowBox[{"fdiff", ">", 
             RowBox[{
              RowBox[{"Round", "[", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"5", " ", "fdiff"}], "/.", 
                 RowBox[{"res1", "[", 
                  RowBox[{"[", "2", "]"}], "]"}]}], ")"}], "]"}], "-", 
              RowBox[{"len", "/", "10"}]}]}], ",", 
            RowBox[{"fdiff", "<", 
             RowBox[{"Round", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"len", "/", "10"}], "+", 
                RowBox[{"5", " ", "fdiff"}]}], "/.", 
               RowBox[{"res1", "[", 
                RowBox[{"[", "2", "]"}], "]"}]}], "]"}]}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"fdiff", "\[Element]", " ", "Integers"}], ",", "fratio"}],
            "}"}], ",", 
          RowBox[{"MaxIterations", "\[Rule]", "1000"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{
       "Print", "[", "\"\<Variance and optimised shift and ratio:\>\"", "]"}],
        ";", "\[IndentingNewLine]", 
       RowBox[{"Print", "[", "res2", "]"}], ";", " ", "\[IndentingNewLine]", 
       RowBox[{"ratio", "=", 
        RowBox[{"fratio", "/.", 
         RowBox[{"res2", "[", 
          RowBox[{"[", "2", "]"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"spp", "=", 
        RowBox[{"tspip", "+", 
         RowBox[{"ratio", " ", "tspap"}]}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"spm", "=", 
        RowBox[{"tspip", "-", 
         RowBox[{"ratio", " ", "tspap"}]}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"Print", "[", 
        RowBox[{"Style", "[", 
         RowBox[{"\"\<Input data\>\"", ",", "\"\<Subsection\>\""}], "]"}], 
        "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{"Print", "[", 
        RowBox[{"ListPlot", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"spp", ",", "spm"}], "}"}], ",", 
          RowBox[{"Joined", "\[Rule]", "True"}], ",", 
          RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"len", "=", 
        RowBox[{"Length", "[", "spp", "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"zspm", "=", 
        RowBox[{"Join", "[", 
         RowBox[{
          RowBox[{"Table", "[", 
           RowBox[{"0", ",", 
            RowBox[{"{", 
             RowBox[{"i", ",", "len"}], "}"}]}], "]"}], ",", 
          RowBox[{"Join", "[", 
           RowBox[{"spm", ",", 
            RowBox[{"Table", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", 
               RowBox[{"i", ",", "len"}], "}"}]}], "]"}]}], "]"}]}], "]"}]}], 
       ";", "\[IndentingNewLine]", 
       RowBox[{"diff", "=", 
        RowBox[{"Table", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", 
            RowBox[{
             RowBox[{"2", " ", "len"}], "+", "1"}]}], "}"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"For", "[", 
        RowBox[{
         RowBox[{"i", "=", "1"}], ",", 
         RowBox[{"i", "\[LessEqual]", 
          RowBox[{"Length", "[", "diff", "]"}]}], ",", 
         RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{
           RowBox[{"diff", "[", 
            RowBox[{"[", "i", "]"}], "]"}], "=", 
           RowBox[{"Total", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"spp", "-", 
               RowBox[{"Take", "[", 
                RowBox[{
                 RowBox[{"RotateRight", "[", 
                  RowBox[{"zspm", ",", 
                   RowBox[{"len", "-", "i"}]}], "]"}], ",", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"len", "+", "1"}], ",", 
                   RowBox[{"2", " ", "len"}]}], "}"}]}], "]"}]}], ")"}], "^", 
             "2"}], "]"}]}], ";"}]}], "\[IndentingNewLine]", "]"}], ";", "\n", 
       RowBox[{"Print", "[", 
        RowBox[{"Style", "[", 
         RowBox[{
         "\"\<RMS difference vs displacement in data points\>\"", ",", 
          "\"\<Subsection\>\""}], "]"}], "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{"Print", "[", 
        RowBox[{"ListPlot", "[", 
         RowBox[{"diff", ",", 
          RowBox[{"Joined", "\[Rule]", "True"}], ",", 
          RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"min", "=", 
        RowBox[{"Min", "[", "diff", "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"For", "[", 
        RowBox[{
         RowBox[{"i", "=", "1"}], ",", 
         RowBox[{"i", "\[LessEqual]", 
          RowBox[{"Length", "[", "diff", "]"}]}], ",", 
         RowBox[{"i", "++"}], ",", " ", 
         RowBox[{
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"diff", "[", 
              RowBox[{"[", "i", "]"}], "]"}], "\[Equal]", "min"}], ",", 
            RowBox[{"minpoint", "=", "i"}]}], "]"}], ";"}]}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"Print", "[", 
        RowBox[{"Style", "[", 
         RowBox[{
         "\"\<Expansion of RMS difference vs displacement in data points, \
with parabolic fit\>\"", ",", "\"\<Subsection\>\""}], "]"}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"dip", "=", 
        RowBox[{"Take", "[", 
         RowBox[{"diff", ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"minpoint", "-", "10"}], ",", 
            RowBox[{"minpoint", "+", "10"}]}], "}"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"dipfit", "=", 
        RowBox[{"NonlinearModelFit", "[", 
         RowBox[{"dip", ",", 
          RowBox[{"a", "+", 
           RowBox[{"b", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"x", "-", "x0"}], ")"}], "^", "2"}]}]}], ",", 
          RowBox[{"{", 
           RowBox[{"a", ",", "b", ",", "x0"}], "}"}], ",", "x"}], "]"}]}], 
       ";", "\[IndentingNewLine]", 
       RowBox[{"Print", "[", 
        RowBox[{"Show", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Plot", "[", 
            RowBox[{
             RowBox[{"dipfit", "[", "x", "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"x", ",", "1", ",", 
               RowBox[{"Length", "[", "dip", "]"}]}], "}"}], ",", 
             RowBox[{"PlotRange", "\[Rule]", 
              RowBox[{"{", 
               RowBox[{"All", ",", 
                RowBox[{"{", 
                 RowBox[{"0", ",", 
                  RowBox[{"1.1", " ", 
                   RowBox[{"Max", "[", "dip", "]"}]}]}], "}"}]}], "}"}]}]}], 
            "]"}], ",", 
           RowBox[{"ListPlot", "[", 
            RowBox[{"dip", ",", 
             RowBox[{"Joined", "\[Rule]", "False"}], ",", 
             RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]}], "}"}], "]"}],
         "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{"Print", "[", 
        RowBox[{
        "\"\<Interpolated frequency shift with best match is \>\"", ",", 
         RowBox[{
          RowBox[{"-", "hzpp"}], 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"x0", "/.", 
              RowBox[{"dipfit", "[", "\"\<BestFitParameters\>\"", "]"}]}], 
             ")"}], "+", "minpoint", "-", "11", "-", "len"}], ")"}]}], ",", 
         " ", "\"\< Hz\>\""}], "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"-", "hzpp"}], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"x0", "/.", 
            RowBox[{"dipfit", "[", "\"\<BestFitParameters\>\"", "]"}]}], 
           ")"}], "+", "minpoint", "-", "11", "-", "len"}], ")"}]}]}]}], 
     "\[IndentingNewLine]", "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"shifts", "=", 
   RowBox[{"{", 
    RowBox[{
    "4.8136", ",", "4.3069", ",", "3.8731", ",", "3.51479", ",", "2.0603", 
     ",", "1.5179"}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"widths", "=", 
   RowBox[{"{", 
    RowBox[{
    "0.03", ",", "0.14", ",", "0.06", ",", "0.06", ",", "0.12", ",", "0.09"}],
     "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"njs", "=", 
   RowBox[{"Length", "[", "shifts", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nreps", "=", "1"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"filestart", "=", "7"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"js", "=", 
   RowBox[{"Table", "[", 
    RowBox[{"0", ",", "njs", ",", "nreps"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
  "filenamebase", "=", 
   "\"\<V:/dropbox/Coral/_Projects/_Publications/IPAP FESTA/Fluorohydrin \
data/data/GDP_fluoridrinaD2O_thais/nmr/\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"procnoIP", "=", "\"\<1001\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"procnoAP", "=", "\"\<1002\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"getpars", "[", 
   RowBox[{
    RowBox[{"filenamebase", "<>", 
     RowBox[{"ToString", "[", "filestart", "]"}]}], ",", "procnoIP"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"starttime", "=", 
   RowBox[{"AbsoluteTime", "[", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"For", "[", 
   RowBox[{
    RowBox[{"jnumber", "=", "1"}], ",", 
    RowBox[{"jnumber", "\[LessEqual]", 
     RowBox[{"Length", "[", "shifts", "]"}]}], ",", 
    RowBox[{"jnumber", "++"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"For", "[", 
      RowBox[{
       RowBox[{"rep", "=", "1"}], ",", 
       RowBox[{"rep", "\[LessEqual]", "nreps"}], ",", 
       RowBox[{"rep", "++"}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"filename", "=", 
         RowBox[{"filenamebase", "<>", 
          RowBox[{"ToString", "[", 
           RowBox[{"filestart", "+", "rep", "-", "1"}], "]"}], "<>", 
          "\"\</pdata/\>\""}]}], ";", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"js", "[", 
          RowBox[{"[", 
           RowBox[{"jnumber", ",", "rep"}], "]"}], "]"}], "=", 
         RowBox[{"process", "[", 
          RowBox[{
           RowBox[{"filename", "<>", "procnoIP"}], ",", 
           RowBox[{"filename", "<>", "procnoAP"}], ",", 
           RowBox[{"shifts", "[", 
            RowBox[{"[", "jnumber", "]"}], "]"}], ",", 
           RowBox[{"widths", "[", 
            RowBox[{"[", "jnumber", "]"}], "]"}], ",", "swp", ",", "offset", 
           ",", "si", ",", "sfo1"}], "]"}]}], ";"}]}], "\[IndentingNewLine]", 
      "]"}], ";"}]}], "\[IndentingNewLine]", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{"Style", "[", 
    RowBox[{"\"\<Coupling constants\>\"", ",", "\"\<Subsection\>\""}], "]"}], 
   "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"TableForm", "[", "js", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"jslb1", "=", "js"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"timeused", "=", 
   RowBox[{
    RowBox[{"AbsoluteTime", "[", "]"}], "-", "starttime"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{"\"\<Time used = \>\"", ",", "timeused", ",", "\"\<seconds\>\""}], 
   "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"meansdandsdmean", "[", "x_", "]"}], ":=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Mean", "[", "x", "]"}], ",", 
     RowBox[{"Sqrt", "[", 
      RowBox[{
       RowBox[{"Variance", "[", "x", "]"}], "/", 
       RowBox[{"(", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Length", "[", "x", "]"}], "-", "1"}], ")"}], ")"}]}], 
      "]"}], ",", 
     RowBox[{"Sqrt", "[", 
      RowBox[{
       RowBox[{"Variance", "[", "x", "]"}], "/", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Length", "[", "x", "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Length", "[", "x", "]"}], "-", "1"}], ")"}]}], ")"}]}], 
      "]"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{"nreps", ">", "1"}], ",", 
    RowBox[{
     RowBox[{"reslb1", "=", 
      RowBox[{"Table", "[", 
       RowBox[{"0", ",", 
        RowBox[{"Length", "[", "shifts", "]"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"reslb1", "=", 
      RowBox[{"Prepend", "[", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"Flatten", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"shifts", "[", 
              RowBox[{"[", "i", "]"}], "]"}], ",", 
             RowBox[{"meansdandsdmean", "[", 
              RowBox[{"jslb1", "[", 
               RowBox[{"[", "i", "]"}], "]"}], "]"}]}], "}"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", 
            RowBox[{"Length", "[", "shifts", "]"}]}], "}"}]}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{
         "\"\<Shift / ppm\>\"", ",", "\"\<JHF / Hz\>\"", ",", 
          "\"\<std dev / Hz\>\"", ",", "\"\<sd of mean of J / Hz\>\""}], 
         "}"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"Print", "[", 
      RowBox[{"TableForm", "[", "reslb1", "]"}], "]"}], ";"}]}], "]"}], 
  "\[IndentingNewLine]", 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.833448292510956*^9, 3.833448473320225*^9}, {
   3.833448567630739*^9, 3.833448597926832*^9}, {3.833448726706624*^9, 
   3.8334488386106873`*^9}, {3.833448894130322*^9, 3.83344899381962*^9}, {
   3.8334490263559*^9, 3.833449034371501*^9}, {3.833449208176523*^9, 
   3.83344924369489*^9}, {3.8334515420085583`*^9, 3.833451676813837*^9}, {
   3.8335325651614*^9, 3.833532637209276*^9}, {3.833532759034121*^9, 
   3.8335330239765873`*^9}, {3.8335330927635307`*^9, 
   3.8335331455943604`*^9}, {3.833533397697961*^9, 3.8335334255106373`*^9}, {
   3.8335334594455547`*^9, 3.833533507765386*^9}, {3.833533539339788*^9, 
   3.833533659575992*^9}, {3.833533697198904*^9, 3.8335337340891523`*^9}, {
   3.833533780205265*^9, 3.833533893496993*^9}, 3.833533985781467*^9, {
   3.8335340192182083`*^9, 3.833534070521394*^9}, {3.833534125296022*^9, 
   3.833534125914562*^9}, 3.833534226165428*^9, {3.833534380477125*^9, 
   3.833534380818433*^9}, {3.8335344656134453`*^9, 3.833534519575261*^9}, {
   3.8335346317293777`*^9, 3.83353463272573*^9}, 3.8335347268726482`*^9, {
   3.8335347781741343`*^9, 3.83353485994346*^9}, {3.833534904539554*^9, 
   3.83353494839614*^9}, {3.833534999551011*^9, 3.833534999698493*^9}, {
   3.833535037301165*^9, 3.833535103927022*^9}, {3.8335351368517733`*^9, 
   3.833535139414091*^9}, {3.8335352378369083`*^9, 3.833535337311174*^9}, {
   3.833535394550235*^9, 3.833535454170685*^9}, {3.8335361679797087`*^9, 
   3.8335362375090513`*^9}, {3.833536274111115*^9, 3.833536278469448*^9}, 
   3.833536449477241*^9, {3.8335364826240788`*^9, 3.8335365448917313`*^9}, {
   3.833538035225528*^9, 3.833538077529106*^9}, {3.8337034631307096`*^9, 
   3.833703463865309*^9}, {3.833703506926898*^9, 3.833703553753542*^9}, {
   3.833703617125688*^9, 3.833703688345792*^9}, {3.833703718670663*^9, 
   3.8337037764894876`*^9}, {3.8337038223632317`*^9, 
   3.8337039123907833`*^9}, {3.83370394998801*^9, 3.833704007351994*^9}, {
   3.833704056375489*^9, 3.833704136756112*^9}, {3.833704176289364*^9, 
   3.833704289758876*^9}, {3.833704391066206*^9, 3.833704429891245*^9}, {
   3.833704972721045*^9, 3.8337049956209497`*^9}, {3.8337050367076*^9, 
   3.833705038457287*^9}, {3.8337053194184847`*^9, 3.833705411458173*^9}, {
   3.8337070792528667`*^9, 3.833707127605337*^9}, {3.835337695095479*^9, 
   3.835337749538929*^9}, {3.835338577798208*^9, 3.835338620041452*^9}, {
   3.835338653990897*^9, 3.835338823765335*^9}, {3.835338865410541*^9, 
   3.835338962622757*^9}, {3.83533899622244*^9, 3.8353390024553337`*^9}, {
   3.835339165977964*^9, 3.835339170838904*^9}, {3.835339226586821*^9, 
   3.835339252159419*^9}, {3.8353394292671547`*^9, 3.835339457784766*^9}, {
   3.835339500275881*^9, 3.8353395120074873`*^9}, 3.8353400097312202`*^9, {
   3.835340043255178*^9, 3.835340049105363*^9}, {3.835340320155546*^9, 
   3.8353403214856653`*^9}, {3.8353429884303017`*^9, 3.835343088575757*^9}, {
   3.835343169936596*^9, 3.83534322437465*^9}, {3.835343746121127*^9, 
   3.8353437642293177`*^9}, {3.8353445222541227`*^9, 3.835344552148288*^9}, {
   3.835344620203895*^9, 3.835344716850436*^9}, {3.835344824168634*^9, 
   3.835344832897682*^9}, {3.835344894608045*^9, 3.835344999609126*^9}, {
   3.8353450692229977`*^9, 3.835345143285017*^9}, {3.835345243601369*^9, 
   3.835345244855967*^9}, 3.8353452928938713`*^9, {3.835345339394802*^9, 
   3.835345341993548*^9}, {3.835345390387436*^9, 3.835345394595192*^9}, 
   3.835345505879159*^9, {3.835345633336461*^9, 3.835345726337473*^9}, {
   3.8353458377226467`*^9, 3.835345843828887*^9}, {3.835372061030136*^9, 
   3.835372071264954*^9}, {3.835372109388467*^9, 3.83537218434414*^9}, 
   3.835372522290762*^9, {3.8354170700934362`*^9, 3.835417083829755*^9}, {
   3.835417167922065*^9, 3.835417196326001*^9}, {3.835418223179352*^9, 
   3.835418229883106*^9}, {3.835418393819128*^9, 3.835418488516716*^9}, {
   3.835418519132303*^9, 3.835418537842663*^9}, {3.83542543494832*^9, 
   3.835425472964828*^9}, 3.8354255498612223`*^9, {3.835425690259713*^9, 
   3.83542571399114*^9}, {3.835431541550761*^9, 3.835431541640277*^9}, {
   3.852979611453643*^9, 3.852979691319852*^9}, {3.8529797654116774`*^9, 
   3.852979781170024*^9}, {3.852979821986277*^9, 3.8529798368790913`*^9}, 
   3.852982940810091*^9, {3.8535786610591493`*^9, 3.853578743107206*^9}, {
   3.8535791499440546`*^9, 3.853579151302937*^9}, 3.8535799422709336`*^9, {
   3.853584626138847*^9, 3.8535846264724474`*^9}, {3.853587210467972*^9, 
   3.85358724124366*^9}, 3.85358885451703*^9, {3.854095691261874*^9, 
   3.8540957193122416`*^9}, 3.8540960783561687`*^9, {3.8541046800683603`*^9, 
   3.8541046823921385`*^9}, 
   3.867412075240703*^9},ExpressionUUID->"83ce1c8d-1a22-4fa3-84c9-\
6c6be868c2d5"],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   StyleBox["\<\"Chemical shift = \"\>", "Subsection",
    StripOnInput->False], "\[InvisibleSpace]", 
   StyleBox["4.8136`", "Subsection",
    StripOnInput->False], "\[InvisibleSpace]", 
   StyleBox["\<\" ppm\"\>", "Subsection",
    StripOnInput->False]}],
  SequenceForm[
   Style["Chemical shift = ", "Subsection"], 
   Style[4.8136, "Subsection"], 
   Style[" ppm", "Subsection"]],
  Editable->False]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8540957320191784`*^9, 3.854096079842099*^9, 3.8541046841659155`*^9},
 CellLabel->
  "During evaluation of \
In[93]:=",ExpressionUUID->"b404ed81-c25f-4e4d-a8f7-25144d8c44a7"],

Cell[BoxData["\<\"Variance and optimised shift and ratio:\"\>"], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8540957320191784`*^9, 3.854096079842099*^9, 3.8541047010593567`*^9},
 CellLabel->
  "During evaluation of \
In[93]:=",ExpressionUUID->"c386d231-2bd8-41e7-a7fe-281cbac89a2a"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"47.808467795509806`", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"fdiff", "\[Rule]", "128"}], ",", 
     RowBox[{"fratio", "\[Rule]", "1.1142741629749329`"}]}], "}"}]}], 
  "}"}]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8540957320191784`*^9, 3.854096079842099*^9, 3.8541047010613832`*^9},
 CellLabel->
  "During evaluation of \
In[93]:=",ExpressionUUID->"b08a29c2-85f0-449a-8720-a94c183491ee"],

Cell[BoxData[
 StyleBox["\<\"Input data\"\>", "Subsection",
  StripOnInput->False]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8540957320191784`*^9, 3.854096079842099*^9, 3.8541047010694103`*^9},
 CellLabel->
  "During evaluation of \
In[93]:=",ExpressionUUID->"382dbe37-78f5-42b2-ae1c-75de84ad8d37"],

Cell[BoxData[
 GraphicsBox[{{}, {{{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
      0.0055000000000000005`], AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJw1mHk8lIv3xyepq3Cj20KLpkWSK3SjRF8f6toqW7Ivw9jXmTGLRE3aiaho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       "]]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[
      0.0055000000000000005`], AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJw1mHlcjPsXx6eUSzfKkpJtIt0itKEr1ScpSZi079O+TZppambUD3Nxu651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       "]]}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
      0.0055000000000000005`], AbsoluteThickness[1.6]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[
      0.0055000000000000005`], AbsoluteThickness[1.6]}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
      0.0055000000000000005`], AbsoluteThickness[1.6]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[
      0.0055000000000000005`], AbsoluteThickness[1.6]}, {}, {}, {}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
      0.0055000000000000005`], AbsoluteThickness[1.6]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[
      0.0055000000000000005`], AbsoluteThickness[
      1.6]}, {}, {}, {}}}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 394.}, {-0.45192026021884146`, 29.360379125973495`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8540957320191784`*^9, 3.854096079842099*^9, 3.854104701142401*^9},
 CellLabel->
  "During evaluation of \
In[93]:=",ExpressionUUID->"68645666-04d3-43c7-bc78-33b4295d5b9d"],

Cell[BoxData[
 StyleBox["\<\"RMS difference vs displacement in data points\"\>", 
  "Subsection",
  StripOnInput->False]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8540957320191784`*^9, 3.854096079842099*^9, 3.854104701284491*^9},
 CellLabel->
  "During evaluation of \
In[93]:=",ExpressionUUID->"170a09c6-be99-4b53-8af9-607491e61525"],

Cell[BoxData[
 GraphicsBox[{{}, {{{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
      0.0055000000000000005`], AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJxF2nlcTVsbB/BMSZFDRdziGK8xiciUXyFRGkhl7JTmyWme60ydczJmSiVk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       "]]}}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
     0.0055000000000000005`], AbsoluteThickness[1.6]}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
      0.0055000000000000005`], AbsoluteThickness[1.6]}, {}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
      0.0055000000000000005`], AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 789.}, {0, 77772.3618645809}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8540957320191784`*^9, 3.854096079842099*^9, 3.854104701412753*^9},
 CellLabel->
  "During evaluation of \
In[93]:=",ExpressionUUID->"eebaeaec-3fd6-4dab-ac43-30a34578a1f7"],

Cell[BoxData[
 StyleBox["\<\"Expansion of RMS difference vs displacement in data points, \
with parabolic fit\"\>", "Subsection",
  StripOnInput->False]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8540957320191784`*^9, 3.854096079842099*^9, 3.8541047014237604`*^9},
 CellLabel->
  "During evaluation of \
In[93]:=",ExpressionUUID->"5188248a-0492-4314-9386-0967426d514f"],

Cell[BoxData[
 GraphicsBox[{{{{}, {}, 
     TagBox[
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJwVlnk01O8Xx4mQJEW+LWiY+XxmLNmakIp3Ki0kWqVlxtj3vWTJWqRCpRQp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        "]]},
      Annotation[#, "Charting`Private`Tag$1928368#1"]& ]}, {}}, {{}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
      0.012833333333333334`], AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJxTTMoPSmViYGAQBWIQDQEf7F8pnH24POWQA1TAQUFbZOYVk31QPofD65Ru
00e6O6B8AYdznJ1BO/ZtgvJFHHImzz644+FqKF/Coajt1bHLsxZD+TIOfJ9v
9WwtmQnlKzjEXa29M9W5F8pXcjgXZ/FqU0Y1lK/i0DwrWyt+aSKUr+aw61TW
/ern7lC+hoPPpJXbol8nQ/laDvP3tm34uqAWytdx8Pi1ePXNe31Qvp7DtJ8P
WjZXz4LyDRx+f902e7XFEijf0OFbdaaj5Mw1UL6Rg8HzTa4r1TdD+cYOwsW9
//2Xwvxv4hBjaHEzdg8sfEwdqiR3B9pvPOQAAITXZD0=
       "]]}, {
      {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
       0.012833333333333334`], AbsoluteThickness[1.6]}, {}}, {
      {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
       0.012833333333333334`], AbsoluteThickness[1.6]}, {}}}, {{}, {}}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{Automatic, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{All, {0, 10527.544149900612`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8540957320191784`*^9, 3.854096079842099*^9, 3.854104701586551*^9},
 CellLabel->
  "During evaluation of \
In[93]:=",ExpressionUUID->"81869e71-2802-48ec-a812-3aaac66f4e5c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Interpolated frequency shift with best match is \"\>", 
   "\[InvisibleSpace]", "4.88438925403771`", 
   "\[InvisibleSpace]", "\<\" Hz\"\>"}],
  SequenceForm[
  "Interpolated frequency shift with best match is ", 4.88438925403771, " Hz"],
  Editable->False]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8540957320191784`*^9, 3.854096079842099*^9, 3.854104701602112*^9},
 CellLabel->
  "During evaluation of \
In[93]:=",ExpressionUUID->"0a52d0b1-6827-428c-a58e-482a8bc159f4"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   StyleBox["\<\"Chemical shift = \"\>", "Subsection",
    StripOnInput->False], "\[InvisibleSpace]", 
   StyleBox["4.3069`", "Subsection",
    StripOnInput->False], "\[InvisibleSpace]", 
   StyleBox["\<\" ppm\"\>", "Subsection",
    StripOnInput->False]}],
  SequenceForm[
   Style["Chemical shift = ", "Subsection"], 
   Style[4.3069, "Subsection"], 
   Style[" ppm", "Subsection"]],
  Editable->False]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8540957320191784`*^9, 3.854096079842099*^9, 3.8541047021566305`*^9},
 CellLabel->
  "During evaluation of \
In[93]:=",ExpressionUUID->"29482d15-69fd-405a-89ae-1e55f2b525f5"],

Cell[BoxData["\<\"Variance and optimised shift and ratio:\"\>"], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8540957320191784`*^9, 3.854096079842099*^9, 3.8541047629248075`*^9},
 CellLabel->
  "During evaluation of \
In[93]:=",ExpressionUUID->"d6cdd17a-7716-4874-acf2-8dc96cb47b12"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"303.3948863775421`", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"fdiff", "\[Rule]", "1270"}], ",", 
     RowBox[{"fratio", "\[Rule]", "1.0036230736099363`"}]}], "}"}]}], 
  "}"}]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8540957320191784`*^9, 3.854096079842099*^9, 3.854104762926823*^9},
 CellLabel->
  "During evaluation of \
In[93]:=",ExpressionUUID->"7acaae15-052f-48ff-9390-e8bbe802ce62"],

Cell[BoxData[
 StyleBox["\<\"Input data\"\>", "Subsection",
  StripOnInput->False]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8540957320191784`*^9, 3.854096079842099*^9, 3.854104762926823*^9},
 CellLabel->
  "During evaluation of \
In[93]:=",ExpressionUUID->"d438e00b-bd57-48b9-af18-ef201e6acacc"],

Cell[BoxData[
 GraphicsBox[{{}, {{{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJw8fHlcjO379iBkL0JIBkUIY4/IgZCEUVESpgVJZVolpWmf9qlZyzYIPYQQ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       "]]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJw8fXlcjN37f0iKJIQohJAtgxCSty1RKVQqqaFFlPZN67RP+zRNq2iQhJAK
2QdFHlsSkjCShJCEkPzuz6/r/j7/PK/3c+77nOtc72s7132mZ8J2j41OfWVk
ZGYMkJH53797/2lftj66zfDthNCr9B9Q0jngVbHEc1kvlMfxiw5bG6emEVaG
7KvxS0Kc9xNWgdjwpP0Qn8OEVRHN389p+neMsDosYkoNzJ6dIqwBFw/zvV2L
SglPxARlYUqFtJywJhYnLLAxjK0gPAWdtVMvuT6+TFgLs29P03I/cp3wdNwc
73HivfAW4ZlQ0D+5bMW+e4S18WLrXnvO+lrCHAQnzp+mrfOE8BwUOC5ROxfS
QHguWtUUylcufUV4HsL7j9g8bGMTYR2cjj53XCfgLeH5KLm2/6DjzPeEF6Ch
21t1TvwnwgsRfLi47bLJV8K6+LneLyxfp5PwIlx7kPe+NOgn4cXo8DB5qz/x
D+EluHRx3laZ2f8I62GZ48y52rV90IuXon7oiqoGyBLWx7+J02tNX8kRXobN
U5UehRUoEAY8X2m6zoxS7MU8wPp1Tv54tyE0vhwJKjenBGkNpfHl2Dj92JeJ
6cNofAVaB/rMH9wxnMZXoEPvyLqxK0bQ+Ep4GrRsSgsfSeMrseQRZ3NYwSga
XwXnfwPWjClSpfFVUP752N0kfDSNr0ZTuXZV4LgxNL4aii+uR9UGE5YxgOJ2
paHeaey4AVrSVDavsmPH12B7Pmdu/luaj7cGqlVNVTdnsfMb4ubwHTdm6bPr
G+KH9dvthuNY+dbC9vwBC4/HtB/eWqyJ7m9c7qpC4+sQeHZAW88H0gdvHbKF
ndcz7ElfMkbw3pGW0X6S9MkzgtjqvJfKNdK3jDHuXvf+56w4kMaNYfNkzN7W
/QNo3ASNkoQlwpD+NG6Clmnr7UwP9KPx9Xh+atmSZf370vh6vLj8fODSAzI0
boqWI+gz+U1Pr73wTBE0dP/k9R+7yX7MUHd1ytRRNmRfMIP+lYOmq6b+pufN
oPYme+Fa/V+9WGKGIa96rE3Cu+j9DRgbbDyGe5PsFRvQ+CCjb+P3H/T+BgR9
Omo06993en8D9I9OS735lrX3jYy/uV6ovvCN3t+IJqX58p7pHfT+RnDEO3Ta
wshfJBvhPSNRI5XXTu9vgvxP3+1qE7/Q+5tw028Lr9GI/I23CT03D9wZ7/+R
3t+EhLadiUqlrH+aw/tb46pp01rpfXMMPFpV9mrwO3rfHCrWOtmS6BZ63xyr
duz5uj2NsIwFEvxbVj9Xpudhgb47DJ9zq9j3LbAVyYbx7jS/xAL9jxXZmb0h
LGMJ3heLF38nkDywxIqvb7eErifMs8STUyO33MonLLFEcaaB1dlVH+j9zfi3
sHaDpzHtD5vhItCZUZ7XRu9vhjhOMfDxL9KHZDPUp8afW65O+pKxQsOT6v1H
b7P6s8KBnJaWfu8I86zQJHtDuD+EsMQKNxVaNs4r/kzvW4Oj5n93Qj7ND2vY
6G+JOePHrm8No/3dKRX6rP6tEXv7yoHzv1j92+C6sC68W8zq3wY86+1O53RY
/dmgn9tVU49rFF8lNnDgh1ZF2TXT+1ugMeXUU+cpb+j9LbBbVjB9+iyKz7wt
KLwlsosLek3vb4GJvtWKtQMJy9jC7varHNdaKb1vi/utNn/X3iHMs0VDUYOZ
23fCEltwXdekytqw72+F2VtjWW05Wo9he97b95bX+5E8vK2YWOt09Mwmkley
FVs198b9a2PzhR1KIzUWXJKw9mMHRYuNBUevsfzbQS7K+NLdj6z+7OBlcOf5
6rWs/u3xvt+5JJ895A+wh7zV38AgOdZ/7JH17IlTrZT8S2KPlLqBmYFjyT9l
uNDrUR9mcp/8WYMLs/i4q5P+sfGAC/OJO2xul1K+4XJx1sFDTq2d8g2Pi8//
8gTWupRvxFzkTTE2HiSmfCPh4quNaqqMMuUbKRfdFo+s1D0G9WKZbbhqJLgW
Uzi4F2tsw7kAhx/1hyleYhv+m1ize0SZci/mbsPGYROrw/zYfLQNw6wSP3hp
UPwVb4PbAe9yjcuEJdugMbVDJcGC8pN0G7YWTxI4sflKZjv83329EZhD8Vxj
O8qTkw0ijSneYzsEv/sEnJOn/MXdjlnvv1+9dpPNZ9sxoipFbV4w5Qvxdvyn
J+sRPoryiWQ7xrhEZKQkEpZux6orS3KktwjLOKDR3/ONnISwhgP6QBM9boTh
gP7JF2fX36f5uQ547um3bMkndn0HjLzTrZf0hOQVOyA6t/j1t320H4kDZEff
C7ptxe7fAWeawvcMVGfztyMO/szs3vWb9KvhiGnBLh36/QjDES/ehGiti1ai
9R1hlnLoxeow4ovniA7rr7vL/lI+EzsixX6dw+r+NC5xxJJlPjMXpRGWOmL5
slmDLmTRfDJOkLk6Qee3LLu+E5T+tWl1fWDXd4K0pq+9SyfxzXVCn799C+1V
2XrDCbs/c1xa1tN+xU6wnT+g+byA9CFh8O30wsgnpC+pE5Szz0jfs/zIOOOI
xXW/IUZUD2g4o7JKO+yyI9UPcIag6r9pTtZqtL4z1rr3XSoap07rO6P5wu8x
NsWExc74dHMqf0QPYYkzZKssXjoNG0vrO+P7oWAT6w80LrMDx0omGq7iE9bY
gR9b+8bc/0zrYQc6zgzJFWuw6+/Ago/NY+9qsPXODjjqHXc+8Y32I94BKU9o
ezef7EWyAyKDwhpos/vfAVWzw+5Wx9j6xQUjg8ZNT9UgfWq4gPfSzWHePtI3
XJCpuJY/bQbrfy4I+pmvuoH1V54LbENs4oYsJH8WuyB6V3hBK+vvEhfoRY8x
CNOlekbqgs/Tvfv1nKR6RmYnvkdzGt56UfzQ2IlA9V9zs4KovsFOmPKmbTO9
0pfW34m7kZfPDJxNmLcTBY8P+3lfpngk3omzQ4MS3bYQljB4Tt+U4B6qh6Q7
YV52pmTY/9VHu7DDvrTcZgVhjV1IXDlAVuk2xTvsguLt4MEfVNj4twtm7+7k
LXVl66ld8F7aPSLxv7+9WLwLjik+IzdrE5bswv3HMoP/Caneku5CrMrI5eq/
2XreFUn3Kxw27ias4Yqbq3+XqfZQ/QVXRK47Ged4nTDXFZqjwnJ5D9j6zBUu
r93iF86n98WuCPM7tMjyD2GJK57KD7SKmUjySF2x+L+Acf2KSH4ZNySYOSUu
W83u3w2+zxvGfnEm/cENH5Qbu4f+n/7dIJeVdzFsA/HFc4Ns45/TrlMp3ovd
8MMgyKtkhTzp3w03ZVsqJWKqb6VumN/4+ITMIrIfmd1IU74Q5/uX4r3GbtRk
dFaMd2ftbzeuRn38KJRSvOLuRnlW8H09I7Jf3m6Mezjgx9GDbPzbDZ9P1QNu
NZC9S3bj/lPLFWPekT9Id+OQ3kmz+Ius/7vjas49l4smrP+7IztfYXRdJmG4
43SxJEEugzDXHeOyK7v8jNnzhDskM6/mKLDxXOyO2ohQtdnD2fjvDjfJyfmN
y9n13TH3vO7W9Y4kn4wH5gy59rxPAsmv4YE1PwdUTr1K+4MHCtMVfhcOIsz1
QHOGjYnAm41/Hvh5sfvp169s/vOAaLFQdXQUm/88MGbLib++aoSlHjhZWzbT
4CR7PvGEYepBO5XZhJU98T1g7IdoERuPPXGitMe6/Azxw/GEsGJafc5Ait/w
xLiEknz7JRT/zTyZ9aYYnHMkvrmeyLt69LlCIdmDpyfmLhx7aLQaxQOeJ+Sf
887feErxQOAJiXWQ9ZR3bD3hCR6Tm36YEC7xhPqubLGbEmGJJ742SS6mzSBc
44nzQh0jlWOEpZ5Q9fK+Oj2F5m/3RJHWvHNJT9nzsBci3F5+KQgl+ZS9cHDK
6mMT3El+DS8YPDfP6JNK++N4QXQ39lvuDXb/Xiivv5Nms4f0ZeYFvuDc3YIY
Nl95YewQtcBhLB+eXrCpWHVC4f/484Lh1tq9b82JX4EXBitJax7OYu3ZC902
MXb+fwmXeKH6sf6eB9dZ+/ZC/t7T1fVs/VHjBR3NoWErp7D1hhcWaH6RC75K
uJ2Rr8J4k2Qle/71hvb7kOuPigkreyPRedZ99a+sP3ijuP3x3jmylG843gh7
OOX34Gesf3gj4+3wfT5OhM288VuQvGr1YVqP6w1ux3+hiXkkn6c35Faumrd+
M1u/eGNcycGkDe/Y/Xsj5LC6xn4u6UfsDb/C+PwpT0ifJd4YuTD91qHNpG+J
N67kq0wY3kTxpMYb8XOv3tlgSflI6o18zXGlU0ZTPmr3hm6Tvv6jeez52gcF
dwIu5B0j+1D2gWvmvMN1QWw+8oGLp2rn5RzKRxwf7Mod+OTB9760fx/M9Zv4
8VAQYTMf6F03jtw0kjDXB4U1Ci4KVyieevqgXfD2eKkHWz/7ICZliKwMh7DA
B11TZq0+0Z/NZz5IHTf1nU0nxecSHzSnXz7j9YuwxAcdBTK3fRTp+RofZPpZ
KFlMJCz1wYoU/bKPcwi3++CTi/j0sIVsv8gXFSOn4/Ncwsq+ELdscHCfRljD
F93eI/pcG0uY44uBX79a/h7C5gdfXNkWXRf5l+Qx80V8//VlnGbCXF8YH0xU
Mr5J2NMXm1YeUhx4gjDPF2tslzldPEJY4Iu9J4a5nbpFWOyL3N1vdU6OofVK
fKG67+i7V4VsfvfFfxrRci67SN81vvhjpBY1zp74kvpi5Pw5P3J5xGe7L+7v
fBbt/JCtP/zgeK4nd5st2YOyHyIkhXoL5pC9aPjh/aKDy6dtJXvi+GFFVV+n
yDdkb/CDYdCjOYm2rP/7YUFQoQq/ifV/P+wv/hRj5EP27OmHjTs2JVn0sPnL
D7Papy3b4E/+IPDDO7l1q41q2fOEH+YkfJDJVyT/KvHD5nkyQ+LY+k/ih761
pbWvB1B9WOOHN/1ULsddICz1g9mTqR6HZ1N92e4Hl/oJaa5ctv70h3fkbaej
6wgr+6Nosu/v9q/0voY/QjuCxx+zI8zxx/XQOnHSXrY+9se7kTXHbpey/u+P
mXriKWuKWf/3x5Mv/9WUJLP+74+kk+ENGras//vD9vFPvtE4im8Cf/y6Orvk
1QvW//3RYv0sbe0Rip8l/hBOmuf2JY70K2HW39JRVZtI+q/xR5Nx+4CsAMpX
Un84KMQvt19M8brdHw+HBd+vcmLrjwBk+e68/5M9vygH4Fn4GG7JAPY8GoCa
nUce58cR5gQg+Peb2uHhbPwPwMP1wSop72g9swA0e4jXvHzK1ssBsBqm+1/j
C5LXMwBzYy2td3ey/cIAJIf3m3hTgY1/AeC6mKyxVmLjfwC+N906of2Djf/M
++HLZiVWsPGfka/yz72A9Wz8D0DP9sAQy9NsvRGAtq4la4oaCLcHIKxzKze4
iu1vBuKz70LlHk/CyoFIGXOwq6OJ5tcIhO2s2x37tAhzAuF54+FMMwv2fByI
ro0/91WEkfxmgRDsbzUYVUH8cQNhsdzO/dNg1v4DcVBflZvB5kNeIBp5eTau
wwkLAiE7Tz102WnSlzgQTcdjfZTWs/E/EI5qpUHXnrPxPxCJ/VP2d5my/Adi
yoxbn16uY/kPxGCNxJJZFcRfeyDWicwGH2hn+w978GeA8fqwfpTvlffguWnB
rM/9qB7Q2AOl4YfObJWjeoGzBzN2uU75NZbiCfZga/KZSV42fWn/e9CqcHwY
l4133D1IMzuBTfeo3vbcg/8qcwze+NF5gLcHdqdyzF6GUj0v2AOVusLcqfXU
jxEz648c5vzdj/qrJXugrb/s7H5D6t9I9sCwszBkzwrqr9bswRWj9HE7N1N/
VboHd7eO3FwSSv2f9j04G6Y6Zegp6g/JBGHiG/dI8XvqryoHQWzwRhwym7BG
EEacfvtPNob6S5wg1Nc9uzGnke0XBmF2rsOKjU+pH2UWBEmg/q9+P6gfyA3C
ybqWBze0CXsGofip1VrNILY/GIQxsjY6C+qpvyUIgkqm/1L1DYTFQYhttZmk
+IX6nSVBCNvrPa2pjLAkCMFNn7dKUgnXBEHpuuagDjvC0iAs/6TwMKKD+mnt
jPyL9ZOOsf1WmWAMm32IP/4F9d+UgxG4t0r1w2Lq72oEg6PZ8eqrD/XvOMGI
zJ9Us6OW7fcFI+JJe09aFvUDzYJRGfZMaUwz9Qu5wbAccfpq2gnCnsFwrwn4
Ou8m218MxibeS/uEb4QFwbiQFB+YrkDziZn3bXQW1/+l8ZJgzD+VefHYe7Yf
GYw2hY96z34TrglG+eb0LWFsf1IajM4A+VO6I0ne9mAc1Ht2sHwk9SdlQjDS
Z2Dm66m0P+UQXJjaWVGsRP1JjRD4f/r94s0BwpwQXFpvxmtoIIwQ/B5xvK/0
CWGzEOyqqxEp/EeYGwKN0Y5DYj4Q9gyB4IJrj4Ud6ZcXggYDjzqVeaR/QQik
HyzCI7dRP1gcgknTl+ZW1hNfJSHQL67a2hnP9kNDwMlwGndkN9lXTQgeWiw+
5xxB9ikNwaD7F0b1kZL9todghvXYy6sGs/YfCnP3hxAuIf9QDsV369KA0i3k
PxqhOHMs2vvYNvIvTii2L3w1vnUt+R9C0WK7aL1AjfzTLBSuqiM/9LQQ5obi
c+LmSSnXyJ89Q+Fz3e39oGv0PYUXCpflUZlzfrH+H4qXuoqb5EMoPohDcbLS
OGG1LcWPklDMjfa1ObGZrf9C8XHxq5LQm2z9FwqeZWuqKIatf0Khom++6PVe
9vwTii2jg4T9FCi+yYThdKWqm9MNNv6FoWjFkrhgNl5qhGF7xbilCTsovnLC
0Dx9W/q27+z5PAxbfGINkwMovpuFwX9Msv1zKXteDUOmfnqN42TKH55hGL+q
RWixmPINLwyqO68vKhlB9YIgDCGTTi4MO8mep8PgsVSmIvcv4ZIwBFl9bPnQ
w56vw3DrwOnNaaWEa8Iw16RPVeZY9vwThqRl5/oeWcvmvzCkNpfNureSPX+H
Y/+zrS89xlA+Uw7HE7OK1UOes/2wcNScv7bHXkD5iRMO62kvpqxezu4/HGLu
1QffX7P5Pxy5zRnheSD9ccORdzP0zdB80q9nOFbc8LU8J0P654XDIOSW2lR3
9vwbjk7Zhvcc9nwhDofuGMng5YVs/R+OIDXtvWoabH8pHP6djQud/cmeasKR
4pM7V8OU7FMaDuM1o/RW57DxPxzJFpyVjxex35950L46ZOjCmRS/5Xmokc84
4r+Y4qcyD+pnZgx+kUP+qsrDreYfjxrtKH5o8LD5n96pZUco/mjxUDi8U2HZ
4BfkLzxMjC/2XPn1WS/W5WHe5IfH7l99Sv7Dw0mfee5vNen7uyEP/nq6i543
1JE/8RCYU5XFufuoF1vxYF5YVD5hLGEuD5JdUd/sRhB24WF814OQoR2EPXlY
kOas+F/5414cyMPO4q0/+gyoJ//jQeRyZ8zj5fS9n8+DvH/G6fqc5+SPPGQb
PT/02Y5wNg+aRQbdAxbSfsQ8dEzgyCgspfmLeFhidCpwYMcD8lceLIeseWbq
XtmLK5j5d3eM99QrI/54KEmY0/7cMaQXV/Pg+MPCsezgoau9fPKwW3a/du3L
E724nofDXlfWzDp8vBdLebAabbI+63teL27l4WbuobvmG1OIbx6MAo8UdI+g
+xVdPAz8zpy2p10j/iPwx2u/5HHcbeI/AorfD9X1uVBD/EfgV2lNaaQ28aEa
gUDxu7bFv4gvjQhYK5rWaKmSPrQisCHS0v3XEdInJwIrN85FSw3pTzcC67uU
zJxKGon/CDhP0rezXEf2YhiBjZpV4e/4hM0i4DnxSPlwI8JWEUh9Xb5jYhC9
z41AgVPfnuFqNL9LBIxH14/ibCJ5PCNwUKNbO3sr2VtgBMYOGbHJJoD44kWg
XN1N5d8dshd+BGYd092U50r3QwQRCMiJVhm1/iHxH4EbBmGjwSX9iCMgkTn7
8PZk4rsoAkHew38n36L7JiUReHK1eizO3yX+I6AkcrX3UCEsicCFL7I+Fm/u
EP8RaL8xu7OVHa+JwIDTuZfzeITrIzCyf0+6yQ/C0gh87fa4edOU1muNwFNp
+tHVewi3R+D+0xH1IjfCXREY2PPDymwSex8mEtFF+QpJCTSffCS037QdFEeQ
PMqRqNyi/vx7C9mHaiRODHpidKqY7tdoRGL/vIF2Ee/JvrUiMfmGTt3pBrIv
TiQuBG1pcDtC93V0I+F7wv2Kwkq6zwNm/a6T7jNfkD8YRqKo8FD8oZ0lxH8k
GkLkn25TPk78RyJww/B7b13ofhE3Eh0DHrVZK9D9I5dI/Fd986bInuzfMxKS
4tmrF+ww6/WPwEjk6WjYanUIejEvEiNNBMt4R/f3Yj7zPC+l/Zx1QS8WRELu
QZ/3FnpHenF2JG425snaTi/qxeJIuCzae2lgMY0XReJD3dW4196FvbiEwdeS
XO9PP9yLKyKhxX/rY8fOL4lEm76m0SJjwtWRMHs0RU1VhZ6viURa5xixKIHm
q49ErUS8dqYjrS9l+FL06pqw/hj5fyT4F3/+mDW0uBe3RyL2Sqvj6GMUP7oi
8XvUmb/f1pzqxTJRaLs9nH9XVNKL5aOwSS5a83fp6V6sHAXZHYlqt1+U9mLV
KPyOPqnx50ZZL9aIgu+dafmn/xDWisJ005mNpziEOVEoTLYdVWpO8+lGoYA7
1n+rJ8mDKIjKcl/pd5L+DKNwsuNnpMEBin9mUShKER0cGXmgF1tFQWvXm+ZZ
tYS5UZhwc8Hf5x/oeZcoBF/dudMxm/TlGYW8X5va5paQvgKjEFb6pfPTvqPE
PzNf6sxfhvmE+VGozv/48V4KYUEUhDppWw9Zk36zo9B37MfLITtJv+Io5B4P
f3fHnPRZFIXDcbJbAvrQfkuiECS7etfkXMIVUdD9wzGQUyEsiQJidHO1B9D7
1VEY9u7x2bAGWq8mCjGF3VVDhpB+6pn1jVx8190me5FG4dd+r2uXthFujcLQ
a7P7HDEl+2mPgvyIqesOxJM+upj5EpK3mWrSfDLRuCUzudjoMY3LRyM3tWOy
wVDCytEYYPXFJfUMzacaDQe7sBPvPGhcIxqXQw+G2uqTfrWi4S1rWrfQnOTn
RKPVTsbZfw/lK91orCjmW+eW0TiioZOpVBzZwPIfjZZ9LipON1j+oyFeXyuM
uZVP/EejtCesvX7uXuKfwSvEirPac4n/aJQMcZCu/LOP+Gfk8amaMbFeTPxH
43Z8yOIpuWQ/PGa9q6v/fA2hcX40OsrVo3mpNL8gGp+9bNpKDTKI/2gYX72r
Y9xM8UMcjRu3t812GUq4KBqSD2Mt9u0SEv/RaNxw71pDOb1fEY1vV3qOOYzP
Iv6jwXnV7VTyRkT8R+PrC87uE+dTiP9ovJRf1HKlLYL4j0bz8ZVP3lb7EP/R
yBl/cLyt2J/4j8ZTBS+7mi2xxH80Nn6NTfmnmU78R8Neq+l0+f0c4j8GLaqF
ySqNtF/5GBw9/nlH88Bs4j8GvgZt9mr+qcR/DNINzw5yeBRI/MeA90cuW1XZ
lOJ/DKboLJ7sqrSb4n8MZLn2RTOytlL8j8GXBzPGVjg4EP/MuPVpHQ9BEPEf
A2Wzsw2pSyKJ/xikjpxwMnp/FPEfA1vVywUjlKKJ/xhY+E6QiYyg/brEYO44
tdFpRxOJ/xi4PJne/smS+AmMwZjAj8+9RrHxPwZN3ORtp6bFEP8xcGrpE7DU
0JjyfwxGV1507lkjoPwfg2/L/WYtMsyn/B+Dxx4W05d4F1D+j0HUp5Phk+8S
LonBu2/fDX+FiCn/x0BOFHh53CAh5f8YCBxmJsgFcCn/x2B482SZBVNovzUx
eMl/0tfqTgLxH4PajMC6kjGkH2kMPJOffB773YTyfwzWTxaaSAbFU/6PwfUF
Xxaef59B+T8GiwdPcRjcmkv5PxaZqZWr/dftpfwfi8TNB9dlr82m/B+LUXsX
T+gbnU75PxYV+9d8/rQgifJ/LDofna/f9pBH/MfC6q3vYIuo7cR/LOavitJa
4e5J/h+LL57zT6SZEH9g3ld5r5Ivm0z8x2JYc0hrq4DszSwWs3j2fDUb2r9V
LBJixrW9qAwm/mOx9+sMLcUoG8r/sWhY6JV2vSKG8n8snpvpfXgxnOQPjMXs
h7667ptzejEvFt6G/S1eWe7rxfxYzJ05pGuIMvEriMXXo4EvP2yn+iI7Fi9v
GamUs/oTx2JgpXlsna6I+I/FlvvWIxw7o4n/WLRfvHn02tUN5P+xqOxz7ZKF
C5/8PxaBYxYd6Ggj/6yOxd1BuZc/SSle1MTilFqQhzMnjfiPxX+H5h+2nhRC
/MfiyuWh5iEif+I/Fj9DR95Q59D97PZYfLCvcS0UEp9dsbD5k7IsMYrlPw7d
Hn/nza3NIv7jsGlOx/ydLWSfynEwThz+XnN9MvEfh3GXujsM0hOI/ziErD4w
aIJqKvEfh2Xzxuj3yyd9cOJQPkqt6HwJracbh+UFX2Z43yT9Ig4vT8YOiNU/
0IsN45h6OtGuZR5hszh8rwyc3fSXnreKw67Lhg7JS/J6MTcOCp1pW9Pn0f5c
4tD/xrTCcAmt7xmHZxoHQj47034C4yCufGmgakP64cWh7XjNurUJhPlxsFz3
frX6SXpeEIe+9bKmmw1pvuw42Idu/HGpgvxJHIe7K3gvnbiZxH8c0hxGnz/2
kMZL4rDx0+Ld77+T/VXE4cLsfV/NhtJ6kjg0f1dZxjBC/h8H/leHY4sWkf3U
xMG3pqz0jHVwL66Pg+Ikd39dC49eLI1DyaKsMZX7LYn/OGi4e2bcubuU4n8c
3hUYy62VmlP8j8Pvg8k5NktXUfznw/Lpg5iIE1uIfz5W/PU5VGXmR/zzEVgm
88hSJpL452Pv0IZ59W6xxD8fyeEvt5+PJn/T4sO5/HdmnUIY8c9H644hHSlW
zsQ/H/UJ50bZzDQm/+dDHCpZu/qhIfk/H1Pu77u5b7YP8c/HXBP1z8FtVM9b
8aFzrm9Zu4Dln4/m5AnHB3cfIv4Z+RyLtTj3Col/5v0J8rWF6XReCORj3Pi1
cUEpFI95fOz2DByaVkZ88/nY9yXHbqrAm/jn42lyJ7bf9ab8z4f6xDfOk9op
/oj52FXff/inSCfK/3y4q37x+mlP+ivhY6FTxdaKA+QvFXxkLoq/I9Zm4z8f
75YUTHvRSLia0bd01OVUb8o3NXwYr+7WMbxM79fzkf2+psxank/88/FsVcOh
wk4ab+VDe2C+yaIBrP/zEe102fNlPNlvFx+aHvb54lSyT5l4zPh5qvVHNK0v
H49un8QVY54Rv8rxWKWicbvomy3xH4/o6munKuR4lP/joe2zYGz9F4rXWvEo
Oz/bw7ub6hlOPDgt13+M5lC9oxuPAQFyy6uCCCMeJ1foik4/ziT+47HBRLjK
vITin1k8vGN2NdZep/hoFY+pu2wKbm+l/M2NR+kql3Ntfdn8H48E389NzUM8
KP/HI6Bvt6FSDvlLYDyGHdJr8n1A9sqLx5hdE55XfSf74jPylH/771gj6V8Q
j0m82ePiA2g8Ox7/Wq0eDlgTR/4fj/9+hhQay5G9F8XD8mLI55Wm9HuZkni0
VMdPLZtI+b2CWf/Z/Ik+5RbEfzyKF0rW9Hwg/6uOx5YhDbEKfPKXmngsjE6Y
WlfjRfzH42XGNY9ZCykeSBm+xK1KhmoUL1rj8dr4iCVXn/JzO7Of96rb9gQQ
v13x8Ls0p8+jiRSvZBLwyMtA+nkoxU/5BOTuTfAeEUX5QDkB7SYzpo+xIPtR
TUDckmVrriwkfWgkYP2jqQ93NkSQ/yeglvvopMbfHeT/zHxfZT7Jhmwh/hNw
VjHKjvuT/AkJYEr0VZa6VE8aJsBNTqFs2cEA4j8Bcx+GmgVupOetEiBeFz58
/edtxH8CsGbeaqmmGfl/AkYnKPQNaqD44ZkApc7qoGt6FL8CEzCRhwk+y6k+
4iVgYGlO4JkO0hc/AeHneB0BJykeCxIQO235a4ES2Ut2AqpLnzbdkvoS/wko
76cxd+vaFeT/Cbi8u6H6Qh7V5yUJaKzVr72yiPZXweinYeO+m8KdlP8TEPjn
3/k713YS/wmojNy7tt938r+aBJx5V3hddyzlj3rmefXmgNsXiB9pAso2Oh2w
qifcmoCr8/L/jfaj59sTcGd93GLBLIoXXQn4V7pknuU0sieZRNzfPHnfuJub
euWRT2TOh2EDeULHXqyciC5d7dNN2wyJ/0R8KHjoH3WS7F0jEUcSm/pfrGPz
fyKG3Zrvs+wz2RcnEVcfWRT6lbP5PxFpUyY3hDoTRiKk1z83dIfQ84aJ0D0z
O+2cI/mfWSLuxi223nsyiuI/I8/5nx4nHpF/cRMBySeldvdJxH8iog/q5fWU
bCf/T8TvI1rlZ/LcenFgIoQf95ktebe7F/MS0f63JVH7IO2Xz8xXartR5rMe
8Z+Ice0PCndqBRD/iRiQaVxp50XxVpyIhl0p+f8yKJ4WJeKj59j2C58pP5Uk
YleQW8aMTLb+T4R7yQ+L86GEJYnwnCbLb4qj56sTMVE9WNOmiOarSURP7TWD
6izyt/pEWNm9MJEeYuN/ItYvdv2kG0/228qs/x/f6yyf/LU9EeZ3y/qP9KL5
uxKxjvN7x+oJVF/JJKFpsF0Tz4GwfBJ4bxuKRdfpeeUkmBzxcojdT/lENQmG
ieoJxy+Qf2kkIbBv7Ktto30p/iehs5pj1Yc9v3GS0Hgkr+VwI53vdJMgGb8g
2+XYd/1e/pOgObHGekYp9b8Nk5CkO7Da+B75m1kSUPk1SDWF/NcqCXXI3Z2u
sIv4T4JuQKnq6K/Ep0sSshV9L30tpd8veiYhubxxy/MGih+BSWjjHW4+eovy
Oy8Jqza1/CxXZPN/EoIu2Eqqy6jeFyQhL/lAfNwoqi+yk3D4+sfoKDXC4iRo
hboOUiqh+rQoCXFLpaN9NcmeS5Iw92zeCLu/FE8qGPnst1gfvEHxWpKESf4q
02q3Uz6pToLwUkR88gDyp5okxE9OqW6QI/nqk2B273eTpib5hzQJLm9sA43z
SD+tSZC535KsV/SrV7/tSUi1zU0wvEPnha4khLV6r90+jPK3TDLaU34sj05Y
Tv6fDN1JxiM9jEhe5WSMVfTf/PclnY9Uk8HhR/bYz6B6SiMZV3yqqk9ZHCH/
T8bdwG+vg1/T+ZeTDJOSmasdZ5A+dZOxY1/UMoUnJD+S4X7j8+iVlpTPDJNR
l6AzSLuC4qFZMvQPJh8d/pz8zyoZqlyvpwrfyP65ybh99tTCjbMo3rkkQ7zj
cdNbF4qHnskQTdJwmiig/BaYjO49+8qyf9A4Lxkt/becO1tMmJ+M6nqNaU9/
0fOCZLx4N3tjoiudj7OTcZRrWh2rQPoQJ+N60KP0USIaL0qGIDJn2BZVlv9k
zLzta5xSz/KfjATZp8/eXtxD/CfjsPOBeVaJbsR/MtZt855VsTWc+E+Gck3Z
qNbHLP/JmNT9L6Qvj+KHNBmSNMNq3SCqd1uT0VliOLXwRRH5fzLUrSUGAj8a
70qGucLjfn9LyV5lUlD1Yl1UwgGKH/Ip4AxzSPux1JbifwpiphYOy9am86pq
CvS/6XYGF9N5XSMFQ5+rN3UuoPpLKwW3dys98XOj+ouTgi2CmcXH97sS/ykY
bv+msmck2StSMGua6PQ4LuVjwxRMP2eXoDKM7N8sBbphM1pVm2n/Vikounoy
5+VY4oubAtXnlVEbQfp3ScHBG9VFQbHEj2cK7DYsXRfmQfEsMAWGlum7Vl5k
+U9BzbPPU16eJ3vkp+Be+J8BPf6UbwQpyFf+mbGzlOJddgo0pzVxetrIPsUp
zHnrqKpmENWXRSnIdF487tlAqg9KUiB692ybsiHl24oUcDkpiads1xD/KXj7
0HfppX5+vfqqTkH7NiVla4+4XlyTgo7hBnFf1lG9W58CHQuzVxvNqB8gTYHT
8Oxpg2cQH60p2Gi4e8uXaxR/21OwOXxpYN8nFB+7UrAsS7xw2qSVxH8q6icO
2B01luo1+VRIX3w9vpxD/TvlVBwSXp48NZjyrWoqtllkTTL5QucbjVS8vX1p
9JctbP8nFc/m7HBR8qZ4xknFkgXqiiI1yl+6qbhsN1mVO5vyCVJh8+vDriNX
CRum4sDuIdM/TyZsloplM9Wzny0nfqxS8XT8jeb8a2Qf3FTIzz62Im8djbuk
4prVjOdRU+h9z1SM9C4evfQ64cBUtFz2O5DMZ8//qaj+bBSoY8fynwqXF4da
+9pSv0OQitiAgGKvNZTvs5n9LTv+4HUCxR8xs5/V14tXbCVclAqZL027QrTJ
nktSsU530wJVPfb8l4rfJ0/++sOe9yWMfHqGfPuL5H/VqfAe+H7e2H1s/E/F
H9UZTVJd1v9ToWJa/9d0A9UH0lSsd9z0cvNUiletqeiuzHl3NZj6W+2pWG2q
XbZ8K9v/SUX7XWHg+QqqD2QEKGhVMnVQpPVkBci6ovk4/jnlJ3kBzjz7lucw
hfKzogD+61MeRKcEkn0I8PbdfUfultBerCKAys8c9dY0tl8ggFK351Tl6zSf
ugDG6Svzpywg/9IQQM7739Cx42l+TQGGD6rU+VVO9qclwN/Zeb/lDm3oxTMF
yJw9vPbYEg7ZlwB7EvUfPJpG5ykdAT7kJYcIr1E81RVgQtX4yyEDSV49AZ77
xA9U307xFQIcHD65Vm4xybtKgMUFLinHnpG8hgIYzTat5vxH/BoLYPZfRKzO
e7IPMwHGfP1+c6ky2ZO5APXLa/+rH0zYSoCuuwZV44YT37YCtDseXq8RSPGf
K8BoxzN/b4zZ0eufjgKmPr8s3HWUPc8KsNFx8Nqn1+l87SbAz34TtFLNyN89
BXAYKmh+kRPei30FiG79dOvdSTpvBgpQXKPaPrKd/DFEgNBpbvtufiB74glw
NvXFtGu1ZE/RAnSXeNwsyiXMZ/hJ3VeatIvsJUmA0x1pu5csISxg5FlrMTFe
SM+LGH70Pl0UT6L4mi3A8nPdo++nUz7ME2DbqcODpvwj/YgF+PTP9OiFO6T/
AgHEDV+Xxvxe17ufIgEOuUeZOefT949iZvyZ9PbgSurXlwgwbFPlHgMRff8o
F8C1NWHQeT+KvxUCjDx4eejFDvLvSwLY9eQsbCskf5AIcOWDm/7zo4QrBZj0
b3y5cyU9Xy3ADs/M9A19KX7fFUCU0mf3Xocwis8CzO0aPI33kb431DH29au4
25gbT/FagEFSdym3iurjRgHul5ZqTj1I80kFWP1Z78WBejrvNQvwLEWcs7OW
4kcro8+T0C0eSvppE6DxQfW1ZdbUH2gXQBryyWHzXZve+TsF4B5e0OHcx4Li
vQBWtXeGfhhD63ULMP97ywyBLc0vkwbei8FGjX2IT9k0KO6N2LH3O/Eln4ZX
8/ctzxTSuGIa8Ey4/8Uusn/lNGT3q+AVTSH5VNJgYfKelziH4oFqGjJ7Ohbf
HU37U09De0JOP5k5VK9ppGHg/vGR3eaUnzXTEFcXUakEOo9opUHv9PfNc2MJ
z0xDVdWVwWr1lN85aUgO26P4dh7Zn04aDj80UDu4ifanm4bTUZWDv8wgefTS
ECRnJozmk/8hDdFle0LurWX9n3m+ocPQWkrx2jANPTHK5V+GkL0ap2GBrmbG
lnryH7M0zBjZ91riP8Lmafi11e1in3y2XknDu1fDRl6+Qtg2DadOqr3ZH0/7
56Zh1b9jDm1TSb+Oaeh0jvzoYsHWs2nYlbVQ23IT2aNbGu5xUvgOS8ifPRl5
RIPyyg9T/eybhrOWAyV7dxLfgWm4nuRRsmMz5euQNAi2umZIZlP85TF8T3iy
+gSH8nN0GjZXrVn0R8qeh9Jg+GPPYVU/wklp+L3khJH/LNKPIA1m6ro32v5Q
fSBKQ/2D+ZxxX6n/kZ0GuYNzq7/nUzzLS8NC9fgD/FDyD3Eahpn9tFz0keqV
gjR09ft+tS6TzutFaeCc0z3VbELxrDgNjg/7N2SOZ/uraWjd2GggOEHng/I0
lGvHxWbE0PeQijSINS/5DPxM+rnE2FdcxK6NFaQ/SRokTauexLH6r0zD3pmv
fy/1JPuqTkPUA4/unM9kf3cZ+UKH5p7tJFyTBuf9q026ZpL91qUh/E2I65V9
lM/rGf8atUxupJIl+T/Dj+KBe3tHULyQMvxNvX1p/2+q55rTMHLOvaUOl+l7
V2saZPbwl83U39qL2xh9Plp407Iv5aP2NCz1iLm35B35a2caCsWlRit0qB7u
SsOOVvejxToU37rT0PTBZt1Atp6SEULHoKXvCDXq58gKodWg3Vp/h/QtL4Sc
U8KEdb7byP+FmCrcNcNOnfxJWYgDdQH1MgsoHqgIkS+3cINlFNsvFKJ9Xk6I
qg7Jpy7ESe9vIyZ0kT1pCKGoY3zqPza/agpRt/PWmm/fiV8tIYrWZd7e934j
+b8QXBvFs6pN9L2TI4S/PW/UDTeyPx0hvlt/yZ52kepRXSHKNh72ufyI+gl6
Quz/801L7iXZP4Tgr334VG4u2csqIcPXZwfzv5N79W0oRH3U363LT9D3S2Mh
Qsb9SXZ96d6LzYSQvuk4HBxjTf4vhKfHwBafvbSelRCBBj/rQs+SPmyFGDZf
5+WoL8QPl5HvVqP9VF06HzsK8UfjTdpaR/Y8w+z3QV11gjHFNzchjEdPaMs6
Rfr2FELma2LB6Km0nq8QChOHqAVPoP0FCjHZYFWY2kSKvyFC3JxaazLNhPyX
J0TG32gn8zqqT6KFuJZ8YsdFUPzkC7Fn/UklwRaqh5KEuP7g0ynBXOr3Cpj1
Ryv/UKig9URCnNNLLhpuSPJlC+HS51aM6kWSP0+Ixu/v61N9yV/EQmRv37Lw
xy86jxYI0W3QuurBQ9JHkRBLrn8ftKuG6tlixv7iNrcaNlF8LBFCpPTg4OxS
sudyxp5fn3m/7xbZV4UQwdwb1Q+UqN94SYgL/btON90h/5UIMU7J3fSwI/Uz
KoVIWj980fkqwtVCbEocV5809yD5P2OvQcOuyYVSfVMjRJfWqxzTWtp/HaOP
gbeE/fWsyP//Z6/nVdr+I/9pFEIQoNjiMpHt3wmxYNCA5v4tJF+zEFvsOZ9K
+lD/pFWI52V8960hdH5vE2KOQnBiFIf6T+2MfdmuG/HXjvTbydjv/Ydzvxoa
Uf4XwjaqbI7dAvqe0s2M/+vR2V1L911k0rEqR2grc4buw8imwyJq6hqtJvY+
SDq2FzfXcGWo/lRMR8moE/f++0vxWTkdLjsGrOzfQ/W6SjpEDztrstaQ/6qm
Q1l9wkKplQP5fzoq6oZVjm6m/r1GOorajy+KOkT9cc10yJ4wujoskPpTWumw
0V3j0H2K6r+Z6Rjp/DD+yCy2v5iO1uNLJXe4dF9Ch5nvWZ+Pb1PpfoEus166
YmUqe59CLx1WDaF9+Up7ejHSIdOZ0X0paHwvXsU8f2HWqbWHKb4ZMvq5phnm
AfIP43TUpExJPpXC9ifSYXw24HoYe94zTwfH6YHwZxHVn1bM/FO/3Nv+ifr9
tumQaN+fIZxG++Ey+ux/7abpCarfHdPB07zn/8DbpBe7pEMq+mE3g+1/u6Uj
up9fwuwusn/PdKgs9ctyWU3+4cvs37duYVIF2WdgOjRE925wPMg/QtIhn7Il
wSeBzls8Zr1jR5VVRy0k/2dwpkFcYfya3vX5zPoHTUPSN1F8TUrHpKR52vb9
yH4F6fix8NrjCYnkb6J0LBmh3Tf9BMmXnY76r3vmTT9M+stLh772mFqDB47k
/+n4uX+AaP0t4qcgHTm5AZ8tftH9qSJmfcshk2L4ZL/F6Tj2VVz5w5byZUk6
POP6mGYakD2UM/pXqLSv2kP3PSvSMT327aa9+6hffCkdcvrWNa6OtL6EsYc/
N47M2WnX+3xlOsYrjF0z9ivZRzVjb4fKU56aUz/5bjo+Vh0euOYptxfXpKNu
2Lybcy9QPKxLR1nKkgUbjlK+q0/HhxK3YSoxFG8a05Fi7IUxahRfpOm4/ko0
9/pcws2Mv3VPkVNdQvGmNR3+dRbzznpTPmhLR2SEuuWHFez3nXTkBQcs/LGG
6rdOxp5UdH7fSSa+uxj+PUf7ST6SPN3pMH+sc+nSCOofyohwbMel9p5mijey
IjSIX7m6f6H+obwIZ42yH/Y00v1bRRG6vfWfLPp2gvK/CFabvg5b9pT+np+K
CI3ReRet1E6T/4uwIoP/Wiyh++fqIqhWRU1zbKG/76chQtfHtVfveZ+j/C+C
3sp4RVW9C5T/RdDx+mmvNpbuD88UYUqqcLiijITyPzNf043Fih5031hHhIJV
EcqqjfT3AHVFuLRmwCGrtXQ/WU8E44RlZnsvVlH+Z97/r0VZS5/uM68SgdOa
7/Xf22ryfxF4IyPuvL7/H/m/CCWO5109Vej+tJkIgWvdNdddp/vf5iKsOh8h
XuRI98WtRMiT/zs56A/dJ7cVIVvhR1FwFN2n5zLzjfohN6Ce7qM7iqDs3nNH
8TXdr3dhnh98kjszj+6vu4nAXX/YKWcs/X7Bk8HTta3iYgn7MvLqrdDu+UY4
UITqvR3PdXbTffgQEeTbtjc3PCPMY/R/zTBTX47u60eLwJ8d3Op1hsb5jH5G
xRv+u0DzJYngKfP+j8VQkkcggpavt41lE+1HJILZzALDEyG032wRND4mXP6l
S/fl80SQXHePe1xK983FIggi/wspe0P3ywsY+QtmvH94k/goYvCcCrVTjcRX
MaOvc5tipxy+QfmfGZ/Y+fCKlOyhnJl/xsO7A3dcpPwvglj9fpke5wz5P/P+
rQqenindL5cw76ut+VaiT/ZdKQIulXlwnOnvVVYz7wvH6J8KKKb8zzz/81uT
tPQk5X8RpGPnnLG2J1zH7F/0esWgP0fJ/xns90qzQcr6P8PXE5WUcQvY7zci
yCxoNNNoo3jVzMj/caGg+wSdl1qZ9bKMurTC6bzUxuA7Zg/HDaL7J+3M+0uM
fJYuo35AJzP/gB9NHSvpfNPFzJdhcXWXEp1fuxl5f6e2FV2leC2Tweivubtt
J2HZDKCtKvbLBvY+SAbaHdyzY8so3ihmQCB391jeO6o3lDNQtJMn905C8UUl
A+Jjs60a3rH3BTNQUq6u++8F5Qt1Zj2vkU0zttN9B40MaMyTLljymvKhJvP+
jtOV8X7sfZIMaO4y3P8b1P+emQEOpr62jqT+DycDEtuV2manKB7rMPKdk//3
OpvqeV1G/oMznExA53s9Rp7Fsklj31B+RwakndO2PapxIv9n5JvbaedYsrF3
PsMMyBiMnDtZf0EvNmbW+7T7cowq5U+zDFRvbfrrfJf2a56BlCUymz/PIr6t
MvBEmHdMdjp9H7PNQOGPr29Hm5B9cTOQZDK1Z6U1YccMrDum83afA8VfF2a/
y1+s3TKf6j+3DKgavVv2aRvlC88MRO51PKmfSOO+GdAJ3Vverk32F5iBz1rZ
4ruDyH5DmOeHzn/Hf0Xxm5cBu7NXT4wZTvYbnYELV2Zndv2h5/kZWLDivPr7
LPKPpAy8fFctzu4geQUZkA17o71QQOMiZn61bA8PDs2fnQH3W95dr+QoP+Rl
IOar67w5E8j/xBlQf32BwzUkXJABBdXiKXFahIsy4Hhp17euGYSLM3DKasW3
aWcIl2SgrnHkioWvKN+UZ2CjySsHNRf6PUlFBuS9z17Z8YjyzaUMrGryFDuV
UTyQZOBa472tp74QrmT0r2y0YqaUcHUG/IM/6byffpb8n5HnkXPELD/KVzUZ
aFE/++vEUMpXdRmwjFgTtLOe8lV9Bjo9+C4YT/mpMQN6t5KMT5hR/JIy+snS
6PxuQvGtmdGHhdL3Q2oU/1ozUGwUZffyE+Wjtgzk6Zm6XOtPv89pz0DbE9P4
qDjKR50ZaK66yf/HoXjbxdhPbXSs03HKR90ZENUolD0ZQr93kslk5FPX2rme
4rdsJsQ1WfNNAykfyWcir9w0R/Mi5SPFTKgu88j/tZbygXImlH1cVxboU/5Q
yUS2TRtko+j3WaqZ4DY6GPV98JL8PxOa+/9NmGFPvxfUyESX33rFYvb3y5qZ
UN+yqHDKRPr9shaz3jeF77sbaXxmJnz1dObfXUeYkwmBUWvgw3n093l1GHn0
7Ew+v6Dfi+lmQlI01PtMGcmjl4l2F+HamAL6vRgywZeb9PYAj+RflQk0FPLv
jaL8Z5gJ3uya+lsWlO+MM2F1N73N0ZT0Y5YJz7+vxtotIX2aM/t5ab28ry2b
/zNhxnkp53CH6gPbTGi0XrvY2Eh8cRl9t8/sp9RA+dAxE1LTb2fnJBF2yYRW
yx5PlcuE3Rh5ykYXNm+k9z2Z9Yr6WnVb3Cf/z0TgRdFTkZTWC8xExfm3y1/3
IXlCGP1Yh3w9ZUX5mZcJF/emherPSf5oZr15R22mOdD++P+TrzGl5zbxn5SJ
mshLQSO/sfmfkSdoU4l7LdmDKBO6fP3Zq91If9mZMHy1Y0GfGsJ5DF/fJ49y
Hkr6FjPzPeSNjVpBuICRZ7LJ9ZUehIsYfl5/mjoll3BxJuRXF8Q+P0+4hNHn
587NhysIlzP67rf0vGEA4YpMtI7YFdJSR+tfYuTZIOw6zdYzEkaeybAUTaX9
VDL2Onb3YKUFtP9qhl/nlYWvR5F+7jLzKRyK2jCA9FnDrC/bIDvImfRfx+jL
IYz/1Ib8s56ZP2P6+foH5L+NmZApcTudFXST/D8THMUBFa5KVJ82M/Zufahb
sJPiRSsjT8Gyo1Y2FE/aGH1turcy3ZF+P9fOyPdt3Ur9KxTfOhlsZ11t/pr9
vSejj2CfZdIiwt2MfZVphi4xpfgok4XW5EdOclcIy2ZBYJBy/5UiYfksWDnO
v6HXQfFWMYuR3zyqfwPFe+UscD5+yns5lvKPShbat76+ot1N5xdVZjz5dL16
LfUr1LOgHFExqnY75TeNLBSZdhds+Uz5R5ORRy//7WceyauVBek/QdXZ9bS/
mVnQkx+T80RAmJMFdSdHveG3SV6dLBRcXOYYK0dYNwszRy1+eXkrYb0sOPZ5
Z6ZhT/EdWdBc80Pjyj3S5ypmvxO9Ou5XXCL/z0JSlJ9R8Yer5P9Z0J+X/nzY
Jao3zbIw0r5/VXMmYXNGvoGCjROP0/NWzH6MF2nyJl0h/8+CfFLPh3FviU9u
FroG/h4//SU975gFft0pz8hpdH5xYfS566yw1Z3yg1sWym9OPmZiSfWyJ8OH
V59S1d0UD3yzcGnXOoNRJyn+B2Yhb/zfg7PYejwkC25vy+4YjqN4z8uCVs7s
K057yd6jGf6HDvH9x/6+l58F1TzzYTMWs/V/FrLPhZz9bU7+JMiC2QDRrZnL
yN9EWXBJHnJkQxvh7CxUPzo36pQZxds8Zv+pW1/pbScszoLncr1C3TGEC7Jg
uG3LMaNA1v8Z+UKGxGyIpfWKmfHmZqOFNiRPSRbEFWOXbR5O/lueBagl/zpf
S/upyIKGRdzrhyW030tZCPyRONjtDPmzhLGvCgc7xyekn0rGPnXN4jN7yL+r
mXGruDkLxhC+y8wfLl3oNJH0W5OFmrOBrbtXsv7P2PvEVXMDtrK/12XeXwKL
f5fp/NjI7H/QvuSb3sSflNnPycEx0+0pPjQz9jCiK3+tAZv/s8B9+OrDq1bi
v42xp5VOk+ZqUbxoz0JF6awKCzWyl05mf+eqNIcPJHvsYvbTp7Vnex7Zczej
7yVf9gs2Ub0ikw3xccNLLmbnyf+zwS+VnuieT1g+G4EfdUaudSOsmI0S+xL1
7aGElbPBuTo67dwOwirZKCrizbCsIKyaDVXBJfeZNnQeU8+GZGRXQv5MsneN
bCgbnb3/qJrk18yGwEG83XYE7V+Lef/vlREPvlE8ncnMn/JvtpY16Z/DzMcr
l/u6hfjTyYbbzwF/El4Sv7rZ0Oy8ldfeTvzrZaN16Irgu3fIPsDsN/p2THc5
2fsqZj1Nf2UFKdmTYTY8V60bqmZF9mfMYLOV3Md/yD7NGH1UhBztSaD6wjwb
9Y6COssr7O/VGf3s8LYX2FH9Y8vIf1o5Kn4DYW425Be1/ivOpecds9EVO7al
aAPN58LwUzJolEkmreeWjYqkR0of49jzPzN/UrnLhxUkv282XOqGybU30f4D
Gf2aXv/lEMPm/2zIfMvy2pBG9spj9qPwdUFQCtlnNKNPYf9E3kTSP59ZX6o9
6L0Z2VsSI++xqy2b+hFfgmxkhzvM/zWS7E2UDY03i88nNZK9ZTN8eonkXv4m
e8j7n/0kl47OovpZzNhXke6QIzUUjwuygYMvp104T/G9iHmfOycjZTnh4mwY
im6EqegQLmH4tLh9lWNKuDybqScmbDfnEq5g5PPQ2mFnxdb/2dA9XpVivpaw
hNHPYg/r1ez7lYw+Vy8+98abcDVjH+d87ONyCN9l+K3ZGjs2lXANw+ckea/Q
qYTrGP3lLuoY7kT5pp7R79gFluOSKZ81MnhxV7vJaMJSRr8TJslU8gk3M/Ln
jBy0YTLN18rY4+90y68NdP5oY/bPUfmosYj8t53Zz9/cEOcDlE86s3F3/vdx
BWtY/2fmV4/hRLlSPdHN2FcRZ+Gxrez/LyMHl1KiO18503lENgcVR1Q+Tq0j
vuVzoKqV23XiIdUrijkItNQ/XsXmH+UcyBvt1+fPoninkgOBUmHQpmFUf6rm
QPfdiiumn8hf1XPAFet++GlA/qqRg/bxpjVDT5O9auagpG39cZ4J+acWM5/7
ijuTtMkfZ+YgO26+7L8V5I+cHHC2nBXs3Uz5Q4d5P0uv5dhEtv7PYerz7zeb
tpG/6TH7mRje7fudMHJgdePp04+fCK/KAX/jpog+MYQNc4AFxma3+hE2ZsZj
V0zyPcD+fYocVF9RO9m9k7B5DsSvh0q26bL+z8w/6uSrY7fIn20ZfW3vGNH3
EcnLZeTZvCLPZwH5t2MO6ne/7QrpQ/7twuz/05h9Jj6kD7ccuNzWrZE2kf48
c2D4R2uK/n7Sr28OlO9dzi3Np3ogMAdSC82L6h/Jv0MYPH39xtH1lG94OZCo
npnjP4T8PZrZb1HnA0tbyjd8hq+RkpiZt8g+kpj9v3wYVJfE+n8OZBY8+8+i
i+xLxOz3fm1TjA6NZzPrfUsz26NN7+cx9tXRtVuaTfYlZsY31r90HEL2VcCs
NytiQpIh2//LAe+7R4JUj+QtZvQ9y+tqvjbZXwmz/mLvSWuSaH/lzH50Xeev
vMD+vQ1GfwUF+daNZI+XmPXHBLsNb6R4KGH0WThbZfsrsr/KHJh5FgxS3MfW
/8x8N5wealdRfL3L6OdukPf7mWSPNTnQWGJe9a6exuuY9cpuz3f/Tu/X50Br
TNG1PxLKP42MvRs7x/7wofWkzPs8nZVqHOKzmZFPszDkxl/is5VZr8zc9eZx
kr+NeX781LdxDuzf92D09Wx1Y5425cdOZv1kuVfFC0g/XYz+dmDVm9Okz27m
+W+ljrurSN8yuWjfnsc/6kpYNhdmhmtV/7JYPhdaZwqM8nay/p8Ll/3nJkT2
I6ycC7HPlyV9u4hPlVxkF/H1H+sR36q5wKtEt/59yT7Uc+HJj1QN1ad4pZGL
knWjH/m9o/pbMxfcttgzSxMpH2jlQvnpxVMvrSiezmTk5YW2G4yheMlh5Fu1
6HLSeur/6OSiXvX4QgsbOq/o5kIjeHBHWBD1o/QYLFNptCyQzh9g1pdfUpP/
nvp1q3LBO1eo8ncL9TcNGfkHbaj1Gkf3CYxzISOvarG0zerq/8dmzHyaNx5/
WUq/VzJn8Nh9wrhOr15sxTx/JVt43HU9+T8z37f4E3XD6P4hNxc1r3N/byml
74eOjH4v3NogV0bfy1wYPN4yycySvr+7Mfzw5sT1XUnfszxzIfkhWr+0P91H
8M2F0LaP/chpdD8tkNHXHMdbDxxJvpBc7Bq56E6ffubk/4y+r1lnF1jQ/YDo
XDhPztty6hT1M/m5CE3caLG6mPq7Sbl41r3v8a5m6icLcqEr7ybry94HFeVC
M2GQxrXL1M/NzkXdnknFhS/p+11eLtqix2y/rUF/r0icCxW1/rJn7envERTk
gvNisquvG91vLGL0N3S6yYU4jV5cnAv5YdeL1zjQ/YUSRt5VdxWd5Yiv8lzc
F2/YnXWZcEUuwmfirOgee/8vF7kDm189vkffU/9fDdceFGUVxQlRDDFMEZG0
MFFRURHJMUA9wqrIoLMJEiiKIz4WZhcxwF0NmQVB0fhjJVLmuxfZQdQ18S1K
voDUMAIlebTWSiTgK8xVzBYGqDvT7/vzzrnPc893zrnf+Z1TJe7LuWi9/h7i
tbfEftbazw1wxf/jOxI9dAzOqd4G/tRJVOI5MqMmDHiOBol2hlj4xQTghZok
alcYPAKqIU9miZL2tUVnZ+I9bJHoUei2lU+mgN4m0aL72gGlEuM7BH+v7zHl
q2Q8r0RZXkH39Wqcp0uiWwOf2auGoW2V6PSxn8bbtcv4H4n8cmZ+0eMCPIFN
8KtY0lh+wfx9Eq1Luurzu4Oc/8PoyomGfEMa3ucOjIy6l63mzXjPD2VUMOAW
c+Eu/ic7M/KdlKNRrpHjf4xWvlDUxC/D9+bKhL81v2JWnhz/Y2S6pw5eqJPj
f4yy9zTW8OX4nj3F/GVbvPp08He8GHUktJ8Zmgh/x1vsp/z4uvPx8B99GClX
77IdjoX+8GVkyCi+Efgv/B1/Rv6jW0JiN0D/zGPkGRm8mQ7BngUxSh6R21+i
hT4kRjbVg60zh0BfKhiZpQPhXUmwJ6GMzn7qcaS3B/o1XNDNmb5f/i3H/8T5
pKURV1ZAX0cyqhjtPuDkAH0eLfafFhO2dzj0f6zY78erimKXwF6sF/uZ8M2G
73Sw9xsZtfU+u52SAH9AxWiEdbLivcfwF9SMVAPj0ub9DH8iWfDjwQTHfVPh
b6SK9fdOslc7oq1j5N17uP79fPRPZ+Tu6D6s+S/Mpxfjby9wi52Ndra4P0O3
45wIuR6a2G/P9ykecr2zPEYNE6Sx2svy/z8hDxcddSFXYO8KGJF2reQSDPtW
KPpHrKmLS5Xjf4zs1A3PPvcCP42i/94LFk0t7qeUkX5Se9KhCNgLk6AfO9y3
5h+8H8sYWYs252qS8H44K+ab5vE8a7fs/zOqejdwnUWWtwrB36BNm8ZyyOc1
Qf/k6x1lfyC+USXWWzwtIFyL+Mwtcd+9p4qnPEd8/I6Qn5WtByUZ71kn1jta
35hxCfGiBjG+//iL8a+A12sS7ZZzmsRZ0G9msX6zz49R9ahnYxH7/7UufukQ
1LtpE/2ddC1XI9DuEG2/TCnGJtfzEfdlsF7qfQu8TpcY/6fl5BEOfWll9HTH
Q/cxnciPfiPu44fxfq07gJ+wif26FGd0+sj4HyFPlW5LAsegXo4dJ9Xyo9dc
v0L9Kwcu3vMzJmt9sd5QQf+2cbtDH+jOnFJnLDhzMgv4oBGc2jSU89QH9WJc
Ob0xTX1n0WDkd7tzUjwNXGW6Cfo4Tn0vj79yjQN/PDmVFhq7+/NR38eLU0Xn
yA8WOWF9b061aRUDPffR34fTNNvr2upDyBf35RSqnXGqdjXihf6cLOf3DJJS
ER+cx2n/qKwx9S3AhwRx6vC1j1aEIb+GOP02Mfi1FIHxCk4hU3PKFR+Bn6Gc
KoNL9i2MRz57OKftpw8uvpAMupLTK2VmanUT8CiRnMLso9JHlqMdzSkyjuLn
JGN8LKcl52Y2NRXh/tZz8V5r1nQNwfk3cjqR1eo2thnnV3GyFljNzitAV3M6
OD99+uC74G8yJ3XdqImzzZC/VE5V4TE7byci/0rHyWjM3WrKRv5EOie7vm49
73L9n67npAxSPDb3A++SLfofuBll7oD9zeVk3jLI2JQC+cnj9OEzW1bjcKxv
4BSgyNu12wn8KOBE0qO5Dt6IXxdyMlRWpsx9C7wXF+fRJsbsvwt8slHIV03U
rsAwxGNLORXGxd2INgKfbeKkv/5k2bBy5CeVcfKcPvuyx+Poyv8AqrB7hQ==

       "]]}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6]}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6]}, {}, {}, {}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6]}, {}, {}, {}}}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 1835.}, {-0.10983779509597086`, 8.662048289792263}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8540957320191784`*^9, 3.854096079842099*^9, 3.8541047630253963`*^9},
 CellLabel->
  "During evaluation of \
In[93]:=",ExpressionUUID->"7c8aeaa5-6376-497a-ac18-8b354568bdb5"],

Cell[BoxData[
 StyleBox["\<\"RMS difference vs displacement in data points\"\>", 
  "Subsection",
  StripOnInput->False]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8540957320191784`*^9, 3.854096079842099*^9, 3.8541047658993287`*^9},
 CellLabel->
  "During evaluation of \
In[93]:=",ExpressionUUID->"ceeeea0d-4020-4f69-a7ed-8c6352e938d2"],

Cell[BoxData[
 GraphicsBox[{{}, {{{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJxE23lcTN//B/D4WEJIkhCSEJIQku0lSUiSrRLapV3aS037VFNN01TTFCJL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       "]]}}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.003666666666666667], 
     AbsoluteThickness[1.6]}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6]}, {}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 3671.}, {0, 15651.288509795208`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8540957320191784`*^9, 3.854096079842099*^9, 3.8541047659677615`*^9},
 CellLabel->
  "During evaluation of \
In[93]:=",ExpressionUUID->"00a3e70f-600b-4b15-b753-334ae6dacecc"],

Cell[BoxData[
 StyleBox["\<\"Expansion of RMS difference vs displacement in data points, \
with parabolic fit\"\>", "Subsection",
  StripOnInput->False]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8540957320191784`*^9, 3.854096079842099*^9, 3.854104765983795*^9},
 CellLabel->
  "During evaluation of \
In[93]:=",ExpressionUUID->"fdd90309-d9a7-44e9-ae44-e4106eb2f3b7"],

Cell[BoxData[
 GraphicsBox[{{{{}, {}, 
     TagBox[
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJwV13k8FP8fB3CVSlLpLvpqrZ11hKQlleOVSpcUlRwlR7nPmN21liRHVEIK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        "]]},
      Annotation[#, "Charting`Private`Tag$1999460#1"]& ]}, {}}, {{}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
      0.012833333333333334`], AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJxTTMoPSmViYGAQBWIQDQEf7KtnrK6b17fAASrg8KTw+L1lkXOgfA6HgBOF
u59cmg7lCzgcK19o9mbOZChfxOFJw3Fzken9UL6EQwabUV/d4w4oX8ZB6X4k
t4JTM5Sv4HCkMe+H/eJaKF/JYZ979pQboeVQvorDqlN/m0UOFEP5ag73LiWU
BH4rgvI1HCKqjHqF/pRA+VoOKyp57i84XAnl6zgcObev3GV6A5Sv5/D53qVX
5e2tUL6BQ1N8dv+lKd1QvqFDjkiarqHfRCjfyOGe1ma+NdZToXxjhzwpkUse
dTOhfBOH/AbdXi7GeVC+qYPm8XcHZ4YvdAAApFJdLQ==
       "]]}, {
      {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
       0.012833333333333334`], AbsoluteThickness[1.6]}, {}}, {
      {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
       0.012833333333333334`], AbsoluteThickness[1.6]}, {}}}, {{}, {}}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{Automatic, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{All, {0, 2441.780338485711}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8540957320191784`*^9, 3.854096079842099*^9, 3.8541047660494266`*^9},
 CellLabel->
  "During evaluation of \
In[93]:=",ExpressionUUID->"202c1fe5-53ca-4f48-94af-a413eaf2c96f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Interpolated frequency shift with best match is \"\>", 
   "\[InvisibleSpace]", "48.45373278853503`", 
   "\[InvisibleSpace]", "\<\" Hz\"\>"}],
  SequenceForm[
  "Interpolated frequency shift with best match is ", 48.45373278853503, 
   " Hz"],
  Editable->False]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8540957320191784`*^9, 3.854096079842099*^9, 3.8541047660494266`*^9},
 CellLabel->
  "During evaluation of \
In[93]:=",ExpressionUUID->"bf2a53f7-6e3f-4edb-97ec-2d6b17f872c0"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   StyleBox["\<\"Chemical shift = \"\>", "Subsection",
    StripOnInput->False], "\[InvisibleSpace]", 
   StyleBox["3.8731`", "Subsection",
    StripOnInput->False], "\[InvisibleSpace]", 
   StyleBox["\<\" ppm\"\>", "Subsection",
    StripOnInput->False]}],
  SequenceForm[
   Style["Chemical shift = ", "Subsection"], 
   Style[3.8731, "Subsection"], 
   Style[" ppm", "Subsection"]],
  Editable->False]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8540957320191784`*^9, 3.854096079842099*^9, 3.8541047665006638`*^9},
 CellLabel->
  "During evaluation of \
In[93]:=",ExpressionUUID->"6ae2c616-7ce3-4faf-b61c-d87f0605ca43"],

Cell[BoxData["\<\"Variance and optimised shift and ratio:\"\>"], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8540957320191784`*^9, 3.854096079842099*^9, 3.8541047965264807`*^9},
 CellLabel->
  "During evaluation of \
In[93]:=",ExpressionUUID->"174ea0bb-428b-42c0-aef4-7956ed6f1912"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"49.601248684507176`", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"fdiff", "\[Rule]", "64"}], ",", 
     RowBox[{"fratio", "\[Rule]", "1.1025462391974825`"}]}], "}"}]}], 
  "}"}]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8540957320191784`*^9, 3.854096079842099*^9, 3.854104796532465*^9},
 CellLabel->
  "During evaluation of \
In[93]:=",ExpressionUUID->"8447fb96-ddaa-4c7f-ad4b-7dd974e1e4d6"],

Cell[BoxData[
 StyleBox["\<\"Input data\"\>", "Subsection",
  StripOnInput->False]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8540957320191784`*^9, 3.854096079842099*^9, 3.8541047965354567`*^9},
 CellLabel->
  "During evaluation of \
In[93]:=",ExpressionUUID->"32cc1ef9-4f67-43f8-9fd8-f62b44420da4"],

Cell[BoxData[
 GraphicsBox[{{}, {{{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJw9mnlczN/3x4eSEELog5is5WMJISKvkkShKCpk0jbt0z7t72aXLbJEKAnZ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       "]]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJw1mnlcjG0Xx1OWHpGQJEVk30pCZPkhSURFezRt2mvap32qqZkISVSEIRSJ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       "]]}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, {}, {}, {}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, {}, {}, {}}}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 787.}, {-0.01806384758750435, 3.0568522984202953`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8540957320191784`*^9, 3.854096079842099*^9, 3.85410479659031*^9},
 CellLabel->
  "During evaluation of \
In[93]:=",ExpressionUUID->"f26b2e54-c915-4f3a-bb8d-7be5652a014e"],

Cell[BoxData[
 StyleBox["\<\"RMS difference vs displacement in data points\"\>", 
  "Subsection",
  StripOnInput->False]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8540957320191784`*^9, 3.854096079842099*^9, 3.8541047971684027`*^9},
 CellLabel->
  "During evaluation of \
In[93]:=",ExpressionUUID->"db0e837e-c842-4624-8813-9437a83c44c0"],

Cell[BoxData[
 GraphicsBox[{{}, {{{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJxF3XlcTN//B/BKEkKWyJYQkhCKEF4SkqWkKFuLJCSptJdpn2qqaXaEJGSr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       "]]}}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6]}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, {}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 1575.}, {0, 1933.8353028127797`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8540957320191784`*^9, 3.854096079842099*^9, 3.8541047972278647`*^9},
 CellLabel->
  "During evaluation of \
In[93]:=",ExpressionUUID->"cc8331e6-4e85-40a3-84be-6b3bd886ff22"],

Cell[BoxData[
 StyleBox["\<\"Expansion of RMS difference vs displacement in data points, \
with parabolic fit\"\>", "Subsection",
  StripOnInput->False]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8540957320191784`*^9, 3.854096079842099*^9, 3.854104797243486*^9},
 CellLabel->
  "During evaluation of \
In[93]:=",ExpressionUUID->"81ab6295-0d13-4b90-984f-cddf153faaa4"],

Cell[BoxData[
 GraphicsBox[{{{{}, {}, 
     TagBox[
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJwV13k4Vd0XB3BFk/AqUmS+95xrSuJmKOXbJPfcaypUoiLcjKlUKpX0Somk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        "]]},
      Annotation[#, "Charting`Private`Tag$2070439#1"]& ]}, {}}, {{}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
      0.012833333333333334`], AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJxTTMoPSmViYGAQBWIQDQEf7HUUj3hcPpLmABVwWOu07vOZ98lQPodDd7n7
0mr/RChfwOEdn9L195dioXwRB6OXz73Xt0ZC+RIOl2zUrnEfDIXyZRz4DNLb
XPuDoHwFh0OLqua9+OYP5Ss5xCU0yK5X8oHyVRw2lzo73d7hCeWrOYTGtG3/
esYDytdwKPnkI3A0Gyav5dDTJqa8YoY3lK/jcOK+qkilD8x8PYdtKUtS1Kxh
9hs4WGp8/X69DuY+Q4cWX+Hk40kw9xs5bBGKj624DvOfsYPqGSfPfWkw/5s4
PF+wyOivVAqUb+qwq8JWOokx3QEAznhWEw==
       "]]}, {
      {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
       0.012833333333333334`], AbsoluteThickness[1.6]}, {}}, {
      {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
       0.012833333333333334`], AbsoluteThickness[1.6]}, {}}}, {{}, {}}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{Automatic, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{All, {0, 202.44754846770084`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8540957320191784`*^9, 3.854096079842099*^9, 3.8541047973258543`*^9},
 CellLabel->
  "During evaluation of \
In[93]:=",ExpressionUUID->"50c0fd92-cca5-48d8-8657-69afd309505c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Interpolated frequency shift with best match is \"\>", 
   "\[InvisibleSpace]", "2.4417371106371983`", 
   "\[InvisibleSpace]", "\<\" Hz\"\>"}],
  SequenceForm[
  "Interpolated frequency shift with best match is ", 2.4417371106371983`, 
   " Hz"],
  Editable->False]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8540957320191784`*^9, 3.854096079842099*^9, 3.854104797341474*^9},
 CellLabel->
  "During evaluation of \
In[93]:=",ExpressionUUID->"9b7f43c5-099f-4f88-a5e1-6ef7ca3cc565"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   StyleBox["\<\"Chemical shift = \"\>", "Subsection",
    StripOnInput->False], "\[InvisibleSpace]", 
   StyleBox["3.51479`", "Subsection",
    StripOnInput->False], "\[InvisibleSpace]", 
   StyleBox["\<\" ppm\"\>", "Subsection",
    StripOnInput->False]}],
  SequenceForm[
   Style["Chemical shift = ", "Subsection"], 
   Style[3.51479, "Subsection"], 
   Style[" ppm", "Subsection"]],
  Editable->False]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8540957320191784`*^9, 3.854096079842099*^9, 3.854104797831933*^9},
 CellLabel->
  "During evaluation of \
In[93]:=",ExpressionUUID->"0945a039-8474-4bb0-9bac-c5fad6d0db53"],

Cell[BoxData["\<\"Variance and optimised shift and ratio:\"\>"], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8540957320191784`*^9, 3.854096079842099*^9, 3.854104826021273*^9},
 CellLabel->
  "During evaluation of \
In[93]:=",ExpressionUUID->"66376e34-c8cc-43b0-a54f-2fbff601f0dd"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"34.396641103289895`", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"fdiff", "\[Rule]", 
      RowBox[{"-", "2"}]}], ",", 
     RowBox[{"fratio", "\[Rule]", "0.8`"}]}], "}"}]}], "}"}]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8540957320191784`*^9, 3.854096079842099*^9, 3.854104826036832*^9},
 CellLabel->
  "During evaluation of \
In[93]:=",ExpressionUUID->"a70ea2be-8f1b-43c5-9cee-d8399f22742d"],

Cell[BoxData[
 StyleBox["\<\"Input data\"\>", "Subsection",
  StripOnInput->False]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8540957320191784`*^9, 3.854096079842099*^9, 3.854104826036832*^9},
 CellLabel->
  "During evaluation of \
In[93]:=",ExpressionUUID->"8b983bca-5f44-4feb-960a-6e90fb130e47"],

Cell[BoxData[
 GraphicsBox[{{}, {{{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJw1mnlczd0Tx69sIWRLtlx7ErIWj+WTSEhaSZKrPUq3fa+7dJeiTSJ7KmRJ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       "]]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJw1mnlczP8Tx1euciYk94pIKTlK5HgJCcUqpRJW6b62e7v33vUlFiFHqZAQ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       "]]}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, {}, {}, {}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, {}, {}, {}}}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 787.}, {-0.005765675, 5.6342540625}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8540957320191784`*^9, 3.854096079842099*^9, 3.8541048261103325`*^9},
 CellLabel->
  "During evaluation of \
In[93]:=",ExpressionUUID->"1c019019-00e5-4721-ba0b-55e2ce7e0cb6"],

Cell[BoxData[
 StyleBox["\<\"RMS difference vs displacement in data points\"\>", 
  "Subsection",
  StripOnInput->False]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8540957320191784`*^9, 3.854096079842099*^9, 3.854104826618515*^9},
 CellLabel->
  "During evaluation of \
In[93]:=",ExpressionUUID->"c70ec75d-4d71-44fb-9fbc-91b866effdee"],

Cell[BoxData[
 GraphicsBox[{{}, {{{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJxFnHlczc3bx5OkiEIooiSEkCRJ+ERIQishLZTSpl17pzrt2zmns0lItiJk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       "]]}}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6]}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, {}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 1575.}, {0, 3305.91285708848}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8540957320191784`*^9, 3.854096079842099*^9, 3.8541048266873274`*^9},
 CellLabel->
  "During evaluation of \
In[93]:=",ExpressionUUID->"7b72d915-25a4-4105-9c69-3cedd088484c"],

Cell[BoxData[
 StyleBox["\<\"Expansion of RMS difference vs displacement in data points, \
with parabolic fit\"\>", "Subsection",
  StripOnInput->False]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8540957320191784`*^9, 3.854096079842099*^9, 3.854104826703017*^9},
 CellLabel->
  "During evaluation of \
In[93]:=",ExpressionUUID->"dde93737-bb24-452e-972e-1723c219bb19"],

Cell[BoxData[
 GraphicsBox[{{{{}, {}, 
     TagBox[
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJwV1nk8VN8bB/BBi6K+KlQq28ydGUvWSbTwMZcxGEklIqXJVvZSyVJaiZJK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        "]]},
      Annotation[#, "Charting`Private`Tag$2141909#1"]& ]}, {}}, {{}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
      0.012833333333333334`], AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJxTTMoPSmViYGAQBWIQDQEf7Df49U5zW1zhABVwUDuhaH1wSgmUz+Fg4ebS
KHOjAMoXcHhpcVF6x+ssKF/EIbtv38H7b1KgfAmH+avmqvxsj4fyZRz64lb5
1TGEQ/kKDgFvHXoc4wKgfCUHnl1zeBTz3aF8FYep/qFrk6ycoHw1h8kFu5WO
GjlC+RoOStfWmYfEu0D5Wg4Z07Ub/+70hvJ1HM5p2eVrzwiG8vUc1K86+3kG
RUP5Bg6dM8PzZlQnQfmGDvPYtux8a5YB5Rs5SCg/s0k+kwflGzt8cdwdMle0
GMo3cVgtkLmrS6Ecyjd1UPgunm1RW+0AAMjRUpI=
       "]]}, {
      {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
       0.012833333333333334`], AbsoluteThickness[1.6]}, {}}, {
      {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
       0.012833333333333334`], AbsoluteThickness[1.6]}, {}}}, {{}, {}}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{Automatic, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{All, {0, 483.8089014081727}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8540957320191784`*^9, 3.854096079842099*^9, 3.854104826766601*^9},
 CellLabel->
  "During evaluation of \
In[93]:=",ExpressionUUID->"2e9a2100-bbe2-4def-8183-7e7a4e565422"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Interpolated frequency shift with best match is \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"-", "0.06520270328017923`"}], "\[InvisibleSpace]", "\<\" Hz\"\>"}],
  SequenceForm[
  "Interpolated frequency shift with best match is ", -0.06520270328017923, 
   " Hz"],
  Editable->False]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8540957320191784`*^9, 3.854096079842099*^9, 3.854104826766601*^9},
 CellLabel->
  "During evaluation of \
In[93]:=",ExpressionUUID->"d446511c-28ec-4275-93da-52feb9d8fc6a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   StyleBox["\<\"Chemical shift = \"\>", "Subsection",
    StripOnInput->False], "\[InvisibleSpace]", 
   StyleBox["2.0603`", "Subsection",
    StripOnInput->False], "\[InvisibleSpace]", 
   StyleBox["\<\" ppm\"\>", "Subsection",
    StripOnInput->False]}],
  SequenceForm[
   Style["Chemical shift = ", "Subsection"], 
   Style[2.0603, "Subsection"], 
   Style[" ppm", "Subsection"]],
  Editable->False]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8540957320191784`*^9, 3.854096079842099*^9, 3.8541048272191978`*^9},
 CellLabel->
  "During evaluation of \
In[93]:=",ExpressionUUID->"a16c1fe8-5f20-49ad-865c-b54a42732f8b"],

Cell[BoxData["\<\"Variance and optimised shift and ratio:\"\>"], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8540957320191784`*^9, 3.854096079842099*^9, 3.854104878096657*^9},
 CellLabel->
  "During evaluation of \
In[93]:=",ExpressionUUID->"1a485463-a7d9-4579-89d4-4530d28d46f0"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"104.13046178925408`", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"fdiff", "\[Rule]", "611"}], ",", 
     RowBox[{"fratio", "\[Rule]", "0.9696483472750007`"}]}], "}"}]}], 
  "}"}]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8540957320191784`*^9, 3.854096079842099*^9, 3.8541048781066885`*^9},
 CellLabel->
  "During evaluation of \
In[93]:=",ExpressionUUID->"64001018-d306-4d88-b08a-fd3ce1fc0b61"],

Cell[BoxData[
 StyleBox["\<\"Input data\"\>", "Subsection",
  StripOnInput->False]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8540957320191784`*^9, 3.854096079842099*^9, 3.8541048781066885`*^9},
 CellLabel->
  "During evaluation of \
In[93]:=",ExpressionUUID->"61d399e9-8f6c-44ab-ae14-e04f149f8f00"],

Cell[BoxData[
 GraphicsBox[{{}, {{{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJw9vHlcjN///z/2IoyEEAYh+6CIwgMhhFCEZFBJJe1NaZn2aZ99xj6olxBC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       "]]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJw9nXlczFvcxyNLSEISJYMihUII4WMPSUhCmNJetO+LqaaaaqppnZEwKKIk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       "]]}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6]}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6]}, {}, {}, {}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6]}, {}, {}, {}}}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 1573.}, {-0.019977757948504177`, 2.027639580231369}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8540957320191784`*^9, 3.854096079842099*^9, 3.8541048781672525`*^9},
 CellLabel->
  "During evaluation of \
In[93]:=",ExpressionUUID->"2c21c813-d630-40b8-ac4d-bd716b872b5b"],

Cell[BoxData[
 StyleBox["\<\"RMS difference vs displacement in data points\"\>", 
  "Subsection",
  StripOnInput->False]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8540957320191784`*^9, 3.854096079842099*^9, 3.8541048801870756`*^9},
 CellLabel->
  "During evaluation of \
In[93]:=",ExpressionUUID->"66d426c5-fcd3-4b98-a141-ce69426cf3a9"],

Cell[BoxData[
 GraphicsBox[{{}, {{{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJxE3HlcjN/7P/AQQsgeQggpSwghvFqFkApFSIqifd+b9mmffabFWwihSEJS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       "]]}}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.003666666666666667], 
     AbsoluteThickness[1.6]}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6]}, {}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 3147.}, {0, 1788.640174519158}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8540957320191784`*^9, 3.854096079842099*^9, 3.8541048802501745`*^9},
 CellLabel->
  "During evaluation of \
In[93]:=",ExpressionUUID->"37f9409f-c8d6-4a2b-83a7-5fff1f1a1815"],

Cell[BoxData[
 StyleBox["\<\"Expansion of RMS difference vs displacement in data points, \
with parabolic fit\"\>", "Subsection",
  StripOnInput->False]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8540957320191784`*^9, 3.854096079842099*^9, 3.8541048802680197`*^9},
 CellLabel->
  "During evaluation of \
In[93]:=",ExpressionUUID->"840304f7-0c6d-4512-a5a5-1ad1610188c8"],

Cell[BoxData[
 GraphicsBox[{{{{}, {}, 
     TagBox[
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJwV13k8lFsYB3Di0q2Uos06ZuYdI0KaZCl+XNcSWrTptTSIQkhUrsiSSpIk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        "]]},
      Annotation[#, "Charting`Private`Tag$2212909#1"]& ]}, {}}, {{}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
      0.012833333333333334`], AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJxTTMoPSmViYGAQBWIQDQEf7BN27eo5m5rgABVwqLu2rVNjRzyUz+Ggn66m
JLkpDsoXcNi1ilH4zp5YKF/EgYvD9EfInRgoX8Jhk+vNw7kiML6MQ8Ik75ot
GdFQvoLDBrYNN1TvREH5Sg4cn6e4GBbC+CoOLuc/W77RhPHVHEL70msiOWB8
DYfdrq/t5/PB+FoOVycam3HZw/g6Dg2brvufmw3j6znob3SYM0kNZr+Bw7Km
N3Lv7sP4hg5fbos/YDkOc6+RA/fTyXU5N2H+M3ZYUSnFliEMCw8TB41JM9eY
WMDCy9Sh2n561ZWvCQ4AxUdUhA==
       "]]}, {
      {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
       0.012833333333333334`], AbsoluteThickness[1.6]}, {}}, {
      {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
       0.012833333333333334`], AbsoluteThickness[1.6]}, {}}}, {{}, {}}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{Automatic, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{All, {0, 149.25040609831507`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8540957320191784`*^9, 3.854096079842099*^9, 3.854104880351265*^9},
 CellLabel->
  "During evaluation of \
In[93]:=",ExpressionUUID->"a5ec8a3d-c14d-4924-a245-9770bdaa61ee"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Interpolated frequency shift with best match is \"\>", 
   "\[InvisibleSpace]", "23.313928666720884`", 
   "\[InvisibleSpace]", "\<\" Hz\"\>"}],
  SequenceForm[
  "Interpolated frequency shift with best match is ", 23.313928666720884`, 
   " Hz"],
  Editable->False]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8540957320191784`*^9, 3.854096079842099*^9, 3.854104880366887*^9},
 CellLabel->
  "During evaluation of \
In[93]:=",ExpressionUUID->"d680ff51-8cbe-4750-9bbb-4cc1c8901424"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   StyleBox["\<\"Chemical shift = \"\>", "Subsection",
    StripOnInput->False], "\[InvisibleSpace]", 
   StyleBox["1.5179`", "Subsection",
    StripOnInput->False], "\[InvisibleSpace]", 
   StyleBox["\<\" ppm\"\>", "Subsection",
    StripOnInput->False]}],
  SequenceForm[
   Style["Chemical shift = ", "Subsection"], 
   Style[1.5179, "Subsection"], 
   Style[" ppm", "Subsection"]],
  Editable->False]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8540957320191784`*^9, 3.854096079842099*^9, 3.8541048808713365`*^9},
 CellLabel->
  "During evaluation of \
In[93]:=",ExpressionUUID->"6aa37a35-8bda-4480-8f9a-fdd19998875b"],

Cell[BoxData["\<\"Variance and optimised shift and ratio:\"\>"], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8540957320191784`*^9, 3.854096079842099*^9, 3.8541049186353035`*^9},
 CellLabel->
  "During evaluation of \
In[93]:=",ExpressionUUID->"8bd984ed-42ae-49f4-bb0f-a164ab4dd870"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"78.83336272743408`", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"fdiff", "\[Rule]", 
      RowBox[{"-", "25"}]}], ",", 
     RowBox[{"fratio", "\[Rule]", "0.8067072261096483`"}]}], "}"}]}], 
  "}"}]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8540957320191784`*^9, 3.854096079842099*^9, 3.8541049186453905`*^9},
 CellLabel->
  "During evaluation of \
In[93]:=",ExpressionUUID->"11603170-6192-4ea0-9f94-3d36bc29c840"],

Cell[BoxData[
 StyleBox["\<\"Input data\"\>", "Subsection",
  StripOnInput->False]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8540957320191784`*^9, 3.854096079842099*^9, 3.8541049186453905`*^9},
 CellLabel->
  "During evaluation of \
In[93]:=",ExpressionUUID->"53de81ee-eb5b-4c91-8499-fc965ce4ffe2"],

Cell[BoxData[
 GraphicsBox[{{}, {{{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJw1nHlcjN37xwsP2YskW0WWkghJyvLJklAkaVMa7bRN+15TTdM0bTNJssQg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       "]]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJw9nHlczN37/4e6CSEKkaUQCS2IrL0iSUIlbci07zWt2ptqpqaaqZlsiZS9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       "]]}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, {}, {}, {}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, {}, {}, {}}}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 1180.}, {-0.026102319831108074`, 1.9500880736239234`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8540957320191784`*^9, 3.854096079842099*^9, 3.8541049187158637`*^9},
 CellLabel->
  "During evaluation of \
In[93]:=",ExpressionUUID->"01535dd4-1c98-4abf-b0eb-62cff4193b10"],

Cell[BoxData[
 StyleBox["\<\"RMS difference vs displacement in data points\"\>", 
  "Subsection",
  StripOnInput->False]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8540957320191784`*^9, 3.854096079842099*^9, 3.8541049198571105`*^9},
 CellLabel->
  "During evaluation of \
In[93]:=",ExpressionUUID->"f22dc776-f031-4be5-8fbb-6018fec74e43"],

Cell[BoxData[
 GraphicsBox[{{}, {{{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJxE3HtcDV/3B/AkhBBCCEnIPQkhfCQkl5IQQipJpfv9errf63Q61emUhBDf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       "]]}}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6]}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, {}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 2361.}, {0, 888.2577700028617}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8540957320191784`*^9, 3.854096079842099*^9, 3.8541049199363656`*^9},
 CellLabel->
  "During evaluation of \
In[93]:=",ExpressionUUID->"1d862de9-5e53-4ec3-a4dd-516ea89969be"],

Cell[BoxData[
 StyleBox["\<\"Expansion of RMS difference vs displacement in data points, \
with parabolic fit\"\>", "Subsection",
  StripOnInput->False]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8540957320191784`*^9, 3.854096079842099*^9, 3.8541049199484854`*^9},
 CellLabel->
  "During evaluation of \
In[93]:=",ExpressionUUID->"0d8bd58b-6ab8-42c2-91a4-6a83df257148"],

Cell[BoxData[
 GraphicsBox[{{{{}, {}, 
     TagBox[
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJwV13k8VN8bB3BbUSTZS42ZuTN2hSahfnyir7QoukOWmi8iLUilnVaVVFIp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        "]]},
      Annotation[#, "Charting`Private`Tag$2283879#1"]& ]}, {}}, {{}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
      0.012833333333333334`], AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJxTTMoPSmViYGAQBWIQDQEf7K2W3TO7cCvSASrgkNNm/Lb9dgSUz+EQpaVZ
7vwyHMoXcFgypbWmmg3GF3GYEfNJj9EsDMqXcOAL4/JXrw6F8mUcbk3L43l2
MwTKV3Co2avbdiMMxldyuPdBVIvjezCUr+LgK9h7fMp+GF/NwZJp/oXQrTC+
hkPfu4kXJtyB8bUcTFwqKq5bwMzTcdBQaXPmOwvj6zmoHRS+3zEb5h4DB7YP
B0Lll8Hca+hwTU8mSPUdzD9GDs4GSw7YlsDCw9jBT26etbhFNJRv4sBuc+qN
tkUslG/q8H1Bf/OSwngHANUPUZY=
       "]]}, {
      {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
       0.012833333333333334`], AbsoluteThickness[1.6]}, {}}, {
      {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
       0.012833333333333334`], AbsoluteThickness[1.6]}, {}}}, {{}, {}}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{Automatic, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{All, {0, 138.35323274544595`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8540957320191784`*^9, 3.854096079842099*^9, 3.8541049199922867`*^9},
 CellLabel->
  "During evaluation of \
In[93]:=",ExpressionUUID->"8758c629-5ce3-424f-8ee8-3394664804c9"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Interpolated frequency shift with best match is \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"-", "0.9095530672557689`"}], "\[InvisibleSpace]", "\<\" Hz\"\>"}],
  SequenceForm[
  "Interpolated frequency shift with best match is ", -0.9095530672557689, 
   " Hz"],
  Editable->False]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8540957320191784`*^9, 3.854096079842099*^9, 3.854104920007849*^9},
 CellLabel->
  "During evaluation of \
In[93]:=",ExpressionUUID->"f0f15c00-9a44-4908-a000-651fe3fbfc9b"],

Cell[BoxData[
 StyleBox["\<\"Coupling constants\"\>", "Subsection",
  StripOnInput->False]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8540957320191784`*^9, 3.854096079842099*^9, 3.854104920007849*^9},
 CellLabel->
  "During evaluation of \
In[93]:=",ExpressionUUID->"1ee35dcc-bb02-4696-8aa4-558fd68045a4"]
}, Open  ]],

Cell[BoxData[
 TagBox[GridBox[{
    {"4.88438925403771`"},
    {"48.45373278853503`"},
    {"2.4417371106371983`"},
    {
     RowBox[{"-", "0.06520270328017923`"}]},
    {"23.313928666720884`"},
    {
     RowBox[{"-", "0.9095530672557689`"}]}
   },
   GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[2.0999999999999996`]}, 
       Offset[0.27999999999999997`]}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.8535790442807336`*^9, 3.8535794424007387`*^9, 
  3.854096010132328*^9, 3.854096370665448*^9, 3.854104920007849*^9},
 CellLabel->
  "Out[110]//TableForm=",ExpressionUUID->"7368533a-3bda-48b4-b625-\
0a4806ea877e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Time used = \"\>", "\[InvisibleSpace]", 
   "236.3720991`9.825141205459728", "\[InvisibleSpace]", "\<\"seconds\"\>"}],
  SequenceForm["Time used = ", 236.3720991`9.825141205459728, "seconds"],
  Editable->False]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.8540957320191784`*^9, 3.854096079842099*^9, 3.854104920023472*^9},
 CellLabel->
  "During evaluation of \
In[93]:=",ExpressionUUID->"9d4f192d-b8ad-4e20-b7f3-85986d1abd5a"]
}, Open  ]]
}, Open  ]]
},
WindowSize->{2544, 1357},
WindowMargins->{{-8, Automatic}, {Automatic, 0}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
FrontEndVersion->"12.0 for Microsoft Windows (64-bit) (April 8, 2019)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 538, 10, 69, "Subsubsection",ExpressionUUID->"e0dd5b4c-3a91-4051-9a25-a39ac98e766a"],
Cell[1121, 34, 1474, 30, 342, "Text",ExpressionUUID->"c61c22a2-f7f7-4bd3-b074-cb3183ff65e0"],
Cell[CellGroupData[{
Cell[2620, 68, 29455, 703, 1872, "Input",ExpressionUUID->"83ce1c8d-1a22-4fa3-84c9-6c6be868c2d5"],
Cell[CellGroupData[{
Cell[32100, 775, 702, 18, 29, "Print",ExpressionUUID->"b404ed81-c25f-4e4d-a8f7-25144d8c44a7"],
Cell[32805, 795, 315, 5, 22, "Print",ExpressionUUID->"c386d231-2bd8-41e7-a7fe-281cbac89a2a"],
Cell[33123, 802, 477, 12, 22, "Print",ExpressionUUID->"b08a29c2-85f0-449a-8720-a94c183491ee"],
Cell[33603, 816, 335, 7, 33, "Print",ExpressionUUID->"382dbe37-78f5-42b2-ae1c-75de84ad8d37"],
Cell[33941, 825, 13452, 239, 224, "Print",ExpressionUUID->"68645666-04d3-43c7-bc78-33b4295d5b9d"],
Cell[47396, 1066, 371, 8, 33, "Print",ExpressionUUID->"170a09c6-be99-4b53-8af9-607491e61525"],
Cell[47770, 1076, 12065, 215, 223, "Print",ExpressionUUID->"eebaeaec-3fd6-4dab-ac43-30a34578a1f7"],
Cell[59838, 1293, 405, 8, 33, "Print",ExpressionUUID->"5188248a-0492-4314-9386-0967426d514f"],
Cell[60246, 1303, 8399, 157, 247, "Print",ExpressionUUID->"81869e71-2802-48ec-a812-3aaac66f4e5c"],
Cell[68648, 1462, 557, 12, 22, "Print",ExpressionUUID->"0a52d0b1-6827-428c-a58e-482a8bc159f4"],
Cell[69208, 1476, 702, 18, 29, "Print",ExpressionUUID->"29482d15-69fd-405a-89ae-1e55f2b525f5"],
Cell[69913, 1496, 315, 5, 22, "Print",ExpressionUUID->"d6cdd17a-7716-4874-acf2-8dc96cb47b12"],
Cell[70231, 1503, 475, 12, 22, "Print",ExpressionUUID->"7acaae15-052f-48ff-9390-e8bbe802ce62"],
Cell[70709, 1517, 333, 7, 33, "Print",ExpressionUUID->"d438e00b-bd57-48b9-af18-ef201e6acacc"],
Cell[71045, 1526, 54630, 914, 232, "Print",ExpressionUUID->"7c8aeaa5-6376-497a-ac18-8b354568bdb5"],
Cell[125678, 2442, 373, 8, 33, "Print",ExpressionUUID->"ceeeea0d-4020-4f69-a7ed-8c6352e938d2"],
Cell[126054, 2452, 48284, 808, 225, "Print",ExpressionUUID->"00a3e70f-600b-4b15-b753-334ae6dacecc"],
Cell[174341, 3262, 403, 8, 33, "Print",ExpressionUUID->"fdd90309-d9a7-44e9-ae44-e4106eb2f3b7"],
Cell[174747, 3272, 8123, 153, 247, "Print",ExpressionUUID->"202c1fe5-53ca-4f48-94af-a413eaf2c96f"],
Cell[182873, 3427, 565, 13, 22, "Print",ExpressionUUID->"bf2a53f7-6e3f-4edb-97ec-2d6b17f872c0"],
Cell[183441, 3442, 702, 18, 29, "Print",ExpressionUUID->"6ae2c616-7ce3-4faf-b61c-d87f0605ca43"],
Cell[184146, 3462, 315, 5, 22, "Print",ExpressionUUID->"174ea0bb-428b-42c0-aef4-7956ed6f1912"],
Cell[184464, 3469, 474, 12, 22, "Print",ExpressionUUID->"8447fb96-ddaa-4c7f-ad4b-7dd974e1e4d6"],
Cell[184941, 3483, 335, 7, 33, "Print",ExpressionUUID->"32cc1ef9-4f67-43f8-9fd8-f62b44420da4"],
Cell[185279, 3492, 24081, 412, 224, "Print",ExpressionUUID->"f26b2e54-c915-4f3a-bb8d-7be5652a014e"],
Cell[209363, 3906, 373, 8, 33, "Print",ExpressionUUID->"db0e837e-c842-4624-8813-9437a83c44c0"],
Cell[209739, 3916, 22612, 388, 233, "Print",ExpressionUUID->"cc8331e6-4e85-40a3-84be-6b3bd886ff22"],
Cell[232354, 4306, 403, 8, 33, "Print",ExpressionUUID->"81ab6295-0d13-4b90-984f-cddf153faaa4"],
Cell[232760, 4316, 8210, 154, 250, "Print",ExpressionUUID->"50c0fd92-cca5-48d8-8657-69afd309505c"],
Cell[240973, 4472, 566, 13, 22, "Print",ExpressionUUID->"9b7f43c5-099f-4f88-a5e1-6ef7ca3cc565"],
Cell[241542, 4487, 702, 18, 29, "Print",ExpressionUUID->"0945a039-8474-4bb0-9bac-c5fad6d0db53"],
Cell[242247, 4507, 313, 5, 22, "Print",ExpressionUUID->"66376e34-c8cc-43b0-a54f-2fbff601f0dd"],
Cell[242563, 4514, 477, 12, 22, "Print",ExpressionUUID->"a70ea2be-8f1b-43c5-9cee-d8399f22742d"],
Cell[243043, 4528, 333, 7, 33, "Print",ExpressionUUID->"8b983bca-5f44-4feb-960a-6e90fb130e47"],
Cell[243379, 4537, 24306, 417, 230, "Print",ExpressionUUID->"1c019019-00e5-4721-ba0b-55e2ce7e0cb6"],
Cell[267688, 4956, 371, 8, 33, "Print",ExpressionUUID->"c70ec75d-4d71-44fb-9fbc-91b866effdee"],
Cell[268062, 4966, 22853, 392, 230, "Print",ExpressionUUID->"7b72d915-25a4-4105-9c69-3cedd088484c"],
Cell[290918, 5360, 403, 8, 33, "Print",ExpressionUUID->"dde93737-bb24-452e-972e-1723c219bb19"],
Cell[291324, 5370, 8174, 154, 247, "Print",ExpressionUUID->"2e9a2100-bbe2-4def-8183-7e7a4e565422"],
Cell[299501, 5526, 583, 13, 22, "Print",ExpressionUUID->"d446511c-28ec-4275-93da-52feb9d8fc6a"],
Cell[300087, 5541, 702, 18, 29, "Print",ExpressionUUID->"a16c1fe8-5f20-49ad-865c-b54a42732f8b"],
Cell[300792, 5561, 313, 5, 22, "Print",ExpressionUUID->"1a485463-a7d9-4579-89d4-4530d28d46f0"],
Cell[301108, 5568, 477, 12, 22, "Print",ExpressionUUID->"64001018-d306-4d88-b08a-fd3ce1fc0b61"],
Cell[301588, 5582, 335, 7, 33, "Print",ExpressionUUID->"61d399e9-8f6c-44ab-ae14-e04f149f8f00"],
Cell[301926, 5591, 45879, 770, 228, "Print",ExpressionUUID->"2c21c813-d630-40b8-ac4d-bd716b872b5b"],
Cell[347808, 6363, 373, 8, 33, "Print",ExpressionUUID->"66d426c5-fcd3-4b98-a141-ce69426cf3a9"],
Cell[348184, 6373, 42260, 710, 230, "Print",ExpressionUUID->"37f9409f-c8d6-4a2b-83a7-5fff1f1a1815"],
Cell[390447, 7085, 405, 8, 33, "Print",ExpressionUUID->"840304f7-0c6d-4512-a5a5-1ad1610188c8"],
Cell[390855, 7095, 7972, 150, 247, "Print",ExpressionUUID->"a5ec8a3d-c14d-4924-a245-9770bdaa61ee"],
Cell[398830, 7247, 566, 13, 22, "Print",ExpressionUUID->"d680ff51-8cbe-4750-9bbb-4cc1c8901424"],
Cell[399399, 7262, 702, 18, 29, "Print",ExpressionUUID->"6aa37a35-8bda-4480-8f9a-fdd19998875b"],
Cell[400104, 7282, 315, 5, 22, "Print",ExpressionUUID->"8bd984ed-42ae-49f4-bb0f-a164ab4dd870"],
Cell[400422, 7289, 497, 13, 22, "Print",ExpressionUUID->"11603170-6192-4ea0-9f94-3d36bc29c840"],
Cell[400922, 7304, 335, 7, 33, "Print",ExpressionUUID->"53de81ee-eb5b-4c91-8499-fc965ce4ffe2"],
Cell[401260, 7313, 35047, 592, 221, "Print",ExpressionUUID->"01535dd4-1c98-4abf-b0eb-62cff4193b10"],
Cell[436310, 7907, 373, 8, 33, "Print",ExpressionUUID->"f22dc776-f031-4be5-8fbb-6018fec74e43"],
Cell[436686, 7917, 33008, 558, 234, "Print",ExpressionUUID->"1d862de9-5e53-4ec3-a4dd-516ea89969be"],
Cell[469697, 8477, 405, 8, 33, "Print",ExpressionUUID->"0d8bd58b-6ab8-42c2-91a4-6a83df257148"],
Cell[470105, 8487, 8019, 151, 247, "Print",ExpressionUUID->"8758c629-5ce3-424f-8ee8-3394664804c9"],
Cell[478127, 8640, 581, 13, 22, "Print",ExpressionUUID->"f0f15c00-9a44-4908-a000-651fe3fbfc9b"],
Cell[478711, 8655, 341, 7, 33, "Print",ExpressionUUID->"1ee35dcc-bb02-4696-8aa4-558fd68045a4"]
}, Open  ]],
Cell[479067, 8665, 848, 25, 130, "Output",ExpressionUUID->"7368533a-3bda-48b4-b625-0a4806ea877e"],
Cell[479918, 8692, 511, 10, 22, "Print",ExpressionUUID->"9d4f192d-b8ad-4e20-b7f3-85986d1abd5a"]
}, Open  ]]
}, Open  ]]
}
]
*)

