(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 11.2' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    488630,       8847]
NotebookOptionsPosition[    481846,       8761]
NotebookOutlinePosition[    482246,       8778]
CellTagsIndexPosition[    482203,       8775]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["\<\
Determination of the signs and magnitudes of all heteronuclear coupling using \
IPAP-MODO-FESTA data.
Automatically determine optimum ratio when combining IP and AP data, \
adjusting ratio and number of points to shift until rms difference is minimum\
\>", "Subsubsection",
 CellChangeTimes->{{3.835342719267295*^9, 3.8353427673607473`*^9}, {
   3.835342957217922*^9, 3.8353429845994587`*^9}, {3.853579885840021*^9, 
   3.853579910287277*^9}, 
   3.8535799927992496`*^9},ExpressionUUID->"e0dd5b4c-3a91-4051-9a25-\
a39ac98e766a"],

Cell["\<\
Automatically determines the optimum ratio when combining the IP and AP data, \
adjusts the ratio and numbers of points required to shift until the RMS \
difference is at its minimum.
Information required:
shifts={chemical shift in ppm}; (each chemical shift to be separated by a \
comma)
widths={width of multiplet in ppm}; (each width to be separated by a comma)
nreps=1; (number of repetitions of that data - typically 1)
filestart=12; (EXPNO in file)
filenamebase=\[CloseCurlyDoubleQuote]data/folder/nmr/filename/\
\[CloseCurlyDoubleQuote]; (filepath of data)
procnoIP=\[CloseCurlyDoubleQuote]1001\[CloseCurlyDoubleQuote];  (PROCNO of IP \
data)
procnoAP=\[CloseCurlyDoubleQuote]1002\[CloseCurlyDoubleQuote]; (PROCNO of AP \
data - ensure IP and AP are processed with identical parameters)
Sample details:
Fluorohydrin in D2O
1H @ 4.6005 ppm; 150Hz
19F @ -200.753 ppm; 1000Hz
J=48.7 HZ
1.70 ppm excluded due to overlapping multiplets - notebook cannot distinguish \
between them: manually calculated to be 32.6 Hz and 1.73 Hz.
cannot calculate 1.4 ppm.\
\>", "Text",
 CellChangeTimes->{{3.835344344114542*^9, 3.835344495255948*^9}, {
   3.835345752399667*^9, 3.83534578817225*^9}, {3.835416894520056*^9, 
   3.8354170090033817`*^9}, {3.8535743479833965`*^9, 
   3.8535743941759214`*^9}, {3.8535744245888777`*^9, 3.853574427182979*^9}, {
   3.8535799150722027`*^9, 3.8535802318062067`*^9}, {3.853587164123898*^9, 
   3.853587177771508*^9}, {3.8535875400501995`*^9, 3.8535875426377263`*^9}, 
   3.8535875757398615`*^9, {3.8541052226155715`*^9, 3.8541052616540804`*^9}, {
   3.8541053109578876`*^9, 
   3.854105315842641*^9}},ExpressionUUID->"c61c22a2-f7f7-4bd3-b074-\
cb3183ff65e0"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{"Evaluate", "[", 
    RowBox[{
     RowBox[{"Context", "[", "]"}], " ", "<>", " ", "\"\<*\>\""}], "]"}], 
   "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"vardiff", "[", 
     RowBox[{"tspip_", ",", "tspap_", ",", 
      RowBox[{"ratio_", "?", "NumericQ"}], ",", 
      RowBox[{"diff_", "?", "NumericQ"}]}], "]"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"zspm", ",", "len"}], "}"}], ",", 
      RowBox[{
       RowBox[{"len", "=", 
        RowBox[{"Length", "[", "tspip", "]"}]}], ";", " ", 
       "\[IndentingNewLine]", 
       RowBox[{"zspm", "=", 
        RowBox[{"Join", "[", 
         RowBox[{
          RowBox[{"Table", "[", 
           RowBox[{"0", ",", 
            RowBox[{"{", 
             RowBox[{"i", ",", "len"}], "}"}]}], "]"}], ",", 
          RowBox[{"Join", "[", 
           RowBox[{
            RowBox[{"tspip", "-", 
             RowBox[{"ratio", " ", "tspap"}]}], ",", 
            RowBox[{"Table", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", 
               RowBox[{"i", ",", "len"}], "}"}]}], "]"}]}], "]"}]}], "]"}]}], 
       ";", "\[IndentingNewLine]", 
       RowBox[{"Total", "[", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"tspip", "+", 
           RowBox[{"ratio", " ", "tspap"}], "-", 
           RowBox[{"Take", "[", 
            RowBox[{
             RowBox[{"RotateRight", "[", 
              RowBox[{"zspm", ",", "diff"}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"len", "+", "1"}], ",", 
               RowBox[{"2", " ", "len"}]}], "}"}]}], "]"}]}], ")"}], "^", 
         "2"}], "]"}]}]}], "\[IndentingNewLine]", "]"}]}], ";"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{
   "Calculate", " ", "variance", " ", "between", " ", "shifted", " ", 
    "spectra", " ", "obtained", " ", "by", " ", "IPAP", " ", "processing"}], 
   " ", "*)"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"getpars", "[", 
    RowBox[{"filenamebase_", ",", "procno_"}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "filename", "}"}], ",", 
     RowBox[{
      RowBox[{"filename", "=", 
       RowBox[{
       "filenamebase", "<>", "\"\</pdata/\>\"", "<>", "procno", "<>", 
        "\"\</procs\>\""}]}], ";", " ", "\[IndentingNewLine]", 
      RowBox[{"stream", "=", 
       RowBox[{"OpenRead", "[", "filename", "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"offset", "=", 
       RowBox[{
        RowBox[{"Read", "[", 
         RowBox[{
          RowBox[{"StringToStream", "[", 
           RowBox[{"Find", "[", 
            RowBox[{"stream", ",", "\"\<OFFSET= \>\""}], "]"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"Word", ",", "Number"}], "}"}]}], "]"}], "[", 
        RowBox[{"[", "2", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"si", "=", 
       RowBox[{
        RowBox[{"Read", "[", 
         RowBox[{
          RowBox[{"StringToStream", "[", 
           RowBox[{"Find", "[", 
            RowBox[{"stream", ",", "\"\<SI= \>\""}], "]"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"Word", ",", "Number"}], "}"}]}], "]"}], "[", 
        RowBox[{"[", "2", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"Close", "[", "stream", "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"filename", "=", 
       RowBox[{"filenamebase", "<>", "\"\</acqus\>\""}]}], ";", " ", 
      "\[IndentingNewLine]", 
      RowBox[{"stream", "=", 
       RowBox[{"OpenRead", "[", "filename", "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"sfo1", "=", 
       RowBox[{
        RowBox[{"Read", "[", 
         RowBox[{
          RowBox[{"StringToStream", "[", 
           RowBox[{"Find", "[", 
            RowBox[{"stream", ",", "\"\<SFO1= \>\""}], "]"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"Word", ",", "Number"}], "}"}]}], "]"}], "[", 
        RowBox[{"[", "2", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"swp", "=", 
       RowBox[{
        RowBox[{"Read", "[", 
         RowBox[{
          RowBox[{"StringToStream", "[", 
           RowBox[{"Find", "[", 
            RowBox[{"stream", ",", "\"\<SW= \>\""}], "]"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"Word", ",", "Number"}], "}"}]}], "]"}], "[", 
        RowBox[{"[", "2", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"Close", "[", "stream", "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"offset", ",", "si", ",", "sfo1", ",", "swp"}], "}"}]}]}], 
    "\[IndentingNewLine]", "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"process", "[", 
     RowBox[{
     "filenamebaseIP_", ",", "filenamebaseAP_", ",", "shift_", ",", "width_", 
      ",", "swp_", ",", "offset_", ",", "si_", ",", "sfo1_"}], "]"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "diff", ",", "dip", ",", "start", ",", "end", ",", "hzpp", ",", 
        "ncproc", ",", "spip", ",", "spap"}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"filename", "=", 
        RowBox[{"filenamebaseIP", "<>", "\"\</procs\>\""}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"stream", "=", 
        RowBox[{"OpenRead", "[", "filename", "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"ncproc", "=", 
        RowBox[{
         RowBox[{"Read", "[", 
          RowBox[{
           RowBox[{"StringToStream", "[", 
            RowBox[{"Find", "[", 
             RowBox[{"stream", ",", "\"\<NC_proc= \>\""}], "]"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"Word", ",", "Number"}], "}"}]}], "]"}], "[", 
         RowBox[{"[", "2", "]"}], "]"}]}], ";", " ", 
       RowBox[{"(*", " ", 
        RowBox[{
        "Need", " ", "to", " ", "correct", " ", "for", " ", "any", " ", 
         "difference", " ", "in", " ", "scaling", " ", "during", " ", "FT", 
         " ", 
         RowBox[{"etc", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
       RowBox[{"Close", "[", "stream", "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{"filename", "=", 
        RowBox[{"filenamebaseIP", "<>", "\"\</1r\>\""}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"spip", "=", 
        RowBox[{
         RowBox[{"2.", "^", "ncproc"}], " ", 
         RowBox[{
          RowBox[{"Import", "[", 
           RowBox[{"filename", ",", "\"\<Integer32\>\""}], "]"}], "/", 
          RowBox[{"10", "^", "6"}]}]}]}], ";", " ", "\[IndentingNewLine]", 
       "\[IndentingNewLine]", 
       RowBox[{"filename", "=", 
        RowBox[{"filenamebaseAP", "<>", "\"\</procs\>\""}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"stream", "=", 
        RowBox[{"OpenRead", "[", "filename", "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"ncproc", "=", 
        RowBox[{
         RowBox[{"Read", "[", 
          RowBox[{
           RowBox[{"StringToStream", "[", 
            RowBox[{"Find", "[", 
             RowBox[{"stream", ",", "\"\<NC_proc= \>\""}], "]"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"Word", ",", "Number"}], "}"}]}], "]"}], "[", 
         RowBox[{"[", "2", "]"}], "]"}]}], ";", " ", 
       RowBox[{"(*", " ", 
        RowBox[{
        "Need", " ", "to", " ", "correct", " ", "for", " ", "any", " ", 
         "difference", " ", "in", " ", "scaling", " ", "during", " ", "FT", 
         " ", 
         RowBox[{"etc", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
       RowBox[{"Close", "[", "stream", "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{"filename", "=", 
        RowBox[{"filenamebaseAP", "<>", "\"\</1r\>\""}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"spap", "=", 
        RowBox[{
         RowBox[{"2.", "^", "ncproc"}], " ", 
         RowBox[{
          RowBox[{"Import", "[", 
           RowBox[{"filename", ",", "\"\<Integer32\>\""}], "]"}], "/", 
          RowBox[{"10", "^", "6"}]}]}]}], ";", " ", "\[IndentingNewLine]", 
       "\[IndentingNewLine]", 
       RowBox[{"hzpp", "=", 
        RowBox[{"swp", " ", 
         RowBox[{"sfo1", "/", 
          RowBox[{"(", 
           RowBox[{"si", "-", "1"}], ")"}]}]}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"start", "=", 
        RowBox[{"Round", "[", 
         RowBox[{"sfo1", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"offset", "-", "shift", "-", 
             RowBox[{"width", "/", "2"}]}], ")"}], "/", "hzpp"}]}], "]"}]}], 
       ";", "\[IndentingNewLine]", 
       RowBox[{"end", "=", 
        RowBox[{"Round", "[", 
         RowBox[{"sfo1", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"offset", "-", "shift", "+", 
             RowBox[{"width", "/", "2"}]}], ")"}], "/", "hzpp"}]}], " ", 
         "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"tspip", "=", 
        RowBox[{"Take", "[", 
         RowBox[{"spip", ",", 
          RowBox[{"{", 
           RowBox[{"start", ",", "end"}], "}"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"len", "=", 
        RowBox[{"Length", "[", "tspip", "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"tspap", "=", 
        RowBox[{"Take", "[", 
         RowBox[{"spap", ",", 
          RowBox[{"{", 
           RowBox[{"start", ",", "end"}], "}"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"Print", "[", 
        RowBox[{
         RowBox[{"Style", "[", 
          RowBox[{"\"\<Chemical shift = \>\"", ",", "\"\<Subsection\>\""}], 
          "]"}], ",", 
         RowBox[{"Style", "[", 
          RowBox[{"shift", ",", "\"\<Subsection\>\""}], "]"}], ",", 
         RowBox[{"Style", "[", 
          RowBox[{"\"\< ppm\>\"", ",", "\"\<Subsection\>\""}], "]"}]}], "]"}],
        ";", "\[IndentingNewLine]", 
       RowBox[{"(*", " ", 
        RowBox[{
         RowBox[{
         "Do", " ", "optimistion", " ", "in", " ", "two", " ", "stages"}], 
         ",", " ", 
         RowBox[{
         "otherwise", " ", "fails", " ", "to", " ", "find", " ", "global", 
          " ", "minimum"}]}], " ", "*)"}], "\[IndentingNewLine]", 
       RowBox[{"res1", "=", 
        RowBox[{"NMinimize", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"vardiff", "[", 
             RowBox[{"tspip", ",", "tspap", ",", "fratio", ",", 
              RowBox[{"5", " ", "fdiff"}]}], "]"}], ",", 
            RowBox[{"fdiff", ">", 
             RowBox[{
              RowBox[{"-", "len"}], "/", "5"}]}], ",", 
            RowBox[{"fdiff", "<", 
             RowBox[{"len", "/", "5"}]}], ",", 
            RowBox[{"fratio", ">", "0.8"}], ",", 
            RowBox[{"fratio", "<", "1.2"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"fdiff", "\[Element]", " ", "Integers"}], ",", "fratio"}],
            "}"}], ",", 
          RowBox[{"MaxIterations", "\[Rule]", "100"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"res2", "=", 
        RowBox[{"NMinimize", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"vardiff", "[", 
             RowBox[{
             "tspip", ",", "tspap", ",", "fratio", ",", " ", "fdiff"}], "]"}],
             ",", 
            RowBox[{"fratio", ">", "0.8"}], ",", 
            RowBox[{"fratio", "<", "1.2"}], ",", 
            RowBox[{"fdiff", ">", 
             RowBox[{
              RowBox[{"Round", "[", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"5", " ", "fdiff"}], "/.", 
                 RowBox[{"res1", "[", 
                  RowBox[{"[", "2", "]"}], "]"}]}], ")"}], "]"}], "-", 
              RowBox[{"len", "/", "10"}]}]}], ",", 
            RowBox[{"fdiff", "<", 
             RowBox[{"Round", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"len", "/", "10"}], "+", 
                RowBox[{"5", " ", "fdiff"}]}], "/.", 
               RowBox[{"res1", "[", 
                RowBox[{"[", "2", "]"}], "]"}]}], "]"}]}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"fdiff", "\[Element]", " ", "Integers"}], ",", "fratio"}],
            "}"}], ",", 
          RowBox[{"MaxIterations", "\[Rule]", "1000"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{
       "Print", "[", "\"\<Variance and optimised shift and ratio:\>\"", "]"}],
        ";", "\[IndentingNewLine]", 
       RowBox[{"Print", "[", "res2", "]"}], ";", " ", "\[IndentingNewLine]", 
       RowBox[{"ratio", "=", 
        RowBox[{"fratio", "/.", 
         RowBox[{"res2", "[", 
          RowBox[{"[", "2", "]"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"spp", "=", 
        RowBox[{"tspip", "+", 
         RowBox[{"ratio", " ", "tspap"}]}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"spm", "=", 
        RowBox[{"tspip", "-", 
         RowBox[{"ratio", " ", "tspap"}]}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"Print", "[", 
        RowBox[{"Style", "[", 
         RowBox[{"\"\<Input data\>\"", ",", "\"\<Subsection\>\""}], "]"}], 
        "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{"Print", "[", 
        RowBox[{"ListPlot", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"spp", ",", "spm"}], "}"}], ",", 
          RowBox[{"Joined", "\[Rule]", "True"}], ",", 
          RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"len", "=", 
        RowBox[{"Length", "[", "spp", "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"zspm", "=", 
        RowBox[{"Join", "[", 
         RowBox[{
          RowBox[{"Table", "[", 
           RowBox[{"0", ",", 
            RowBox[{"{", 
             RowBox[{"i", ",", "len"}], "}"}]}], "]"}], ",", 
          RowBox[{"Join", "[", 
           RowBox[{"spm", ",", 
            RowBox[{"Table", "[", 
             RowBox[{"0", ",", 
              RowBox[{"{", 
               RowBox[{"i", ",", "len"}], "}"}]}], "]"}]}], "]"}]}], "]"}]}], 
       ";", "\[IndentingNewLine]", 
       RowBox[{"diff", "=", 
        RowBox[{"Table", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", 
            RowBox[{
             RowBox[{"2", " ", "len"}], "+", "1"}]}], "}"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"For", "[", 
        RowBox[{
         RowBox[{"i", "=", "1"}], ",", 
         RowBox[{"i", "\[LessEqual]", 
          RowBox[{"Length", "[", "diff", "]"}]}], ",", 
         RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{
           RowBox[{"diff", "[", 
            RowBox[{"[", "i", "]"}], "]"}], "=", 
           RowBox[{"Total", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"spp", "-", 
               RowBox[{"Take", "[", 
                RowBox[{
                 RowBox[{"RotateRight", "[", 
                  RowBox[{"zspm", ",", 
                   RowBox[{"len", "-", "i"}]}], "]"}], ",", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"len", "+", "1"}], ",", 
                   RowBox[{"2", " ", "len"}]}], "}"}]}], "]"}]}], ")"}], "^", 
             "2"}], "]"}]}], ";"}]}], "\[IndentingNewLine]", "]"}], ";", "\n", 
       RowBox[{"Print", "[", 
        RowBox[{"Style", "[", 
         RowBox[{
         "\"\<RMS difference vs displacement in data points\>\"", ",", 
          "\"\<Subsection\>\""}], "]"}], "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{"Print", "[", 
        RowBox[{"ListPlot", "[", 
         RowBox[{"diff", ",", 
          RowBox[{"Joined", "\[Rule]", "True"}], ",", 
          RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"min", "=", 
        RowBox[{"Min", "[", "diff", "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"For", "[", 
        RowBox[{
         RowBox[{"i", "=", "1"}], ",", 
         RowBox[{"i", "\[LessEqual]", 
          RowBox[{"Length", "[", "diff", "]"}]}], ",", 
         RowBox[{"i", "++"}], ",", " ", 
         RowBox[{
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"diff", "[", 
              RowBox[{"[", "i", "]"}], "]"}], "\[Equal]", "min"}], ",", 
            RowBox[{"minpoint", "=", "i"}]}], "]"}], ";"}]}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"Print", "[", 
        RowBox[{"Style", "[", 
         RowBox[{
         "\"\<Expansion of RMS difference vs displacement in data points, \
with parabolic fit\>\"", ",", "\"\<Subsection\>\""}], "]"}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"dip", "=", 
        RowBox[{"Take", "[", 
         RowBox[{"diff", ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"minpoint", "-", "10"}], ",", 
            RowBox[{"minpoint", "+", "10"}]}], "}"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"dipfit", "=", 
        RowBox[{"NonlinearModelFit", "[", 
         RowBox[{"dip", ",", 
          RowBox[{"a", "+", 
           RowBox[{"b", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"x", "-", "x0"}], ")"}], "^", "2"}]}]}], ",", 
          RowBox[{"{", 
           RowBox[{"a", ",", "b", ",", "x0"}], "}"}], ",", "x"}], "]"}]}], 
       ";", "\[IndentingNewLine]", 
       RowBox[{"Print", "[", 
        RowBox[{"Show", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Plot", "[", 
            RowBox[{
             RowBox[{"dipfit", "[", "x", "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"x", ",", "1", ",", 
               RowBox[{"Length", "[", "dip", "]"}]}], "}"}], ",", 
             RowBox[{"PlotRange", "\[Rule]", 
              RowBox[{"{", 
               RowBox[{"All", ",", 
                RowBox[{"{", 
                 RowBox[{"0", ",", 
                  RowBox[{"1.1", " ", 
                   RowBox[{"Max", "[", "dip", "]"}]}]}], "}"}]}], "}"}]}]}], 
            "]"}], ",", 
           RowBox[{"ListPlot", "[", 
            RowBox[{"dip", ",", 
             RowBox[{"Joined", "\[Rule]", "False"}], ",", 
             RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]}], "}"}], "]"}],
         "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{"Print", "[", 
        RowBox[{
        "\"\<Interpolated frequency shift with best match is \>\"", ",", 
         RowBox[{
          RowBox[{"-", "hzpp"}], 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"x0", "/.", 
              RowBox[{"dipfit", "[", "\"\<BestFitParameters\>\"", "]"}]}], 
             ")"}], "+", "minpoint", "-", "11", "-", "len"}], ")"}]}], ",", 
         " ", "\"\< Hz\>\""}], "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"-", "hzpp"}], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"x0", "/.", 
            RowBox[{"dipfit", "[", "\"\<BestFitParameters\>\"", "]"}]}], 
           ")"}], "+", "minpoint", "-", "11", "-", "len"}], ")"}]}]}]}], 
     "\[IndentingNewLine]", "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"shifts", "=", 
   RowBox[{"{", 
    RowBox[{
    "4.8919", ",", "4.5999", ",", "3.86557", ",", "3.55438", ",", "2.01032", 
     ",", "1.465"}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"widths", "=", 
   RowBox[{"{", 
    RowBox[{
    "0.04", ",", "0.14", ",", "0.06", ",", "0.06", ",", "0.10", ",", "0.10"}],
     "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"njs", "=", 
   RowBox[{"Length", "[", "shifts", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nreps", "=", "1"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"filestart", "=", "9"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"js", "=", 
   RowBox[{"Table", "[", 
    RowBox[{"0", ",", "njs", ",", "nreps"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
  "filenamebase", "=", 
   "\"\<V:/dropbox/Coral/_Projects/_Publications/IPAP FESTA/Fluorohydrin \
data/data/GDP_fluoridrinaD2O_thais/nmr/\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"procnoIP", "=", "\"\<1001\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"procnoAP", "=", "\"\<1002\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"getpars", "[", 
   RowBox[{
    RowBox[{"filenamebase", "<>", 
     RowBox[{"ToString", "[", "filestart", "]"}]}], ",", "procnoIP"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"starttime", "=", 
   RowBox[{"AbsoluteTime", "[", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"For", "[", 
   RowBox[{
    RowBox[{"jnumber", "=", "1"}], ",", 
    RowBox[{"jnumber", "\[LessEqual]", 
     RowBox[{"Length", "[", "shifts", "]"}]}], ",", 
    RowBox[{"jnumber", "++"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"For", "[", 
      RowBox[{
       RowBox[{"rep", "=", "1"}], ",", 
       RowBox[{"rep", "\[LessEqual]", "nreps"}], ",", 
       RowBox[{"rep", "++"}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"filename", "=", 
         RowBox[{"filenamebase", "<>", 
          RowBox[{"ToString", "[", 
           RowBox[{"filestart", "+", "rep", "-", "1"}], "]"}], "<>", 
          "\"\</pdata/\>\""}]}], ";", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"js", "[", 
          RowBox[{"[", 
           RowBox[{"jnumber", ",", "rep"}], "]"}], "]"}], "=", 
         RowBox[{"process", "[", 
          RowBox[{
           RowBox[{"filename", "<>", "procnoIP"}], ",", 
           RowBox[{"filename", "<>", "procnoAP"}], ",", 
           RowBox[{"shifts", "[", 
            RowBox[{"[", "jnumber", "]"}], "]"}], ",", 
           RowBox[{"widths", "[", 
            RowBox[{"[", "jnumber", "]"}], "]"}], ",", "swp", ",", "offset", 
           ",", "si", ",", "sfo1"}], "]"}]}], ";"}]}], "\[IndentingNewLine]", 
      "]"}], ";"}]}], "\[IndentingNewLine]", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{"Style", "[", 
    RowBox[{"\"\<Coupling constants\>\"", ",", "\"\<Subsection\>\""}], "]"}], 
   "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"TableForm", "[", "js", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"jslb1", "=", "js"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"timeused", "=", 
   RowBox[{
    RowBox[{"AbsoluteTime", "[", "]"}], "-", "starttime"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{"\"\<Time used = \>\"", ",", "timeused", ",", "\"\<seconds\>\""}], 
   "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"meansdandsdmean", "[", "x_", "]"}], ":=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Mean", "[", "x", "]"}], ",", 
     RowBox[{"Sqrt", "[", 
      RowBox[{
       RowBox[{"Variance", "[", "x", "]"}], "/", 
       RowBox[{"(", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Length", "[", "x", "]"}], "-", "1"}], ")"}], ")"}]}], 
      "]"}], ",", 
     RowBox[{"Sqrt", "[", 
      RowBox[{
       RowBox[{"Variance", "[", "x", "]"}], "/", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Length", "[", "x", "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Length", "[", "x", "]"}], "-", "1"}], ")"}]}], ")"}]}], 
      "]"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{"nreps", ">", "1"}], ",", 
    RowBox[{
     RowBox[{"reslb1", "=", 
      RowBox[{"Table", "[", 
       RowBox[{"0", ",", 
        RowBox[{"Length", "[", "shifts", "]"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"reslb1", "=", 
      RowBox[{"Prepend", "[", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"Flatten", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"shifts", "[", 
              RowBox[{"[", "i", "]"}], "]"}], ",", 
             RowBox[{"meansdandsdmean", "[", 
              RowBox[{"jslb1", "[", 
               RowBox[{"[", "i", "]"}], "]"}], "]"}]}], "}"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", 
            RowBox[{"Length", "[", "shifts", "]"}]}], "}"}]}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{
         "\"\<Shift / ppm\>\"", ",", "\"\<JHF / Hz\>\"", ",", 
          "\"\<std dev / Hz\>\"", ",", "\"\<sd of mean of J / Hz\>\""}], 
         "}"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"Print", "[", 
      RowBox[{"TableForm", "[", "reslb1", "]"}], "]"}], ";"}]}], "]"}], 
  "\[IndentingNewLine]", 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.833448292510956*^9, 3.833448473320225*^9}, {
   3.833448567630739*^9, 3.833448597926832*^9}, {3.833448726706624*^9, 
   3.8334488386106873`*^9}, {3.833448894130322*^9, 3.83344899381962*^9}, {
   3.8334490263559*^9, 3.833449034371501*^9}, {3.833449208176523*^9, 
   3.83344924369489*^9}, {3.8334515420085583`*^9, 3.833451676813837*^9}, {
   3.8335325651614*^9, 3.833532637209276*^9}, {3.833532759034121*^9, 
   3.8335330239765873`*^9}, {3.8335330927635307`*^9, 
   3.8335331455943604`*^9}, {3.833533397697961*^9, 3.8335334255106373`*^9}, {
   3.8335334594455547`*^9, 3.833533507765386*^9}, {3.833533539339788*^9, 
   3.833533659575992*^9}, {3.833533697198904*^9, 3.8335337340891523`*^9}, {
   3.833533780205265*^9, 3.833533893496993*^9}, 3.833533985781467*^9, {
   3.8335340192182083`*^9, 3.833534070521394*^9}, {3.833534125296022*^9, 
   3.833534125914562*^9}, 3.833534226165428*^9, {3.833534380477125*^9, 
   3.833534380818433*^9}, {3.8335344656134453`*^9, 3.833534519575261*^9}, {
   3.8335346317293777`*^9, 3.83353463272573*^9}, 3.8335347268726482`*^9, {
   3.8335347781741343`*^9, 3.83353485994346*^9}, {3.833534904539554*^9, 
   3.83353494839614*^9}, {3.833534999551011*^9, 3.833534999698493*^9}, {
   3.833535037301165*^9, 3.833535103927022*^9}, {3.8335351368517733`*^9, 
   3.833535139414091*^9}, {3.8335352378369083`*^9, 3.833535337311174*^9}, {
   3.833535394550235*^9, 3.833535454170685*^9}, {3.8335361679797087`*^9, 
   3.8335362375090513`*^9}, {3.833536274111115*^9, 3.833536278469448*^9}, 
   3.833536449477241*^9, {3.8335364826240788`*^9, 3.8335365448917313`*^9}, {
   3.833538035225528*^9, 3.833538077529106*^9}, {3.8337034631307096`*^9, 
   3.833703463865309*^9}, {3.833703506926898*^9, 3.833703553753542*^9}, {
   3.833703617125688*^9, 3.833703688345792*^9}, {3.833703718670663*^9, 
   3.8337037764894876`*^9}, {3.8337038223632317`*^9, 
   3.8337039123907833`*^9}, {3.83370394998801*^9, 3.833704007351994*^9}, {
   3.833704056375489*^9, 3.833704136756112*^9}, {3.833704176289364*^9, 
   3.833704289758876*^9}, {3.833704391066206*^9, 3.833704429891245*^9}, {
   3.833704972721045*^9, 3.8337049956209497`*^9}, {3.8337050367076*^9, 
   3.833705038457287*^9}, {3.8337053194184847`*^9, 3.833705411458173*^9}, {
   3.8337070792528667`*^9, 3.833707127605337*^9}, {3.835337695095479*^9, 
   3.835337749538929*^9}, {3.835338577798208*^9, 3.835338620041452*^9}, {
   3.835338653990897*^9, 3.835338823765335*^9}, {3.835338865410541*^9, 
   3.835338962622757*^9}, {3.83533899622244*^9, 3.8353390024553337`*^9}, {
   3.835339165977964*^9, 3.835339170838904*^9}, {3.835339226586821*^9, 
   3.835339252159419*^9}, {3.8353394292671547`*^9, 3.835339457784766*^9}, {
   3.835339500275881*^9, 3.8353395120074873`*^9}, 3.8353400097312202`*^9, {
   3.835340043255178*^9, 3.835340049105363*^9}, {3.835340320155546*^9, 
   3.8353403214856653`*^9}, {3.8353429884303017`*^9, 3.835343088575757*^9}, {
   3.835343169936596*^9, 3.83534322437465*^9}, {3.835343746121127*^9, 
   3.8353437642293177`*^9}, {3.8353445222541227`*^9, 3.835344552148288*^9}, {
   3.835344620203895*^9, 3.835344716850436*^9}, {3.835344824168634*^9, 
   3.835344832897682*^9}, {3.835344894608045*^9, 3.835344999609126*^9}, {
   3.8353450692229977`*^9, 3.835345143285017*^9}, {3.835345243601369*^9, 
   3.835345244855967*^9}, 3.8353452928938713`*^9, {3.835345339394802*^9, 
   3.835345341993548*^9}, {3.835345390387436*^9, 3.835345394595192*^9}, 
   3.835345505879159*^9, {3.835345633336461*^9, 3.835345726337473*^9}, {
   3.8353458377226467`*^9, 3.835345843828887*^9}, {3.835372061030136*^9, 
   3.835372071264954*^9}, {3.835372109388467*^9, 3.83537218434414*^9}, 
   3.835372522290762*^9, {3.8354170700934362`*^9, 3.835417083829755*^9}, {
   3.835417167922065*^9, 3.835417196326001*^9}, {3.835418223179352*^9, 
   3.835418229883106*^9}, {3.835418393819128*^9, 3.835418488516716*^9}, {
   3.835418519132303*^9, 3.835418537842663*^9}, {3.83542543494832*^9, 
   3.835425472964828*^9}, 3.8354255498612223`*^9, {3.835425690259713*^9, 
   3.83542571399114*^9}, {3.835431541550761*^9, 3.835431541640277*^9}, {
   3.852979611453643*^9, 3.852979691319852*^9}, {3.8529797654116774`*^9, 
   3.852979781170024*^9}, {3.852979821986277*^9, 3.8529798368790913`*^9}, 
   3.852982940810091*^9, {3.8535786610591493`*^9, 3.853578743107206*^9}, {
   3.8535791499440546`*^9, 3.853579151302937*^9}, 3.8535799422709336`*^9, {
   3.853584626138847*^9, 3.8535846264724474`*^9}, {3.853587210467972*^9, 
   3.85358724124366*^9}, {3.8535887940303073`*^9, 3.8535887947170734`*^9}, {
   3.8535888423758307`*^9, 3.8535888436927686`*^9}, {3.854105334495309*^9, 
   3.8541053654070845`*^9}, 3.8674120648254538`*^9, {3.8674128324610825`*^9, 
   3.8674128334895535`*^9}, {3.8674135067612314`*^9, 3.8674135144055395`*^9}},
 CellLabel->"In[70]:=",ExpressionUUID->"83ce1c8d-1a22-4fa3-84c9-6c6be868c2d5"],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   StyleBox["\<\"Chemical shift = \"\>", "Subsection",
    StripOnInput->False], "\[InvisibleSpace]", 
   StyleBox["4.8919`", "Subsection",
    StripOnInput->False], "\[InvisibleSpace]", 
   StyleBox["\<\" ppm\"\>", "Subsection",
    StripOnInput->False]}],
  SequenceForm[
   Style["Chemical shift = ", "Subsection"], 
   Style[4.8919, "Subsection"], 
   Style[" ppm", "Subsection"]],
  Editable->False]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.854105376254239*^9, 3.867412067991088*^9, 3.8674128375558405`*^9, 
  3.8674135202602744`*^9},
 CellLabel->
  "During evaluation of \
In[70]:=",ExpressionUUID->"0b4d12f4-a4ee-42b7-a87d-7eec19ca5fd2"],

Cell[BoxData["\<\"Variance and optimised shift and ratio:\"\>"], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.854105376254239*^9, 3.867412067991088*^9, 3.8674128375558405`*^9, 
  3.8674135418105955`*^9},
 CellLabel->
  "During evaluation of \
In[70]:=",ExpressionUUID->"8a314209-d967-45d4-a3bb-99969ea8e2e8"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1.2812464404169916`", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"fdiff", "\[Rule]", "385"}], ",", 
     RowBox[{"fratio", "\[Rule]", "0.9488829926077583`"}]}], "}"}]}], 
  "}"}]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.854105376254239*^9, 3.867412067991088*^9, 3.8674128375558405`*^9, 
  3.867413541822562*^9},
 CellLabel->
  "During evaluation of \
In[70]:=",ExpressionUUID->"4e1ba429-d4da-48f7-b838-b7a50a1cb883"],

Cell[BoxData[
 StyleBox["\<\"Input data\"\>", "Subsection",
  StripOnInput->False]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.854105376254239*^9, 3.867412067991088*^9, 3.8674128375558405`*^9, 
  3.8674135418265505`*^9},
 CellLabel->
  "During evaluation of \
In[70]:=",ExpressionUUID->"54c5157e-4818-40d4-a48f-4b1ece8c6508"],

Cell[BoxData[
 GraphicsBox[{{}, {{{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJw1mHtcTPn/x0/JbmtdkpbWkkFCSCK3wotSkktK6SbT/V5TMzVTTdNh40tu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       "]]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJw1mHlcTPsbx8dWkZhKZG2k3MgSRZboI8pSNC3SJtM60z7N1FTTdiRZSkJu
lmSuEBUiqVuWkSSyZMmaJFv2brLei9/8Xj3HH7zenvP9fp7P8zzne86c0X6R
zoE9ORzOANVf//+3+0+H9bvtJyxKQnZZ03/gWeeTA8N89xFrgL877+h/kw8R
c/FH5zTDRvujxIMwSFceeW3hCWJ9GCkKmxszy4lH4KqbS8+2MX8T8+C3fc7+
305niA0hOFD9KmDqeWIjtNmFF8c51xKPBZNow48yric2QYXXuLAL1VeJx8Oq
T6f3hf43iScg36OX5d0Rd4gnYciVMfbSjfeIzWBSsSHbcvkj4il4rvsmfOea
J8RTYfJooXazdhuxOb7XDhUN3/+c2ALlud8sbjKviKfBd9TC/T7Fb4inY4Kf
W/sGgw/Elhi8YEfJkfYO4hnQqMg5/O1eJ/FMjGCKv45t6iKehWftj/w1H34h
no2DL8u/Dnz+jdgKvU/OSr/46QfxHMz5dC/oQ7+fxHMxYrmRTee438TW0H+k
O/7HQQ6ovVjXsLdkVmWPbmaAnFlvtznV9qT4PNzJkLXdqOtF8XmQek7auOh0
b4rbwNOo4GPlvj4Ut4GOmoGdSbwaxedjwMyvzy7MVaf4fJxfP/CceicxZwFk
BjFqidkaFF+A8f33nrAa0pfitthf/ehyvzRixhbttQXznO6ycTs0J9hNWz2w
H8XtIPjW31o+lZizEDrfD9iY27DxhVime3/xfLDxRWgLX3NPbQIbX4SH64+Y
P+zJxhdju1Dy3Ps8q78Y2UF9bM0CWf0lSM3/eTHwA5v/EvxXsLL+6ypijj1s
FQfMDc6x/u1x1rHvX23arH8H3J8v/ZGzkurFOCDIrjjw8wGqJ2cp9Hu9+GT3
nurNLIURf5/OtGls/Zdh49ukss8pbH+W4eONg8LeN9n+OeIWzz9feyIx44gT
idVzpuykfnP4GF83u7ZiKDH4OJXUGu95nOaD4eNWk0/5TwGxko/EF5sL5pqw
8+OEDYe7zgapEcMJlTYH4rK/0LwxTjh8dPygHerseieI3g4L3z+BXe+MBV4T
c3aFsuudMWHmryk1tay+M6Y/rOitZUn5KZ2x69u1QUZKNn8XJKeJx931Jn9w
wYK36oF7+rL1cAFzWXronxpipQvkyVwNu7Vs/VwRNkqScMmB6g1XaJjcaxiq
x/bDFc0N0kKnB8RKVdza7vuiHLZ/y9F6+23hzHnUbyyHRv7DiYHN7DwsB6r1
utL9aV6Uy2HxwyH3RRM7P27IHC20/GVO8wY3DMiwsXudzM6jGyZ6djkUVxAr
3ZCmdeTmvhZ2PlegZY5N0LRP7PoVmLzNYssVlpkVeP7EZZUOe71yBSp/501b
d4xd747n7/V2awWx690h78x/tZ7DrndH0NAbIy1T2PzdkTxkcGTpM3a+PXCs
ZcisNWasfw+IhPLVm0TsvHvgbsNq0xVZbP08ULJVT+PvAna+PbFI/5I/p4j6
AU/sf3iv/9p9bP88cbp08KrgzdRfpSfqh/rPHBbN9t8LaN+WM305Oz9eiKix
HL4t8hfNnxc+DTZWWuC/blZ64ZHWKYtJo9nz0huzhtfvuqxD5ym84cbhqiu1
6bxlvLHlQZLswVA6j5Xe+G8wd82ocex5vRKHHDX6TLOh8xwrYS0rt8598I7W
r0Tpm7yxucLXtH4lOkvvflFf8JLW++BEJLduZdIzWu8Du0m/fZMHP6X1PtCp
KDS00mqh9T5QL87d4iJ/SOtXoX+J/8ljjvQ8wyrof+tzNkZMzztmFa5y86yD
rtHzULkKX5ZqtGvUX6f1Ahz6o+XIqqgr3cwToKd25dmi/DraT4DSHHfdKocL
3SwQoE3xoZAJVdL+AqQu2xy86lJ1NysEeDDcoY9ybgXpCXC6t/lu0eiybm4V
wO/T/aiD19j3BV+037l8Y9BYep/g+eJL1EdO+Ap634AvwguFR5rP0PuIwBeH
z2y6WLJ0K+n74kbv+rlW5umk74tNjqvtC/ylpO+L3ueHRZ2KsTvXre+LOUai
IdVqsd3M8YPO7Akzb2us7WaeHwb0N9/pI8jqZvjB6oDdnqX/bOtmgR9uXRRt
Wf5gRzczfrjNfRT+1/U93azww8D3SmWp7V/drPSD0aZ0053uBaTvh/5TJts3
du0nfX9M+DRmx4keB0nfH/WrDKbWJhPDH0Fph6fzWRb4Q/PRuPYew4gZf8iy
Pao6gw+Qvj8cdj5rEqbR/kp/5DxeLM9ay+r7o4ek74nVuftIPwD/HlCzrO2g
fHkBuN9kmr+ylhgBuFI+Om+bCV0vCEBNsEFzUw/ajwnAy+2PlzRxSE8RgBY9
+zlHq1j9ACw7krzv123i1gCEWBiGiExZ/4Gw6tr+fMh72p8XiJf1vg+DU1n9
QHyO/lhW6acg/UBMbTjRXnVqL+kHos54nea6u8SKQDQfzrI7YkvXKwMxotGp
syqBuDUQZS+v93O3JOYE4Urv0qdLGvNJPwj90tr+2b4tj/SDsOevUaHvU3aR
fhD+fHLnzlXLnaQfhNj1K6OmsfOgCAK/YW5r0ltiZRBqT1a/+1pI3BqEwaGN
SaWyXNIXqs7v4Q0T3beTvhDp0UKXp/9uJX0hmsxzfzpGbiF9IZQmwY6jM4kZ
IZJ9Kp54SGk+FUJYf7Hi9vb7k/SF2D/9ptahX6y+ECd/fhV0/aT8OSI4KMZt
HdpAcZ4IFgP3Gfd6SPlAhOQ3N2/9llI+AhHw2VforJdN+iLoTzY5y3hvJn0R
Rg2NV2aaUn5KEYKCgybbpFN+rSIYdUydybjQ/pxg6N83fJ+znvUfjFO/a3Rb
++WQfjAS5hqt1TvL+g/Gt96zfos1WP1gGK8OKo8fQKwIxrwmtxiLgZSvMhgZ
Pewbz82g/VuDIbIIbvPTIr+cEOyY7+WlZ0T14IVgjXE/nVVPqD8IQc9N/5mi
mvIRhOBOS5SMr8nWPwSev5S7P+Zlkn4ITmG+vqJ9I+mHoNLA/PCs1xRvDYF9
Wa/2hSGULycUE57KhqYOp3x5oZDkpjf3VbD9D8WHhnmT3l1h/YfiR93dZcVj
WP+hEA0vqNH9xuqHIvuXw86Qa6x+KAaWbJ0/rmYD6YfibZXc5Pr59aQfhpK3
tjox0nTSD4OZ2Far2DyV9MNwf4ygK9kmnvTDwP04IZS7IZz0w7Bs5ICDlV8F
pB+GBVoZnYdArAzDr7Twv7c/EpF+GMqzioMOHYki/XB8qtFJcTgpJf1wGE/6
qjvWSkz64XhyuvpBRRbtJwhHv7iorTV9den8D8etuA2p3CUudP6H407h+UuX
rObT+R+OuxL1k8p1HqQfjoTrL45FHWX1I7Bvg6nL3uVy0o+A4ORUV2FeIulH
oL88M+LviXGkHwHPfsLq1zMoPyYCCVeM/T3hT/4j8LGgvSAmmPUfgT8FfsJF
A4NJPwK9C4VHI9aTX04kIqKM5d/Z/XmRMCs69djUVkb6kRj20Xu73ylaL4iE
6MUek4qFU8h/JGr+XX2/xDSM/EciPG1wwiPtGPIfCd33aZ38n/Q8bI1EUy99
j+/3gun5K0Ze9MvQ7BqqH1eMxm/ljasnT6fnsRj7a1KdSjRdu9lMjLM39QLU
NcLp+SyG0OmSw7VF8d3MF+P05S92hu0p9LwW46C+o3OZAbFYjGanjafH7oml
/MWY61FjMZ8f2s3ZqnyurZFahXuRHzGaBo42vb7Zu5tLxXBZ63pzmw3pK8U4
eXxcRWsa6Teq8hfK87J6ria/YkyuF3GfHCXuEGMGt1+YJz+R/EdBrf1D6ojT
keQ/CoKDZs2bNR3JfxQ4lvbq14/P7q6/WRTEWTNqee3zyL+K/ymujThH+fCj
0FI91udcGes/CqLPaqkOoevIfxTGJSV36lzNIP9R8JjiraVrnEn+o5C+e+qJ
w9hA/qOQyttklPcujfxHYZFO/ctKDvlRRmFF5NJzS4clkf8oJP5q+7VkRAL5
j4Leo/ehfkI5+Y/Cl9knjGx+x5F/CXpe76jdVU7zwpXAcHPXCrsSMfmXoGjD
a+FU3SDqvwTBN0UzN5W5k38JJH+etbC2XUj+Jah3PTx26Kep5F+C1s6pnebj
6X4VS8B/lXIqfPJoun8kEBel7tD7NqubsyX40/P4tbMjF9L9JIGnq8v4hib7
bi6V4MvlAv4bd3qfU0pg9V3nbZiE9mtU5bP+WYVzxCLyL4HccerLmnMryb8E
DbN2DdF+IyT/UqgZP3RNH0l+uVL4pQ5Le3GA7heeFGEtXZlxCTLyL8WL9eab
lhRS/SDF4tkZTyPnU335UmQ7layblUD1F0ghml6wxyOd5k0shdOrL1422dQv
RorJiT/ND21Jpv5Lsetk7bi8GTQ/Cime5wuKTnCIS6VIqXTqUZJG65VS1BqG
8aa9Jv1GKXr2eH6Fy6P8WqW4FKD9ofEi5d8hRcao7U4DMtj+R6NX2/dDQ3xI
nxuNzALfO69a1pD/aCzX7J2xdhnNo1k03JPfuP34vYn8R0NuOj0jbmE2+Y/G
+QTvGx6jiQXR8Dm+qLXag64Xq/bfY7hK9mo9+Y9G/e3aa+9caL6zo1Gyymez
wVmG/EfDJjNw6Ece+S2NxsmbeduvdZFfZTRsN0x8snEbe/9HI7FiTNDP23S+
tEajbXF72NZ4mu+OaORHZi98P436y4mBprNN9Ql1CfmPQVVdgEIcQsyLQf2S
x8bnX9P1ZjHI/20x9FIw7YcY3F8W2t/rFzE/BjWRR5q6aogFMZj5bHnoX7pU
f3EM7vTwnKf7hOrPxIBZUoUKL+pvdgwch1ZnlkVSPRQxMLRa8O6nE9W/NAaD
PUvqUoV0XihjUOz/R5loAnFjDJ5bjnilFkb1bY1Ban6Z/fYtqeRfxSVVc97M
o/pxZFBIY54MZ58XXBnePF53ZFsN1Y8nQ/Pz3j6nllA/zGSIKhv5ctKSteRf
hsor3938+5MeX4bbhct0tF7T7zGBDIl+NozSnfTFMpS9Dlq0fTf1i5GBd3Dt
oPdvqd7ZMjhOdpjS1I/yUciw44TrCKM37PzLEDfyc3pdCJ2nShmevFrrNSmQ
5qtRhomLHyys0NlM/mWI3by1F5rovO2Q4erNv6cfy6X8ObE4vVRTtzyG9ufG
Iqu2uU6PT/XhxcL9uKl2vgXNn1ks/Az7TSkfRX4QC1lG9W4vE+oXPxYtkXsK
RGV0Pgti4TR1yx/RO6PJfyyy7dc3Vm6ZSf5V6+9f6JFpLKTzLxZnKrbmTJ3B
vk/E4umkMdec4gPJfyy2rlt/cMN/lL8yFjH6B9zv+m0j/7EwLr1fNNBjB/mP
hZaLPPrL8VzyH4sJu0a/WndmC/mPg9qdol7Wm8kPNw6MprbcVOlH/lU8zeFi
bRe9b5jFwbW2ouhOBJ2XiMOdDZOuVXVQP/hxsNU78zz3F+UjiINbQ+E40TjK
RxyH64cN786w/ZP8x6HUUvmUOyCL+h+HVhsNdb8ndL8oVPpee/uOn+JG538c
eOOKjujdoPdJZRw4Zhu6jGOdyX8cMGlh6LCZ5Kc1Du6rZxh8vk7nUUccOl5k
zalYn0P+4yGutL4o30XfE7jx4P678m6vyTTPvHgw4yOOLm8gv2bx4LTNrSpL
onyg4il9fOLnUL/4Ko4IuqDfy4n8q3hCjzebzGiexPFQcmdfyRlE/WNU8W3r
ph0NYM8/FSvu+LfspftBodLfZ+tRvVNC/uOBjpLNwh2byL/q+ooMJv8W/d5r
VMWX8rXWDNndza3x4AUY/OPSQdyh2m90g/WfzsQcOVDp3V+hJObKwZl+YPzH
AfR7mqfiC7dLja7T73MzOVq1H+iEmxSSfzkU5zLeNhcWk39VfOmepdfijnWz
QA6xaOzM4tHHu1ksB3N68t6no0/Q81/FpldH+mqW0fyr1reeeX9y4kmafzkE
rSbOfY6Vk385sreXPFkhryD/cnQ4rsk84PA3+Vetny13G3mvivzL0WjFu/X6
WTX5V/mJWbv7Rehp8p+A0jMJY7/lEHMT0Oj82jY/j5iXAMYnfnlaFbFZAgSW
GtWnNc6Qf9X6RwYlu+XE/AS0etctvv+MWKDa72KPvsaaZ8m/Kp4xSeqkpDiT
AF7of1kBH2j/7ARkqy+Jyd5P+SpU10sLqp/pkp/S/+eb1OWWWkn+E9BxZfhO
5+lUj8YEcMa2O08UnCL/CVCmaaVc1yDuUK2XTvqW3J+Yk6jq13j/BmNibiLE
OR+1s9SIeYlgrju2HZVR/c1U8aLP9eZh1B8kAsdWj0nVpv7xE6EU7LAvKKd+
CxLRaLrpxfySUvKfCIXZOWu+KTGTCLNXRXo9phNnq/Smq+9y3kusUMXX1dUV
GdJ+pYng6R7ZG5ROrEyEIL/n8XeniBsT0dFQyVReJW5V6XfM/n3xB3GHyi8n
rn5xJM0fJwnZG/rZdVhS/twkmA3Cls8zyB8vCbzdKz8aWrH+VZxep7Z1INUH
Sej4fPT8xAJifhIah2Rush5E/RCoeOLv4c17icVJKK1Tzypm+8ckga95BC13
aX6zVfrPZ/+QpLL9V+X3rvOdzJrmpTQJnNt1bhOqaJ6USeA+mDElsfwc+U8C
k7V49lptJflX6V+81aJguUOl13/j64YPdD0nGaXe70Rtp4i5yWjV26s5MouY
lwz+3waJNYHEZqrrrT6/8DIgRjK4SzcJth2kfPjJYPS/iC71JBYkg2Pk0vTG
lfIXq/bT3+83p4bmnVHFPyWJnNzZ+U8Gr+SBS+W/rH9VPh/+sdwRTlyajOzi
F1PeC+l+UKrWJxQ9n3yB6tmoYkv1Qze2sPOfDFFQ5a0hhtTPjmSY5NvfLn1G
88BJgcnspSUrrWjeuCng7J0hclUeJf8pMFsc8G/PFGKzFCiZtqRRxnS+IQWN
KYEGFz8T81OwYGjVSu3xtJ8gBXGBeySCLxQXp6AybX/i1je0H6PS7+daOl96
hPynQPDY/MPIJjpPFar4liF9IsyLyH8KJlznpFzJPET+U5Bzuf+HP+7Q9+DG
FLSbTj93UJu+B7eq/Dyc2f5JQt9rO1T57/9RFz2X/f7LwG7FTS2PY/S9VYNB
3vk51kdvEHMZnN1742udkK7XZxCRMT4jfwDtx2PgfaZo4jxXYhMGrUZt7bkd
7POCga84V5LbQvvNYFBU09Xxrxt9fwWDm6EFzKRV9P18EQOXx8npwwLpeyuf
we6LpZIuNfpe587AffiUf3Tn0PNOwOCSY+GjHQ/p+5yIgUbPuQaa5+l7o5hB
/bi6+fu+bz33P7etP0Y=
       "]]}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, {}, {}, {}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, {}, {}, {}}}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 526.}, {-0.12553797607465222`, 3.46781718127145}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.854105376254239*^9, 3.867412067991088*^9, 3.8674128375558405`*^9, 
  3.867413541906336*^9},
 CellLabel->
  "During evaluation of \
In[70]:=",ExpressionUUID->"a7150d36-8109-46ae-badc-364ccbbfcb52"],

Cell[BoxData[
 StyleBox["\<\"RMS difference vs displacement in data points\"\>", 
  "Subsection",
  StripOnInput->False]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.854105376254239*^9, 3.867412067991088*^9, 3.8674128375558405`*^9, 
  3.867413542135725*^9},
 CellLabel->
  "During evaluation of \
In[70]:=",ExpressionUUID->"423e0afc-1dd9-4fbc-9858-85cd622456f4"],

Cell[BoxData[
 GraphicsBox[{{}, {{{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJxF23lcTPv/B/AQst4QsidJQhISwkuS7CNaUVNp36Z9r2mdaZqasWdLwpV0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       "]]}}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6]}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, {}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 1053.}, {0, 1393.6717477096638`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.854105376254239*^9, 3.867412067991088*^9, 3.8674128375558405`*^9, 
  3.8674135422194996`*^9},
 CellLabel->
  "During evaluation of \
In[70]:=",ExpressionUUID->"86d43bbe-342a-4f40-bc71-b2b37e2de900"],

Cell[BoxData[
 StyleBox["\<\"Expansion of RMS difference vs displacement in data points, \
with parabolic fit\"\>", "Subsection",
  StripOnInput->False]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.854105376254239*^9, 3.867412067991088*^9, 3.8674128375558405`*^9, 
  3.8674135422274804`*^9},
 CellLabel->
  "During evaluation of \
In[70]:=",ExpressionUUID->"0eb20ed8-bc67-42cd-9a73-3d73de4e4f67"],

Cell[BoxData[
 GraphicsBox[{{{{}, {}, 
     TagBox[
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJwVlnk01P/3x8dSaki2tCHMzHvGkqiJqLyfSaKmLIMWFSkiWRLRxxJKSoVv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        "]]},
      Annotation[#, "Charting`Private`Tag$1248702#1"]& ]}, {}}, {{}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
      0.012833333333333334`], AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJxTTMoPSmViYGAQBWIQDQEf7BU/Neq6R4U5QAUcTsx31BLtCYLyORz23c/X
vcrvB+ULONTdeaJ/eZU7lC/iUCVrV2n93RHKl3DYz7n2Wy+zFZQv43DJTDrX
Y7UhlK/gsG3BLyPHj6pQvpJD18lFO5e/FofyVRw2vDJjWPOGFcpXc6gJrHb5
U//FHsLXcJjtUC6+7cpPKF/L4V7BxZySR7xQ9ToOKoJfw+Lq5KB8PQfv4GXh
wtVaUL6Bg4pl/Zq+DhMo39DBin9XTHi+LZRv5MAX+HXBxHfOUL6xw4T3b96y
3vWE8k0c2GZ3XLxiFQDlmzocFzuY9+5KsAMAkdZW3w==
       "]]}, {
      {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
       0.012833333333333334`], AbsoluteThickness[1.6]}, {}}, {
      {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
       0.012833333333333334`], AbsoluteThickness[1.6]}, {}}}, {{}, {}}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{Automatic, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{All, {0, 98.35165378054641}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.854105376254239*^9, 3.867412067991088*^9, 3.8674128375558405`*^9, 
  3.8674135423860564`*^9},
 CellLabel->
  "During evaluation of \
In[70]:=",ExpressionUUID->"34be553a-2e5f-41d4-8854-3c41c9d515e2"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Interpolated frequency shift with best match is \"\>", 
   "\[InvisibleSpace]", "14.674723990859691`", 
   "\[InvisibleSpace]", "\<\" Hz\"\>"}],
  SequenceForm[
  "Interpolated frequency shift with best match is ", 14.674723990859691`, 
   " Hz"],
  Editable->False]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.854105376254239*^9, 3.867412067991088*^9, 3.8674128375558405`*^9, 
  3.8674135423920393`*^9},
 CellLabel->
  "During evaluation of \
In[70]:=",ExpressionUUID->"df9494ad-aaf2-46da-9e08-2a1756e96547"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   StyleBox["\<\"Chemical shift = \"\>", "Subsection",
    StripOnInput->False], "\[InvisibleSpace]", 
   StyleBox["4.5999`", "Subsection",
    StripOnInput->False], "\[InvisibleSpace]", 
   StyleBox["\<\" ppm\"\>", "Subsection",
    StripOnInput->False]}],
  SequenceForm[
   Style["Chemical shift = ", "Subsection"], 
   Style[4.5999, "Subsection"], 
   Style[" ppm", "Subsection"]],
  Editable->False]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.854105376254239*^9, 3.867412067991088*^9, 3.8674128375558405`*^9, 
  3.8674135429919596`*^9},
 CellLabel->
  "During evaluation of \
In[70]:=",ExpressionUUID->"1c8bdb26-289f-49a6-b8b4-e5023f83a650"],

Cell[BoxData["\<\"Variance and optimised shift and ratio:\"\>"], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.854105376254239*^9, 3.867412067991088*^9, 3.8674128375558405`*^9, 
  3.8674136072292194`*^9},
 CellLabel->
  "During evaluation of \
In[70]:=",ExpressionUUID->"acd31d52-cb17-4d62-ae5d-b3189ba61070"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"16.549823344768768`", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"fdiff", "\[Rule]", "1272"}], ",", 
     RowBox[{"fratio", "\[Rule]", "0.8799544778866109`"}]}], "}"}]}], 
  "}"}]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.854105376254239*^9, 3.867412067991088*^9, 3.8674128375558405`*^9, 
  3.867413607239193*^9},
 CellLabel->
  "During evaluation of \
In[70]:=",ExpressionUUID->"1550085c-73a1-4cfc-91b8-7e823dcfd104"],

Cell[BoxData[
 StyleBox["\<\"Input data\"\>", "Subsection",
  StripOnInput->False]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.854105376254239*^9, 3.867412067991088*^9, 3.8674128375558405`*^9, 
  3.8674136072441792`*^9},
 CellLabel->
  "During evaluation of \
In[70]:=",ExpressionUUID->"263fdca2-1bff-447f-a91a-c24fe8e71909"],

Cell[BoxData[
 GraphicsBox[{{}, {{{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJw8fHlczO33/iCEMLaEkD0qBiFLXAghGSRRMlFJUtOiom3ap32afSoMoSiE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       "]]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJw8fXlcjO37dgghiUIIIYSQR8hWB4UQ2igVRpu0MO17Tfu0T9O0h1QISQgh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       "]]}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6]}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6]}, {}, {}, {}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6]}, {}, {}, {}}}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 1835.}, {-0.06097267553291301, 2.0682817624160075`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.854105376254239*^9, 3.867412067991088*^9, 3.8674128375558405`*^9, 
  3.867413607328953*^9},
 CellLabel->
  "During evaluation of \
In[70]:=",ExpressionUUID->"3c5c4703-08e1-4595-ace8-33aa5a34ff10"],

Cell[BoxData[
 StyleBox["\<\"RMS difference vs displacement in data points\"\>", 
  "Subsection",
  StripOnInput->False]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.854105376254239*^9, 3.867412067991088*^9, 3.8674128375558405`*^9, 
  3.8674136101085215`*^9},
 CellLabel->
  "During evaluation of \
In[70]:=",ExpressionUUID->"7fa0c99c-82a2-49a2-8afd-47e9df873ec7"],

Cell[BoxData[
 GraphicsBox[{{}, {{{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJxM23lcTF/4B/D4huwhCUkIIYQQwgchCaGSJJU2LbRrU9O+19RM07QghEqI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       "]]}}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.003666666666666667], 
     AbsoluteThickness[1.6]}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6]}, {}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 3671.}, {0, 1088.6935238807077`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.854105376254239*^9, 3.867412067991088*^9, 3.8674128375558405`*^9, 
  3.867413610231154*^9},
 CellLabel->
  "During evaluation of \
In[70]:=",ExpressionUUID->"e4f1e2f3-cb95-447c-900a-90cd36241112"],

Cell[BoxData[
 StyleBox["\<\"Expansion of RMS difference vs displacement in data points, \
with parabolic fit\"\>", "Subsection",
  StripOnInput->False]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.854105376254239*^9, 3.867412067991088*^9, 3.8674128375558405`*^9, 
  3.867413610239134*^9},
 CellLabel->
  "During evaluation of \
In[70]:=",ExpressionUUID->"1777d3c0-979d-428b-a3c9-9f55a74b2502"],

Cell[BoxData[
 GraphicsBox[{{{{}, {}, 
     TagBox[
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJwV13k8VPsbB3BFkuhHlAgNM+fMkGTOjC3RB5UWLUQGWVNIxKWbW5Ro1UKu
UNlT2YpKZMm+lUslonJTWmVfs5XfuX/N6/2a1+t8v+d7nuf5Po+K6yHLfXOF
hIQWzxES+u9XoTrSW0hocB016JEuK2OLFoa5DUN+cF3QhekDCRK2uBw83xjU
4Dq9bX5ctqgthHWPy4a4Da6bMBV9ZjgpQG+GV/Fs/eC6+N+takc6BSiN2Lhg
9srQuj/TJdIUsgVwtZ9J+8UcWXem6XUoa6MAGcPuHVNm4+vG977vNg22QXtb
tbeO3K917w+w1DPbrJGX9N38z8I5mL7PbV7rZIWC4Wg/uzYRKCvKKNn9toS4
yil2p54Ypn4T629dscBlqQb1FOeFUNN/ctRk+064vrMqE/5nEb6uvbY3SWQ7
Cl1N7hfISONqXIqFeeJW2OmdUbuYthhVlvmKhaGbkXrM64eWjSyCh4Sh4miG
0KQZi9HeJfiwNTjFNGQDhF59QMlROTweUt7Q12AKMmB/oJW6PMjsD+uPLjXB
57HY3QufKEDCWtNlcTKw5cuB4Cg/RYRtsZ5ScDTC9s+RK5WVlSHY8TJxaYsB
flS5htTfXYHxa3pLvR7rI1as53JKDgPx8m8acwt0MbzRv+LZAwbeJkUn1uTq
Yvvp6ZGRRwzktzldfJ+hC9G5ErYbSxjYtocoU4zXRcC0BrOnngGhwoMnn4Xo
wrLfp4DfxYBbeW9gzxZdLGoZ7qyTVYHW/Ac80y4dnE6a0ur/SwWdARbtm5V0
UMKQFbEPVsEnGyW570t1MJqyqq0uRAVra2zUL0jpwDXNOTjlrAqmjZY1dQrr
wCij9qnVVRXE3asTr/qhjfEHUa7FuSrYcfyDwK9QG/tr1aPPfVPBvc5JM287
bSSYrXcf+6GCHMlY2dtW2mipd1jj2q8CsdrUR5+2a8OkIfKDwZgKKlvnHfY2
1Ybyi3GNgbmq2O039b1IQxuv31TWWCurYiou4ZahkDbM+ux+qlqrgpfZ4NeV
yUeibNirEwJVNOv7dzbe4mPUICunw14V3//XO/okmY/k8Gn3GFdVBEZYyGXH
8DHFjm9f4KsK5Y4e/fJQPrJd/y0cDFdFdJbDeJ09H1LtTkGl5apgMHXMraX5
2D97VrC8WhWnT4rmtUrwUULm8gPrVOFMplfZifHheVioj9ukir9Mnd7+MctD
5eIUh1vvVMFviP/yto+HgG1dRhfHVdEiZe0f3sBDe6XbHDsNJnIDirzcw3kY
NH6rELyaiTZxkf6yMzzMr9jBT6aYMIu+FKwYxoNO2Rr3r3pMzDnpXP3xGA/R
xVKNf2xg4mPFvKF4bx525JXEXXBkYufHbbWtFjzU3pLVehJJ/x/T4myhxMN7
VvjmD38zQcYoXlipwMPYzVlX4Vgm8s6lVS6Q44GV+uPq5gQmsswCbJuleAhN
LJ9uzWBCZJUMGS3Cg1Hswbr+Sibcrm43eNtL4dG5akfGGBPvOoqtfcsppG9p
WHZ2ggmO+Jv9fz+hcF2iublvmokwf2OD4iIKIZGdG4vnsuAwNbJK/hEF87gp
zd1SLGS2d65ZlEmh647W7IWVLKS3NQ93RFNo9dQtHNZkobzmpp55FIX6lUb+
thQLXwfKjMsjKNzN2fqN1GfBZuJNQn44hcCC/c8rNrLQ/CY6uCOEwqK6+KSf
LiyodRLvJHwozDl/09ZxHwuSlzOt670ojG7JlKnxYOF34NG/z3lSeNNUcDbq
EAuiwjMCuX0U0l43H1oVzMLdb6cX+uyhsOarGPbGseA0krdIyJzC/nmHPzQ1
sbBJNuRSviYFhRVP26ZfsuD9suU+uYpCk57Sc04rCxO8Rb+ur6Sgc7DmSeg7
Fgy7NcUiORREXy25ofOdhTOynKEsVQq3kvOtE+cQWOIzKZklR0FQJL6tQYRA
xMm4ZIelFCRaHNdPzCfgs0bRTnYJhYD583mWiwjsiX9pfHkxhfU+NlKiywmM
M0Y/PZSk8Nlg4pk3nwB71TL/WhEKcdbmldd1CYzFzAkoFqbP/1ByYd0aApzb
z2/kzaWQl7opXcWYQGmevPNDIQqnFlw73bqNQEbUvuKuGS70mH1Bcy0IpLAD
Riamuehdaxyw2orArIu7pQxtK99u1/N2BLprp09ZTXLBatOHoTuBYIuOErFx
LtoHL+keOEAgSVpKA2NcXBTv0oz1JkAe4VQeG+Vi1DBcacifwD5q/t7ZYS6q
095OpYXQ63kGHdEb5CKwVHP4ZRiBPqtWpSsDXGi0h3b/PkM/78vinr5+LqIX
rmwXXCJA/TSYetjHxd4/jj2SuE5A7t2GHr8eLnSo94/UEgjoG71z7v/Bhfgw
8jcmE4gLmH3lQzvXT7Qg5DYBMfvRB8e6uQjjehYkZBBQWFijLEZ791BDQVE2
AY/LrHNx37mY8b3yePQBgfxFkbtqvnHxXGv0sXQ+gYKF8Y9caKcO7i7ULCQw
+k5nyVzam30VizzKCDDGlzVu/8qFotaJotOVBKTgTEx/4WJw4GNRag2BtQ46
x7Joxxy6U9zRQMBMOmLFMtqeq8VLJpvo80qX9mn5zMXagYMlS5sJGC9mFkXT
lsp5XsJrJRC7o0rYlvYnH+rJznYC6s7DW1Ro52tefeL9jsCEaW5E3ycuwvt/
Pgl/T2Du9MzLJ7Qd7tmV3vlIr3e6XTqKtpbPk9LqzwSedpnsOEBbWJNR9vEb
gTMya8M30n7dF1r2+weBE3LVlSTtjLtfypb3E8jrfzshTjvIe1O53hAB4lqI
xkgXFztWZZVbjxJ4ufSRQydt1T7Jij9+Eih0D7z4nPZ4tm9FxBSBfy88e1xF
++nBVxXZvwgYhmV1FdOO19CpfCpEon3bcvHHtH174yq/CpPI6ZFf/Z9Ns6cr
heeTqNxzx6KE9tKDjlUMcRLSKVV+1bS7V1ZUGUqSiH/sE/GCdkkPs9pOioTr
zfTMD7Qjss5UH5Eh4ebiVzVK29Wruzp6KYnU4fo3EvT7aK80r7kvT2K5TU4f
h7ZYz72aJkUSLy+zZjfR7siUru1ZQa9/jbPIm3bOgYBaMSaJgSPFCldph6q3
1RIkCYHav6wK2rt/6NeZqJGYuXtJY4j2jOdsXdBqEhNaN/gO9Pd6ruZaf40i
sXP1BP8a7dTu6vp8bRKfhT5Tb2hv9gx/OmhAolTJg72Pjg9Ftb6nkutIzPMU
Ur7/Xzx93/FM3YTEubPsxXPoeIvxWNLgtomEsZHqSDZtT05gw8mtJI68HusU
o+Nz7fe3DYnbSXw3FjzzoN3lnvxPuxWJE1FPY/l0vK92X9lk7kLiqILjkhk6
H957rjh0140Ed/1AUiidPxcPykgt8iAxMlnbIUnnW7fftMVzHxLXFmzxpnq5
uBnU0GoRRMKnMLH7IZ2vlifK/nxwgkSIqZuoM53PQqEP5WTCSCTY+rZK0fnu
cPaGbct5ElNqe8JDhriQi/L6d3csCQP70B1xdL2ojXY6XnCdRPqGoN+edD0J
iN21YlkiCUZJiRPoevMy3sDlTRoJapu0/vRPLi7cWfjF/gGJD7NiZhl0vZot
yep1biThcId68ZWuh/fKki5VvKD3Y3n1pvA8Cnsq/9ZUbSFx77yRGiFKobDu
mO+ntyRWxbtt/VOMgn/z1tF930k8tJj9sZOut9++9UwfEGbj42+f2G90/Y75
0RnfIMpG8YE1ETvk6frc98pQQ5yNJFdz/RIFCinDxSf6pNgIHzdNu6lEwf7X
BWFfZTa+3zvZmsmk8HyxxsLD+mzUuejeuq5Fwcjbu/vGWjYcTerDtSh6v3X3
6irXsZGrZH/2GY/C5SDuKamNbJysPlMjrkvX9686v7Is2XjbPGZdYkjhWaHx
QJcXG4eGqbpPW+n7TDasccEhNm4f/6RYvI1Cpk91ltYfbMTNizkfs4PCeaaZ
x/FANjKE56Tb7qKw6ZL5R/nTbISV909I2VOocbZ5tTORjWWGaj2m9H3KL467
fySFjYGAydw93vT9ueRtRGIavZ87DZf+OkTfJ8/2mPdmstE8c/himT8FE75r
zdkCNjQ8uhKCgiiUz/cuKH3BRqWxgnTxZQrF90JvaAhzcEhIVH9zPn1fmlsr
xIpycO6XuIhSIQWLbva1OeIcXFIYiB8rps+f2RjzWooD+zwrvUcVFGSuyUWF
KHMg4n51iU8jBa+w7HMt+hxE1Pd61n6hsFzw+nCQLwengkb+kqb7of1j6aNf
/TmQO9IhdILul+5HHfO3OMJB7JU06yEGD2aNDD/yOAd2ZLPHZzYP/iZeB19c
4KC/KVVbRIeHBg2hvaw7HGxTVPBU38XDsTnqO//5l4OeO8660ld4+Lp+YTv5
kYNrUVE35l3lYee5XqeTn2n/ZKX8jqP7r//lHNLp4SBGyyvydzIP/yjyI5In
ODjhGDyrfZ8HZT2jpgAZNchkPl4R1kz3lz6W5kqb1cATuuARs4wP8Y6jm3zy
1GCfnrg85QEfOkcyJCMK1CD0ROL2vgI+XBa3N+cUqWG67LGuZgkfjzdpOwyV
q+F35DPfhhq6v3004BfQqIaVTq36Om/4qLjsduPoVzWoZp9lN9L9dqDx9v4z
y9QRKebkJ7RLG19uq0QnBanDuaG9NIieB3pPfZwUDlGHpGudSvkCHQy7pjh5
hKlje1CwsRg9PwitUFnJDVdHjAEKbivqQCGWUVkZqw7NLyuCFHV0sPPsisEv
D9QR/dnMq8eTnkfclcw1utWhFL2mc2mrDqI58iKF1iuxOj9TKa1QF5HX99e5
MDRQG7lk9aJYfdhFOzRJfNPAQ8cESc0sA0ysvzWZVLoKzePzLPfxjfDpi0lg
5VlNDNzZm1p5AEg15C5vdFmNcfflGntmjPG6sujcw6VamFB8/vHDVVNUZd6/
dfKoFtYGPgotMtsAhf4XLVVftRA3sKD+ookZYtVu3G3cyoXyUJ9etOFmHC+/
FLe1kIuhoKAc+XNbYb7c+tYzFoVEzqN8v75tgE+dvfR5CslrGrMuEjuRqOjK
+meMwsRCt7ZVIRZgVt2J2W7Pw7BPWsZIiyUiVlWqN5fyoOr24Ygizwr7RkRe
PlXnQ7b4/Y75FdZwuT/MOB/BxznfqqtGG2xwIHTXzJYrfLgm7mSomdsgYFde
m8TffNTXWQ7K7rLBmbHDlyPpuYchme886GyDbP3J6dgEPrRcJ0Lzg2wwUTH7
+nYWH5naBxtP5NkgslniUnUdHxKhUkdFCQGu3/T2OPOUj2aG4UN5DQFuBjSZ
bmrgQ6H4PVeTJ0D+0siphiY+1neFzNoZC9BhJ+PxqpWP4Sl0VDkIwP4kb9r1
iY9U69wbzTECaOUdVU77wkd7tobGVIIAa06/m9z3jY+4WaW5zFsCmLMTcrt/
8HE71ul44EMB/vBiKA8N8aEa5fiYeiFA0NqTkw9G+IiuCQ1waxPgtGRXS8AY
H+Gjy/+MfS9AXM7NCxMT9By34e7mOX0CpIaIuBdN0XPg/lvL9UYFyLLYZxI0
w0de2GKe77QAeaq1Ska/+dgePxqRMdcWpSPk5OwsHwG5W6nPC2zxf5Njm1k=

        "]]},
      Annotation[#, "Charting`Private`Tag$1319669#1"]& ]}, {}}, {{}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
      0.012833333333333334`], AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJxTTMoPSmViYGAQBWIQDQEf7GWOrVniVhThABVwOJWkNWmTdCiUz+EQuuTz
qg/vAqF8AYe49/Yexl98oXwRh4KJR1c+meIB5Us4PPj25WPWDWcoX8ahW+7y
vaqV9lC+gkPMoq8rL1paQvlKDu84VTSdGk2gfBWHGyzRy9ZPN4Ty1Ry+RLNY
HuwxgPI1HHoK82Mi02HyWg4fjm2b768K06/j0GE2b3fVbgsoX89hX5KLNZ8Y
zH4DB7Z5dh/m98DcZ+jwaO6uOr5AmPuNHF67vbi78zDMf8YO969u/br2Gcz/
Jg4boq2tTLVg4WPq8OW6qOmeeREOAGybWoA=
       "]]}, {
      {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
       0.012833333333333334`], AbsoluteThickness[1.6]}, {}}, {
      {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
       0.012833333333333334`], AbsoluteThickness[1.6]}, {}}}, {{}, {}}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{Automatic, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{All, {0, 108.32826099249341`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.854105376254239*^9, 3.867412067991088*^9, 3.8674128375558405`*^9, 
  3.867413610327896*^9},
 CellLabel->
  "During evaluation of \
In[70]:=",ExpressionUUID->"9b03d023-bd21-4db3-8537-e39972ddbf7c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Interpolated frequency shift with best match is \"\>", 
   "\[InvisibleSpace]", "48.52315312265558`", 
   "\[InvisibleSpace]", "\<\" Hz\"\>"}],
  SequenceForm[
  "Interpolated frequency shift with best match is ", 48.52315312265558, 
   " Hz"],
  Editable->False]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.854105376254239*^9, 3.867412067991088*^9, 3.8674128375558405`*^9, 
  3.8674136103378687`*^9},
 CellLabel->
  "During evaluation of \
In[70]:=",ExpressionUUID->"5d1d6e79-f44c-44ee-9823-0b82ed405495"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   StyleBox["\<\"Chemical shift = \"\>", "Subsection",
    StripOnInput->False], "\[InvisibleSpace]", 
   StyleBox["3.86557`", "Subsection",
    StripOnInput->False], "\[InvisibleSpace]", 
   StyleBox["\<\" ppm\"\>", "Subsection",
    StripOnInput->False]}],
  SequenceForm[
   Style["Chemical shift = ", "Subsection"], 
   Style[3.86557, "Subsection"], 
   Style[" ppm", "Subsection"]],
  Editable->False]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.854105376254239*^9, 3.867412067991088*^9, 3.8674128375558405`*^9, 
  3.8674136108813076`*^9},
 CellLabel->
  "During evaluation of \
In[70]:=",ExpressionUUID->"b02781d0-f581-4202-84a2-6966f5acd79b"],

Cell[BoxData["\<\"Variance and optimised shift and ratio:\"\>"], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.854105376254239*^9, 3.867412067991088*^9, 3.8674128375558405`*^9, 
  3.867413641255188*^9},
 CellLabel->
  "During evaluation of \
In[70]:=",ExpressionUUID->"5b26182b-46e8-4e3e-99c6-0336907b2cca"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1.4959992508302251`", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"fdiff", "\[Rule]", 
      RowBox[{"-", "1"}]}], ",", 
     RowBox[{"fratio", "\[Rule]", "0.8`"}]}], "}"}]}], "}"}]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.854105376254239*^9, 3.867412067991088*^9, 3.8674128375558405`*^9, 
  3.867413641265221*^9},
 CellLabel->
  "During evaluation of \
In[70]:=",ExpressionUUID->"87955e44-8157-4d61-9377-f8f344f25885"],

Cell[BoxData[
 StyleBox["\<\"Input data\"\>", "Subsection",
  StripOnInput->False]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.854105376254239*^9, 3.867412067991088*^9, 3.8674128375558405`*^9, 
  3.8674136412721424`*^9},
 CellLabel->
  "During evaluation of \
In[70]:=",ExpressionUUID->"a1ea6495-58e5-43af-85b8-60b956b3f89b"],

Cell[BoxData[
 GraphicsBox[{{}, {{{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJw9mndczd8fx6+R7G9mJXKTkVEySkReJRpIZZQ0bpqat33bd99rF19kpXyN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       "]]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJw9m3lczc/3xy+RyHLtS5YrIltSJIRXSkpFpY1St0X7ctv3uvutkLKWNQmh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       "]]}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, {}, {}, {}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, {}, {}, {}}}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 787.}, {-0.009046025000000001, 0.81046303671875}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.854105376254239*^9, 3.867412067991088*^9, 3.8674128375558405`*^9, 
  3.867413641361901*^9},
 CellLabel->
  "During evaluation of \
In[70]:=",ExpressionUUID->"3ca9541e-3a09-4638-bc22-8d3a244437fc"],

Cell[BoxData[
 StyleBox["\<\"RMS difference vs displacement in data points\"\>", 
  "Subsection",
  StripOnInput->False]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.854105376254239*^9, 3.867412067991088*^9, 3.8674128375558405`*^9, 
  3.8674136419503264`*^9},
 CellLabel->
  "During evaluation of \
In[70]:=",ExpressionUUID->"35037686-b22a-4190-9fa8-5c83c67a9d4c"],

Cell[BoxData[
 GraphicsBox[{{}, {{{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJxF3HlcTN//B/AiZInsIQlFJYQQwktCSEJIQmlV2tO+TPu0z0yzIYRSEkII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       "]]}}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6]}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, {}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 1575.}, {0, 98.09587681903635}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.854105376254239*^9, 3.867412067991088*^9, 3.8674128375558405`*^9, 
  3.8674136419962044`*^9},
 CellLabel->
  "During evaluation of \
In[70]:=",ExpressionUUID->"d7ad230c-4b42-46f8-b677-267fe54337fb"],

Cell[BoxData[
 StyleBox["\<\"Expansion of RMS difference vs displacement in data points, \
with parabolic fit\"\>", "Subsection",
  StripOnInput->False]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.854105376254239*^9, 3.867412067991088*^9, 3.8674128375558405`*^9, 
  3.867413642002189*^9},
 CellLabel->
  "During evaluation of \
In[70]:=",ExpressionUUID->"ee0cc410-9131-424e-a036-0797f724442b"],

Cell[BoxData[
 GraphicsBox[{{{{}, {}, 
     TagBox[
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJwVl3k4VW0Xxo+hFCpFhOIcZ+8ziAydRMmzlKFBvZEpRE7GjBVvA5VQxkRk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        "]]},
      Annotation[#, "Charting`Private`Tag$1390886#1"]& ]}, {}}, {{}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
      0.012833333333333334`], AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJxTTMoPSmViYGAQBWIQDQEf7L10Da22v1V1gAo4mLGKeYrPUoLyORyWPTmw
7fgPOShfwGFGkNCt3Q6SUL6Ig9m1vWs3KopA+RIOae28D3kS+KF8GQftDSmT
ZP+xQ/kKDmsC2V/mODJB+UoOPxbPPfFo4h97CF/F4YTo/Flfw39A+WoObg1C
L+e8/w7lazjcSIv6sST6N5Sv5XB1TlJyhgsj1DwdB584q2v1K9igfD2HNwzv
K9kP8EL5Bg5x0gZP5MyEoXxDh4azq30nu0pA+UYOd2favnnyWxbKN3YoE5Fq
jlWChYeJQ9WvOds3tMDCy9TBZt/WLi8JTQcA67hVDQ==
       "]]}, {
      {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
       0.012833333333333334`], AbsoluteThickness[1.6]}, {}}, {
      {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
       0.012833333333333334`], AbsoluteThickness[1.6]}, {}}}, {{}, {}}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{Automatic, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{All, {0, 13.802188079980834`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.854105376254239*^9, 3.867412067991088*^9, 3.8674128375558405`*^9, 
  3.867413642055047*^9},
 CellLabel->
  "During evaluation of \
In[70]:=",ExpressionUUID->"0c2dc76e-b286-493c-883e-8954bcdaaaf9"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Interpolated frequency shift with best match is \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"-", "0.022838772801344435`"}], 
   "\[InvisibleSpace]", "\<\" Hz\"\>"}],
  SequenceForm[
  "Interpolated frequency shift with best match is ", -0.022838772801344435`, 
   " Hz"],
  Editable->False]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.854105376254239*^9, 3.867412067991088*^9, 3.8674128375558405`*^9, 
  3.8674136420600324`*^9},
 CellLabel->
  "During evaluation of \
In[70]:=",ExpressionUUID->"0a753a9a-529d-47bb-a111-642195258f4c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   StyleBox["\<\"Chemical shift = \"\>", "Subsection",
    StripOnInput->False], "\[InvisibleSpace]", 
   StyleBox["3.55438`", "Subsection",
    StripOnInput->False], "\[InvisibleSpace]", 
   StyleBox["\<\" ppm\"\>", "Subsection",
    StripOnInput->False]}],
  SequenceForm[
   Style["Chemical shift = ", "Subsection"], 
   Style[3.55438, "Subsection"], 
   Style[" ppm", "Subsection"]],
  Editable->False]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.854105376254239*^9, 3.867412067991088*^9, 3.8674128375558405`*^9, 
  3.8674136425324135`*^9},
 CellLabel->
  "During evaluation of \
In[70]:=",ExpressionUUID->"e58dada2-ecfa-49fd-b38b-b821e2535446"],

Cell[BoxData["\<\"Variance and optimised shift and ratio:\"\>"], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.854105376254239*^9, 3.867412067991088*^9, 3.8674128375558405`*^9, 
  3.8674136719458227`*^9},
 CellLabel->
  "During evaluation of \
In[70]:=",ExpressionUUID->"0f1fafc9-abd0-4507-a25b-a9485e672c68"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"6.159189138603258`", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"fdiff", "\[Rule]", "51"}], ",", 
     RowBox[{"fratio", "\[Rule]", "0.8428185170611242`"}]}], "}"}]}], 
  "}"}]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.854105376254239*^9, 3.867412067991088*^9, 3.8674128375558405`*^9, 
  3.867413671954799*^9},
 CellLabel->
  "During evaluation of \
In[70]:=",ExpressionUUID->"1e5bd060-960a-49d4-943a-c2e9f3010db6"],

Cell[BoxData[
 StyleBox["\<\"Input data\"\>", "Subsection",
  StripOnInput->False]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.854105376254239*^9, 3.867412067991088*^9, 3.8674128375558405`*^9, 
  3.867413671960783*^9},
 CellLabel->
  "During evaluation of \
In[70]:=",ExpressionUUID->"2bba5e9d-6bdb-4a15-a9f6-07f2e6dfff2c"],

Cell[BoxData[
 GraphicsBox[{{}, {{{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJw9m3lcjO/3/yeFEMaeLSNbvOM9CCXyilCkRWmPkbRQmvapprpnaZqyDZIk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       "]]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJw9WnlcjO33HnsIobeSMJYoa9HrLetlT6gplVRqWrU3rTPt08w0TdnGnoRB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       "]]}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, {}, {}, {}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, {}, {}, {}}}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 787.}, {-0.0033001911176317247`, 1.39981092560949}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.854105376254239*^9, 3.867412067991088*^9, 3.8674128375558405`*^9, 
  3.867413672018629*^9},
 CellLabel->
  "During evaluation of \
In[70]:=",ExpressionUUID->"94f60c1c-b5de-4d4d-a042-5170d0446f1c"],

Cell[BoxData[
 StyleBox["\<\"RMS difference vs displacement in data points\"\>", 
  "Subsection",
  StripOnInput->False]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.854105376254239*^9, 3.867412067991088*^9, 3.8674128375558405`*^9, 
  3.8674136725541973`*^9},
 CellLabel->
  "During evaluation of \
In[70]:=",ExpressionUUID->"2f32cb14-782d-4cb8-8466-926f9c7e7d73"],

Cell[BoxData[
 GraphicsBox[{{}, {{{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJxFnXlczN/3x0MIfRSSEEJSSUJRCS+kklBJKqlUKKV9mfZpn/aZZppJQkKy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       "]]}}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334], 
     AbsoluteThickness[1.6]}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, {}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.004583333333333334],
       AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 1575.}, {0, 173.90609526196013`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.854105376254239*^9, 3.867412067991088*^9, 3.8674128375558405`*^9, 
  3.867413672643958*^9},
 CellLabel->
  "During evaluation of \
In[70]:=",ExpressionUUID->"0b1347bd-5113-4385-8ad7-8d038a038a9f"],

Cell[BoxData[
 StyleBox["\<\"Expansion of RMS difference vs displacement in data points, \
with parabolic fit\"\>", "Subsection",
  StripOnInput->False]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.854105376254239*^9, 3.867412067991088*^9, 3.8674128375558405`*^9, 
  3.8674136726529903`*^9},
 CellLabel->
  "During evaluation of \
In[70]:=",ExpressionUUID->"2c170236-0402-435a-a53c-241ba02bc6a5"],

Cell[BoxData[
 GraphicsBox[{{{{}, {}, 
     TagBox[
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJwV13k8VN8bB3Dii5BEqTszxjBzZ8gSmiRZPtMilZLSRqlUZFdUEpFWlaIU
lSVbkUpKZI+s2SqKpE1Zy07W+N3fX/f1fp05M+fOec7zPEfZzn3zwRlCQkKz
hYWE/v+kFYe4Cgn1mfSN9kR7zBWgnmW+nUX0mcSsFdogJSvAVT9xAXT7TJL0
zz6+LyWAyNJTcwMO9JlU9/88922GAH+SnXOmy/tMbN7OCNvZD+RfM505Hdpv
csU4n3SvAexsJhP+sQdNTL6pK7GCgOQBh+bxNX9Nfui0ON4WAhobil315v8z
OZt1v8Wi2AjpMR3mx7KE4fJXtFimZDkyB8IOWzeIQvIWa9N/bcsgqXyW901f
Agd2q4suG1mKq7KVC2P3SkHmHlesGHqw+2xVIFIlg7/bg57+589Hlt2KtEz5
OYgziAzhf9OFtf55tSsJcviieTfE4ogO4k46d2lvn4tNnb1HDkwvQmDMpOXQ
n3lYfltcztdHE0J135HrMx+s2MtL7bTUwfWy97ZaSMCcVr34+Q9V/BoO3yaV
R8OlKRuFii4u1rU6+V0/zMB3xQp3vUkONv4KUWcymVjp0jTctJaNrtd2AeWP
lfDQQy/paIsywiV+X41NZWFpqvfY6assDJh6Fr55xsLK+vwZvUEsbDw3MTj4
ggW9mwrfbM+xIDZDeqdpLgsNXeOya3xZ8JrQYP8uZ0Gi9dbOZU4sbO5xy+S3
sMCYxziVaMqCTP3At7K5yph9wGZupDAL52LGtXtOKGONj81vUSEl5LLmitr4
KWN1sI5p/AgTQ7GaDWUBymiSnlxh1suEXcJev9gLyqi3dFO5/5UJ4+TSCqub
yhgdKPNOy2Pi77PrdjlPlfEv1OKMmB8T9qULwy62U+Mrns5+KMRE1JpVDsNd
ymB2yiczxhRRX77bwK5HGV8nnH/d7FfEisqQ78uHlaHmMIbIFkUw3/7V6J2h
gh6roNDRYkV8/FRUspWpgiXBfiG9lxSxptt6RGWrCp57ZP7XQFdE9Nwzdf47
VDBY28UxmqeIoeUpqc02KjjLqklKllHEvUsTDrfsVBB6M+HrTWFFjPMiG2d6
qGB7bciMnHYGHtl9yeq7pIKE0/bq+i8YkG3c45v/SgWLf4gJT1kxYD99YQe9
WAVmTvoZ2hYM5HKf8r3LVPDoF/HWcS0DjkeFunVqVLDn8R+dXiMGiuRidyd+
VoHX1XePTXkMeG1oMb7yVwW7r0WcV52go7HogLC1BhvsK/TczAd09AmaaH6L
2EgntxRJx9MhXmjBv6fLxojlyA6HaDr0Cgwc2vTZuGF3bqnmTTrCcmSrj6xm
g3PgZdZEIB0W6bkRl23ZSOo48T5+Dx2liXO180LY0Btx2spSpOMr59La7zfY
kGjnO/IIOobjp+1EwtkIdnSexZ9HByeu6+baKDZSuExx21l0BEa/mviQzAZO
3ykY+keDcbhLWU8RG9WZPas0v9Pw4mKxLWuYDdeF/8W+SaIhaV3lggujbPxE
zh6jRBruSL9/3z3Bxura5qSMWBoCQr6Z5szgoHSLXVPuHRrMI8a1tslSnjiW
PT+YhpYH2tOX1TkoKSt1E/ek4YPj0qwBLQ5ad/HrW9xpKFc39typy0GP46zi
YhcaHqeub+cu4+D1b+GVkfY0eGfa1xaacuB4dSjvtjUNMmWRMSP7OHhmIZRU
s5IG4aD4nbYHOfDZT6bLCWgYWvdQvuQQB5q9L9btNqbhU03mhevuHFi5EfPF
ltGQ8PG9u6YfBzFSXRr3tWgwaJPA/ggOdIvSzFl0GjSTZo9X3OUg3urqdNUC
GlhOCunaMRxM2340DFCg4b8etupUIgfen5O2jc+h4e2wsezt5xwc8twubjST
Bvv/jn6vqeFgldLnXZOjBGhKFQ0T7ziIvFMroztCoEZfsVb1Awfrixy8XIcJ
6LmU5AV+5iBN4Yz1cD8Bsbp5d/U6OAivO3h97W8C2X8cr+//zcGjtOM/HnUS
cBPLDwrp4WCBoeaveR0EPi6z9+4a4mB06xnRsV8EEu9lbI0WJlEX9fmpyDcC
O7IlN1SKkkj8KhkV9oWAdL3tqlFxErWVXwzVmwl4iYsv3ixDQjXFLdzxE4FV
bttlxegkRvwMXy6sJ/Br+egbVz4JEa+LSflvCERsNS+6s5SEhc9AzcMKKk+6
38sqMyAxoCGUHFlOID3OLElZQALhYt6hpQTOzrx97sMG6vv8C04XFBHQZ3f7
zrAkIdRpuvpTIYE/hgKvRVYk9k4dzh19RcDKo9MuyJpaj9bzErMCApyGZTBy
oN4n9sdKzVwCjX3BS52cSNx2PZ/glUPgimSLVrgriczWmpeF2QSGjC4p9nuS
GG1aN+mSRSBp+9e5zOMkFHecUq98SWDXYV3p9T7U/NNbZRZRLk5oGk8IIBHx
qadHPJOAd77WwLszJOgSaX98MwhoNAZ2Tp0nMdyiED3ygkCYlHrjjmASaVHV
9Kl0Amakf+25EBLX/ZgdQZQnjetKn90gUTlT/hCd8v4jJ19I3yGxmtceaPGc
2m/dry/UokiYFhu1Dj4jIDmADNN7JPqsvYqiKH9Ji8/YH09ixe9LtA2Unx4W
ywy4T8Lw6OluYcpndBwzo5JJfB3dvjw3jcC2/srM7Eck1I7JiPpSVkvTetmQ
SoLRnbBGQHnSI/Tl0DMSL3fTxaQp12oPvZyTQWKy7LBJ81MCcX3bsrSySHSo
Jw2mUT72NCtrfS4J36B8lWDKaz0Y2YcKqPnf06tcKTO0/bPPFZGI0rncv4Vy
X++P7LgSEuq+glATyq9TV+UUlFP7+aohRZvyLfcHOc2VJIynNgh4lB0XSeaO
1ZAoXpJgyaZs2OuSq/Ceih/7pmYOZdnU2tzFH0hUhPa1qFP+6aabt6mRhFlG
2359yhlaN/NcP5Nwr8/ds47ypZ6RvEtfSZj8OfJxH+XdT6zzH/wgkfFPovwU
ZW23vPziXyQ+SvjzYymLaLEKfrSTiJn1gV5B+WN3YMFUF4nZ0lKn/lJOftxa
QO+h4k9U2UaN+r98Xc1e6feT6BpWeL6PsoVmyqutQyS2/PhzLoaySveswiMj
JA6WxtW1UK5wqSt89I9EoN+Tbyeo/YrU0CuqEOLiioVodDVljz8RRW0iXIBu
0MCl4kHBxfY1S5KL6JjV2Z2UO9ULXxvNovqMHfQDW6j4yf3NLraWpcYl310s
omzn3FkcpkDN39W8Io2KxyXq5iVpBBfBEzqN2lS8Svx+UlLD4CIwzKHjBeVU
J69SCTYX9s+PnHhLxfek43SZ7yIuZBMlbNdQ56VWza78ti4X9+bYvhmgHNdZ
XJ6xhIuG4zfS4qnztdbxUkXfcur3dKL75uVR+3loXuUBMy6Gti/WMaTOq6Oq
d+Xp9VyUhl70kqfOs2FHU2X0RurzJXm6fZRbHO5VNVpxoUGUK2W/JrDIQb3G
fB8XXV67cq+VEfjqqOT++AAXy36fl0+m8scVF3lZmUNcNPXlfSmn8kvn4QnL
Wjcu5B5aVtKrCMT7Vn6w9OXCtn621Ox3BDb7Fxx75s+FSUn0uM17AkKBz+fL
n+Hi8GqD3al1VDxcuLuzPoiLmsFbJx0/Eph/3fnLtnAu9km0M/6f/0rD9pzK
vMNFnWdTQgqVH73CtygtiOYiwq0pRpfKn+8il+/7lMDFAjmh3i0tBC4/kGq1
ecbFgGxL/08q/07npvzZW02tr0fo0jIqvz8piAkufMtF8sa8FcpjVL4puqGl
Us9FqPF5t9kTBLLKTnr8bOJiR5WR0vQUAc/364cOdnBRGLOyVV2chvb23xNO
IjxMkw9Fcqj6c6vrW2SlGA9ZJxd1z6Tq06ruOiMNSR5K9hau3aNIQ+xAjn+3
LA91jZK7FFVosPl3WcSDyUNlAL+1TZ2GWjkNqaPLeOA+bQlKBVXvXV077xry
cE3OSm4pVT+flD0pKzLhIco/Qr94NQ1XfXXOypry8PDEHdvedVQ9b9P7l7KZ
B//uQNmgrTS8yRL0tjjzwKlvlXrjTKPWsb1uUzQPG6IG9wZG0sDPiUg7HsuD
jVVpfF4MVW/nNV2LTuBhtoLL2ak4Gs6+2WX+5yEP9lnaSqHJNKzg25VcyOTh
nX909lgGDa/EXTPz3/IQKyUd1PiehpwngXc1RFShpLTobJUMHWLmW2nhYqqQ
8+WpycrTYdnJuy0sqQrJiTkO1vPpaGdX3/ooqwqxPXmPZ7DokL89/3oAU5Xq
s1zt43TocD7z6GL9MlW4f+efY26jg77j41FfD1Wsub/Le2YCHfbDSUNtnqqo
Wnl7OSuZjrTrJz0tj6vCSqQ83OgJHWuqWYe5p1Th2TFBu/KSDs8Vzi5vL6ui
fV2euXc1HZUaQvs5D1SR7HF/d/AoHSeFF26q+qKKGyZySx5uYaBtlVQjl7pX
mGzedsB7JwObLv7Zc/qXKrLnH+k138MAZ3aqu95vVbBytImZzgxUMfjX7o2q
4sn+N9nVgQww9Y1rvOTV0LjcXe/ic6ofddtsrrhWDTsl/GcXEYqQbPYxc0tX
g5hcptlaqh/XO54861qmGhQknjdrUf36PrnG96nZatDy/DxKiDPx0mzJ7v5X
avBNSqsQmkf19y96D3tVqyHwmme1rA4ThVcP3PVpU4OJxYbdBk5MeAs29pxf
sBBnb+6Ifv6didb7ymExvguhY1STaPxVCWGqhGjWVnVYBW+zJVSVEXLHvmwf
SwO5F08oGpxUgXXY7hrpdg1kKw6kPBtkY3RV4lhMvibeE5OMM3kkfrau8C66
oAWLOvGS3ls8xBnp0Kv3LUKc6IKA6Ddq+FiUffG5gjaOBFrds5XQwOuHaYmn
fbSx6LX0YwsHLdB63ta/btOGJefYjPSb2ghXu/u4er0O+CeqjvqN6ODUq+CI
9VnUs7uj1ipkMczpWxPfcHTRHFzn5bN8CeBWZjMnSBdOmr7m/d/1EM2w41QN
6wKu/qPir/XBfv3g1kabxeiYbrN/FGmAa5pFC9/nL8avg44mC84Y4uCg6LuK
hXxUebbevZ5ijH1pA6yga3xYJZmHqO0HnAK3TK4L5ePfK/eGYQfAa0t6g/QN
PqKXSE0VuQDnh49eDblF3Wt1Uzr3HAMeLRubCI/iw8P3mkECdb8eLZz+eD+F
j8oNnUXbngIh76WDi8v40On44bp/CrgT73rofAUfPv6yCetFBIj3qllpVslH
xpHMLL6EABkKIeOVNXzMdnU7M1NOgGZr+UN1H/gwTAsIySMF4P0kVrb85CPg
uF6oxQYBtNN9mAmtfMyr6cpfvVkAg3Ofxw628xEfML/KcLsA5ryop51dfNwa
+3RWc58AR5xZzP5+PqYMRDyIowL4Gp4eezbIh/Fhn9sKPgKcm9VS7zVMvY+I
U9xcfwEiUuMvj47y8WL5s83yQQLEBYg6ZI/zUf5Dclz+qgAplgdX+E7yUfPz
c8C8GwKkq5QqGk9R4wKyfX6EAPmD3LHpaT5yJto06FEC/A/UdG46
        "]]},
      Annotation[#, "Charting`Private`Tag$1461944#1"]& ]}, {}}, {{}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
      0.012833333333333334`], AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJxTTMoPSmViYGAQBWIQDQEf7B0bp5nLnnVwgAo4XFvmFZB10gbK53DoPq/d
+DLIAsoXcNjQe0nkoqMJlC/isOuNwBvNhQZQvoRDT9vKRU3ftaB8GYefpk9N
O7arQvkKDgy6ihbxUxShfCWHxfG/Kt5YyEL5Kg4CgT84J26WhPLVHLZtd6hi
WiwB5Ws4RE9b1NPKIQXlazlkuHd+e34Xpl/H4ZXvFp5j3EpQvp5DXO3qzULB
alC+gYOk4l3/I7u1oXxDh9ySfxenyBpC+UYOlx+Z39d8BPOfscNMiegvy5Qt
oXwTh/Tvszndb9hC+aYODXP211pUOToAALoBVC0=
       "]]}, {
      {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
       0.012833333333333334`], AbsoluteThickness[1.6]}, {}}, {
      {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
       0.012833333333333334`], AbsoluteThickness[1.6]}, {}}}, {{}, {}}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{Automatic, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{All, {0, 38.45033387223839}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.854105376254239*^9, 3.867412067991088*^9, 3.8674128375558405`*^9, 
  3.867413672738705*^9},
 CellLabel->
  "During evaluation of \
In[70]:=",ExpressionUUID->"8900c5bc-de5b-46db-86a9-f27a20c6608f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Interpolated frequency shift with best match is \"\>", 
   "\[InvisibleSpace]", "1.949112451185596`", 
   "\[InvisibleSpace]", "\<\" Hz\"\>"}],
  SequenceForm[
  "Interpolated frequency shift with best match is ", 1.949112451185596, 
   " Hz"],
  Editable->False]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.854105376254239*^9, 3.867412067991088*^9, 3.8674128375558405`*^9, 
  3.867413672753668*^9},
 CellLabel->
  "During evaluation of \
In[70]:=",ExpressionUUID->"0f5e4345-5f93-4edc-ba71-78b16cb7551a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   StyleBox["\<\"Chemical shift = \"\>", "Subsection",
    StripOnInput->False], "\[InvisibleSpace]", 
   StyleBox["2.01032`", "Subsection",
    StripOnInput->False], "\[InvisibleSpace]", 
   StyleBox["\<\" ppm\"\>", "Subsection",
    StripOnInput->False]}],
  SequenceForm[
   Style["Chemical shift = ", "Subsection"], 
   Style[2.01032, "Subsection"], 
   Style[" ppm", "Subsection"]],
  Editable->False]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.854105376254239*^9, 3.867412067991088*^9, 3.8674128375558405`*^9, 
  3.867413673370116*^9},
 CellLabel->
  "During evaluation of \
In[70]:=",ExpressionUUID->"c99c5c1c-8f5b-44d5-987a-8f85d9d33906"],

Cell[BoxData["\<\"Variance and optimised shift and ratio:\"\>"], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.854105376254239*^9, 3.867412067991088*^9, 3.8674128375558405`*^9, 
  3.867413718035689*^9},
 CellLabel->
  "During evaluation of \
In[70]:=",ExpressionUUID->"88687ee4-19e7-4e56-ab82-9f3e204097a8"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"3.3763658106903804`", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"fdiff", "\[Rule]", "275"}], ",", 
     RowBox[{"fratio", "\[Rule]", "0.914288683254361`"}]}], "}"}]}], 
  "}"}]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.854105376254239*^9, 3.867412067991088*^9, 3.8674128375558405`*^9, 
  3.867413718040675*^9},
 CellLabel->
  "During evaluation of \
In[70]:=",ExpressionUUID->"e106273e-e01e-489d-b858-204333adedc6"],

Cell[BoxData[
 StyleBox["\<\"Input data\"\>", "Subsection",
  StripOnInput->False]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.854105376254239*^9, 3.867412067991088*^9, 3.8674128375558405`*^9, 
  3.867413718043667*^9},
 CellLabel->
  "During evaluation of \
In[70]:=",ExpressionUUID->"c271dc35-b465-4b79-aa93-ea49967b0370"],

Cell[BoxData[
 GraphicsBox[{{}, {{{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJw9nHlcTF/cx8cehRDKOpKKLFlLtg9CFEa2UjK2SlqmfdqnmmqmdZYoFUZC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       "]]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJw9nHlcTF/cx8cekqyFMBFCpWyF8NEmCZWkVJrSrjLte03TNu3TTAj9MlIJ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       "]]}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6]}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6]}, {}, {}, {}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6]}, {}, {}, {}}}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 1311.}, {-0.014777229452738338`, 0.46217238273375005`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.854105376254239*^9, 3.867412067991088*^9, 3.8674128375558405`*^9, 
  3.867413718115475*^9},
 CellLabel->
  "During evaluation of \
In[70]:=",ExpressionUUID->"ceea7094-2d9c-4dbb-9727-e0c9d0f86eed"],

Cell[BoxData[
 StyleBox["\<\"RMS difference vs displacement in data points\"\>", 
  "Subsection",
  StripOnInput->False]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.854105376254239*^9, 3.867412067991088*^9, 3.8674128375558405`*^9, 
  3.8674137195257053`*^9},
 CellLabel->
  "During evaluation of \
In[70]:=",ExpressionUUID->"af8ca347-ad4b-497f-b3dd-badd32ad60d2"],

Cell[BoxData[
 GraphicsBox[{{}, {{{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJxE3HlcTN//B/DKFkIIISRJCKGSRC+EkCRFJUkqpaJ9X6Z9r2mamaYphBBC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       "]]}}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.003666666666666667], 
     AbsoluteThickness[1.6]}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6]}, {}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 2623.}, {0, 66.16529432908312}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.854105376254239*^9, 3.867412067991088*^9, 3.8674128375558405`*^9, 
  3.8674137196663857`*^9},
 CellLabel->
  "During evaluation of \
In[70]:=",ExpressionUUID->"b9339332-1feb-4167-9ed8-3511bb7c5455"],

Cell[BoxData[
 StyleBox["\<\"Expansion of RMS difference vs displacement in data points, \
with parabolic fit\"\>", "Subsection",
  StripOnInput->False]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.854105376254239*^9, 3.867412067991088*^9, 3.8674128375558405`*^9, 
  3.8674137196812897`*^9},
 CellLabel->
  "During evaluation of \
In[70]:=",ExpressionUUID->"578151bf-9aa5-438c-bbef-8e3ab1e00927"],

Cell[BoxData[
 GraphicsBox[{{{{}, {}, 
     TagBox[
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJwV13k8VN0fB3BKkTtqsk6bMHPHWBNDSHzIE5UWHlqkhYoQlShFkkKpJClK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        "]]},
      Annotation[#, "Charting`Private`Tag$1532957#1"]& ]}, {}}, {{}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
      0.012833333333333334`], AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJxTTMoPSmViYGAQBWIQDQEf7JWDHL1ecUk4QAUcDOxslvM4i0H5HA4zjYU5
+aaLQPkCDv+sFQ5P4BGG8kUcHq4+9r9phSCUL+GwL6qrvjdfAMqXcZj2S2jN
hzN8UL6Cw7NV6u7TVHihfCWHeWf6zgt+4IbyVRx+NXe+VrWA8dUcAn8zipxh
gvE1HHhzzq78HAjjazkcM+kU5VfmgfJ1HL45//i0JR9mvp6DyJnab+r6/FC+
gcMH/i5u0TUw9xk6SP7YVK37EeZ+I4fr9klxfskw/xk7VHyPkjb9D/O/iYP/
QuOpFgdh4WPqYJn2fkvzEgkHALh4TiI=
       "]]}, {
      {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
       0.012833333333333334`], AbsoluteThickness[1.6]}, {}}, {
      {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
       0.012833333333333334`], AbsoluteThickness[1.6]}, {}}}, {{}, {}}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{Automatic, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{All, {0, 6.776724538634254}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.854105376254239*^9, 3.867412067991088*^9, 3.8674128375558405`*^9, 
  3.8674137197690573`*^9},
 CellLabel->
  "During evaluation of \
In[70]:=",ExpressionUUID->"3ddec383-6ecd-4cdd-b835-09ff06dcf62f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Interpolated frequency shift with best match is \"\>", 
   "\[InvisibleSpace]", "10.495134243226339`", 
   "\[InvisibleSpace]", "\<\" Hz\"\>"}],
  SequenceForm[
  "Interpolated frequency shift with best match is ", 10.495134243226339`, 
   " Hz"],
  Editable->False]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.854105376254239*^9, 3.867412067991088*^9, 3.8674128375558405`*^9, 
  3.8674137197820215`*^9},
 CellLabel->
  "During evaluation of \
In[70]:=",ExpressionUUID->"eb669b24-5bff-49f5-97a1-0d805ece4ff5"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   StyleBox["\<\"Chemical shift = \"\>", "Subsection",
    StripOnInput->False], "\[InvisibleSpace]", 
   StyleBox["1.465`", "Subsection",
    StripOnInput->False], "\[InvisibleSpace]", 
   StyleBox["\<\" ppm\"\>", "Subsection",
    StripOnInput->False]}],
  SequenceForm[
   Style["Chemical shift = ", "Subsection"], 
   Style[1.465, "Subsection"], 
   Style[" ppm", "Subsection"]],
  Editable->False]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.854105376254239*^9, 3.867412067991088*^9, 3.8674128375558405`*^9, 
  3.8674137202716827`*^9},
 CellLabel->
  "During evaluation of \
In[70]:=",ExpressionUUID->"101e45c0-e4bc-4431-9756-0f3a3b4c8ec3"],

Cell[BoxData["\<\"Variance and optimised shift and ratio:\"\>"], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.854105376254239*^9, 3.867412067991088*^9, 3.8674128375558405`*^9, 
  3.8674137662668085`*^9},
 CellLabel->
  "During evaluation of \
In[70]:=",ExpressionUUID->"b78ec418-563f-4d65-9ccb-882b83f006e2"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"2.2675121229574433`", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"fdiff", "\[Rule]", 
      RowBox[{"-", "9"}]}], ",", 
     RowBox[{"fratio", "\[Rule]", "0.8`"}]}], "}"}]}], "}"}]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.854105376254239*^9, 3.867412067991088*^9, 3.8674128375558405`*^9, 
  3.8674137662767825`*^9},
 CellLabel->
  "During evaluation of \
In[70]:=",ExpressionUUID->"9d416a0a-abbf-4853-aeb4-ecb4df8f93ae"],

Cell[BoxData[
 StyleBox["\<\"Input data\"\>", "Subsection",
  StripOnInput->False]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.854105376254239*^9, 3.867412067991088*^9, 3.8674128375558405`*^9, 
  3.8674137662827663`*^9},
 CellLabel->
  "During evaluation of \
In[70]:=",ExpressionUUID->"22417b5a-87ab-43eb-9b38-dab0dcf4a076"],

Cell[BoxData[
 GraphicsBox[{{}, {{{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJw1nHlcTN8bx0NpkQyKZMuSQgghhI8kbSoJqSQppc207zXVtG+zlfiGrIUo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       "]]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJw9nHlczc/3x69s2ZK1kGQPRaWoRK+USpJUtKpbitJ22/e6bbfbfpcQSmVJ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       "]]}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6]}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6]}, {}, {}, {}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6]}, 
     {RGBColor[0.880722, 0.611041, 0.142051], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6]}, {}, {}, {}}}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 1311.}, {-0.009205275781250001, 0.32952960234375}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.854105376254239*^9, 3.867412067991088*^9, 3.8674128375558405`*^9, 
  3.867413766356569*^9},
 CellLabel->
  "During evaluation of \
In[70]:=",ExpressionUUID->"dff94a16-34b3-4aef-bf77-3def58f3e20c"],

Cell[BoxData[
 StyleBox["\<\"RMS difference vs displacement in data points\"\>", 
  "Subsection",
  StripOnInput->False]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.854105376254239*^9, 3.867412067991088*^9, 3.8674128375558405`*^9, 
  3.867413767804696*^9},
 CellLabel->
  "During evaluation of \
In[70]:=",ExpressionUUID->"3df544d3-b931-4810-9cbf-a9983ce34026"],

Cell[BoxData[
 GraphicsBox[{{}, {{{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJxE23tcTF0XB/AQQiWEJIqSIoSQkB+iEJJuklRSUah0v073e81MU00XlFsh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       "]]}}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.003666666666666667], 
     AbsoluteThickness[1.6]}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6]}, {}}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.003666666666666667],
       AbsoluteThickness[1.6]}, {}}}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 2623.}, {0, 30.964085759224908`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.854105376254239*^9, 3.867412067991088*^9, 3.8674128375558405`*^9, 
  3.8674137679114122`*^9},
 CellLabel->
  "During evaluation of \
In[70]:=",ExpressionUUID->"d27ac4bc-21f0-49d9-a70d-af25651b9231"],

Cell[BoxData[
 StyleBox["\<\"Expansion of RMS difference vs displacement in data points, \
with parabolic fit\"\>", "Subsection",
  StripOnInput->False]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.854105376254239*^9, 3.867412067991088*^9, 3.8674128375558405`*^9, 
  3.867413767917395*^9},
 CellLabel->
  "During evaluation of \
In[70]:=",ExpressionUUID->"93951b7c-d200-4852-b9e2-5203952c388a"],

Cell[BoxData[
 GraphicsBox[{{{{}, {}, 
     TagBox[
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJwV13lYTesXB/DaJ43nlxQipHPO3qdENJybMtRXUlRSaBBCSpQmJY3E1Ygk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        "]]},
      Annotation[#, "Charting`Private`Tag$1604285#1"]& ]}, {}}, {{}, {
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
      0.012833333333333334`], AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJxTTMoPSmViYGAQBWIQDQEf7B8sFFx31ZTLASrgsDxsg3D6GQ4on8Phu8iz
Jp0GdihfwEGySzbbNpQNyhdxSFJfM8XJlxXKl3C4+jzAVCeDBcqXcaiTXjBp
2VJmKF/BYULvz//9bDC+ksO7gxxfLvQyQfkqDlfKL971cIDx1RxYxKJT7yrD
+BoOStZqaix2ML6WQ17996TASTC+jsOpPJ+o2Yow8/Uctht9yGd5BeMbOHjc
nf7i0nOY+wwdWnRUfiwQg/nHyMFD0zMzrAjmX2OHU8rZ1zu+w8LDxKH0iVq8
/mJYeJk6cGz40/a0kMcBAPpkTWs=
       "]]}, {
      {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
       0.012833333333333334`], AbsoluteThickness[1.6]}, {}}, {
      {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
       0.012833333333333334`], AbsoluteThickness[1.6]}, {}}}, {{}, {}}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{Automatic, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{All, {0, 3.9111749268007814`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.854105376254239*^9, 3.867412067991088*^9, 3.8674128375558405`*^9, 
  3.867413768006538*^9},
 CellLabel->
  "During evaluation of \
In[70]:=",ExpressionUUID->"45032d1c-1dde-4dd0-9dd8-a82bfc447b70"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Interpolated frequency shift with best match is \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"-", "0.32530559321358293`"}], "\[InvisibleSpace]", "\<\" Hz\"\>"}],
  SequenceForm[
  "Interpolated frequency shift with best match is ", -0.32530559321358293`, 
   " Hz"],
  Editable->False]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.854105376254239*^9, 3.867412067991088*^9, 3.8674128375558405`*^9, 
  3.867413768017445*^9},
 CellLabel->
  "During evaluation of \
In[70]:=",ExpressionUUID->"d481e938-944c-47f2-9847-98ab30a9b061"],

Cell[BoxData[
 StyleBox["\<\"Coupling constants\"\>", "Subsection",
  StripOnInput->False]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.854105376254239*^9, 3.867412067991088*^9, 3.8674128375558405`*^9, 
  3.8674137680204363`*^9},
 CellLabel->
  "During evaluation of \
In[70]:=",ExpressionUUID->"2d48ece8-093f-40da-aa37-a76b95b2aeba"]
}, Open  ]],

Cell[BoxData[
 TagBox[GridBox[{
    {"14.674723990859691`"},
    {"48.52315312265558`"},
    {
     RowBox[{"-", "0.022838772801344435`"}]},
    {"1.949112451185596`"},
    {"10.495134243226339`"},
    {
     RowBox[{"-", "0.32530559321358293`"}]}
   },
   GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[2.0999999999999996`]}, 
       Offset[0.27999999999999997`]}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.8535790442807336`*^9, 3.8535794424007387`*^9, 
  3.8541055633410826`*^9, 3.8674122660853357`*^9, 3.8674130399647613`*^9, 
  3.867413768023431*^9},
 CellLabel->
  "Out[87]//TableForm=",ExpressionUUID->"981740ab-8c73-4972-93d8-\
be9a70c4ee70"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Time used = \"\>", "\[InvisibleSpace]", 
   "248.3543809`9.846616818724797", "\[InvisibleSpace]", "\<\"seconds\"\>"}],
  SequenceForm["Time used = ", 248.3543809`9.846616818724797, "seconds"],
  Editable->False]], "Print",
 CellChangeTimes->{3.853578749640018*^9, 3.853579153998145*^9, 
  3.854105376254239*^9, 3.867412067991088*^9, 3.8674128375558405`*^9, 
  3.867413768030412*^9},
 CellLabel->
  "During evaluation of \
In[70]:=",ExpressionUUID->"cf1a74b9-764b-4d58-9cb1-93a194b6c905"]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1920, 997},
WindowMargins->{{Automatic, -1928}, {Automatic, -8}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
FrontEndVersion->"12.0 for Microsoft Windows (64-bit) (April 8, 2019)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 538, 10, 69, "Subsubsection",ExpressionUUID->"e0dd5b4c-3a91-4051-9a25-a39ac98e766a"],
Cell[1121, 34, 1694, 34, 364, "Text",ExpressionUUID->"c61c22a2-f7f7-4bd3-b074-cb3183ff65e0"],
Cell[CellGroupData[{
Cell[2840, 72, 29585, 703, 1872, "Input",ExpressionUUID->"83ce1c8d-1a22-4fa3-84c9-6c6be868c2d5"],
Cell[CellGroupData[{
Cell[32450, 779, 727, 19, 29, "Print",ExpressionUUID->"0b4d12f4-a4ee-42b7-a87d-7eec19ca5fd2"],
Cell[33180, 800, 340, 6, 22, "Print",ExpressionUUID->"8a314209-d967-45d4-a3bb-99969ea8e2e8"],
Cell[33523, 808, 500, 13, 22, "Print",ExpressionUUID->"4e1ba429-d4da-48f7-b838-b7a50a1cb883"],
Cell[34026, 823, 360, 8, 33, "Print",ExpressionUUID->"54c5157e-4818-40d4-a48f-4b1ece8c6508"],
Cell[34389, 833, 17046, 298, 225, "Print",ExpressionUUID->"a7150d36-8109-46ae-badc-364ccbbfcb52"],
Cell[51438, 1133, 396, 9, 33, "Print",ExpressionUUID->"423e0afc-1dd9-4fbc-9858-85cd622456f4"],
Cell[51837, 1144, 15032, 264, 230, "Print",ExpressionUUID->"86d43bbe-342a-4f40-bc71-b2b37e2de900"],
Cell[66872, 1410, 430, 9, 33, "Print",ExpressionUUID->"0eb20ed8-bc67-42cd-9a73-3d73de4e4f67"],
Cell[67305, 1421, 8302, 156, 247, "Print",ExpressionUUID->"34be553a-2e5f-41d4-8854-3c41c9d515e2"],
Cell[75610, 1579, 593, 14, 22, "Print",ExpressionUUID->"df9494ad-aaf2-46da-9e08-2a1756e96547"],
Cell[76206, 1595, 727, 19, 29, "Print",ExpressionUUID->"1c8bdb26-289f-49a6-b8b4-e5023f83a650"],
Cell[76936, 1616, 340, 6, 22, "Print",ExpressionUUID->"acd31d52-cb17-4d62-ae5d-b3189ba61070"],
Cell[77279, 1624, 501, 13, 22, "Print",ExpressionUUID->"1550085c-73a1-4cfc-91b8-7e823dcfd104"],
Cell[77783, 1639, 360, 8, 33, "Print",ExpressionUUID->"263fdca2-1bff-447f-a91a-c24fe8e71909"],
Cell[78146, 1649, 54491, 912, 225, "Print",ExpressionUUID->"3c5c4703-08e1-4595-ace8-33aa5a34ff10"],
Cell[132640, 2563, 398, 9, 33, "Print",ExpressionUUID->"7fa0c99c-82a2-49a2-8afd-47e9df873ec7"],
Cell[133041, 2574, 47063, 789, 230, "Print",ExpressionUUID->"e4f1e2f3-cb95-447c-900a-90cd36241112"],
Cell[180107, 3365, 428, 9, 33, "Print",ExpressionUUID->"1777d3c0-979d-428b-a3c9-9f55a74b2502"],
Cell[180538, 3376, 8319, 157, 247, "Print",ExpressionUUID->"9b03d023-bd21-4db3-8537-e39972ddbf7c"],
Cell[188860, 3535, 590, 14, 22, "Print",ExpressionUUID->"5d1d6e79-f44c-44ee-9823-0b82ed405495"],
Cell[189453, 3551, 729, 19, 29, "Print",ExpressionUUID->"b02781d0-f581-4202-84a2-6966f5acd79b"],
Cell[190185, 3572, 338, 6, 22, "Print",ExpressionUUID->"5b26182b-46e8-4e3e-99c6-0336907b2cca"],
Cell[190526, 3580, 502, 13, 22, "Print",ExpressionUUID->"87955e44-8157-4d61-9377-f8f344f25885"],
Cell[191031, 3595, 360, 8, 33, "Print",ExpressionUUID->"a1ea6495-58e5-43af-85b8-60b956b3f89b"],
Cell[191394, 3605, 24382, 418, 223, "Print",ExpressionUUID->"3ca9541e-3a09-4638-bc22-8d3a244437fc"],
Cell[215779, 4025, 398, 9, 33, "Print",ExpressionUUID->"35037686-b22a-4190-9fa8-5c83c67a9d4c"],
Cell[216180, 4036, 22732, 390, 234, "Print",ExpressionUUID->"d7ad230c-4b42-46f8-b677-267fe54337fb"],
Cell[238915, 4428, 428, 9, 33, "Print",ExpressionUUID->"ee0cc410-9131-424e-a036-0797f724442b"],
Cell[239346, 4439, 8298, 156, 247, "Print",ExpressionUUID->"0c2dc76e-b286-493c-883e-8954bcdaaaf9"],
Cell[247647, 4597, 617, 15, 22, "Print",ExpressionUUID->"0a753a9a-529d-47bb-a111-642195258f4c"],
Cell[248267, 4614, 729, 19, 29, "Print",ExpressionUUID->"e58dada2-ecfa-49fd-b38b-b821e2535446"],
Cell[248999, 4635, 340, 6, 22, "Print",ExpressionUUID->"0f1fafc9-abd0-4507-a25b-a9485e672c68"],
Cell[249342, 4643, 498, 13, 22, "Print",ExpressionUUID->"1e5bd060-960a-49d4-943a-c2e9f3010db6"],
Cell[249843, 4658, 358, 8, 33, "Print",ExpressionUUID->"2bba5e9d-6bdb-4a15-a9f6-07f2e6dfff2c"],
Cell[250204, 4668, 24445, 419, 225, "Print",ExpressionUUID->"94f60c1c-b5de-4d4d-a042-5170d0446f1c"],
Cell[274652, 5089, 398, 9, 33, "Print",ExpressionUUID->"2f32cb14-782d-4cb8-8466-926f9c7e7d73"],
Cell[275053, 5100, 22862, 392, 234, "Print",ExpressionUUID->"0b1347bd-5113-4385-8ad7-8d038a038a9f"],
Cell[297918, 5494, 430, 9, 33, "Print",ExpressionUUID->"2c170236-0402-435a-a53c-241ba02bc6a5"],
Cell[298351, 5505, 8251, 155, 247, "Print",ExpressionUUID->"8900c5bc-de5b-46db-86a9-f27a20c6608f"],
Cell[306605, 5662, 588, 14, 22, "Print",ExpressionUUID->"0f5e4345-5f93-4edc-ba71-78b16cb7551a"],
Cell[307196, 5678, 727, 19, 29, "Print",ExpressionUUID->"c99c5c1c-8f5b-44d5-987a-8f85d9d33906"],
Cell[307926, 5699, 338, 6, 22, "Print",ExpressionUUID->"88687ee4-19e7-4e56-ab82-9f3e204097a8"],
Cell[308267, 5707, 499, 13, 22, "Print",ExpressionUUID->"e106273e-e01e-489d-b858-204333adedc6"],
Cell[308769, 5722, 358, 8, 33, "Print",ExpressionUUID->"c271dc35-b465-4b79-aa93-ea49967b0370"],
Cell[309130, 5732, 38979, 657, 225, "Print",ExpressionUUID->"ceea7094-2d9c-4dbb-9727-e0c9d0f86eed"],
Cell[348112, 6391, 398, 9, 33, "Print",ExpressionUUID->"af8ca347-ad4b-497f-b3dd-badd32ad60d2"],
Cell[348513, 6402, 35733, 603, 238, "Print",ExpressionUUID->"b9339332-1feb-4167-9ed8-3511bb7c5455"],
Cell[384249, 7007, 430, 9, 33, "Print",ExpressionUUID->"578151bf-9aa5-438c-bbef-8e3ab1e00927"],
Cell[384682, 7018, 8168, 154, 247, "Print",ExpressionUUID->"3ddec383-6ecd-4cdd-b835-09ff06dcf62f"],
Cell[392853, 7174, 593, 14, 22, "Print",ExpressionUUID->"eb669b24-5bff-49f5-97a1-0d805ece4ff5"],
Cell[393449, 7190, 725, 19, 29, "Print",ExpressionUUID->"101e45c0-e4bc-4431-9756-0f3a3b4c8ec3"],
Cell[394177, 7211, 340, 6, 22, "Print",ExpressionUUID->"b78ec418-563f-4d65-9ccb-882b83f006e2"],
Cell[394520, 7219, 504, 13, 22, "Print",ExpressionUUID->"9d416a0a-abbf-4853-aeb4-ecb4df8f93ae"],
Cell[395027, 7234, 360, 8, 33, "Print",ExpressionUUID->"22417b5a-87ab-43eb-9b38-dab0dcf4a076"],
Cell[395390, 7244, 39226, 661, 221, "Print",ExpressionUUID->"dff94a16-34b3-4aef-bf77-3def58f3e20c"],
Cell[434619, 7907, 396, 9, 33, "Print",ExpressionUUID->"3df544d3-b931-4810-9cbf-a9983ce34026"],
Cell[435018, 7918, 35886, 606, 238, "Print",ExpressionUUID->"d27ac4bc-21f0-49d9-a70d-af25651b9231"],
Cell[470907, 8526, 428, 9, 33, "Print",ExpressionUUID->"93951b7c-d200-4852-b9e2-5203952c388a"],
Cell[471338, 8537, 8062, 152, 247, "Print",ExpressionUUID->"45032d1c-1dde-4dd0-9dd8-a82bfc447b70"],
Cell[479403, 8691, 609, 14, 22, "Print",ExpressionUUID->"d481e938-944c-47f2-9847-98ab30a9b061"],
Cell[480015, 8707, 368, 8, 33, "Print",ExpressionUUID->"2d48ece8-093f-40da-aa37-a76b95b2aeba"]
}, Open  ]],
Cell[480398, 8718, 881, 26, 130, "Output",ExpressionUUID->"981740ab-8c73-4972-93d8-be9a70c4ee70"],
Cell[481282, 8746, 536, 11, 22, "Print",ExpressionUUID->"cf1a74b9-764b-4d58-9cb1-93a194b6c905"]
}, Open  ]]
}, Open  ]]
}
]
*)

